@@ -1,9 +1,12 @@
+from __future__ import annotations
+
 """This module contains shared TypeAliases"""
 
 import pathlib
-from typing import Dict, List, Union
+from typing import TYPE_CHECKING, Dict, List, Union
 
-from typing_extensions import TypeAlias
+if TYPE_CHECKING:
+    from typing_extensions import TypeAlias
 
 PathStr: TypeAlias = Union[str, pathlib.Path]
 JSONValues: TypeAlias = Union[
