@@ -1,51 +1,47 @@
 from __future__ import annotations
 
-import datetime
 import json
 import logging
 from copy import deepcopy
-from typing import TYPE_CHECKING, List, Optional
-from uuid import UUID
+from typing import TYPE_CHECKING, List, Optional, Union
 
 from marshmallow import Schema, fields, post_dump, post_load, pre_dump
 from typing_extensions import TypedDict
 
 import great_expectations.exceptions as gx_exceptions
-from great_expectations import __version__ as ge_version
-from great_expectations.alias_types import JSONValues  # noqa: TCH001
-from great_expectations.core._docs_decorators import public_api
-from great_expectations.core.batch import BatchDefinition, BatchMarkers  # noqa: TCH001
-from great_expectations.core.expectation_configuration import (
-    ExpectationConfigurationSchema,
-)
-from great_expectations.core.id_dict import BatchSpec  # noqa: TCH001
-from great_expectations.core.run_identifier import RunIdentifier  # noqa: TCH001
-from great_expectations.core.util import (
-    convert_to_json_serializable,
-    ensure_json_serializable,
-    in_jupyter_notebook,
+from great_expectations._docs_decorators import public_api
+from great_expectations.alias_types import JSONValues  # noqa: TC001 # FIXME CoP
+from great_expectations.compatibility.typing_extensions import override
+from great_expectations.core.batch import (  # noqa: TC001 # FIXME CoP
+    BatchMarkers,
+    LegacyBatchDefinition,
 )
+from great_expectations.core.id_dict import BatchSpec  # noqa: TC001 # FIXME CoP
+from great_expectations.core.run_identifier import RunIdentifier  # noqa: TC001 # FIXME CoP
 from great_expectations.data_context.util import instantiate_class_from_config
 from great_expectations.exceptions import ClassInstantiationError
 from great_expectations.render import (
-    AtomicDiagnosticRendererType,
-    AtomicPrescriptiveRendererType,
     AtomicRendererType,
     RenderedAtomicContent,
     RenderedAtomicContentSchema,
 )
 from great_expectations.types import SerializableDictDot
+from great_expectations.util import (
+    convert_to_json_serializable,  # noqa: TID251 # FIXME CoP
+    ensure_json_serializable,  # noqa: TID251 # FIXME CoP
+)
 
 if TYPE_CHECKING:
-    from great_expectations.core.expectation_configuration import (
+    from great_expectations.expectations.expectation_configuration import (
         ExpectationConfiguration,
     )
+    from great_expectations.expectations.metadata_types import FailureSeverity
     from great_expectations.render.renderer.inline_renderer import InlineRendererConfig
 
 logger = logging.getLogger(__name__)
 
 
-def get_metric_kwargs_id(metric_name, metric_kwargs):
+def get_metric_kwargs_id(metric_kwargs: dict) -> str | None:
     ###
     #
     # WARNING
@@ -56,10 +52,15 @@ def get_metric_kwargs_id(metric_name, metric_kwargs):
     # WARNING
     #
     ###
+    if metric_kwargs is None:
+        metric_kwargs = {}
+
     if "metric_kwargs_id" in metric_kwargs:
         return metric_kwargs["metric_kwargs_id"]
+
     if "column" in metric_kwargs:
         return f"column={metric_kwargs.get('column')}"
+
     return None
 
 
@@ -82,14 +83,14 @@ class ExpectationValidationResult(SerializableDictDot):
         InvalidCacheValueError: Raised if the result does not pass validation.
     """
 
-    def __init__(
+    def __init__(  # noqa: PLR0913 # FIXME CoP
         self,
         success: Optional[bool] = None,
         expectation_config: Optional[ExpectationConfiguration] = None,
         result: Optional[dict] = None,
         meta: Optional[dict] = None,
         exception_info: Optional[dict] = None,
-        rendered_content: Optional[RenderedAtomicContent] = None,
+        rendered_content: Union[RenderedAtomicContent, List[RenderedAtomicContent], None] = None,
         **kwargs: dict,
     ) -> None:
         if result and not self.validate_result_dict(result):
@@ -113,8 +114,9 @@ class ExpectationValidationResult(SerializableDictDot):
         }
         self.rendered_content = rendered_content
 
+    @override
     def __eq__(self, other):
-        """ExpectationValidationResult equality ignores instance identity, relying only on properties."""
+        """ExpectationValidationResult equality ignores instance identity, relying only on properties."""  # noqa: E501 # FIXME CoP
         # NOTE: JPC - 20200213 - need to spend some time thinking about whether we want to
         # consistently allow dict as a comparison alternative in situations like these...
         # if isinstance(other, dict):
@@ -124,33 +126,28 @@ class ExpectationValidationResult(SerializableDictDot):
         #         return NotImplemented
         if not isinstance(other, self.__class__):
             # Delegate comparison to the other instance's __eq__.
-            return NotImplemented
+            return other == self
         try:
             if self.result and other.result:
                 common_keys = set(self.result.keys()) & other.result.keys()
                 result_dict = self.to_json_dict()["result"]
                 other_result_dict = other.to_json_dict()["result"]
-                contents_equal = all(
-                    [result_dict[k] == other_result_dict[k] for k in common_keys]
-                )
+                contents_equal = all(result_dict[k] == other_result_dict[k] for k in common_keys)
             else:
                 contents_equal = False
 
             return all(
                 (
                     self.success == other.success,
-                    (
-                        self.expectation_config is None
-                        and other.expectation_config is None
-                    )
+                    (self.expectation_config is None and other.expectation_config is None)
                     or (
                         self.expectation_config is not None
                         and self.expectation_config.isEquivalentTo(
                             other=other.expectation_config, match_type="success"
                         )
                     ),
-                    # Result is a dictionary allowed to have nested dictionaries that are still of complex types (e.g.
-                    # numpy) consequently, series' comparison can persist. Wrapping in all() ensures comparison is
+                    # Result is a dictionary allowed to have nested dictionaries that are still of complex types (e.g.  # noqa: E501 # FIXME CoP
+                    # numpy) consequently, series' comparison can persist. Wrapping in all() ensures comparison is  # noqa: E501 # FIXME CoP
                     # handled appropriately.
                     not (self.result or other.result) or contents_equal,
                     self.meta == other.meta,
@@ -161,8 +158,34 @@ class ExpectationValidationResult(SerializableDictDot):
             # if invalid comparisons are attempted, the objects are not equal.
             return False
 
-    def __ne__(self, other):
-        # Negated implementation of '__eq__'. TODO the method should be deleted when it will coincide with __eq__.
+    @override
+    def __hash__(self) -> int:
+        """Overrides the default implementation"""
+        # note that it is possible for two results to be equal but have different hashes
+        # this is because during comparison we only compare common keys
+        if self.result:
+            result_hash = hash(tuple(sorted(self.result.items())))
+        else:
+            result_hash = hash(None)
+
+        # Handle expectation_config hash
+        if self.expectation_config:
+            config_hash = hash(self.expectation_config)
+        else:
+            config_hash = hash(None)
+
+        return hash(
+            (
+                self.success,
+                config_hash,
+                result_hash,
+                tuple(sorted(self.meta.items())) if self.meta else (),
+                tuple(sorted(self.exception_info.items())) if self.exception_info else (),
+            )
+        )
+
+    def __ne__(self, other):  # type: ignore[explicit-override] # FIXME
+        # Negated implementation of '__eq__'. TODO the method should be deleted when it will coincide with __eq__.  # noqa: E501 # FIXME CoP
         # return not self == other
         if not isinstance(other, self.__class__):
             # Delegate comparison to the other instance's __ne__.
@@ -171,17 +194,12 @@ class ExpectationValidationResult(SerializableDictDot):
             return any(
                 (
                     self.success != other.success,
-                    (
-                        self.expectation_config is None
-                        and other.expectation_config is not None
-                    )
+                    (self.expectation_config is None and other.expectation_config is not None)
                     or (
                         self.expectation_config is not None
-                        and not self.expectation_config.isEquivalentTo(
-                            other.expectation_config
-                        )
+                        and not self.expectation_config.isEquivalentTo(other.expectation_config)
                     ),
-                    # TODO should it be wrapped in all()/any()? Since it is the only difference to __eq__:
+                    # TODO should it be wrapped in all()/any()? Since it is the only difference to __eq__:  # noqa: E501 # FIXME CoP
                     (self.result is None and other.result is not None)
                     or (self.result != other.result),
                     self.meta != other.meta,
@@ -192,39 +210,23 @@ class ExpectationValidationResult(SerializableDictDot):
             # if invalid comparisons are attempted, the objects are not equal.
             return True
 
+    @override
     def __repr__(self) -> str:
         """
         # TODO: <Alex>5/9/2022</Alex>
         This implementation is non-ideal (it was agreed to employ it for development expediency).  A better approach
         would consist of "__str__()" calling "__repr__()", while all output options are handled through state variables.
-        """
+        """  # noqa: E501 # FIXME CoP
         json_dict: dict = self.to_json_dict()
-        if in_jupyter_notebook():
-            if (
-                "expectation_config" in json_dict
-                and "kwargs" in json_dict["expectation_config"]
-                and "auto" in json_dict["expectation_config"]["kwargs"]
-                and json_dict["expectation_config"]["kwargs"]["auto"]
-            ):
-                json_dict["expectation_config"]["meta"] = {
-                    "auto_generated_at": datetime.datetime.now(
-                        datetime.timezone.utc
-                    ).strftime("%Y%m%dT%H%M%S.%fZ"),
-                    "great_expectations_version": ge_version,
-                }
-                json_dict["expectation_config"]["kwargs"].pop("auto")
-                json_dict["expectation_config"]["kwargs"].pop("batch_id", None)
-            else:
-                json_dict.pop("expectation_config", None)
-
         return json.dumps(json_dict, indent=2)
 
+    @override
     def __str__(self) -> str:
         """
         # TODO: <Alex>5/9/2022</Alex>
         This implementation is non-ideal (it was agreed to employ it for development expediency).  A better approach
         would consist of "__str__()" calling "__repr__()", while all output options are handled through state variables.
-        """
+        """  # noqa: E501 # FIXME CoP
         return json.dumps(self.to_json_dict(), indent=2)
 
     def render(self) -> None:
@@ -251,58 +253,42 @@ class ExpectationValidationResult(SerializableDictDot):
                 class_name=inline_renderer_config["class_name"],
             )
 
-        rendered_content: List[
-            RenderedAtomicContent
-        ] = inline_renderer.get_rendered_content()
+        rendered_content: List[RenderedAtomicContent] = inline_renderer.get_rendered_content()
 
-        diagnostic_rendered_content: List[RenderedAtomicContent] = [
+        self.rendered_content = [
             content_block
             for content_block in rendered_content
             if content_block.name.startswith(AtomicRendererType.DIAGNOSTIC)
         ]
 
-        self.rendered_content = (
-            inline_renderer.replace_or_keep_existing_rendered_content(
-                existing_rendered_content=self.rendered_content,
-                new_rendered_content=diagnostic_rendered_content,
-                failed_renderer_type=AtomicDiagnosticRendererType.FAILED,
-            )
-        )
-
-        prescriptive_rendered_content: List[RenderedAtomicContent] = [
-            content_block
-            for content_block in rendered_content
-            if content_block.name.startswith(AtomicRendererType.PRESCRIPTIVE)
-        ]
-
-        self.expectation_config.rendered_content = inline_renderer.replace_or_keep_existing_rendered_content(  # type: ignore[union-attr] # config could be None
-            existing_rendered_content=self.expectation_config.rendered_content,  # type: ignore[union-attr] # config could be None
-            new_rendered_content=prescriptive_rendered_content,
-            failed_renderer_type=AtomicPrescriptiveRendererType.FAILED,
-        )
+        if self.expectation_config:
+            self.expectation_config.rendered_content = [
+                content_block
+                for content_block in rendered_content
+                if content_block.name.startswith(AtomicRendererType.PRESCRIPTIVE)
+            ]
 
     @staticmethod
     def validate_result_dict(result):
         if result.get("unexpected_count") and result["unexpected_count"] < 0:
             return False
         if result.get("unexpected_percent") and (
-            result["unexpected_percent"] < 0 or result["unexpected_percent"] > 100
+            result["unexpected_percent"] < 0 or result["unexpected_percent"] > 100  # noqa: PLR2004 # FIXME CoP
         ):
             return False
         if result.get("missing_percent") and (
-            result["missing_percent"] < 0 or result["missing_percent"] > 100
+            result["missing_percent"] < 0 or result["missing_percent"] > 100  # noqa: PLR2004 # FIXME CoP
         ):
             return False
         if result.get("unexpected_percent_nonmissing") and (
             result["unexpected_percent_nonmissing"] < 0
-            or result["unexpected_percent_nonmissing"] > 100
+            or result["unexpected_percent_nonmissing"] > 100  # noqa: PLR2004 # FIXME CoP
         ):
             return False
-        if result.get("missing_count") and result["missing_count"] < 0:
-            return False
-        return True
+        return not (result.get("missing_count") and result["missing_count"] < 0)
 
     @public_api
+    @override
     def to_json_dict(self) -> dict[str, JSONValues]:
         """Returns a JSON-serializable dict representation of this ExpectationValidationResult.
 
@@ -310,7 +296,7 @@ class ExpectationValidationResult(SerializableDictDot):
             A JSON-serializable dict representation of this ExpectationValidationResult.
         """
         myself = expectationValidationResultSchema.dump(self)
-        # NOTE - JPC - 20191031: migrate to expectation-specific schemas that subclass result with properly-typed
+        # NOTE - JPC - 20191031: migrate to expectation-specific schemas that subclass result with properly-typed  # noqa: E501 # FIXME CoP
         # schemas to get serialization all-the-way down via dump
         if "expectation_config" in myself:
             myself["expectation_config"] = convert_to_json_serializable(
@@ -321,75 +307,89 @@ class ExpectationValidationResult(SerializableDictDot):
         if "meta" in myself:
             myself["meta"] = convert_to_json_serializable(myself["meta"])
         if "exception_info" in myself:
-            myself["exception_info"] = convert_to_json_serializable(
-                myself["exception_info"]
-            )
+            myself["exception_info"] = convert_to_json_serializable(myself["exception_info"])
         if "rendered_content" in myself:
-            myself["rendered_content"] = convert_to_json_serializable(
-                myself["rendered_content"]
-            )
+            myself["rendered_content"] = convert_to_json_serializable(myself["rendered_content"])
         return myself
 
-    def get_metric(self, metric_name, **kwargs):
+    def get_metric(self, metric_name, **kwargs):  # noqa: C901 #  too complex
         if not self.expectation_config:
-            raise gx_exceptions.UnavailableMetricError(
+            raise gx_exceptions.UnavailableMetricError(  # noqa: TRY003 # FIXME CoP
                 "No ExpectationConfig found in this ExpectationValidationResult. Unable to "
                 "return a metric."
             )
 
         metric_name_parts = metric_name.split(".")
-        metric_kwargs_id = get_metric_kwargs_id(metric_name, kwargs)
+        metric_kwargs_id = get_metric_kwargs_id(metric_kwargs=kwargs)
 
-        if metric_name_parts[0] == self.expectation_config.expectation_type:
-            curr_metric_kwargs = get_metric_kwargs_id(
-                metric_name, self.expectation_config.kwargs
-            )
+        if metric_name_parts[0] == self.expectation_config.type:
+            curr_metric_kwargs = get_metric_kwargs_id(metric_kwargs=self.expectation_config.kwargs)
             if metric_kwargs_id != curr_metric_kwargs:
                 raise gx_exceptions.UnavailableMetricError(
-                    "Requested metric_kwargs_id (%s) does not match the configuration of this "
-                    "ExpectationValidationResult (%s)."
-                    % (metric_kwargs_id or "None", curr_metric_kwargs or "None")
+                    "Requested metric_kwargs_id ({}) does not match the configuration of this "
+                    "ExpectationValidationResult ({}).".format(
+                        metric_kwargs_id or "None", curr_metric_kwargs or "None"
+                    )
                 )
-            if len(metric_name_parts) < 2:
-                raise gx_exceptions.UnavailableMetricError(
+            if len(metric_name_parts) < 2:  # noqa: PLR2004 # FIXME CoP
+                raise gx_exceptions.UnavailableMetricError(  # noqa: TRY003 # FIXME CoP
                     "Expectation-defined metrics must include a requested metric."
                 )
-            elif len(metric_name_parts) == 2:
+            elif len(metric_name_parts) == 2:  # noqa: PLR2004 # FIXME CoP
                 if metric_name_parts[1] == "success":
                     return self.success
                 else:
-                    raise gx_exceptions.UnavailableMetricError(
-                        "Metric name must have more than two parts for keys other than "
-                        "success."
+                    raise gx_exceptions.UnavailableMetricError(  # noqa: TRY003 # FIXME CoP
+                        "Metric name must have more than two parts for keys other than success."
                     )
             elif metric_name_parts[1] == "result":
                 try:
-                    if len(metric_name_parts) == 3:
+                    if len(metric_name_parts) == 3:  # noqa: PLR2004 # FIXME CoP
                         return self.result.get(metric_name_parts[2])
                     elif metric_name_parts[2] == "details":
                         return self.result["details"].get(metric_name_parts[3])
                 except KeyError:
-                    raise gx_exceptions.UnavailableMetricError(
-                        "Unable to get metric {} -- KeyError in "
-                        "ExpectationValidationResult.".format(metric_name)
+                    raise gx_exceptions.UnavailableMetricError(  # noqa: TRY003 # FIXME CoP
+                        f"Unable to get metric {metric_name} -- KeyError in "
+                        "ExpectationValidationResult."
                     )
-        raise gx_exceptions.UnavailableMetricError(
-            f"Unrecognized metric name {metric_name}"
-        )
+        raise gx_exceptions.UnavailableMetricError(f"Unrecognized metric name {metric_name}")  # noqa: TRY003 # FIXME CoP
+
+    def describe_dict(self) -> dict:
+        if self.expectation_config:
+            expectation_type = self.expectation_config.type
+            kwargs = self.expectation_config.kwargs
+        else:
+            expectation_type = None
+            kwargs = None
+        describe_dict = {
+            "expectation_type": expectation_type,
+            "success": self.success,
+            "kwargs": kwargs,
+            "result": self.result,
+        }
+        if self.exception_info.get("raised_exception"):
+            describe_dict["exception_info"] = self.exception_info
+        return convert_to_json_serializable(describe_dict)
+
+    @public_api
+    def describe(self) -> str:
+        """JSON string description of this ExpectationValidationResult"""
+        return json.dumps(self.describe_dict(), indent=4)
 
 
 class ExpectationValidationResultSchema(Schema):
     success = fields.Bool(required=False, allow_none=True)
     expectation_config = fields.Nested(
-        lambda: ExpectationConfigurationSchema, required=False, allow_none=True  # type: ignore[arg-type,return-value]
+        lambda: "ExpectationConfigurationSchema",  # type: ignore[arg-type,return-value] # FIXME CoP
+        required=False,
+        allow_none=True,
     )
     result = fields.Dict(required=False, allow_none=True)
     meta = fields.Dict(required=False, allow_none=True)
     exception_info = fields.Dict(required=False, allow_none=True)
     rendered_content = fields.List(
-        fields.Nested(
-            lambda: RenderedAtomicContentSchema, required=False, allow_none=True  # type: ignore[arg-type,return-value]
-        )
+        fields.Nested(lambda: RenderedAtomicContentSchema, required=False, allow_none=True)
     )
 
     # noinspection PyUnusedLocal
@@ -407,7 +407,11 @@ class ExpectationValidationResultSchema(Schema):
     @post_dump
     def clean_null_attrs(self, data: dict, **kwargs: dict) -> dict:
         """Removes the attributes in ExpectationValidationResultSchema.REMOVE_KEYS_IF_NONE during serialization if
-        their values are None."""
+        their values are None."""  # noqa: E501 # FIXME CoP
+        from great_expectations.expectations.expectation_configuration import (
+            ExpectationConfigurationSchema,
+        )
+
         data = deepcopy(data)
         for key in ExpectationConfigurationSchema.REMOVE_KEYS_IF_NONE:
             if key in data and data[key] is None:
@@ -421,8 +425,9 @@ class ExpectationValidationResultSchema(Schema):
 
 
 class ExpectationSuiteValidationResultMeta(TypedDict):
-    active_batch_definition: BatchDefinition
+    active_batch_definition: LegacyBatchDefinition
     batch_markers: BatchMarkers
+    batch_parameters: dict | None
     batch_spec: BatchSpec
     checkpoint_id: Optional[str]
     checkpoint_name: str
@@ -486,41 +491,46 @@ class ExpectationSuiteValidationResult(SerializableDictDot):
     Args:
         success: Boolean indicating the success or failure of this collection of results, or None.
         results: List of ExpectationValidationResults, or None.
-        evaluation_parameters: Dict of Evaluation Parameters used to produce these results, or None.
+        suite_parameters: Dict of Suite Parameters used to produce these results, or None.
         statistics: Dict of values describing the results.
         meta: Instance of ExpectationSuiteValidationResult, a Dict of meta values, or None.
+        batch_id: A unique identifier for the batch of data that was validated.
+        result_url: A URL where the results are stored.
+    """  # noqa: E501 # FIXME CoP
 
-    """
-
-    def __init__(
+    def __init__(  # noqa: PLR0913 # FIXME CoP
         self,
-        success: Optional[bool] = None,
-        results: Optional[list] = None,
-        evaluation_parameters: Optional[dict] = None,
+        success: bool,
+        results: list[ExpectationValidationResult],
+        suite_name: str,
+        suite_parameters: Optional[dict] = None,
         statistics: Optional[dict] = None,
-        meta: Optional[ExpectationSuiteValidationResult | dict] = None,
-        ge_cloud_id: Optional[UUID] = None,
+        meta: Optional[ExpectationSuiteValidationResultMeta | dict] = None,
+        batch_id: Optional[str] = None,
+        result_url: Optional[str] = None,
+        id: Optional[str] = None,
     ) -> None:
         self.success = success
-        if results is None:
-            results = []
         self.results = results
-        if evaluation_parameters is None:
-            evaluation_parameters = {}
-        self.evaluation_parameters = evaluation_parameters
-        if statistics is None:
-            statistics = {}
-        self.statistics = statistics
-        if meta is None:
-            meta = {}
-        ensure_json_serializable(
-            meta
-        )  # We require meta information to be serializable.
+        self.suite_name = suite_name
+        self.suite_parameters = suite_parameters or {}
+        self.statistics = statistics or {}
+        meta = meta or {}
+        ensure_json_serializable(meta)  # We require meta information to be serializable.
         self.meta = meta
+        self.batch_id = batch_id
+        self.result_url = result_url
+        self.id = id
         self._metrics: dict = {}
 
-    def __eq__(self, other):
-        """ExpectationSuiteValidationResult equality ignores instance identity, relying only on properties."""
+    @property
+    def asset_name(self) -> str | None:
+        if "active_batch_definition" in self.meta:
+            return self.meta["active_batch_definition"].get("data_asset_name")
+        return None
+
+    def __eq__(self, other):  # type: ignore[explicit-override] # FIXME
+        """ExpectationSuiteValidationResult equality ignores instance identity, relying only on properties."""  # noqa: E501 # FIXME CoP
         if not isinstance(other, self.__class__):
             # Delegate comparison to the other instance's __eq__.
             return NotImplemented
@@ -528,19 +538,33 @@ class ExpectationSuiteValidationResult(SerializableDictDot):
             (
                 self.success == other.success,
                 self.results == other.results,
-                self.evaluation_parameters == other.evaluation_parameters,
+                self.suite_parameters == other.suite_parameters,
                 self.statistics == other.statistics,
                 self.meta == other.meta,
             )
         )
 
-    def __repr__(self):
+    @override
+    def __hash__(self) -> int:
+        return hash(
+            (
+                self.success,
+                tuple(sorted(hash(result) for result in self.results)),
+                tuple(sorted(self.suite_parameters.items())) if self.suite_parameters else (),
+                tuple(sorted(self.statistics.items())) if self.statistics else (),
+                tuple(sorted(self.meta.items())) if self.meta else (),
+            )
+        )
+
+    def __repr__(self):  # type: ignore[explicit-override] # FIXME
         return json.dumps(self.to_json_dict(), indent=2)
 
+    @override
     def __str__(self):
         return json.dumps(self.to_json_dict(), indent=2)
 
     @public_api
+    @override
     def to_json_dict(self):
         """Returns a JSON-serializable dict representation of this ExpectationSuiteValidationResult.
 
@@ -548,29 +572,26 @@ class ExpectationSuiteValidationResult(SerializableDictDot):
             A JSON-serializable dict representation of this ExpectationSuiteValidationResult.
         """
         myself = deepcopy(self)
-        # NOTE - JPC - 20191031: migrate to expectation-specific schemas that subclass result with properly-typed
+        # NOTE - JPC - 20191031: migrate to expectation-specific schemas that subclass result with properly-typed  # noqa: E501 # FIXME CoP
         # schemas to get serialization all-the-way down via dump
-        myself["evaluation_parameters"] = convert_to_json_serializable(
-            myself["evaluation_parameters"]
-        )
+        myself["suite_parameters"] = convert_to_json_serializable(myself["suite_parameters"])
         myself["statistics"] = convert_to_json_serializable(myself["statistics"])
         myself["meta"] = convert_to_json_serializable(myself["meta"])
+        myself["results"] = [convert_to_json_serializable(result) for result in myself["results"]]
         myself = expectationSuiteValidationResultSchema.dump(myself)
         return myself
 
-    def get_metric(self, metric_name, **kwargs):
+    def get_metric(self, metric_name, **kwargs):  # noqa: C901 #  too complex
         metric_name_parts = metric_name.split(".")
-        metric_kwargs_id = get_metric_kwargs_id(metric_name, kwargs)
+        metric_kwargs_id = get_metric_kwargs_id(metric_kwargs=kwargs)
 
         metric_value = None
         # Expose overall statistics
         if metric_name_parts[0] == "statistics":
-            if len(metric_name_parts) == 2:
+            if len(metric_name_parts) == 2:  # noqa: PLR2004 # FIXME CoP
                 return self.statistics.get(metric_name_parts[1])
             else:
-                raise gx_exceptions.UnavailableMetricError(
-                    f"Unrecognized metric {metric_name}"
-                )
+                raise gx_exceptions.UnavailableMetricError(f"Unrecognized metric {metric_name}")  # noqa: TRY003 # FIXME CoP
 
         # Expose expectation-defined metrics
         elif metric_name_parts[0].lower().startswith("expect_"):
@@ -580,10 +601,7 @@ class ExpectationSuiteValidationResult(SerializableDictDot):
             else:
                 for result in self.results:
                     try:
-                        if (
-                            metric_name_parts[0]
-                            == result.expectation_config.expectation_type
-                        ):
+                        if metric_name_parts[0] == result.expectation_config.type:
                             metric_value = result.get_metric(metric_name, **kwargs)
                             break
                     except gx_exceptions.UnavailableMetricError:
@@ -592,10 +610,8 @@ class ExpectationSuiteValidationResult(SerializableDictDot):
                     self._metrics[(metric_name, metric_kwargs_id)] = metric_value
                     return metric_value
 
-        raise gx_exceptions.UnavailableMetricError(
-            "Metric {} with metric_kwargs_id {} is not available.".format(
-                metric_name, metric_kwargs_id
-            )
+        raise gx_exceptions.UnavailableMetricError(  # noqa: TRY003 # FIXME CoP
+            f"Metric {metric_name} with metric_kwargs_id {metric_kwargs_id} is not available."
         )
 
     def get_failed_validation_results(
@@ -603,7 +619,7 @@ class ExpectationSuiteValidationResult(SerializableDictDot):
     ) -> ExpectationSuiteValidationResult:
         validation_results = [result for result in self.results if not result.success]
 
-        successful_expectations = sum(exp.success for exp in validation_results)
+        successful_expectations = sum(exp.success or False for exp in validation_results)
         evaluated_expectations = len(validation_results)
         unsuccessful_expectations = evaluated_expectations - successful_expectations
         success = successful_expectations == evaluated_expectations
@@ -622,20 +638,85 @@ class ExpectationSuiteValidationResult(SerializableDictDot):
         return ExpectationSuiteValidationResult(
             success=success,
             results=validation_results,
-            evaluation_parameters=self.evaluation_parameters,
+            suite_name=self.suite_name,
+            suite_parameters=self.suite_parameters,
             statistics=statistics,
             meta=self.meta,
         )
 
+    def describe_dict(self) -> dict:
+        return convert_to_json_serializable(
+            {
+                "success": self.success,
+                "statistics": self.statistics,
+                "expectations": [expectation.describe_dict() for expectation in self.results],
+                "result_url": self.result_url,
+            }
+        )
+
+    @public_api
+    def describe(self) -> str:
+        """JSON string description of this ExpectationSuiteValidationResult"""
+        return json.dumps(self.describe_dict(), indent=4)
+
+    @public_api
+    def get_max_severity_failure(self) -> FailureSeverity | None:
+        """Get the maximum severity failure for Expectations in the validation result.
+
+        Returns the maximum severity level among failed expectations. The severity levels
+        are ordered as: CRITICAL > WARNING > INFO. If no failures exist, returns None.
+
+        Returns:
+            The maximum severity failure level, or None if no failures exist.
+        """
+        from great_expectations.expectations import metadata_types
+
+        if not self.results:
+            return None
+
+        max_severity = None
+
+        for result in self.results:
+            # Only consider failed expectations
+            if not result.success:
+                if result.expectation_config is None:
+                    logger.error(
+                        f"Expectation configuration is None for failed expectation "
+                        f"(Validation Result ID: {self.id}). "
+                        f"Skipping this result."
+                    )
+                    continue
+
+                severity_str = result.expectation_config.get("severity")
+                try:
+                    severity = metadata_types.FailureSeverity(severity_str)
+
+                    # Short-circuit: highest possible severity level found
+                    if severity == metadata_types.FailureSeverity.CRITICAL:
+                        return severity
+
+                    if max_severity is None or severity > max_severity:
+                        max_severity = severity
+
+                except ValueError:
+                    logger.exception(
+                        f"Invalid severity value '{severity_str}' found in expectation "
+                        f"'{result.expectation_config.type}' "
+                        f"(Validation Result ID: {self.id}). "
+                        f"Skipping this result."
+                    )
+
+        return max_severity
+
 
 class ExpectationSuiteValidationResultSchema(Schema):
     success = fields.Bool()
     results = fields.List(fields.Nested(ExpectationValidationResultSchema))
-    evaluation_parameters = fields.Dict()
+    suite_name = fields.String(required=True, allow_none=False)
+    suite_parameters = fields.Dict()
     statistics = fields.Dict()
     meta = fields.Dict(allow_none=True)
-    ge_cloud_id = fields.UUID(required=False, allow_none=True)
-    checkpoint_name = fields.String(required=False, allow_none=True)
+    id = fields.UUID(required=False, allow_none=True)
 
     # noinspection PyUnusedLocal
     @pre_dump
@@ -646,14 +727,23 @@ class ExpectationSuiteValidationResultSchema(Schema):
             data.statistics = convert_to_json_serializable(data=data.statistics)
         elif isinstance(data, dict):
             data["meta"] = convert_to_json_serializable(data=data.get("meta"))
-            data["statistics"] = convert_to_json_serializable(
-                data=data.get("statistics")
-            )
+            data["statistics"] = convert_to_json_serializable(data=data.get("statistics"))
+        return data
+
+    def _convert_uuids_to_str(self, data):
+        """
+        Utilize UUID for data validation but convert to string before usage in business logic
+        """
+        attr = "id"
+        uuid_val = data.get(attr)
+        if uuid_val:
+            data[attr] = str(uuid_val)
         return data
 
     # noinspection PyUnusedLocal
     @post_load
     def make_expectation_suite_validation_result(self, data, **kwargs):
+        data = self._convert_uuids_to_str(data=data)
         return ExpectationSuiteValidationResult(**data)
 
 
