@@ -1,8 +1,9 @@
 from great_expectations.data_context.data_context import (
     AbstractDataContext,
-    BaseDataContext,
     CloudDataContext,
-    DataContext,
     EphemeralDataContext,
     FileDataContext,
+    get_context,
+    project_manager,
+    set_context,
 )
