@@ -1,10 +1,13 @@
-import logging
-from typing import Optional, Union
+from __future__ import annotations
 
+import logging
+from typing import TYPE_CHECKING, Optional, Union
+
+import marshmallow
 from ruamel.yaml import YAML
-from ruamel.yaml.comments import CommentedMap
 
 import great_expectations.exceptions as gx_exceptions
+from great_expectations.compatibility.typing_extensions import override
 from great_expectations.data_context.cloud_constants import GXCloudRESTResource
 from great_expectations.data_context.store.store import Store
 from great_expectations.data_context.store.tuple_store_backend import TupleStoreBackend
@@ -19,6 +22,9 @@ from great_expectations.util import (
     verify_dynamic_loading_support,
 )
 
+if TYPE_CHECKING:
+    from ruamel.yaml.comments import CommentedMap
+
 yaml = YAML()
 
 yaml.indent(mapping=2, sequence=4, offset=2)
@@ -28,10 +34,9 @@ logger = logging.getLogger(__name__)
 
 
 class ConfigurationStore(Store):
-
     """
     Configuration Store provides a way to store any Marshmallow Schema compatible Configuration (using the YAML format).
-    """
+    """  # noqa: E501 # FIXME CoP
 
     _key_class = ConfigurationIdentifier
 
@@ -45,28 +50,22 @@ class ConfigurationStore(Store):
         runtime_environment: Optional[dict] = None,
     ) -> None:
         if not issubclass(self._configuration_class, BaseYamlConfig):
-            raise gx_exceptions.DataContextError(
-                "Invalid configuration: A configuration_class needs to inherit from the BaseYamlConfig class."
+            raise gx_exceptions.DataContextError(  # noqa: TRY003 # FIXME CoP
+                "Invalid configuration: A configuration_class needs to inherit from the BaseYamlConfig class."  # noqa: E501 # FIXME CoP
             )
 
         if store_backend is not None:
             store_backend_module_name = store_backend.get(
                 "module_name", "great_expectations.data_context.store"
             )
-            store_backend_class_name = store_backend.get(
-                "class_name", "InMemoryStoreBackend"
-            )
+            store_backend_class_name = store_backend.get("class_name", "InMemoryStoreBackend")
             verify_dynamic_loading_support(module_name=store_backend_module_name)
-            store_backend_class = load_class(
-                store_backend_class_name, store_backend_module_name
-            )
+            store_backend_class = load_class(store_backend_class_name, store_backend_module_name)
 
             # Store Backend Class was loaded successfully; verify that it is of a correct subclass.
             if issubclass(store_backend_class, TupleStoreBackend):
                 # Provide defaults for this common case
-                store_backend["filepath_suffix"] = store_backend.get(
-                    "filepath_suffix", ".yml"
-                )
+                store_backend["filepath_suffix"] = store_backend.get("filepath_suffix", ".yml")
 
         super().__init__(
             store_backend=store_backend,
@@ -74,8 +73,8 @@ class ConfigurationStore(Store):
             store_name=store_name,
         )
 
-        # Gather the call arguments of the present function (include the "module_name" and add the "class_name"), filter
-        # out the Falsy values, and set the instance "_config" variable equal to the resulting dictionary.
+        # Gather the call arguments of the present function (include the "module_name" and add the "class_name"), filter  # noqa: E501 # FIXME CoP
+        # out the Falsy values, and set the instance "_config" variable equal to the resulting dictionary.  # noqa: E501 # FIXME CoP
         self._config = {
             "store_name": store_name,
             "store_backend": store_backend,
@@ -88,17 +87,14 @@ class ConfigurationStore(Store):
 
         self._overwrite_existing = overwrite_existing
 
-    def remove_key(self, key):
-        return self.store_backend.remove_key(key)
-
-    def serialize(self, value):
+    def serialize(self, value):  # type: ignore[explicit-override] # FIXME
         if self.cloud_mode:
             # GXCloudStoreBackend expects a json str
             config_schema = value.get_schema_class()()
             return config_schema.dump(value)
         return value.to_yaml_str()
 
-    def deserialize(self, value):
+    def deserialize(self, value):  # type: ignore[explicit-override] # FIXME
         config = value
         if isinstance(value, str):
             config: CommentedMap = yaml.load(value)
@@ -107,6 +103,10 @@ class ConfigurationStore(Store):
         except gx_exceptions.InvalidBaseYamlConfigError:
             # Just to be explicit about what we intended to catch
             raise
+        except marshmallow.ValidationError as e:
+            raise gx_exceptions.InvalidBaseYamlConfigError(  # noqa: TRY003 # FIXME CoP
+                f"Deserialized configuration failed validation: {e}"
+            )
 
     @property
     def overwrite_existing(self) -> bool:
@@ -117,54 +117,23 @@ class ConfigurationStore(Store):
         self._overwrite_existing = overwrite_existing
 
     @property
+    @override
     def config(self) -> dict:
         return self._config
 
-    def self_check(self, pretty_print: bool = True) -> dict:  # type: ignore[override]
-        # Provide visibility into parameters that ConfigurationStore was instantiated with.
-        report_object: dict = {"config": self.config}
-
-        if pretty_print:
-            print("Checking for existing keys...")
-
-        report_object["keys"] = sorted(
-            key.configuration_key for key in self.list_keys()  # type: ignore[attr-defined]
-        )
-
-        report_object["len_keys"] = len(report_object["keys"])
-        len_keys: int = report_object["len_keys"]
-
-        if pretty_print:
-            print(f"\t{len_keys} keys found")
-            if report_object["len_keys"] > 0:
-                for key in report_object["keys"][:10]:
-                    print(f"		{str(key)}")
-            if len_keys > 10:
-                print("\t\t...")
-            print()
-
-        self.serialization_self_check(pretty_print=pretty_print)
-
-        return report_object
-
-    def serialization_self_check(self, pretty_print: bool) -> None:
-        raise NotImplementedError
-
-    def determine_key(
-        self, name: Optional[str] = None, ge_cloud_id: Optional[str] = None
+    def get_key(
+        self, name: Optional[str] = None, id: Optional[str] = None
     ) -> Union[GXCloudIdentifier, ConfigurationIdentifier]:
-        assert bool(name) ^ bool(
-            ge_cloud_id
-        ), "Must provide either name or ge_cloud_id."
+        assert bool(name) ^ bool(id), "Must provide either name or id."
 
         key: Union[GXCloudIdentifier, ConfigurationIdentifier]
-        if ge_cloud_id or self.ge_cloud_mode:
+        if id or self.cloud_mode:
             key = GXCloudIdentifier(
                 resource_type=GXCloudRESTResource.CHECKPOINT,
-                cloud_id=ge_cloud_id,
+                id=id,
                 resource_name=name,
             )
         else:
-            key = ConfigurationIdentifier(configuration_key=name)  # type: ignore[arg-type]
+            key = ConfigurationIdentifier(configuration_key=name)  # type: ignore[arg-type] # FIXME CoP
 
         return key
