@@ -1,11 +1,14 @@
+from __future__ import annotations
+
 import logging
 from typing import Set, Union
 
+from great_expectations.compatibility.typing_extensions import override
 from great_expectations.data_context.data_context_variables import (
     DataContextVariableSchema,
 )
 from great_expectations.data_context.store.configuration_store import ConfigurationStore
-from great_expectations.data_context.types.base import DataContextConfig
+from great_expectations.data_context.types.base import BaseYamlConfig, DataContextConfig
 
 logger = logging.getLogger(__name__)
 
@@ -15,19 +18,16 @@ class DataContextStore(ConfigurationStore):
     A DataContextStore manages persistence around DataContextConfigs.
     """
 
-    _configuration_class = DataContextConfig
+    _configuration_class: type[BaseYamlConfig] = DataContextConfig
 
     cloud_exclude_field_names: Set[DataContextVariableSchema] = {
-        DataContextVariableSchema.ANONYMOUS_USAGE_STATISTICS,
         DataContextVariableSchema.CHECKPOINT_STORE_NAME,
         DataContextVariableSchema.DATASOURCES,
-        DataContextVariableSchema.EVALUATION_PARAMETER_STORE_NAME,
         DataContextVariableSchema.EXPECTATIONS_STORE_NAME,
-        DataContextVariableSchema.PROFILER_STORE_NAME,
         DataContextVariableSchema.VALIDATIONS_STORE_NAME,
-        DataContextVariableSchema.VALIDATION_OPERATORS,
     }
 
+    @override
     def serialize(self, value: DataContextConfig) -> Union[dict, str]:
         """
         Please see `ConfigurationStore.serialize` for more information.
@@ -49,8 +49,6 @@ class DataContextStore(ConfigurationStore):
             for attr in self.cloud_exclude_field_names:
                 if attr in payload:
                     payload.pop(attr)
-                    logger.debug(
-                        f"Removed {attr} from DataContextConfig while serializing to JSON"
-                    )
+                    logger.debug(f"Removed {attr} from DataContextConfig while serializing to JSON")
 
         return payload
