@@ -1,11 +1,25 @@
 from __future__ import annotations
 
 import logging
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Tuple, Type
+from pprint import pformat as pf
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    ClassVar,
+    Dict,
+    List,
+    Optional,
+    Tuple,
+    Type,
+)
 
-from typing_extensions import NotRequired, TypedDict
+from marshmallow import ValidationError as MarshmallowValidationError
+from typing_extensions import TypedDict
 
 import great_expectations.exceptions as gx_exceptions
+from great_expectations.analytics import submit as submit_analytics_event
+from great_expectations.analytics.events import DomainObjectAllDeserializationEvent
+from great_expectations.compatibility.pydantic import ValidationError as PydanticValidationError
 from great_expectations.core.data_context_key import DataContextKey
 from great_expectations.data_context.store.gx_cloud_store_backend import (
     GXCloudStoreBackend,
@@ -16,9 +30,17 @@ from great_expectations.data_context.types.resource_identifiers import (
     GXCloudIdentifier,
 )
 from great_expectations.data_context.util import instantiate_class_from_config
-from great_expectations.exceptions import ClassInstantiationError, DataContextError
+from great_expectations.exceptions import (
+    ClassInstantiationError,
+    DataContextError,
+    StoreBackendError,
+)
+from great_expectations.util import load_class, verify_dynamic_loading_support
 
 if TYPE_CHECKING:
+    # min version of typing_extension missing `NotRequired`, so it can't be imported at runtime
+    from typing_extensions import NotRequired
+
     from great_expectations.core.configuration import AbstractConfig
 
 logger = logging.getLogger(__name__)
@@ -31,6 +53,14 @@ class StoreConfigTypedDict(TypedDict):
     store_backend: dict
 
 
+class DataDocsSiteConfigTypedDict(TypedDict):
+    # NOTE: TypeDict values may be incomplete, update as needed
+    class_name: str
+    module_name: NotRequired[str]
+    store_backend: dict
+    site_index_builder: dict
+
+
 class Store:
     """A store is responsible for reading and writing Great Expectations objects
     to appropriate backends. It provides a generic API that the DataContext can
@@ -44,7 +74,7 @@ class Store:
     All keys must have a to_tuple() method.
     """
 
-    _key_class = DataContextKey
+    _key_class: ClassVar[Type] = DataContextKey
 
     def __init__(
         self,
@@ -58,7 +88,7 @@ class Store:
             store_backend:
             runtime_environment:
             store_name: store name given in the DataContextConfig (via either in-code or yaml configuration)
-        """
+        """  # noqa: E501 # FIXME CoP
         if store_backend is None:
             store_backend = {"class_name": "InMemoryStoreBackend"}
         self._store_name = store_name
@@ -77,24 +107,61 @@ class Store:
                 module_name=module_name, package_name=None, class_name=store_backend
             )
         if not isinstance(self._store_backend, StoreBackend):
-            raise DataContextError(
+            raise DataContextError(  # noqa: TRY003 # FIXME CoP
                 "Invalid StoreBackend configuration: expected a StoreBackend instance."
             )
         self._use_fixed_length_key = self._store_backend.fixed_length_key
 
-    def ge_cloud_response_json_to_object_dict(self, response_json: Dict) -> Dict:
+    @staticmethod
+    def _determine_store_backend_class(store_backend: dict | None) -> type:
+        store_backend = store_backend or {}
+        store_backend_module_name = store_backend.get(
+            "module_name", "great_expectations.data_context.store"
+        )
+        store_backend_class_name = store_backend.get("class_name", "InMemoryStoreBackend")
+        verify_dynamic_loading_support(module_name=store_backend_module_name)
+        return load_class(store_backend_class_name, store_backend_module_name)
+
+    @classmethod
+    def gx_cloud_response_json_to_object_dict(cls, response_json: Dict) -> Dict:
         """
         This method takes full json response from GX cloud and outputs a dict appropriate for
         deserialization into a GX object
         """
         return response_json
 
+    @classmethod
+    def gx_cloud_response_json_to_object_collection(cls, response_json: Dict) -> List[Dict]:
+        """
+        This method takes full json response from GX cloud and outputs a list of dicts appropriate for
+        deserialization into a collection of GX objects
+        """  # noqa: E501 # FIXME CoP
+        logger.debug(f"GE Cloud Response JSON ->\n{pf(response_json, depth=3)}")
+        data = response_json["data"]
+        if not isinstance(data, list):
+            raise TypeError("GX Cloud did not return a collection of Datasources when expected")  # noqa: TRY003 # FIXME CoP
+
+        return [cls._convert_raw_json_to_object_dict(d) for d in data]
+
+    @staticmethod
+    def _convert_raw_json_to_object_dict(data: dict[str, Any]) -> dict[str, Any]:
+        """Method to convert data from API to raw object dict
+
+        This SHOULD be used by both gx_cloud_response_json_to_object_collection
+        and gx_cloud_response_json_to_object_dict. It is a means of keeping
+        response parsing DRY for different response types, e.g. collections
+        may be shaped like {"data": [item1, item2, ...]} while single items
+        may be shaped like {"data": item}. This allows for pulling out the
+        data key and passing it to the appropriate method for conversion.
+        """
+        raise NotImplementedError
+
     def _validate_key(self, key: DataContextKey) -> None:
         # STORE_BACKEND_ID_KEY always validated
-        if key == StoreBackend.STORE_BACKEND_ID_KEY:
+        if key == StoreBackend.STORE_BACKEND_ID_KEY or isinstance(key, self.key_class):
             return
-        elif not isinstance(key, self.key_class):
-            raise TypeError(
+        else:
+            raise TypeError(  # noqa: TRY003 # FIXME CoP
                 f"key must be an instance of {self.key_class.__name__}, not {type(key)}"
             )
 
@@ -102,11 +169,6 @@ class Store:
     def cloud_mode(self) -> bool:
         return isinstance(self._store_backend, GXCloudStoreBackend)
 
-    @property
-    def ge_cloud_mode(self) -> bool:
-        # <GX_RENAME> Deprecated 0.15.37
-        return self.cloud_mode
-
     @property
     def store_backend(self) -> StoreBackend:
         return self._store_backend
@@ -136,7 +198,7 @@ class Store:
         Report the store_backend_id of the currently-configured StoreBackend, suppressing warnings for invalid configurations.
         Returns:
             store_backend_id which is a UUID(version=4)
-        """
+        """  # noqa: E501 # FIXME CoP
         return self._store_backend.store_backend_id_warnings_suppressed
 
     @property
@@ -155,7 +217,7 @@ class Store:
 
     def tuple_to_key(self, tuple_: Tuple[str, ...]) -> DataContextKey:
         if tuple_ == StoreBackend.STORE_BACKEND_ID_KEY:
-            return StoreBackend.STORE_BACKEND_ID_KEY[0]  # type: ignore[return-value]
+            return StoreBackend.STORE_BACKEND_ID_KEY[0]  # type: ignore[return-value] # FIXME CoP
         if self._use_fixed_length_key:
             return self.key_class.from_fixed_length_tuple(tuple_)
         return self.key_class.from_tuple(tuple_)
@@ -175,7 +237,7 @@ class Store:
             value = self._store_backend.get(self.key_to_tuple(key))
             # TODO [Robby] MER-285: Handle non-200 http errors
             if value:
-                value = self.ge_cloud_response_json_to_object_dict(response_json=value)
+                value = self.gx_cloud_response_json_to_object_dict(response_json=value)
         else:
             self._validate_key(key)
             value = self._store_backend.get(self.key_to_tuple(key))
@@ -185,37 +247,81 @@ class Store:
 
         return None
 
-    def set(self, key: DataContextKey, value: Any, **kwargs) -> None:
+    def get_all(self) -> list[Any]:
+        objs = self._store_backend.get_all()
+        if self.cloud_mode:
+            objs = self.gx_cloud_response_json_to_object_collection(objs)
+
+        deserializable_objs: list[Any] = []
+        bad_objs: list[Any] = []
+        for obj in objs:
+            try:
+                deserializable_objs.append(self.deserialize(obj))
+            except (
+                MarshmallowValidationError,
+                PydanticValidationError,
+                StoreBackendError,
+            ) as e:
+                bad_objs.append(obj)
+                self.submit_all_deserialization_event(e)
+            except Exception as e:
+                # For a general error we want to log so we can understand if there
+                # is user pain here and then we reraise.
+                self.submit_all_deserialization_event(e)
+                raise
+
+        if bad_objs:
+            prefix = "\n    SKIPPED: "
+            skipped = prefix + prefix.join([str(bad) for bad in bad_objs])
+            logger.warning(f"Skipping Bad Configs:{skipped}")
+        return deserializable_objs
+
+    def submit_all_deserialization_event(self, e: Exception):
+        error_type = type(e)
+        submit_analytics_event(
+            DomainObjectAllDeserializationEvent(
+                error_type=f"{error_type.__module__}.{error_type.__qualname__}",
+                store_name=type(self).__name__,
+            )
+        )
+
+    def set(self, key: DataContextKey, value: Any, **kwargs) -> Any:
         if key == StoreBackend.STORE_BACKEND_ID_KEY:
             return self._store_backend.set(key, value, **kwargs)
 
         self._validate_key(key)
-        return self._store_backend.set(
-            self.key_to_tuple(key), self.serialize(value), **kwargs
-        )
+        return self._store_backend.set(self.key_to_tuple(key), self.serialize(value), **kwargs)
 
     def add(self, key: DataContextKey, value: Any, **kwargs) -> None:
         """
         Essentially `set` but validates that a given key-value pair does not already exist.
         """
+        return self._add(key=key, value=value, **kwargs)
+
+    def _add(self, key: DataContextKey, value: Any, **kwargs) -> Any:
         self._validate_key(key)
-        return self._store_backend.add(
-            self.key_to_tuple(key), self.serialize(value), **kwargs
-        )
+        output = self._store_backend.add(self.key_to_tuple(key), self.serialize(value), **kwargs)
+        if hasattr(value, "id") and hasattr(output, "id"):
+            value.id = output.id
+        return output
 
     def update(self, key: DataContextKey, value: Any, **kwargs) -> None:
         """
         Essentially `set` but validates that a given key-value pair does already exist.
         """
-        self._validate_key(key)
-        return self._store_backend.update(
-            self.key_to_tuple(key), self.serialize(value), **kwargs
-        )
+        return self._update(key=key, value=value, **kwargs)
 
-    def add_or_update(self, key: DataContextKey, value: Any, **kwargs) -> None:
+    def _update(self, key: DataContextKey, value: Any, **kwargs) -> None:
+        self._validate_key(key)
+        return self._store_backend.update(self.key_to_tuple(key), self.serialize(value), **kwargs)
+
+    def add_or_update(self, key: DataContextKey, value: Any, **kwargs) -> None | GXCloudIdentifier:
         """
         Conditionally calls `add` or `update` based on the presence of the given key.
         """
+        return self._add_or_update(key=key, value=value, **kwargs)
+
+    def _add_or_update(self, key: DataContextKey, value: Any, **kwargs) -> None | GXCloudIdentifier:
         self._validate_key(key)
         return self._store_backend.add_or_update(
             self.key_to_tuple(key), self.serialize(value), **kwargs
@@ -225,31 +331,24 @@ class Store:
         keys_without_store_backend_id = [
             key
             for key in self._store_backend.list_keys()
-            if not key == StoreBackend.STORE_BACKEND_ID_KEY
+            if key != StoreBackend.STORE_BACKEND_ID_KEY
         ]
         return [self.tuple_to_key(key) for key in keys_without_store_backend_id]
 
     def has_key(self, key: DataContextKey) -> bool:
         if key == StoreBackend.STORE_BACKEND_ID_KEY:
-            return self._store_backend.has_key(key)  # noqa: W601
+            return self._store_backend.has_key(key)
         else:
             if self._use_fixed_length_key:
-                return self._store_backend.has_key(  # noqa: W601
-                    key.to_fixed_length_tuple()
-                )
-            return self._store_backend.has_key(key.to_tuple())  # noqa: W601
+                return self._store_backend.has_key(key.to_fixed_length_tuple())
+            return self._store_backend.has_key(key.to_tuple())
 
-    def self_check(self, pretty_print: bool) -> None:
-        NotImplementedError(
-            f"The test method is not implemented for Store class {self.__class__.__name__}."
-        )
+    def remove_key(self, key):
+        return self.store_backend.remove_key(key)
 
     def _build_key_from_config(self, config: AbstractConfig) -> DataContextKey:
         id: Optional[str] = None
-        # Chetan - 20220831 - Explicit fork in logic to cover legacy behavior (particularly around Checkpoints).
-        # Will be removed as part of the effort to rename `ge_cloud_id` to `id` across the codebase.
-        if hasattr(config, "ge_cloud_id"):
-            id = config.ge_cloud_id
+        # Chetan - 20220831 - Explicit fork in logic to cover legacy behavior (particularly around Checkpoints).  # noqa: E501 # FIXME CoP
         if hasattr(config, "id"):
             id = config.id
 
@@ -261,32 +360,30 @@ class Store:
 
     @staticmethod
     def build_store_from_config(
-        store_name: Optional[str] = None,
-        store_config: StoreConfigTypedDict | dict | None = None,
+        name: Optional[str] = None,
+        config: StoreConfigTypedDict | dict | None = None,
         module_name: str = "great_expectations.data_context.store",
         runtime_environment: Optional[dict] = None,
     ) -> Store:
-        if store_config is None or module_name is None:
-            raise gx_exceptions.StoreConfigurationError(
+        if config is None or module_name is None:
+            raise gx_exceptions.StoreConfigurationError(  # noqa: TRY003 # FIXME CoP
                 "Cannot build a store without both a store_config and a module_name"
             )
 
         try:
             config_defaults: dict = {
-                "store_name": store_name,
+                "store_name": name,
                 "module_name": module_name,
             }
             new_store = instantiate_class_from_config(
-                config=store_config,
+                config=config,
                 runtime_environment=runtime_environment,
                 config_defaults=config_defaults,
             )
         except gx_exceptions.DataContextError as e:
-            logger.critical(
-                f"Error {e} occurred while attempting to instantiate a store."
-            )
-            class_name: str = store_config["class_name"]
-            module_name = store_config.get("module_name", module_name)
+            logger.critical(f"Error {e} occurred while attempting to instantiate a store.")
+            class_name: str = config["class_name"]
+            module_name = config.get("module_name", module_name)
             raise gx_exceptions.ClassInstantiationError(
                 module_name=module_name,
                 package_name=None,
