@@ -1,11 +1,18 @@
+from __future__ import annotations
+
 import importlib
 import itertools
 import json
 from collections.abc import Iterable
-from typing import Any, Dict, List, Optional, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union
 
 from marshmallow import ValidationError
 
+from great_expectations.compatibility.typing_extensions import override
+
+if TYPE_CHECKING:
+    import requests
+
 
 class GreatExpectationsError(Exception):
     def __init__(self, message) -> None:
@@ -13,6 +20,16 @@ class GreatExpectationsError(Exception):
         super().__init__(message)
 
 
+class GreatExpectationsAggregateError(ValueError):
+    def __init__(self, errors: list[GreatExpectationsError]) -> None:
+        self._errors = errors
+        super().__init__("\n\t" + "\n\t".join(str(e) for e in errors))
+
+    @property
+    def errors(self) -> list[GreatExpectationsError]:
+        return self._errors
+
+
 class GreatExpectationsValidationError(ValidationError, GreatExpectationsError):
     def __init__(self, message, validation_error=None) -> None:
         self.message = message
@@ -20,16 +37,17 @@ class GreatExpectationsValidationError(ValidationError, GreatExpectationsError):
         if validation_error is not None:
             self.messages = validation_error.messages
 
+    @override
     def __str__(self) -> str:
         if self.message is None:
             return str(self.messages)
         return self.message
 
 
-class SuiteEditNotebookCustomTemplateModuleNotFoundError(ModuleNotFoundError):
-    def __init__(self, custom_module) -> None:
-        message = f"The custom module '{custom_module}' could not be found"
-        super().__init__(message)
+class UnhashableColumnError(GreatExpectationsError):
+    def __init__(self, col_name: str) -> None:
+        msg = f"Unhashable column: {col_name}"
+        super().__init__(msg)
 
 
 class DataContextError(GreatExpectationsError):
@@ -40,19 +58,58 @@ class ExpectationSuiteError(DataContextError):
     pass
 
 
+class ValidationDefinitionError(DataContextError):
+    pass
+
+
+class NoDataDocsError(DataContextError):
+    def __init__(self) -> None:
+        super().__init__(
+            "No Data Docs found. Please check that you have run a checkpoint, "
+            "and that the checkpoint has a UpdateDataDocsAction in its actions."
+        )
+
+
+class ValidationDefinitionNotFoundError(ValidationDefinitionError):
+    def __init__(self, name: str) -> None:
+        super().__init__(
+            f"ValidationDefinition '{name}' not found. Please check the name and try again."
+        )
+
+
 class CheckpointError(DataContextError):
     pass
 
 
 class CheckpointNotFoundError(CheckpointError):
-    pass
+    def __init__(self, name: str) -> None:
+        super().__init__(f"Checkpoint '{name}' not found. Please check the name and try again.")
+
+
+class CheckpointRunWithoutValidationDefinitionError(CheckpointError):
+    def __init__(self) -> None:
+        super().__init__(
+            "Checkpoint.run() requires at least one validation definition. "
+            "Please add one and try your action again."
+        )
 
 
 class StoreBackendError(DataContextError):
     pass
 
 
-class ParserError(GreatExpectationsError):
+class GitIgnoreScaffoldingError(GreatExpectationsError):
+    pass
+
+
+class StoreBackendUnsupportedResourceTypeError(StoreBackendError):
+    def __init__(self, resource_type: str) -> None:
+        super().__init__(f"Unsupported resource type: {resource_type}")
+
+
+class StoreBackendTransientError(StoreBackendError):
+    """The result of a timeout or other networking issues"""
+
     pass
 
 
@@ -64,10 +121,6 @@ class InvalidTopLevelConfigKeyError(GreatExpectationsError):
     pass
 
 
-class MissingTopLevelConfigKeyError(GreatExpectationsValidationError):
-    pass
-
-
 class RenderingError(GreatExpectationsError):
     pass
 
@@ -79,7 +132,7 @@ class InvalidBaseYamlConfigError(GreatExpectationsValidationError):
                 validation_error
                 and validation_error.messages
                 and isinstance(validation_error.messages, dict)
-                and all([key is None for key in validation_error.messages.keys()])
+                and all(key is None for key in validation_error.messages)
             ):
                 validation_error.messages = list(
                     itertools.chain.from_iterable(validation_error.messages.values())
@@ -92,14 +145,6 @@ class InvalidDataContextConfigError(InvalidBaseYamlConfigError):
     pass
 
 
-class InvalidCheckpointConfigError(InvalidBaseYamlConfigError):
-    pass
-
-
-class InvalidBatchKwargsError(GreatExpectationsError):
-    pass
-
-
 class InvalidBatchSpecError(GreatExpectationsError):
     pass
 
@@ -108,6 +153,16 @@ class InvalidBatchRequestError(GreatExpectationsError):
     pass
 
 
+class BuildBatchRequestError(GreatExpectationsError):
+    def __init__(self, message: str):
+        super().__init__(f"Bad input to build_batch_request: {message}")
+
+
+class NoAvailableBatchesError(GreatExpectationsError):
+    def __init__(self) -> None:
+        super().__init__("No available batches found.")
+
+
 class InvalidBatchIdError(GreatExpectationsError):
     pass
 
@@ -120,43 +175,20 @@ class UnsupportedConfigVersionError(DataContextError):
     pass
 
 
-class EvaluationParameterError(GreatExpectationsError):
-    pass
+class MissingDataContextError(DataContextError):
+    def __init__(self) -> None:
+        super().__init__("Missing DataContext")
 
 
-class ProfilerError(GreatExpectationsError):
-    pass
+class DataContextRequiredError(DataContextError):
+    def __init__(self) -> None:
+        super().__init__(
+            "This action requires an active data context. "
+            "Please call `great_expectations.get_context()` first, then try your action again."
+        )
 
 
-class ProfilerConfigurationError(ProfilerError):
-    """A configuration error for a "RuleBasedProfiler" class."""
-
-    pass
-
-
-class ProfilerExecutionError(ProfilerError):
-    """A runtime error for a "RuleBasedProfiler" class."""
-
-    pass
-
-
-class ProfilerNotFoundError(ProfilerError):
-    pass
-
-
-class DataAssistantError(ProfilerError):
-    pass
-
-
-class DataAssistantExecutionError(DataAssistantError):
-    """A runtime error for a "DataAssistant" class."""
-
-    pass
-
-
-class DataAssistantResultExecutionError(DataAssistantError):
-    """A runtime error for a "DataAssistantResult" class."""
-
+class SuiteParameterError(GreatExpectationsError):
     pass
 
 
@@ -175,13 +207,6 @@ class MissingConfigVariableError(InvalidConfigError):
         super().__init__(self.message)
 
 
-class AmbiguousDataAssetNameError(DataContextError):
-    def __init__(self, message, candidates=None) -> None:
-        self.message = message
-        self.candidates = candidates
-        super().__init__(self.message)
-
-
 class StoreConfigurationError(DataContextError):
     pass
 
@@ -198,10 +223,6 @@ class ExpectationNotFoundError(GreatExpectationsError):
     pass
 
 
-class InvalidValidationResultError(GreatExpectationsError):
-    pass
-
-
 class GreatExpectationsTypeError(TypeError):
     pass
 
@@ -222,7 +243,7 @@ Invalid result values were found when trying to instantiate an ExpectationValida
 - Great Expectations enables caching by default.
 - Please ensure that caching behavior is consistent between the underlying Dataset (e.g. Spark) and Great Expectations.
 Result: {}
-"""
+"""  # noqa: E501 # FIXME CoP
         self.message = template.format(json.dumps(result_dict, indent=2))
         super().__init__(self.message)
 
@@ -231,10 +252,10 @@ class ConfigNotFoundError(DataContextError):
     """The great_expectations dir could not be found."""
 
     def __init__(self) -> None:
-        self.message = """Error: No great_expectations directory was found here!
+        self.message = """Error: No gx directory was found here!
     - Please check that you are in the correct directory or have specified the correct directory.
     - If you have never run Great Expectations in this project, please run `great_expectations init` to get started.
-"""
+"""  # noqa: E501 # FIXME CoP
         super().__init__(self.message)
 
 
@@ -251,9 +272,7 @@ No module named `{}` could be found in your plugins directory.
 
         colored_template = f"<red>{template}</red>"
         module_snippet = f"</red><yellow>{module_name}</yellow><red>"
-        self.cli_colored_message = colored_template.format(
-            module_snippet, module_snippet
-        )
+        self.cli_colored_message = colored_template.format(module_snippet, module_snippet)
         super().__init__(self.message)
 
 
@@ -265,14 +284,8 @@ class PluginClassNotFoundError(DataContextError, AttributeError):
             "FixedLengthTupleFilesystemStoreBackend": "TupleFilesystemStoreBackend",
             "FixedLengthTupleS3StoreBackend": "TupleS3StoreBackend",
             "FixedLengthTupleGCSStoreBackend": "TupleGCSStoreBackend",
-            "InMemoryEvaluationParameterStore": "EvaluationParameterStore",
-            "DatabricksTableGenerator": "DatabricksTableBatchKwargsGenerator",
-            "GlobReaderGenerator": "GlobReaderBatchKwargsGenerator",
             "SubdirReaderGenerator": "SubdirReaderBatchKwargsGenerator",
-            "QueryGenerator": "QueryBatchKwargsGenerator",
-            "TableGenerator": "TableBatchKwargsGenerator",
-            "S3Generator": "S3GlobReaderBatchKwargsGenerator",
-            "ExtractAndStoreEvaluationParamsAction": "StoreEvaluationParametersAction",
+            "ExtractAndStoreSuiteParamsAction": "StoreSuiteParametersAction",
             "StoreAction": "StoreValidationResultAction",
             "PartitionDefinitionSubset": "IDDict",
             "PartitionRequest": "IDDict",
@@ -295,9 +308,7 @@ class PluginClassNotFoundError(DataContextError, AttributeError):
         module_snippet = f"</red><yellow>{module_name}</yellow><red>"
         class_snippet = f"</red><yellow>{class_name}</yellow><red>"
         if class_name_changes.get(class_name):
-            new_class_snippet = (
-                f"</red><yellow>{class_name_changes.get(class_name)}</yellow><red>"
-            )
+            new_class_snippet = f"</red><yellow>{class_name_changes.get(class_name)}</yellow><red>"
             self.cli_colored_message = colored_template.format(
                 module_snippet, class_snippet, class_snippet, new_class_snippet
             )
@@ -313,38 +324,29 @@ class PluginClassNotFoundError(DataContextError, AttributeError):
 class ClassInstantiationError(GreatExpectationsError):
     def __init__(self, module_name, package_name, class_name) -> None:
         # noinspection PyUnresolvedReferences
-        module_spec: Optional[
-            importlib.machinery.ModuleSpec
-        ] = importlib.util.find_spec(module_name, package=package_name)
+        module_spec: Optional[importlib.machinery.ModuleSpec] = importlib.util.find_spec(
+            module_name, package=package_name
+        )
         if not module_spec:
             if not package_name:
                 package_name = ""
             self.message = f"""No module named "{package_name + module_name}" could be found in the repository.  \
 Please make sure that the file, corresponding to this package and module, exists and that dynamic loading of code \
 modules, templates, and assets is supported in your execution environment.  This error is unrecoverable.
-            """
+            """  # noqa: E501 # FIXME CoP
         else:
             self.message = f"""The module "{module_name}" exists; however, the system is unable to create an instance \
 of the class "{class_name}", searched for inside this module.  Please make sure that the class named "{class_name}" is \
 properly defined inside its intended module and declared correctly by the calling entity.  This error is unrecoverable.
-            """
+            """  # noqa: E501 # FIXME CoP
         super().__init__(self.message)
 
 
 class ExpectationSuiteNotFoundError(GreatExpectationsError):
-    def __init__(self, data_asset_name) -> None:
-        self.data_asset_name = data_asset_name
-        self.message = (
-            f"No expectation suite found for data_asset_name {data_asset_name}"
+    def __init__(self, name: str) -> None:
+        super().__init__(
+            f"ExpectationSuite '{name}' not found. Please check the name and try again."
         )
-        super().__init__(self.message)
-
-
-class BatchKwargsError(DataContextError):
-    def __init__(self, message, batch_kwargs=None) -> None:
-        self.message = message
-        self.batch_kwargs = batch_kwargs
-        super().__init__(self.message)
 
 
 class BatchDefinitionError(DataContextError):
@@ -353,6 +355,13 @@ class BatchDefinitionError(DataContextError):
         super().__init__(self.message)
 
 
+class BatchDefinitionNotFoundError(BatchDefinitionError):
+    def __init__(self, name: str) -> None:
+        super().__init__(
+            f"BatchDefinition '{name}' not found. Please check the name and try again."
+        )
+
+
 class BatchSpecError(DataContextError):
     def __init__(self, message) -> None:
         self.message = message
@@ -361,16 +370,10 @@ class BatchSpecError(DataContextError):
 
 class DatasourceError(DataContextError):
     def __init__(self, datasource_name: str, message: str) -> None:
-        self.message = (
-            f"Cannot initialize datasource {datasource_name}, error: {message}"
-        )
+        self.message = f"Cannot initialize datasource {datasource_name}, error: {message}"
         super().__init__(self.message)
 
 
-class DatasourceConfigurationError(DatasourceError):
-    pass
-
-
 class DatasourceInitializationError(DatasourceError):
     pass
 
@@ -383,13 +386,13 @@ class DatasourceNotFoundError(DataContextError):
     pass
 
 
-class InvalidConfigValueTypeError(DataContextError):
+class DataAssetNotFoundError(DataContextError):
     pass
 
 
-class DataConnectorError(DataContextError):
-    def __init__(self, message) -> None:
-        self.message = message
+class DataAssetInitializationError(GreatExpectationsError):
+    def __init__(self, message: str) -> None:
+        self.message = f"Cannot initialize data asset: {message}"
         super().__init__(self.message)
 
 
@@ -448,16 +451,54 @@ class GXCloudError(GreatExpectationsError):
     Generic error used to provide additional context around Cloud-specific issues.
     """
 
+    response: requests.Response
+
+    def __init__(self, message: str, response: requests.Response) -> None:
+        super().__init__(message)
+        self.response = response
+
 
 class GXCloudConfigurationError(GreatExpectationsError):
     """
     Error finding and verifying the required configuration values when preparing to connect to GX Cloud
-    """
+    """  # noqa: E501 # FIXME CoP
 
 
+# Only used in tests
 class DatabaseConnectionError(GreatExpectationsError):
     """Error connecting to a database including during an integration test."""
 
 
-class MigrationError(GreatExpectationsError):
-    """Error when using the migration tool."""
+class SqlAddBatchDefinitionError(Exception):
+    def __init__(self, msg: str):
+        super().__init__(f"Failed adding batch definition: {msg}")
+
+
+class ValidationActionRegistryError(GreatExpectationsError):
+    pass
+
+
+class ValidationActionAlreadyRegisteredError(ValidationActionRegistryError):
+    def __init__(self, action_type: str) -> None:
+        super().__init__(message=f"Action of type {action_type} is already registered.")
+
+
+class ValidationActionRegistryRetrievalError(ValidationActionRegistryError):
+    def __init__(self, action_type: str | None) -> None:
+        if action_type:
+            message = f"Invalid action configuration; no action of type {action_type} found."
+        else:
+            message = "Invalid action configuration; no 'type' key found."
+
+        super().__init__(message)
+
+
+class RedshiftExecutionEngineError(GreatExpectationsError):
+    def __init__(self, message: str) -> None:
+        msg = f"Redshift execution engine error: {message}"
+        super().__init__(msg)
+
+
+class InvalidSetTypeError(GreatExpectationsError):
+    def __init__(self, expected_type: str, actual_type: str) -> None:
+        super().__init__(f"Expected a set[{expected_type}], got an element of type {actual_type}")
