@@ -18,49 +18,41 @@ from typing import (
 )
 
 import great_expectations.exceptions as gx_exceptions
-from great_expectations.core._docs_decorators import public_api
+from great_expectations.compatibility.typing_extensions import override
 from great_expectations.core.batch_manager import BatchManager
 from great_expectations.core.metric_domain_types import MetricDomainTypes
-from great_expectations.core.util import convert_to_json_serializable
 from great_expectations.expectations.registry import get_metric_provider
 from great_expectations.expectations.row_conditions import (
     RowCondition,
     RowConditionParserType,
 )
 from great_expectations.types import DictDot
-from great_expectations.util import filter_properties_dict
-from great_expectations.validator.computed_metric import MetricValue  # noqa: TCH001
-from great_expectations.validator.metric_configuration import (
-    MetricConfiguration,  # noqa: TCH001
+from great_expectations.util import (
+    convert_to_json_serializable,  # noqa: TID251 # FIXME CoP
+    filter_properties_dict,
 )
+from great_expectations.validator.computed_metric import MetricValue  # noqa: TC001 # FIXME CoP
 
 if TYPE_CHECKING:
-    # noinspection PyPep8Naming
-    import pyspark.sql.functions as F
-    import sqlalchemy as sa
-
+    from great_expectations.compatibility.pyspark import functions as F
+    from great_expectations.compatibility.sqlalchemy import sqlalchemy as sa
     from great_expectations.core.batch import (
         BatchData,
         BatchDataType,
+        BatchDataUnion,
         BatchMarkers,
         BatchSpec,
     )
     from great_expectations.expectations.metrics.metric_provider import MetricProvider
+    from great_expectations.validator.metric_configuration import (
+        MetricConfiguration,
+        MetricConfigurationID,
+    )
     from great_expectations.validator.validator import Validator
 
 logger = logging.getLogger(__name__)
 
 
-try:
-    import pandas as pd
-except ImportError:
-    pd = None
-
-    logger.debug(
-        "Unable to load pandas; install optional pandas dependency for support."
-    )
-
-
 class NoOpDict:
     def __getitem__(self, item):
         return None
@@ -77,15 +69,15 @@ class NoOpDict:
 class MetricComputationConfiguration(DictDot):
     """
     MetricComputationConfiguration is a "dataclass" object, which holds components required for metric computation.
-    """
+    """  # noqa: E501 # FIXME CoP
 
     metric_configuration: MetricConfiguration
-    metric_fn: sa.func | F
+    metric_fn: sa.func | F  # type: ignore[valid-type] # FIXME CoP
     metric_provider_kwargs: dict
     compute_domain_kwargs: Optional[dict] = None
     accessor_domain_kwargs: Optional[dict] = None
 
-    @public_api
+    @override
     def to_dict(self) -> dict:
         """Returns: this MetricComputationConfiguration as a Python dictionary
 
@@ -94,7 +86,6 @@ class MetricComputationConfiguration(DictDot):
         """
         return asdict(self)
 
-    @public_api
     def to_json_dict(self) -> dict:
         """Returns: this MetricComputationConfiguration as a JSON dictionary
 
@@ -105,8 +96,8 @@ class MetricComputationConfiguration(DictDot):
 
 
 @dataclass
-class SplitDomainKwargs:
-    """compute_domain_kwargs, accessor_domain_kwargs when split from domain_kwargs
+class PartitionDomainKwargs:
+    """compute_domain_kwargs, accessor_domain_kwargs when partitioned from domain_kwargs
 
     The union of compute_domain_kwargs, accessor_domain_kwargs is the input domain_kwargs
     """
@@ -115,7 +106,6 @@ class SplitDomainKwargs:
     accessor: dict
 
 
-@public_api
 class ExecutionEngine(ABC):
     """ExecutionEngine defines interfaces and provides common methods for loading Batch of data and compute metrics.
 
@@ -135,7 +125,7 @@ class ExecutionEngine(ABC):
     to provide specific functionality (bundling of computation is available only for "deferred execution" computational
     systems, such as SQLAlchemy and Spark; it is not available for Pandas, because Pandas computations are immediate).
 
-    Finally, ExecutionEngine defines interfaces for Batch data sampling and splitting Batch of data along defined axes.
+    Finally, ExecutionEngine defines interfaces for Batch data sampling and partitioning Batch of data along defined axes.
 
     Constructor builds an ExecutionEngine, using provided configuration options (instatiation is done by child classes).
 
@@ -145,7 +135,7 @@ class ExecutionEngine(ABC):
         batch_spec_defaults: dictionary of BatchSpec overrides (useful for amending configuration at runtime).
         batch_data_dict: dictionary of Batch objects with corresponding IDs as keys supplied at initialization time
         validator: Validator object (optional) -- not utilized in V3 and later versions
-    """
+    """  # noqa: E501 # FIXME CoP
 
     recognized_batch_spec_defaults: Set[str] = set()
 
@@ -160,7 +150,7 @@ class ExecutionEngine(ABC):
         self.name = name
         self._validator = validator
 
-        # NOTE: using caching makes the strong assumption that the user will not modify the core data store
+        # NOTE: using caching makes the strong assumption that the user will not modify the core data store  # noqa: E501 # FIXME CoP
         # (e.g. self.spark_df) over the lifetime of the dataset instance
         self._caching = caching
         # NOTE: 20200918 - this is a naive cache; update.
@@ -176,7 +166,7 @@ class ExecutionEngine(ABC):
         if not batch_spec_defaults_keys <= self.recognized_batch_spec_defaults:
             logger.warning(
                 f"""Unrecognized batch_spec_default(s): \
-{str(batch_spec_defaults_keys - self.recognized_batch_spec_defaults)}
+{batch_spec_defaults_keys - self.recognized_batch_spec_defaults!s}
 """
             )
 
@@ -193,7 +183,7 @@ class ExecutionEngine(ABC):
 
         self._load_batch_data_from_dict(batch_data_dict=batch_data_dict)
 
-        # Gather the call arguments of the present function (and add the "class_name"), filter out the Falsy values, and
+        # Gather the call arguments of the present function (and add the "class_name"), filter out the Falsy values, and  # noqa: E501 # FIXME CoP
         # set the instance "_config" variable equal to the resulting dictionary.
         self._config = {
             "name": name,
@@ -206,7 +196,9 @@ class ExecutionEngine(ABC):
         }
         filter_properties_dict(properties=self._config, clean_falsy=True, inplace=True)
 
-    def configure_validator(self, validator) -> None:
+    def configure_validator(  # noqa: B027 # empty-method-without-abstract-decorator
+        self, validator
+    ) -> None:
         """Optionally configure the validator as appropriate for the execution engine."""
         pass
 
@@ -223,18 +215,16 @@ class ExecutionEngine(ABC):
         """Getter for batch_manager"""
         return self._batch_manager
 
-    def _load_batch_data_from_dict(
-        self, batch_data_dict: Dict[str, BatchDataType]
-    ) -> None:
+    def _load_batch_data_from_dict(self, batch_data_dict: Dict[str, BatchDataType]) -> None:
         """
         Loads all data in batch_data_dict using cache_batch_data
         """
         batch_id: str
         batch_data: BatchDataType
         for batch_id, batch_data in batch_data_dict.items():
-            self.load_batch_data(batch_id=batch_id, batch_data=batch_data)
+            self.load_batch_data(batch_id=batch_id, batch_data=batch_data)  # type: ignore[arg-type] # FIXME CoP
 
-    def load_batch_data(self, batch_id: str, batch_data: BatchDataType) -> None:
+    def load_batch_data(self, batch_id: str, batch_data: BatchDataUnion) -> None:
         self._batch_manager.save_batch_data(batch_id=batch_id, batch_data=batch_data)
 
     def get_batch_data(
@@ -260,9 +250,9 @@ class ExecutionEngine(ABC):
     def resolve_metrics(
         self,
         metrics_to_resolve: Iterable[MetricConfiguration],
-        metrics: Optional[Dict[Tuple[str, str, str], MetricValue]] = None,
+        metrics: Optional[dict[MetricConfigurationID, MetricValue]] = None,
         runtime_configuration: Optional[dict] = None,
-    ) -> Dict[Tuple[str, str, str], MetricValue]:
+    ) -> dict[MetricConfigurationID, MetricValue]:
         """resolve_metrics is the main entrypoint for an execution engine. The execution engine will compute the value
         of the provided metrics.
 
@@ -273,7 +263,7 @@ class ExecutionEngine(ABC):
 
         Returns:
             resolved_metrics (Dict): a dictionary with the values for the metrics that have just been resolved.
-        """
+        """  # noqa: E501 # FIXME CoP
         if not metrics_to_resolve:
             return metrics or {}
 
@@ -292,13 +282,10 @@ class ExecutionEngine(ABC):
             metric_fn_bundle_configurations=metric_fn_bundle_configurations,
         )
 
-    def resolve_metric_bundle(
-        self, metric_fn_bundle
-    ) -> Dict[Tuple[str, str, str], MetricValue]:
-        """Resolve a bundle of metrics with the same compute Domain as part of a single trip to the compute engine."""
+    def resolve_metric_bundle(self, metric_fn_bundle) -> dict[MetricConfigurationID, MetricValue]:
+        """Resolve a bundle of metrics with the same compute Domain as part of a single trip to the compute engine."""  # noqa: E501 # FIXME CoP
         raise NotImplementedError
 
-    @public_api
     def get_domain_records(
         self,
         domain_kwargs: dict,
@@ -310,11 +297,10 @@ class ExecutionEngine(ABC):
 
         Returns:
             data corresponding to the compute domain
-        """
+        """  # noqa: E501 # FIXME CoP
 
         raise NotImplementedError
 
-    @public_api
     def get_compute_domain(
         self,
         domain_kwargs: dict,
@@ -342,15 +328,14 @@ class ExecutionEngine(ABC):
 
             In general, the union of the compute_domain_kwargs and accessor_domain_kwargs will be the same as the
             domain_kwargs provided to this method.
-        """
+        """  # noqa: E501 # FIXME CoP
 
         raise NotImplementedError
 
     def add_column_row_condition(
         self, domain_kwargs, column_name=None, filter_null=True, filter_nan=False
     ):
-        """EXPERIMENTAL
-
+        """
         Add a row condition for handling null filter.
 
         Args:
@@ -359,22 +344,21 @@ class ExecutionEngine(ABC):
                 table_domain_kwargs
             filter_null: if true, add a filter for null values
             filter_nan: if true, add a filter for nan values
-        """
+        """  # noqa: E501 # FIXME CoP
         if filter_null is False and filter_nan is False:
-            logger.warning(
-                "add_column_row_condition called with no filter condition requested"
-            )
+            logger.warning("add_column_row_condition called with no filter condition requested")
             return domain_kwargs
 
         if filter_nan:
-            raise gx_exceptions.GreatExpectationsError(
+            raise gx_exceptions.GreatExpectationsError(  # noqa: TRY003 # FIXME CoP
                 "Base ExecutionEngine does not support adding nan condition filters"
             )
 
         new_domain_kwargs = copy.deepcopy(domain_kwargs)
-        assert (
-            "column" in domain_kwargs or column_name is not None
-        ), "No column provided: A column must be provided in domain_kwargs or in the column_name parameter"
+        assert "column" in domain_kwargs or column_name is not None, (
+            "No column provided: A column must be provided "
+            "in domain_kwargs or in the column_name parameter"
+        )
         if column_name is not None:
             column = column_name
         else:
@@ -390,7 +374,7 @@ class ExecutionEngine(ABC):
     def _build_direct_and_bundled_metric_computation_configurations(
         self,
         metrics_to_resolve: Iterable[MetricConfiguration],
-        metrics: Optional[Dict[Tuple[str, str, str], MetricValue]] = None,
+        metrics: Optional[dict[MetricConfigurationID, MetricValue]] = None,
         runtime_configuration: Optional[dict] = None,
     ) -> Tuple[
         List[MetricComputationConfiguration],
@@ -410,7 +394,7 @@ class ExecutionEngine(ABC):
 
         Returns:
             Tuple with two elements: directly-computable and bundled "MetricComputationConfiguration" objects
-        """
+        """  # noqa: E501 # FIXME CoP
         metric_fn_direct_configurations: List[MetricComputationConfiguration] = []
         metric_fn_bundle_configurations: List[MetricComputationConfiguration] = []
 
@@ -428,7 +412,7 @@ class ExecutionEngine(ABC):
         ]
         metric_class: MetricProvider
         metric_fn: Union[Callable, None]
-        metric_aggregate_fn: sa.func | F
+        metric_aggregate_fn: sa.func | F  # type: ignore[valid-type] # FIXME CoP
         metric_provider_kwargs: dict
         compute_domain_kwargs: dict
         accessor_domain_kwargs: dict
@@ -457,12 +441,10 @@ class ExecutionEngine(ABC):
                         metric_aggregate_fn,
                         compute_domain_kwargs,
                         accessor_domain_kwargs,
-                    ) = resolved_metric_dependencies_by_metric_name.pop(
-                        "metric_partial_fn"
-                    )
+                    ) = resolved_metric_dependencies_by_metric_name.pop("metric_partial_fn")
                 except KeyError as e:
                     raise gx_exceptions.MetricError(
-                        message=f'Missing metric dependency: {str(e)} for metric "{metric_to_resolve.metric_name}".'
+                        message=f'Missing metric dependency: {e!s} for metric "{metric_to_resolve.metric_name}".'  # noqa: E501 # FIXME CoP
                     )
 
                 metric_fn_bundle_configurations.append(
@@ -491,7 +473,7 @@ class ExecutionEngine(ABC):
     def _get_computed_metric_evaluation_dependencies_by_metric_name(
         self,
         metric_to_resolve: MetricConfiguration,
-        metrics: Dict[Tuple[str, str, str], MetricValue],
+        metrics: Dict[MetricConfigurationID, MetricValue],
     ) -> Dict[str, Union[MetricValue, Tuple[Any, dict, dict]]]:
         """
         Gathers resolved (already computed) evaluation dependencies of metric-to-resolve (not yet computed)
@@ -503,7 +485,7 @@ class ExecutionEngine(ABC):
 
         Returns:
             Dictionary keyed by "metric_name" with values as computed metric or partial bundling information tuple
-        """
+        """  # noqa: E501 # FIXME CoP
         metric_dependencies_by_metric_name: Dict[
             str, Union[MetricValue, Tuple[Any, dict, dict]]
         ] = {}
@@ -515,16 +497,14 @@ class ExecutionEngine(ABC):
             metric_configuration,
         ) in metric_to_resolve.metric_dependencies.items():
             if metric_configuration.id in metrics:
-                metric_dependencies_by_metric_name[metric_name] = metrics[
-                    metric_configuration.id
-                ]
+                metric_dependencies_by_metric_name[metric_name] = metrics[metric_configuration.id]
             elif self._caching and metric_configuration.id in self._metric_cache:  # type: ignore[operator] # TODO: update NoOpDict
                 metric_dependencies_by_metric_name[metric_name] = self._metric_cache[
                     metric_configuration.id
                 ]
             else:
                 raise gx_exceptions.MetricError(
-                    message=f'Missing metric dependency: "{metric_name}" for metric "{metric_to_resolve.metric_name}".'
+                    message=f'Missing metric dependency: "{metric_name}" for metric "{metric_to_resolve.metric_name}".'  # noqa: E501 # FIXME CoP
                 )
 
         return metric_dependencies_by_metric_name
@@ -533,7 +513,7 @@ class ExecutionEngine(ABC):
         self,
         metric_fn_direct_configurations: List[MetricComputationConfiguration],
         metric_fn_bundle_configurations: List[MetricComputationConfiguration],
-    ) -> Dict[Tuple[str, str, str], MetricValue]:
+    ) -> dict[MetricConfigurationID, MetricValue]:
         """
         This method processes directly-computable and bundled "MetricComputationConfiguration" objects.
 
@@ -543,32 +523,28 @@ class ExecutionEngine(ABC):
 
         Returns:
             resolved_metrics (Dict): a dictionary with the values for the metrics that have just been resolved.
-        """
-        resolved_metrics: Dict[Tuple[str, str, str], MetricValue] = {}
+        """  # noqa: E501 # FIXME CoP
+        resolved_metrics: dict[MetricConfigurationID, MetricValue] = {}
 
         metric_computation_configuration: MetricComputationConfiguration
 
         for metric_computation_configuration in metric_fn_direct_configurations:
             try:
-                resolved_metrics[
-                    metric_computation_configuration.metric_configuration.id
-                ] = metric_computation_configuration.metric_fn(
-                    **metric_computation_configuration.metric_provider_kwargs
+                resolved_metrics[metric_computation_configuration.metric_configuration.id] = (
+                    metric_computation_configuration.metric_fn(  # type: ignore[misc] # F not callable
+                        **metric_computation_configuration.metric_provider_kwargs
+                    )
                 )
             except Exception as e:
                 raise gx_exceptions.MetricResolutionError(
                     message=str(e),
-                    failed_metrics=(
-                        metric_computation_configuration.metric_configuration,
-                    ),
+                    failed_metrics=(metric_computation_configuration.metric_configuration,),
                 ) from e
 
         try:
             # an engine-specific way of computing metrics together
-            resolved_metric_bundle: Dict[
-                Tuple[str, str, str], MetricValue
-            ] = self.resolve_metric_bundle(
-                metric_fn_bundle=metric_fn_bundle_configurations
+            resolved_metric_bundle: dict[MetricConfigurationID, MetricValue] = (
+                self.resolve_metric_bundle(metric_fn_bundle=metric_fn_bundle_configurations)
             )
             resolved_metrics.update(resolved_metric_bundle)
         except Exception as e:
@@ -585,13 +561,13 @@ class ExecutionEngine(ABC):
 
         return resolved_metrics
 
-    def _split_domain_kwargs(
+    def _partition_domain_kwargs(
         self,
         domain_kwargs: Dict[str, Any],
         domain_type: Union[str, MetricDomainTypes],
         accessor_keys: Optional[Iterable[str]] = None,
-    ) -> SplitDomainKwargs:
-        """Split domain_kwargs for all Domain types into compute and accessor Domain kwargs.
+    ) -> PartitionDomainKwargs:
+        """Partition domain_kwargs for all Domain types into compute and accessor Domain kwargs.
 
         Args:
             domain_kwargs: A dictionary consisting of the Domain kwargs specifying which data to obtain
@@ -605,7 +581,7 @@ class ExecutionEngine(ABC):
         Returns:
             compute_domain_kwargs, accessor_domain_kwargs from domain_kwargs
             The union of compute_domain_kwargs, accessor_domain_kwargs is the input domain_kwargs
-        """
+        """  # noqa: E501 # FIXME CoP
         # Extracting value from enum if it is given for future computation
         domain_type = MetricDomainTypes(domain_type)
 
@@ -615,49 +591,47 @@ class ExecutionEngine(ABC):
             and accessor_keys is not None
             and len(list(accessor_keys)) > 0
         ):
-            logger.warning(
-                'Accessor keys ignored since Metric Domain Type is not "table"'
-            )
+            logger.warning('Accessor keys ignored since Metric Domain Type is not "table"')
 
-        split_domain_kwargs: SplitDomainKwargs
+        partition_domain_kwargs: PartitionDomainKwargs
         if domain_type == MetricDomainTypes.TABLE:
-            split_domain_kwargs = self._split_table_metric_domain_kwargs(
+            partition_domain_kwargs = self._partition_table_metric_domain_kwargs(
                 domain_kwargs, domain_type, accessor_keys
             )
 
         elif domain_type == MetricDomainTypes.COLUMN:
-            split_domain_kwargs = self._split_column_metric_domain_kwargs(
+            partition_domain_kwargs = self._partition_column_metric_domain_kwargs(
                 domain_kwargs,
                 domain_type,
             )
 
         elif domain_type == MetricDomainTypes.COLUMN_PAIR:
-            split_domain_kwargs = self._split_column_pair_metric_domain_kwargs(
+            partition_domain_kwargs = self._partition_column_pair_metric_domain_kwargs(
                 domain_kwargs,
                 domain_type,
             )
 
         elif domain_type == MetricDomainTypes.MULTICOLUMN:
-            split_domain_kwargs = self._split_multi_column_metric_domain_kwargs(
+            partition_domain_kwargs = self._partition_multi_column_metric_domain_kwargs(
                 domain_kwargs,
                 domain_type,
             )
         else:
             compute_domain_kwargs = copy.deepcopy(domain_kwargs)
             accessor_domain_kwargs: Dict[str, Any] = {}
-            split_domain_kwargs = SplitDomainKwargs(
+            partition_domain_kwargs = PartitionDomainKwargs(
                 compute_domain_kwargs, accessor_domain_kwargs
             )
 
-        return split_domain_kwargs
+        return partition_domain_kwargs
 
     @staticmethod
-    def _split_table_metric_domain_kwargs(
+    def _partition_table_metric_domain_kwargs(
         domain_kwargs: dict,
         domain_type: MetricDomainTypes,
         accessor_keys: Optional[Iterable[str]] = None,
-    ) -> SplitDomainKwargs:
-        """Split domain_kwargs for table Domain types into compute and accessor Domain kwargs.
+    ) -> PartitionDomainKwargs:
+        """Partition domain_kwargs for table Domain types into compute and accessor Domain kwargs.
 
         Args:
             domain_kwargs: A dictionary consisting of the Domain kwargs specifying which data to obtain
@@ -669,10 +643,10 @@ class ExecutionEngine(ABC):
         Returns:
             compute_domain_kwargs, accessor_domain_kwargs from domain_kwargs
             The union of compute_domain_kwargs, accessor_domain_kwargs is the input domain_kwargs
-        """
-        assert (
-            domain_type == MetricDomainTypes.TABLE
-        ), "This method only supports MetricDomainTypes.TABLE"
+        """  # noqa: E501 # FIXME CoP
+        assert domain_type == MetricDomainTypes.TABLE, (
+            "This method only supports MetricDomainTypes.TABLE"
+        )
 
         compute_domain_kwargs: Dict = copy.deepcopy(domain_kwargs)
         accessor_domain_kwargs: Dict = {}
@@ -695,17 +669,17 @@ class ExecutionEngine(ABC):
                     map(lambda element: f'"{element}"', unexpected_keys)
                 )
                 logger.warning(
-                    f"""Unexpected key(s) {unexpected_keys_str} found in domain_kwargs for Domain type "{domain_type.value}"."""
+                    f"""Unexpected key(s) {unexpected_keys_str} found in domain_kwargs for Domain type "{domain_type.value}"."""  # noqa: E501 # FIXME CoP
                 )
 
-        return SplitDomainKwargs(compute_domain_kwargs, accessor_domain_kwargs)
+        return PartitionDomainKwargs(compute_domain_kwargs, accessor_domain_kwargs)
 
     @staticmethod
-    def _split_column_metric_domain_kwargs(
+    def _partition_column_metric_domain_kwargs(
         domain_kwargs: dict,
         domain_type: MetricDomainTypes,
-    ) -> SplitDomainKwargs:
-        """Split domain_kwargs for column Domain types into compute and accessor Domain kwargs.
+    ) -> PartitionDomainKwargs:
+        """Partition domain_kwargs for column Domain types into compute and accessor Domain kwargs.
 
         Args:
             domain_kwargs: A dictionary consisting of the Domain kwargs specifying which data to obtain
@@ -715,29 +689,29 @@ class ExecutionEngine(ABC):
         Returns:
             compute_domain_kwargs, accessor_domain_kwargs from domain_kwargs
             The union of compute_domain_kwargs, accessor_domain_kwargs is the input domain_kwargs
-        """
-        assert (
-            domain_type == MetricDomainTypes.COLUMN
-        ), "This method only supports MetricDomainTypes.COLUMN"
+        """  # noqa: E501 # FIXME CoP
+        assert domain_type == MetricDomainTypes.COLUMN, (
+            "This method only supports MetricDomainTypes.COLUMN"
+        )
 
         compute_domain_kwargs: Dict = copy.deepcopy(domain_kwargs)
         accessor_domain_kwargs: Dict = {}
 
         if "column" not in compute_domain_kwargs:
-            raise gx_exceptions.GreatExpectationsError(
+            raise gx_exceptions.GreatExpectationsError(  # noqa: TRY003 # FIXME CoP
                 "Column not provided in compute_domain_kwargs"
             )
 
         accessor_domain_kwargs["column"] = compute_domain_kwargs.pop("column")
 
-        return SplitDomainKwargs(compute_domain_kwargs, accessor_domain_kwargs)
+        return PartitionDomainKwargs(compute_domain_kwargs, accessor_domain_kwargs)
 
     @staticmethod
-    def _split_column_pair_metric_domain_kwargs(
+    def _partition_column_pair_metric_domain_kwargs(
         domain_kwargs: dict,
         domain_type: MetricDomainTypes,
-    ) -> SplitDomainKwargs:
-        """Split domain_kwargs for column pair Domain types into compute and accessor Domain kwargs.
+    ) -> PartitionDomainKwargs:
+        """Partition domain_kwargs for column pair Domain types into compute and accessor Domain kwargs.
 
         Args:
             domain_kwargs: A dictionary consisting of the Domain kwargs specifying which data to obtain
@@ -747,30 +721,30 @@ class ExecutionEngine(ABC):
         Returns:
             compute_domain_kwargs, accessor_domain_kwargs from domain_kwargs
             The union of compute_domain_kwargs, accessor_domain_kwargs is the input domain_kwargs
-        """
-        assert (
-            domain_type == MetricDomainTypes.COLUMN_PAIR
-        ), "This method only supports MetricDomainTypes.COLUMN_PAIR"
+        """  # noqa: E501 # FIXME CoP
+        assert domain_type == MetricDomainTypes.COLUMN_PAIR, (
+            "This method only supports MetricDomainTypes.COLUMN_PAIR"
+        )
 
         compute_domain_kwargs: Dict = copy.deepcopy(domain_kwargs)
         accessor_domain_kwargs: Dict = {}
 
         if not ("column_A" in domain_kwargs and "column_B" in domain_kwargs):
-            raise gx_exceptions.GreatExpectationsError(
+            raise gx_exceptions.GreatExpectationsError(  # noqa: TRY003 # FIXME CoP
                 "column_A or column_B not found within domain_kwargs"
             )
 
         accessor_domain_kwargs["column_A"] = compute_domain_kwargs.pop("column_A")
         accessor_domain_kwargs["column_B"] = compute_domain_kwargs.pop("column_B")
 
-        return SplitDomainKwargs(compute_domain_kwargs, accessor_domain_kwargs)
+        return PartitionDomainKwargs(compute_domain_kwargs, accessor_domain_kwargs)
 
     @staticmethod
-    def _split_multi_column_metric_domain_kwargs(
+    def _partition_multi_column_metric_domain_kwargs(
         domain_kwargs: dict,
         domain_type: MetricDomainTypes,
-    ) -> SplitDomainKwargs:
-        """Split domain_kwargs for multicolumn Domain types into compute and accessor Domain kwargs.
+    ) -> PartitionDomainKwargs:
+        """Partition domain_kwargs for multicolumn Domain types into compute and accessor Domain kwargs.
 
         Args:
             domain_kwargs: A dictionary consisting of the Domain kwargs specifying which data to obtain
@@ -780,26 +754,24 @@ class ExecutionEngine(ABC):
         Returns:
             compute_domain_kwargs, accessor_domain_kwargs from domain_kwargs
             The union of compute_domain_kwargs, accessor_domain_kwargs is the input domain_kwargs
-        """
-        assert (
-            domain_type == MetricDomainTypes.MULTICOLUMN
-        ), "This method only supports MetricDomainTypes.MULTICOLUMN"
+        """  # noqa: E501 # FIXME CoP
+        assert domain_type == MetricDomainTypes.MULTICOLUMN, (
+            "This method only supports MetricDomainTypes.MULTICOLUMN"
+        )
 
         compute_domain_kwargs: Dict = copy.deepcopy(domain_kwargs)
         accessor_domain_kwargs: Dict = {}
 
         if "column_list" not in domain_kwargs:
-            raise gx_exceptions.GreatExpectationsError(
-                "column_list not found within domain_kwargs"
-            )
+            raise gx_exceptions.GreatExpectationsError("column_list not found within domain_kwargs")  # noqa: TRY003 # FIXME CoP
 
         column_list = compute_domain_kwargs.pop("column_list")
 
-        if len(column_list) < 2:
-            raise gx_exceptions.GreatExpectationsError(
+        if len(column_list) < 2:  # noqa: PLR2004 # FIXME CoP
+            raise gx_exceptions.GreatExpectationsError(  # noqa: TRY003 # FIXME CoP
                 "column_list must contain at least 2 columns"
             )
 
         accessor_domain_kwargs["column_list"] = column_list
 
-        return SplitDomainKwargs(compute_domain_kwargs, accessor_domain_kwargs)
+        return PartitionDomainKwargs(compute_domain_kwargs, accessor_domain_kwargs)
