@@ -1,7 +1,12 @@
-import pandas as pd
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
 
 from great_expectations.core.batch import BatchData
 
+if TYPE_CHECKING:
+    import pandas as pd
+
 
 class PandasBatchData(BatchData):
     def __init__(self, execution_engine, dataframe: pd.DataFrame) -> None:
