@@ -1,85 +1,74 @@
+from __future__ import annotations
+
 import datetime
 import hashlib
 import logging
 import pickle
-import warnings
 from functools import partial
 from io import BytesIO
-from typing import Any, Callable, Dict, Iterable, Optional, Tuple, Union, cast, overload
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Callable,
+    Dict,
+    Iterable,
+    Optional,
+    Tuple,
+    Union,
+    cast,
+    overload,
+)
 
 import pandas as pd
-from typing_extensions import TypeAlias
 
 import great_expectations.exceptions as gx_exceptions
-from great_expectations.core._docs_decorators import public_api
+from great_expectations.compatibility import aws, azure, google
+from great_expectations.compatibility.sqlalchemy_and_pandas import (
+    execute_pandas_reader_fn,
+)
+from great_expectations.compatibility.typing_extensions import override
 from great_expectations.core.batch import BatchMarkers
 from great_expectations.core.batch_spec import (
     AzureBatchSpec,
     BatchSpec,
+    FabricBatchSpec,
     GCSBatchSpec,
     PandasBatchSpec,
+    PandasBatchSpecProtocol,
     PathBatchSpec,
     RuntimeDataBatchSpec,
     S3BatchSpec,
 )
 from great_expectations.core.metric_domain_types import (
-    MetricDomainTypes,  # noqa: TCH001
+    MetricDomainTypes,  # noqa: TC001 # FIXME CoP
 )
 from great_expectations.core.util import AzureUrl, GCSUrl, S3Url, sniff_s3_compression
 from great_expectations.execution_engine import ExecutionEngine
 from great_expectations.execution_engine.execution_engine import (
-    SplitDomainKwargs,  # noqa: TCH001
+    PartitionDomainKwargs,  # noqa: TC001 # FIXME CoP
 )
 from great_expectations.execution_engine.pandas_batch_data import PandasBatchData
-from great_expectations.execution_engine.split_and_sample.pandas_data_sampler import (
+from great_expectations.execution_engine.partition_and_sample.pandas_data_partitioner import (
+    PandasDataPartitioner,
+)
+from great_expectations.execution_engine.partition_and_sample.pandas_data_sampler import (
     PandasDataSampler,
 )
-from great_expectations.execution_engine.split_and_sample.pandas_data_splitter import (
-    PandasDataSplitter,
-)
+from great_expectations.expectations.model_field_types import CONDITION_PARSER_PANDAS
+
+if TYPE_CHECKING:
+    from typing_extensions import TypeAlias
+
+    from great_expectations.validator.metric_configuration import MetricConfigurationID
 
 logger = logging.getLogger(__name__)
 
-try:
-    import boto3
-    from botocore.exceptions import ClientError, ParamValidationError
-except ImportError:
-    boto3 = None
-    ClientError = None
-    ParamValidationError = None
-    logger.debug(
-        "Unable to load AWS connection object; install optional boto3 dependency for support"
-    )
-
-try:
-    from azure.storage.blob import BlobServiceClient
-except ImportError:
-    BlobServiceClient = None
-    logger.debug(
-        "Unable to load Azure connection object; install optional azure dependency for support"
-    )
-
-try:
-    from google.api_core.exceptions import GoogleAPIError
-    from google.auth.exceptions import DefaultCredentialsError
-    from google.cloud import storage
-    from google.oauth2 import service_account
-except ImportError:
-    storage = None
-    service_account = None
-    GoogleAPIError = None
-    DefaultCredentialsError = None
-    logger.debug(
-        "Unable to load GCS connection object; install optional google dependency for support"
-    )
-
 
 HASH_THRESHOLD = 1e9
 
 DataFrameFactoryFn: TypeAlias = Callable[..., pd.DataFrame]
 
 
-@public_api
 class PandasExecutionEngine(ExecutionEngine):
     """PandasExecutionEngine instantiates the ExecutionEngine API to support computations using Pandas.
 
@@ -113,7 +102,7 @@ class PandasExecutionEngine(ExecutionEngine):
             expectation_completeness: Complete
 
     --ge-feature-maturity-info--
-    """
+    """  # noqa: E501 # FIXME CoP
 
     recognized_batch_spec_defaults = {
         "reader_method",
@@ -131,7 +120,7 @@ class PandasExecutionEngine(ExecutionEngine):
         # Instantiate cloud provider clients as None at first.
         # They will be instantiated if/when passed cloud-specific in BatchSpec is passed in
         self._s3 = None
-        self._azure = None
+        self._azure: azure.BlobServiceClient | None = None
         self._gcs = None
 
         super().__init__(*args, **kwargs)
@@ -145,26 +134,26 @@ class PandasExecutionEngine(ExecutionEngine):
             }
         )
 
-        self._data_splitter = PandasDataSplitter()
+        self._data_partitioner = PandasDataPartitioner()
         self._data_sampler = PandasDataSampler()
 
     def _instantiate_azure_client(self) -> None:
-        azure_options = self.config.get("azure_options", {})
-        try:
-            if "conn_str" in azure_options:
-                self._azure = BlobServiceClient.from_connection_string(**azure_options)
-            else:
-                self._azure = BlobServiceClient(**azure_options)
-        except (TypeError, AttributeError):
-            self._azure = None
+        self._azure = None
+        if azure.BlobServiceClient:  # type: ignore[truthy-function] # False if NotImported
+            azure_options = self.config.get("azure_options", {})
+            try:
+                if "conn_str" in azure_options:
+                    self._azure = azure.BlobServiceClient.from_connection_string(**azure_options)
+                else:
+                    self._azure = azure.BlobServiceClient(**azure_options)
+            except (TypeError, AttributeError):
+                # If exception occurs, then "self._azure = None" remains in effect.
+                pass
 
     def _instantiate_s3_client(self) -> None:
-        # Try initializing cloud provider client. If unsuccessful, we'll catch it when/if a BatchSpec is passed in.
+        # Try initializing cloud provider client. If unsuccessful, we'll die here.
         boto3_options = self.config.get("boto3_options", {})
-        try:
-            self._s3 = boto3.client("s3", **boto3_options)
-        except (TypeError, AttributeError):
-            self._s3 = None
+        self._s3 = aws.boto3.client("s3", **boto3_options)
 
     def _instantiate_gcs_client(self) -> None:
         """
@@ -175,43 +164,49 @@ class PandasExecutionEngine(ExecutionEngine):
             2. passing in explicit credentials via gcs_options
             3. running Great Expectations from within a GCP container, at which you would be able to create a Client
                 without passing in an additional environment variable or explicit credentials
-        """
+        """  # noqa: E501 # FIXME CoP
         gcs_options = self.config.get("gcs_options", {})
         try:
             credentials = None  # If configured with gcloud CLI / env vars
             if "filename" in gcs_options:
                 filename = gcs_options.pop("filename")
-                credentials = service_account.Credentials.from_service_account_file(
+                credentials = google.service_account.Credentials.from_service_account_file(
                     filename=filename
                 )
             elif "info" in gcs_options:
                 info = gcs_options.pop("info")
-                credentials = service_account.Credentials.from_service_account_info(
+                credentials = google.service_account.Credentials.from_service_account_info(
                     info=info
                 )
-            self._gcs = storage.Client(credentials=credentials, **gcs_options)
-        except (TypeError, AttributeError, DefaultCredentialsError):
+            self._gcs = google.storage.Client(credentials=credentials, **gcs_options)
+        # This exception handling causes a TypeError if google dependency not installed
+        except (TypeError, AttributeError, google.DefaultCredentialsError):
             self._gcs = None
 
+    @override
     def configure_validator(self, validator) -> None:
         super().configure_validator(validator)
         validator.expose_dataframe_methods = True
 
+    @override
     def load_batch_data(
-        self, batch_id: str, batch_data: Union[PandasBatchData, pd.DataFrame]
+        self,
+        batch_id: str,
+        batch_data: Union[PandasBatchData, pd.DataFrame],  # type: ignore[override] # FIXME CoP
     ) -> None:
         if isinstance(batch_data, pd.DataFrame):
             batch_data = PandasBatchData(self, batch_data)
         elif not isinstance(batch_data, PandasBatchData):
-            raise gx_exceptions.GreatExpectationsError(
-                "PandasExecutionEngine requires batch data that is either a DataFrame or a PandasBatchData object"
+            raise gx_exceptions.GreatExpectationsError(  # noqa: TRY003 # FIXME CoP
+                "PandasExecutionEngine requires batch data that is either a DataFrame or a PandasBatchData object"  # noqa: E501 # FIXME CoP
             )
 
         super().load_batch_data(batch_id=batch_id, batch_data=batch_data)
 
-    def get_batch_data_and_markers(  # noqa: C901 - 22
-        self, batch_spec: BatchSpec
-    ) -> Tuple[Any, BatchMarkers]:  # batch_data
+    @override
+    def get_batch_data_and_markers(  # noqa: C901, PLR0912, PLR0915 # FIXME CoP
+        self, batch_spec: BatchSpec | PandasBatchSpecProtocol
+    ) -> Tuple[PandasBatchData, BatchMarkers]:  # batch_data
         # We need to build a batch_markers to be used in the dataframe
         batch_markers = BatchMarkers(
             {
@@ -226,9 +221,9 @@ class PandasExecutionEngine(ExecutionEngine):
             # batch_data != None is already checked when RuntimeDataBatchSpec is instantiated
             batch_data = batch_spec.batch_data
             if isinstance(batch_data, str):
-                raise gx_exceptions.ExecutionEngineError(
+                raise gx_exceptions.ExecutionEngineError(  # noqa: TRY003 # FIXME CoP
                     f"""PandasExecutionEngine has been passed a string type batch_data, "{batch_data}", which is illegal.  Please check your config.
-"""
+"""  # noqa: E501 # FIXME CoP
                 )
 
             if isinstance(batch_spec.batch_data, pd.DataFrame):
@@ -236,8 +231,8 @@ class PandasExecutionEngine(ExecutionEngine):
             elif isinstance(batch_spec.batch_data, PandasBatchData):
                 df = batch_spec.batch_data.dataframe
             else:
-                raise ValueError(
-                    "RuntimeDataBatchSpec must provide a Pandas DataFrame or PandasBatchData object."
+                raise ValueError(  # noqa: TRY003, TRY004 # FIXME CoP
+                    "RuntimeDataBatchSpec must provide a Pandas DataFrame or PandasBatchData object."  # noqa: E501 # FIXME CoP
                 )
 
             batch_spec.batch_data = "PandasDataFrame"
@@ -245,34 +240,28 @@ class PandasExecutionEngine(ExecutionEngine):
         elif isinstance(batch_spec, S3BatchSpec):
             if self._s3 is None:
                 self._instantiate_s3_client()
-            # if we were not able to instantiate S3 client, then raise error
-            if self._s3 is None:
-                raise gx_exceptions.ExecutionEngineError(
-                    """PandasExecutionEngine has been passed a S3BatchSpec,
-                        but the ExecutionEngine does not have a boto3 client configured. Please check your config."""
-                )
             s3_engine = self._s3
             try:
                 reader_method: str = batch_spec.reader_method
                 reader_options: dict = batch_spec.reader_options or {}
                 path: str = batch_spec.path
                 s3_url = S3Url(path)
-                if "compression" not in reader_options.keys():
+                if "compression" not in reader_options:
                     inferred_compression_param = sniff_s3_compression(s3_url)
                     if inferred_compression_param is not None:
                         reader_options["compression"] = inferred_compression_param
-                s3_object = s3_engine.get_object(Bucket=s3_url.bucket, Key=s3_url.key)
-            except (ParamValidationError, ClientError) as error:
-                raise gx_exceptions.ExecutionEngineError(
-                    f"""PandasExecutionEngine encountered the following error while trying to read data from S3 Bucket: {error}"""
+                if s3_engine:
+                    s3_object: dict = s3_engine.get_object(Bucket=s3_url.bucket, Key=s3_url.key)
+            except (
+                aws.exceptions.ParamValidationError,
+                aws.exceptions.ClientError,
+            ) as error:
+                raise gx_exceptions.ExecutionEngineError(  # noqa: TRY003 # FIXME CoP
+                    f"""PandasExecutionEngine encountered the following error while trying to read data from S3 Bucket: {error}"""  # noqa: E501 # FIXME CoP
                 )
-            logger.debug(
-                f"Fetching s3 object. Bucket: {s3_url.bucket} Key: {s3_url.key}"
-            )
-            reader_fn: DataFrameFactoryFn = self._get_reader_fn(
-                reader_method, s3_url.key
-            )
-            buf = BytesIO(s3_object["Body"].read())
+            logger.debug(f"Fetching s3 object. Bucket: {s3_url.bucket} Key: {s3_url.key}")
+            reader_fn: DataFrameFactoryFn = self._get_reader_fn(reader_method, s3_url.key)
+            buf = BytesIO(s3_object["Body"].read())  # type: ignore[possibly-undefined] # FIXME
             buf.seek(0)
             df = reader_fn(buf, **reader_options)
 
@@ -281,9 +270,9 @@ class PandasExecutionEngine(ExecutionEngine):
                 self._instantiate_azure_client()
             # if we were not able to instantiate Azure client, then raise error
             if self._azure is None:
-                raise gx_exceptions.ExecutionEngineError(
+                raise gx_exceptions.ExecutionEngineError(  # noqa: TRY003 # FIXME CoP
                     """PandasExecutionEngine has been passed a AzureBatchSpec,
-                        but the ExecutionEngine does not have an Azure client configured. Please check your config."""
+                        but the ExecutionEngine does not have an Azure client configured. Please check your config."""  # noqa: E501 # FIXME CoP
                 )
             azure_engine = self._azure
             reader_method = batch_spec.reader_method
@@ -307,9 +296,9 @@ class PandasExecutionEngine(ExecutionEngine):
                 self._instantiate_gcs_client()
             # if we were not able to instantiate GCS client, then raise error
             if self._gcs is None:
-                raise gx_exceptions.ExecutionEngineError(
+                raise gx_exceptions.ExecutionEngineError(  # noqa: TRY003 # FIXME CoP
                     """PandasExecutionEngine has been passed a GCSBatchSpec,
-                        but the ExecutionEngine does not have an GCS client configured. Please check your config."""
+                        but the ExecutionEngine does not have an GCS client configured. Please check your config."""  # noqa: E501 # FIXME CoP
                 )
             gcs_engine = self._gcs
             gcs_url = GCSUrl(batch_spec.path)
@@ -318,13 +307,11 @@ class PandasExecutionEngine(ExecutionEngine):
             try:
                 gcs_bucket = gcs_engine.get_bucket(gcs_url.bucket)
                 gcs_blob = gcs_bucket.blob(gcs_url.blob)
-                logger.debug(
-                    f"Fetching GCS blob. Bucket: {gcs_url.bucket} Blob: {gcs_url.blob}"
-                )
-            except GoogleAPIError as error:
-                raise gx_exceptions.ExecutionEngineError(
+                logger.debug(f"Fetching GCS blob. Bucket: {gcs_url.bucket} Blob: {gcs_url.blob}")
+            except google.GoogleAPIError as error:
+                raise gx_exceptions.ExecutionEngineError(  # noqa: TRY003 # FIXME CoP
                     f"""PandasExecutionEngine encountered the following error while trying to read data from GCS \
-Bucket: {error}"""
+Bucket: {error}"""  # noqa: E501 # FIXME CoP
                 )
             reader_fn = self._get_reader_fn(reader_method, gcs_url.blob)
             buf = BytesIO(gcs_blob.download_as_bytes())
@@ -343,15 +330,31 @@ Bucket: {error}"""
             reader_method = batch_spec.reader_method
             reader_options = batch_spec.reader_options
             reader_fn = self._get_reader_fn(reader_method)
-            df = reader_fn(**reader_options)
+            reader_fn_result: pd.DataFrame | list[pd.DataFrame] = execute_pandas_reader_fn(
+                reader_fn, reader_options
+            )
+            if isinstance(reader_fn_result, list):
+                if len(reader_fn_result) > 1:
+                    raise gx_exceptions.ExecutionEngineError(  # noqa: TRY003 # FIXME CoP
+                        "Pandas reader method must return a single DataFrame, "
+                        f'but "{reader_method}" returned {len(reader_fn_result)} DataFrames.'
+                    )
+                else:
+                    df = reader_fn_result[0]
+            else:
+                df = reader_fn_result
+
+        elif isinstance(batch_spec, FabricBatchSpec):
+            reader_fn = batch_spec.get_reader_function()
+            df = reader_fn(**batch_spec.reader_options)
 
         else:
-            raise gx_exceptions.BatchSpecError(
-                f"""batch_spec must be of type RuntimeDataBatchSpec, PathBatchSpec, S3BatchSpec, or AzureBatchSpec, \
-not {batch_spec.__class__.__name__}"""
+            raise gx_exceptions.BatchSpecError(  # noqa: TRY003 # FIXME CoP
+                f"""batch_spec must be of type RuntimeDataBatchSpec, PandasBatchSpec, PathBatchSpec, S3BatchSpec, AzureBatchSpec or FabricBatchSpec \
+not {batch_spec.__class__.__name__}"""  # noqa: E501 # FIXME CoP
             )
 
-        df = self._apply_splitting_and_sampling_methods(batch_spec, df)
+        df = self._apply_partitioning_and_sampling_methods(batch_spec, df)  # type: ignore[arg-type] # FIXME CoP
         if df.memory_usage().sum() < HASH_THRESHOLD:
             batch_markers["pandas_data_fingerprint"] = hash_pandas_dataframe(df)
 
@@ -359,21 +362,25 @@ not {batch_spec.__class__.__name__}"""
 
         return typed_batch_data, batch_markers
 
-    def _apply_splitting_and_sampling_methods(self, batch_spec, batch_data):
-        splitter_method_name: Optional[str] = batch_spec.get("splitter_method")
-        if splitter_method_name:
-            splitter_fn: Callable = self._data_splitter.get_splitter_method(
-                splitter_method_name
-            )
-            splitter_kwargs: dict = batch_spec.get("splitter_kwargs") or {}
-            batch_data = splitter_fn(batch_data, **splitter_kwargs)
+    def _apply_partitioning_and_sampling_methods(
+        self,
+        batch_spec: BatchSpec | PandasBatchSpecProtocol,
+        batch_data: PandasBatchData,
+    ):
+        # partitioning and sampling not supported for FabricBatchSpec
+        if isinstance(batch_spec, BatchSpec):
+            partitioner_method_name: Optional[str] = batch_spec.get("partitioner_method")
+            if partitioner_method_name:
+                partitioner_fn: Callable = self._data_partitioner.get_partitioner_method(
+                    partitioner_method_name
+                )
+                partitioner_kwargs: dict = batch_spec.get("partitioner_kwargs") or {}
+                batch_data = partitioner_fn(batch_data, **partitioner_kwargs)
 
-        sampler_method_name: Optional[str] = batch_spec.get("sampling_method")
-        if sampler_method_name:
-            sampling_fn: Callable = self._data_sampler.get_sampler_method(
-                sampler_method_name
-            )
-            batch_data = sampling_fn(batch_data, batch_spec)
+            sampler_method_name: Optional[str] = batch_spec.get("sampling_method")
+            if sampler_method_name:
+                sampling_fn: Callable = self._data_sampler.get_sampler_method(sampler_method_name)
+                batch_data = sampling_fn(batch_data, batch_spec)
 
         return batch_data
 
@@ -381,18 +388,18 @@ not {batch_spec.__class__.__name__}"""
     def dataframe(self) -> pd.DataFrame:
         """Tests whether or not a Batch has been loaded. If the loaded batch does not exist, raises a
         ValueError Exception
-        """
+        """  # noqa: E501 # FIXME CoP
         # Changed to is None because was breaking prior
         if self.batch_manager.active_batch_data is None:
-            raise ValueError(
+            raise ValueError(  # noqa: TRY003 # FIXME CoP
                 "Batch has not been loaded - please run load_batch_data() to load a batch."
             )
 
-        return cast(PandasBatchData, self.batch_manager.active_batch_data).dataframe
+        return cast("PandasBatchData", self.batch_manager.active_batch_data).dataframe
 
     # NOTE Abe 20201105: Any reason this shouldn't be a private method?
     @staticmethod
-    def guess_reader_method_from_path(path: str):
+    def guess_reader_method_from_path(path: str):  # noqa: C901, PLR0911 # FIXME CoP
         """Helper method for deciding which reader to use to read in a certain path.
 
         Args:
@@ -405,9 +412,7 @@ not {batch_spec.__class__.__name__}"""
         path = path.lower()
         if path.endswith(".csv") or path.endswith(".tsv"):
             return {"reader_method": "read_csv"}
-        elif (
-            path.endswith(".parquet") or path.endswith(".parq") or path.endswith(".pqt")
-        ):
+        elif path.endswith(".parquet") or path.endswith(".parq") or path.endswith(".pqt"):
             return {"reader_method": "read_parquet"}
         elif path.endswith(".xlsx") or path.endswith(".xls"):
             return {"reader_method": "read_excel"}
@@ -426,21 +431,17 @@ not {batch_spec.__class__.__name__}"""
             return {"reader_method": "read_sas"}
 
         else:
-            raise gx_exceptions.ExecutionEngineError(
+            raise gx_exceptions.ExecutionEngineError(  # noqa: TRY003 # FIXME CoP
                 f'Unable to determine reader method from path: "{path}".'
             )
 
     @overload
     def _get_reader_fn(
         self, reader_method: str = ..., path: Optional[str] = ...
-    ) -> DataFrameFactoryFn:
-        ...
+    ) -> DataFrameFactoryFn: ...
 
     @overload
-    def _get_reader_fn(
-        self, reader_method: None = ..., path: str = ...
-    ) -> DataFrameFactoryFn:
-        ...
+    def _get_reader_fn(self, reader_method: None = ..., path: str = ...) -> DataFrameFactoryFn: ...
 
     def _get_reader_fn(
         self, reader_method: Optional[str] = None, path: Optional[str] = None
@@ -455,9 +456,9 @@ not {batch_spec.__class__.__name__}"""
         Returns:
             ReaderMethod to use for the filepath
 
-        """
+        """  # noqa: E501 # FIXME CoP
         if reader_method is None and path is None:
-            raise gx_exceptions.ExecutionEngineError(
+            raise gx_exceptions.ExecutionEngineError(  # noqa: TRY003 # FIXME CoP
                 "Unable to determine pandas reader function without reader_method or path."
             )
 
@@ -475,20 +476,17 @@ not {batch_spec.__class__.__name__}"""
                 reader_fn = partial(reader_fn, **reader_options)
             return reader_fn
         except AttributeError:
-            raise gx_exceptions.ExecutionEngineError(
+            raise gx_exceptions.ExecutionEngineError(  # noqa: TRY003 # FIXME CoP
                 f'Unable to find reader_method "{reader_method}" in pandas.'
             )
 
-    def resolve_metric_bundle(
-        self, metric_fn_bundle
-    ) -> Dict[Tuple[str, str, str], Any]:
-        """Resolve a bundle of metrics with the same compute Domain as part of a single trip to the compute engine."""
-        return (
-            {}
-        )  # This is NO-OP for "PandasExecutionEngine" (no bundling for direct execution computational backend).
+    @override
+    def resolve_metric_bundle(self, metric_fn_bundle) -> dict[MetricConfigurationID, Any]:
+        """Resolve a bundle of metrics with the same compute Domain as part of a single trip to the compute engine."""  # noqa: E501 # FIXME CoP
+        return {}  # This is NO-OP for "PandasExecutionEngine" (no bundling for direct execution computational backend).  # noqa: E501 # FIXME CoP
 
-    @public_api
-    def get_domain_records(  # noqa: C901 - 17
+    @override
+    def get_domain_records(  # noqa: C901, PLR0912 # FIXME CoP
         self,
         domain_kwargs: dict,
     ) -> pd.DataFrame:
@@ -499,10 +497,10 @@ not {batch_spec.__class__.__name__}"""
 
         Returns:
             A DataFrame (the data on which to compute returned in the format of a Pandas DataFrame)
-        """
+        """  # noqa: E501 # FIXME CoP
         table = domain_kwargs.get("table", None)
         if table:
-            raise ValueError(
+            raise ValueError(  # noqa: TRY003 # FIXME CoP
                 "PandasExecutionEngine does not currently support multiple named tables."
             )
 
@@ -510,20 +508,18 @@ not {batch_spec.__class__.__name__}"""
         if batch_id is None:
             # We allow no batch id specified if there is only one batch
             if self.batch_manager.active_batch_data_id is not None:
-                data = cast(
-                    PandasBatchData, self.batch_manager.active_batch_data
-                ).dataframe
+                data = cast("PandasBatchData", self.batch_manager.active_batch_data).dataframe
             else:
-                raise gx_exceptions.ValidationError(
+                raise gx_exceptions.ValidationError(  # noqa: TRY003 # FIXME CoP
                     "No batch is specified, but could not identify a loaded batch."
                 )
-        else:
+        else:  # noqa: PLR5501 # FIXME CoP
             if batch_id in self.batch_manager.batch_data_cache:
                 data = cast(
-                    PandasBatchData, self.batch_manager.batch_data_cache[batch_id]
+                    "PandasBatchData", self.batch_manager.batch_data_cache[batch_id]
                 ).dataframe
             else:
-                raise gx_exceptions.ValidationError(
+                raise gx_exceptions.ValidationError(  # noqa: TRY003 # FIXME CoP
                     f"Unable to find batch with batch_id {batch_id}"
                 )
 
@@ -532,15 +528,12 @@ not {batch_spec.__class__.__name__}"""
         if row_condition:
             condition_parser = domain_kwargs.get("condition_parser", None)
 
-            # Ensuring proper condition parser has been provided
-            if condition_parser not in ["python", "pandas"]:
-                raise ValueError(
-                    "condition_parser is required when setting a row_condition,"
-                    " and must be 'python' or 'pandas'"
-                )
-            else:
-                # Querying row condition
+            if condition_parser == CONDITION_PARSER_PANDAS:
                 data = data.query(row_condition, parser=condition_parser)
+            else:
+                raise ValueError(  # noqa: TRY003 # FIXME CoP
+                    "condition_parser for Pandas is required when setting a row_condition."
+                )
 
         if "column" in domain_kwargs:
             return data
@@ -568,21 +561,9 @@ not {batch_spec.__class__.__name__}"""
                     how="any",
                     subset=[column_A_name, column_B_name],
                 )
-            else:
-                if ignore_row_if not in ["neither", "never"]:
-                    raise ValueError(
-                        f'Unrecognized value of ignore_row_if ("{ignore_row_if}").'
-                    )
-
-                if ignore_row_if == "never":
-                    # deprecated-v0.13.29
-                    warnings.warn(
-                        f"""The correct "no-action" value of the "ignore_row_if" directive for the column pair case is \
-"neither" (the use of "{ignore_row_if}" is deprecated as of v0.13.29 and will be removed in v0.16).  \
-Please use "neither" instead.
-""",
-                        DeprecationWarning,
-                    )
+            else:  # noqa: PLR5501 # FIXME CoP
+                if ignore_row_if != "neither":
+                    raise ValueError(f'Unrecognized value of ignore_row_if ("{ignore_row_if}").')  # noqa: TRY003 # FIXME CoP
 
             return data
 
@@ -602,17 +583,15 @@ Please use "neither" instead.
                     how="any",
                     subset=column_list,
                 )
-            else:
+            else:  # noqa: PLR5501 # FIXME CoP
                 if ignore_row_if != "never":
-                    raise ValueError(
-                        f'Unrecognized value of ignore_row_if ("{ignore_row_if}").'
-                    )
+                    raise ValueError(f'Unrecognized value of ignore_row_if ("{ignore_row_if}").')  # noqa: TRY003 # FIXME CoP
 
             return data
 
         return data
 
-    @public_api
+    @override
     def get_compute_domain(
         self,
         domain_kwargs: dict,
@@ -639,20 +618,20 @@ Please use "neither" instead.
               - a dictionary of compute_domain_kwargs, describing the DataFrame
               - a dictionary of accessor_domain_kwargs, describing any accessors needed to
                 identify the Domain within the compute domain
-        """
-        table: str = domain_kwargs.get("table", None)
+        """  # noqa: E501 # FIXME CoP
+        table: Optional[str] = domain_kwargs.get("table", None)
         if table:
-            raise ValueError(
+            raise ValueError(  # noqa: TRY003 # FIXME CoP
                 "PandasExecutionEngine does not currently support multiple named tables."
             )
 
         data: pd.DataFrame = self.get_domain_records(domain_kwargs=domain_kwargs)
 
-        split_domain_kwargs: SplitDomainKwargs = self._split_domain_kwargs(
+        partition_domain_kwargs: PartitionDomainKwargs = self._partition_domain_kwargs(
             domain_kwargs, domain_type, accessor_keys
         )
 
-        return data, split_domain_kwargs.compute, split_domain_kwargs.accessor
+        return data, partition_domain_kwargs.compute, partition_domain_kwargs.accessor
 
 
 def hash_pandas_dataframe(df):
