@@ -8,7 +8,7 @@ from .expect_column_distinct_values_to_equal_set import (
     ExpectColumnDistinctValuesToEqualSet,
 )
 from .expect_column_kl_divergence_to_be_less_than import (
-    ExpectColumnKlDivergenceToBeLessThan,
+    ExpectColumnKLDivergenceToBeLessThan,
 )
 from .expect_column_max_to_be_between import ExpectColumnMaxToBeBetween
 from .expect_column_mean_to_be_between import ExpectColumnMeanToBeBetween
@@ -17,14 +17,14 @@ from .expect_column_min_to_be_between import ExpectColumnMinToBeBetween
 from .expect_column_most_common_value_to_be_in_set import (
     ExpectColumnMostCommonValueToBeInSet,
 )
-from .expect_column_pair_cramers_phi_value_to_be_less_than import (
-    ExpectColumnPairCramersPhiValueToBeLessThan,
-)
 from .expect_column_pair_values_a_to_be_greater_than_b import (
     ExpectColumnPairValuesAToBeGreaterThanB,
 )
 from .expect_column_pair_values_to_be_equal import ExpectColumnPairValuesToBeEqual
 from .expect_column_pair_values_to_be_in_set import ExpectColumnPairValuesToBeInSet
+from .expect_column_proportion_of_non_null_values_to_be_between import (
+    ExpectColumnProportionOfNonNullValuesToBeBetween,
+)
 from .expect_column_proportion_of_unique_values_to_be_between import (
     ExpectColumnProportionOfUniqueValuesToBeBetween,
 )
@@ -87,6 +87,7 @@ from .expect_column_values_to_not_match_regex_list import (
 from .expect_compound_columns_to_be_unique import ExpectCompoundColumnsToBeUnique
 from .expect_multicolumn_sum_to_equal import ExpectMulticolumnSumToEqual
 from .expect_multicolumn_values_to_be_unique import ExpectMulticolumnValuesToBeUnique
+from .expect_query_results_to_match_comparison import ExpectQueryResultsToMatchComparison
 from .expect_select_column_values_to_be_unique_within_record import (
     ExpectSelectColumnValuesToBeUniqueWithinRecord,
 )
@@ -101,3 +102,4 @@ from .expect_table_row_count_to_equal import ExpectTableRowCountToEqual
 from .expect_table_row_count_to_equal_other_table import (
     ExpectTableRowCountToEqualOtherTable,
 )
+from .unexpected_rows_expectation import UnexpectedRowsExpectation
