@@ -1,19 +1,21 @@
+from __future__ import annotations
+
 from numbers import Number
-from typing import TYPE_CHECKING, Dict, List, Optional, Union
+from typing import TYPE_CHECKING, Any, ClassVar, Dict, List, Optional, Type, Union
 
 import numpy as np
 
-from great_expectations.core import (
-    ExpectationConfiguration,  # noqa: TCH001
-    ExpectationValidationResult,  # noqa: TCH001
+from great_expectations.compatibility import pydantic
+from great_expectations.core.suite_parameters import (
+    SuiteParameterDict,  # noqa: TC001 # FIXME CoP
 )
-from great_expectations.core._docs_decorators import public_api
 from great_expectations.exceptions import InvalidExpectationConfigurationError
-from great_expectations.execution_engine import ExecutionEngine  # noqa: TCH001
 from great_expectations.expectations.expectation import (
-    ColumnExpectation,
-    render_evaluation_parameter_string,
+    COLUMN_DESCRIPTION,
+    ColumnAggregateExpectation,
+    render_suite_parameter_string,
 )
+from great_expectations.expectations.metadata_types import DataQualityIssues, SupportedDataSources
 from great_expectations.render import (
     AtomicDiagnosticRendererType,
     AtomicPrescriptiveRendererType,
@@ -36,81 +38,83 @@ from great_expectations.render.util import (
     parse_row_condition_string_pandas_engine,
     substitute_none_for_missing,
 )
-from great_expectations.rule_based_profiler.config import (
-    ParameterBuilderConfig,
-    RuleBasedProfilerConfig,
-)
-from great_expectations.rule_based_profiler.parameter_container import (
-    DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
-    FULLY_QUALIFIED_PARAMETER_NAME_METADATA_KEY,
-    FULLY_QUALIFIED_PARAMETER_NAME_SEPARATOR_CHARACTER,
-    FULLY_QUALIFIED_PARAMETER_NAME_VALUE_KEY,
-    PARAMETER_KEY,
-    VARIABLES_KEY,
-)
 from great_expectations.util import isclose
-from great_expectations.validator.validator import (
-    ValidationDependencies,  # noqa: TCH001
-)
 
 if TYPE_CHECKING:
+    from great_expectations.core import (
+        ExpectationValidationResult,
+    )
+    from great_expectations.execution_engine import ExecutionEngine
+    from great_expectations.expectations.expectation_configuration import (
+        ExpectationConfiguration,
+    )
     from great_expectations.render.renderer_configuration import AddParamArgs
+    from great_expectations.validator.validator import (
+        ValidationDependencies,
+    )
 
 
-class ExpectColumnQuantileValuesToBeBetween(ColumnExpectation):
+class QuantileRange(pydantic.BaseModel):
+    quantiles: List[float]
+    value_ranges: List[List[Union[float, int, None]]]
+
+
+EXPECTATION_SHORT_DESCRIPTION = (
+    "Expect the specific provided column quantiles "
+    "to be between a minimum value and a maximum value."
+)
+QUANTILE_RANGES_DESCRIPTION = (
+    "Key 'quantiles' is an increasingly ordered list of desired quantile values (floats). "
+    "Key 'value_ranges' is a list of 2-value lists that specify a lower and upper bound "
+    "(inclusive) for the corresponding quantile (with [min, max] ordering)."
+)
+ALLOW_RELATIVE_ERROR_DESCRIPTION = (
+    "Whether to allow relative error in quantile "
+    "communications on backends that support or require it."
+)
+DATA_QUALITY_ISSUES = [DataQualityIssues.NUMERIC.value]
+SUPPORTED_DATA_SOURCES = [
+    SupportedDataSources.PANDAS.value,
+    SupportedDataSources.SPARK.value,
+    SupportedDataSources.SQLITE.value,
+    SupportedDataSources.POSTGRESQL.value,
+    SupportedDataSources.AURORA.value,
+    SupportedDataSources.CITUS.value,
+    SupportedDataSources.ALLOY.value,
+    SupportedDataSources.NEON.value,
+    SupportedDataSources.MYSQL.value,
+    SupportedDataSources.MSSQL.value,
+    SupportedDataSources.BIGQUERY.value,
+    SupportedDataSources.SNOWFLAKE.value,
+    SupportedDataSources.REDSHIFT.value,
+]
+
+
+class ExpectColumnQuantileValuesToBeBetween(ColumnAggregateExpectation):
     # noinspection PyUnresolvedReferences
-    """Expect the specific provided column quantiles to be between a minimum value and a maximum value.
+    __doc__ = f"""{EXPECTATION_SHORT_DESCRIPTION}
 
-    expect_column_quantile_values_to_be_between is a \
-    [Column Aggregate Expectation](https://docs.greatexpectations.io/docs/guides/expectations/creating_custom_expectations/how_to_create_custom_column_aggregate_expectations).
+    ExpectColumnQuantileValuesToBeBetween is a \
+    Column Aggregate Expectation.
 
-    For example:
-    ::
+    Column Aggregate Expectations are one of the most common types of Expectation.
+    They are evaluated for a single column, and produce an aggregate Metric, such as a mean, standard deviation, number of unique values, column type, etc.
+    If that Metric meets the conditions you set, the Expectation considers that data valid.
 
-        # my_df.my_col = [1,2,2,3,3,3,4]
-        >>> my_df.expect_column_quantile_values_to_be_between(
-            "my_col",
-            {
-                "quantiles": [0., 0.333, 0.6667, 1.],
-                "value_ranges": [[0,1], [2,3], [3,4], [4,5]]
-            }
-        )
-        {
-          "success": True,
-            "result": {
-              "observed_value": {
-                "quantiles: [0., 0.333, 0.6667, 1.],
-                "values": [1, 2, 3, 4],
-              }
-              "element_count": 7,
-              "missing_count": 0,
-              "missing_percent": 0.0,
-              "details": {
-                "success_details": [true, true, true, true]
-              }
-            }
-          }
-        }
-
-    expect_column_quantile_values_to_be_between can be computationally intensive for large datasets.
+    ExpectColumnQuantileValuesToBeBetween can be computationally intensive for large datasets.
 
     Args:
         column (str): \
-            The column name.
+            {COLUMN_DESCRIPTION}
         quantile_ranges (dictionary with keys 'quantiles' and 'value_ranges'): \
-            Key 'quantiles' is an increasingly ordered list of desired quantile values (floats). \
-            Key 'value_ranges' is a list of 2-value lists that specify a lower and upper bound (inclusive) \
-            for the corresponding quantile (with [min, max] ordering). The length of the 'quantiles' list \
-            and the 'value_ranges' list must be equal.
+            {QUANTILE_RANGES_DESCRIPTION} The length of the 'quantiles' list and the 'value_ranges' list must be equal.
         allow_relative_error (boolean or string): \
-            Whether to allow relative error in quantile communications on backends that support or require it.
+            {ALLOW_RELATIVE_ERROR_DESCRIPTION}
 
     Other Parameters:
         result_format (str or None): \
             Which output mode to use: BOOLEAN_ONLY, BASIC, COMPLETE, or SUMMARY. \
             For more detail, see [result_format](https://docs.greatexpectations.io/docs/reference/expectations/result_format).
-        include_config (boolean): \
-            If True, then include the expectation config as part of the result object.
         catch_exceptions (boolean or None): \
             If True, then catch exceptions and include them as part of the result object. \
             For more detail, see [catch_exceptions](https://docs.greatexpectations.io/docs/reference/expectations/standard_arguments/#catch_exceptions).
@@ -121,7 +125,7 @@ class ExpectColumnQuantileValuesToBeBetween(ColumnExpectation):
     Returns:
         An [ExpectationSuiteValidationResult](https://docs.greatexpectations.io/docs/terms/validation_result)
 
-        Exact fields vary depending on the values passed to result_format, include_config, catch_exceptions, and meta.
+        Exact fields vary depending on the values passed to result_format, catch_exceptions, and meta.
 
     Notes:
         * min_value and max_value are both inclusive.
@@ -130,13 +134,139 @@ class ExpectColumnQuantileValuesToBeBetween(ColumnExpectation):
         * details.success_details field in the result object is customized for this expectation
 
     See Also:
-        [expect_column_min_to_be_between](https://greatexpectations.io/expectations/expect_column_min_to_be_between)
-        [expect_column_max_to_be_between](https://greatexpectations.io/expectations/expect_column_max_to_be_between)
-        [expect_column_median_to_be_between](https://greatexpectations.io/expectations/expect_column_median_to_be_between)
-    """
+        [ExpectColumnMinToBeBetween](https://greatexpectations.io/expectations/expect_column_min_to_be_between)
+        [ExpectColumnMaxToBeBetween](https://greatexpectations.io/expectations/expect_column_max_to_be_between)
+        [ExpectColumnMedianToBeBetween](https://greatexpectations.io/expectations/expect_column_median_to_be_between)
+
+    Supported Data Sources:
+        [{SUPPORTED_DATA_SOURCES[0]}](https://docs.greatexpectations.io/docs/application_integration_support/)
+        [{SUPPORTED_DATA_SOURCES[1]}](https://docs.greatexpectations.io/docs/application_integration_support/)
+        [{SUPPORTED_DATA_SOURCES[2]}](https://docs.greatexpectations.io/docs/application_integration_support/)
+        [{SUPPORTED_DATA_SOURCES[3]}](https://docs.greatexpectations.io/docs/application_integration_support/)
+        [{SUPPORTED_DATA_SOURCES[4]}](https://docs.greatexpectations.io/docs/application_integration_support/)
+        [{SUPPORTED_DATA_SOURCES[5]}](https://docs.greatexpectations.io/docs/application_integration_support/)
+        [{SUPPORTED_DATA_SOURCES[6]}](https://docs.greatexpectations.io/docs/application_integration_support/)
+        [{SUPPORTED_DATA_SOURCES[7]}](https://docs.greatexpectations.io/docs/application_integration_support/)
+        [{SUPPORTED_DATA_SOURCES[8]}](https://docs.greatexpectations.io/docs/application_integration_support/)
+        [{SUPPORTED_DATA_SOURCES[9]}](https://docs.greatexpectations.io/docs/application_integration_support/)
+        [{SUPPORTED_DATA_SOURCES[10]}](https://docs.greatexpectations.io/docs/application_integration_support/)
+        [{SUPPORTED_DATA_SOURCES[11]}](https://docs.greatexpectations.io/docs/application_integration_support/)
+
+    Data Quality Issues:
+        {DATA_QUALITY_ISSUES[0]}
+
+    Example Data:
+                test
+            0 	1       1
+            1 	2       7
+            2 	2       2.5
+            3   3       3
+            4   3       2
+            5   3       5
+            6   4       6
+
+    Code Examples:
+        Passing Case:
+            Input:
+                ExpectColumnQuantileValuesToBeBetween(
+                    column="test",
+                    quantile_ranges={{
+                        "quantiles": [0, .333, .667, 1],
+                        "value_ranges": [[0,1], [2,3], [3,4], [4,5]]
+                    }}
+                )
+
+            Output:
+                {{
+                  "exception_info": {{
+                    "raised_exception": false,
+                    "exception_traceback": null,
+                    "exception_message": null
+                  }},
+                  "result": {{
+                    "observed_value": {{
+                      "quantiles": [
+                        0,
+                        0.333,
+                        0.6667,
+                        1
+                      ],
+                      "values": [
+                        1,
+                        2,
+                        3,
+                        4
+                      ]
+                    }},
+                    "details": {{
+                      "success_details": [
+                        true,
+                        true,
+                        true,
+                        true
+                      ]
+                    }}
+                  }},
+                  "meta": {{}},
+                  "success": true
+                }}
+
+        Failing Case:
+            Input:
+                ExpectColumnQuantileValuesToBeBetween(
+                    column="test2",
+                    quantile_ranges={{
+                        "quantiles": [0, .333, .667, 1],
+                        "value_ranges": [[0,1], [2,3], [3,4], [4,5]]
+                    }}
+                )
+
+            Output:
+                {{
+                  "exception_info": {{
+                    "raised_exception": false,
+                    "exception_traceback": null,
+                    "exception_message": null
+                  }},
+                  "result": {{
+                    "observed_value": {{
+                      "quantiles": [
+                        0,
+                        0.333,
+                        0.6667,
+                        1
+                      ],
+                      "values": [
+                        1.0,
+                        2.5,
+                        5.0,
+                        7.0
+                      ]
+                    }},
+                    "details": {{
+                      "success_details": [
+                        true,
+                        true,
+                        false,
+                        false
+                      ]
+                    }}
+                  }},
+                  "meta": {{}},
+                  "success": false
+                }}
+    """  # noqa: E501 # FIXME CoP
+
+    quantile_ranges: Union[QuantileRange, SuiteParameterDict] = pydantic.Field(
+        description=QUANTILE_RANGES_DESCRIPTION
+    )
+    allow_relative_error: Union[bool, str, SuiteParameterDict] = pydantic.Field(
+        default=False,
+        description=ALLOW_RELATIVE_ERROR_DESCRIPTION,
+    )
 
     # This dictionary contains metadata for display in the public gallery
-    library_metadata = {
+    library_metadata: ClassVar[Dict[str, Union[str, list, bool]]] = {
         "maturity": "production",
         "tags": ["core expectation", "column aggregate expectation"],
         "contributors": ["@great_expectations"],
@@ -145,159 +275,73 @@ class ExpectColumnQuantileValuesToBeBetween(ColumnExpectation):
         "manually_reviewed_code": True,
     }
 
+    _library_metadata = library_metadata
+
     metric_dependencies = ("column.quantile_values",)
     success_keys = (
         "quantile_ranges",
         "allow_relative_error",
-        "auto",
-        "profiler_config",
     )
 
-    quantile_value_ranges_estimator_parameter_builder_config = ParameterBuilderConfig(
-        module_name="great_expectations.rule_based_profiler.parameter_builder",
-        class_name="NumericMetricRangeMultiBatchParameterBuilder",
-        name="quantile_value_ranges_estimator",
-        metric_name="column.quantile_values",
-        metric_multi_batch_parameter_builder_name=None,
-        metric_domain_kwargs=DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
-        metric_value_kwargs={
-            "quantiles": f"{VARIABLES_KEY}quantiles",
-            "allow_relative_error": f"{VARIABLES_KEY}allow_relative_error",
-        },
-        enforce_numeric_metric=True,
-        replace_nan_with_zero=True,
-        reduce_scalar_metric=True,
-        false_positive_rate=f"{VARIABLES_KEY}false_positive_rate",
-        estimator=f"{VARIABLES_KEY}estimator",
-        n_resamples=f"{VARIABLES_KEY}n_resamples",
-        random_seed=f"{VARIABLES_KEY}random_seed",
-        quantile_statistic_interpolation_method=f"{VARIABLES_KEY}quantile_statistic_interpolation_method",
-        quantile_bias_correction=f"{VARIABLES_KEY}quantile_bias_correction",
-        quantile_bias_std_error_ratio_threshold=f"{VARIABLES_KEY}quantile_bias_std_error_ratio_threshold",
-        include_estimator_samples_histogram_in_details=f"{VARIABLES_KEY}include_estimator_samples_histogram_in_details",
-        truncate_values=f"{VARIABLES_KEY}truncate_values",
-        round_decimals=f"{VARIABLES_KEY}round_decimals",
-        evaluation_parameter_builder_configs=None,
-    )
-    validation_parameter_builder_configs: List[ParameterBuilderConfig] = [
-        quantile_value_ranges_estimator_parameter_builder_config,
-    ]
-    default_profiler_config = RuleBasedProfilerConfig(
-        name="expect_column_quantile_values_to_be_between",  # Convention: use "expectation_type" as profiler name.
-        config_version=1.0,
-        variables={},
-        rules={
-            "default_expect_column_quantile_values_to_be_between_rule": {
-                "variables": {
-                    "quantiles": [
-                        0.25,
-                        0.5,
-                        0.75,
-                    ],
-                    "allow_relative_error": "linear",
-                    "estimator": "exact",
-                    "include_estimator_samples_histogram_in_details": False,
-                    "truncate_values": {
-                        "lower_bound": None,
-                        "upper_bound": None,
-                    },
-                    "round_decimals": None,
-                },
-                "domain_builder": {
-                    "class_name": "ColumnDomainBuilder",
-                    "module_name": "great_expectations.rule_based_profiler.domain_builder",
-                },
-                "expectation_configuration_builders": [
-                    {
-                        "expectation_type": "expect_column_quantile_values_to_be_between",
-                        "class_name": "DefaultExpectationConfigurationBuilder",
-                        "module_name": "great_expectations.rule_based_profiler.expectation_configuration_builder",
-                        "validation_parameter_builder_configs": validation_parameter_builder_configs,
-                        "column": f"{DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME}{FULLY_QUALIFIED_PARAMETER_NAME_SEPARATOR_CHARACTER}column",
-                        "quantile_ranges": {
-                            "quantiles": f"{VARIABLES_KEY}quantiles",
-                            "value_ranges": f"{PARAMETER_KEY}{quantile_value_ranges_estimator_parameter_builder_config.name}{FULLY_QUALIFIED_PARAMETER_NAME_SEPARATOR_CHARACTER}{FULLY_QUALIFIED_PARAMETER_NAME_VALUE_KEY}",
-                        },
-                        "allow_relative_error": f"{VARIABLES_KEY}allow_relative_error",
-                        "meta": {
-                            "profiler_details": f"{PARAMETER_KEY}{quantile_value_ranges_estimator_parameter_builder_config.name}{FULLY_QUALIFIED_PARAMETER_NAME_SEPARATOR_CHARACTER}{FULLY_QUALIFIED_PARAMETER_NAME_METADATA_KEY}",
-                        },
-                    }
-                ],
-            },
-        },
-    )
-
-    default_kwarg_values = {
-        "row_condition": None,
-        "condition_parser": None,
-        "quantile_ranges": None,
-        "result_format": "BASIC",
-        "allow_relative_error": False,
-        "include_config": True,
-        "catch_exceptions": False,
-        "meta": None,
-        "auto": False,
-        "profiler_config": default_profiler_config,
-    }
     args_keys = (
         "column",
         "quantile_ranges",
         "allow_relative_error",
     )
 
-    @public_api
-    def validate_configuration(
-        self, configuration: Optional[ExpectationConfiguration] = None
-    ) -> None:
-        """Validates the configuration of an Expectation.
+    class Config:
+        title = "Expect column quantile values to be between"
 
-        For `expect_column_quantile_values_to_be_between` it is required that the `configuration.kwargs` contain a
-        `quantile_ranges` key that is a `dict`. Also, `quantile_ranges` must contain a `value_ranges` key that is a
-        list of ordered pairs, as well as a `quantiles` key that is a list of the same length as `values_ranges`.
-
-        The configuration will also be validated using each of the `validate_configuration` methods in its Expectation
-        superclass hierarchy.
-
-        Args:
-            configuration: An `ExpectationConfiguration` to validate. If no configuration is provided, it will be pulled
-                from the configuration attribute of the Expectation instance.
-
-        Raises:
-            InvalidExpectationConfigurationError: The configuration does not contain the values required by the
-                Expectation.
-            ValueError: `value_ranges` and `quantiles` are not the same length.
-        """
-        super().validate_configuration(configuration)
-        configuration = configuration or self.configuration
-        try:
-            assert (
-                "quantile_ranges" in configuration.kwargs
-            ), "quantile_ranges must be provided"
-            assert isinstance(
-                configuration.kwargs["quantile_ranges"], dict
-            ), "quantile_ranges should be a dictionary"
-
-            assert all(
-                [
-                    True if None in x or x == sorted(x) else False
-                    for x in configuration.kwargs["quantile_ranges"]["value_ranges"]
-                ]
-            ), "quantile_ranges must consist of ordered pairs"
-
-        except AssertionError as e:
-            raise InvalidExpectationConfigurationError(str(e))
-
-        # Ensuring actual quantiles and their value ranges match up
-        quantile_ranges = configuration.kwargs["quantile_ranges"]
-        quantiles = quantile_ranges["quantiles"]
-        quantile_value_ranges = quantile_ranges["value_ranges"]
-
-        if len(quantiles) != len(quantile_value_ranges):
-            raise ValueError(
-                "quantile_values and quantiles must have the same number of elements"
+        @staticmethod
+        def schema_extra(
+            schema: Dict[str, Any], model: Type[ExpectColumnQuantileValuesToBeBetween]
+        ) -> None:
+            ColumnAggregateExpectation.Config.schema_extra(schema, model)
+            schema["properties"]["metadata"]["properties"].update(
+                {
+                    "data_quality_issues": {
+                        "title": "Data Quality Issues",
+                        "type": "array",
+                        "const": DATA_QUALITY_ISSUES,
+                    },
+                    "library_metadata": {
+                        "title": "Library Metadata",
+                        "type": "object",
+                        "const": model._library_metadata,
+                    },
+                    "short_description": {
+                        "title": "Short Description",
+                        "type": "string",
+                        "const": EXPECTATION_SHORT_DESCRIPTION,
+                    },
+                    "supported_data_sources": {
+                        "title": "Supported Data Sources",
+                        "type": "array",
+                        "const": SUPPORTED_DATA_SOURCES,
+                    },
+                }
             )
 
+    @pydantic.validator("quantile_ranges")
+    def validate_quantile_ranges(
+        cls, quantile_ranges: QuantileRange | SuiteParameterDict
+    ) -> Optional[QuantileRange | SuiteParameterDict]:
+        if isinstance(quantile_ranges, QuantileRange):
+            try:
+                assert all(
+                    True if None in x else x == sorted([val for val in x if val is not None])
+                    for x in quantile_ranges.value_ranges
+                ), "quantile_ranges must consist of ordered pairs"
+            except AssertionError as e:
+                raise InvalidExpectationConfigurationError(str(e))
+
+            if len(quantile_ranges.quantiles) != len(quantile_ranges.value_ranges):
+                raise ValueError(  # noqa: TRY003
+                    "quantile_values and quantiles must have the same number of elements"
+                )  # FIXME CoP
+
+        return quantile_ranges
+
     @classmethod
     def _prescriptive_template(
         cls,
@@ -320,9 +364,9 @@ class ExpectColumnQuantileValuesToBeBetween(ColumnExpectation):
         quantiles: list = renderer_configuration.kwargs.get("quantile_ranges", {}).get(
             "quantiles", []
         )
-        value_ranges: list = renderer_configuration.kwargs.get(
-            "quantile_ranges", {}
-        ).get("value_ranges", [])
+        value_ranges: list = renderer_configuration.kwargs.get("quantile_ranges", {}).get(
+            "value_ranges", []
+        )
 
         header_row = [
             RendererTableValue(
@@ -342,15 +386,11 @@ class ExpectColumnQuantileValuesToBeBetween(ColumnExpectation):
         quantile_strings = {0.25: "Q1", 0.75: "Q3", 0.50: "Median"}
         for quantile, value_range in zip(quantiles, value_ranges):
             quantile_string = quantile_strings.get(quantile, f"{quantile:3.2f}")
-            value_range_lower: Union[Number, str] = (
-                value_range[0] if value_range[0] else "Any"
-            )
+            value_range_lower: Union[Number, str] = value_range[0] if value_range[0] else "Any"
             value_rage_lower_type = (
                 RendererValueType.NUMBER if value_range[0] else RendererValueType.STRING
             )
-            value_range_upper: Union[Number, str] = (
-                value_range[1] if value_range[1] else "Any"
-            )
+            value_range_upper: Union[Number, str] = value_range[1] if value_range[1] else "Any"
             value_range_upper_type = (
                 RendererValueType.NUMBER if value_range[0] else RendererValueType.STRING
             )
@@ -377,7 +417,7 @@ class ExpectColumnQuantileValuesToBeBetween(ColumnExpectation):
 
     @classmethod
     @renderer(renderer_type=AtomicPrescriptiveRendererType.SUMMARY)
-    @render_evaluation_parameter_string
+    @render_suite_parameter_string
     def _prescriptive_summary(
         cls,
         configuration: Optional[ExpectationConfiguration] = None,
@@ -419,7 +459,7 @@ class ExpectColumnQuantileValuesToBeBetween(ColumnExpectation):
 
     @classmethod
     @renderer(renderer_type=LegacyRendererType.PRESCRIPTIVE)
-    @render_evaluation_parameter_string
+    @render_suite_parameter_string
     def _prescriptive_renderer(
         cls,
         configuration: Optional[ExpectationConfiguration] = None,
@@ -428,9 +468,7 @@ class ExpectColumnQuantileValuesToBeBetween(ColumnExpectation):
         **kwargs,
     ):
         runtime_configuration = runtime_configuration or {}
-        include_column_name = (
-            False if runtime_configuration.get("include_column_name") is False else True
-        )
+        include_column_name = runtime_configuration.get("include_column_name") is not False
         _ = runtime_configuration.get("styling")
         params = substitute_none_for_missing(
             configuration["kwargs"],
@@ -447,10 +485,7 @@ class ExpectColumnQuantileValuesToBeBetween(ColumnExpectation):
                 conditional_params,
             ) = parse_row_condition_string_pandas_engine(params["row_condition"])
             template_str = (
-                conditional_template_str
-                + ", then "
-                + template_str[0].lower()
-                + template_str[1:]
+                conditional_template_str + ", then " + template_str[0].lower() + template_str[1:]
             )
             params.update(conditional_params)
 
@@ -459,8 +494,8 @@ class ExpectColumnQuantileValuesToBeBetween(ColumnExpectation):
             "string_template": {"template": template_str, "params": params},
         }
 
-        quantiles = params["quantile_ranges"]["quantiles"]
-        value_ranges = params["quantile_ranges"]["value_ranges"]
+        quantiles = params["quantile_ranges"].get("quantiles", [])
+        value_ranges = params["quantile_ranges"].get("value_ranges", [])
 
         table_header_row = ["Quantile", "Min Value", "Max Value"]
         table_rows = []
@@ -556,17 +591,15 @@ class ExpectColumnQuantileValuesToBeBetween(ColumnExpectation):
         quantiles = renderer_configuration.result.result.get("observed_value", {}).get(
             "quantiles", []
         )
-        value_ranges = renderer_configuration.result.result.get(
-            "observed_value", {}
-        ).get("values", [])
+        value_ranges = renderer_configuration.result.result.get("observed_value", {}).get(
+            "values", []
+        )
 
         header_row = [
             RendererTableValue(
                 schema=RendererSchema(type=RendererValueType.STRING), value="Quantile"
             ),
-            RendererTableValue(
-                schema=RendererSchema(type=RendererValueType.STRING), value="Value"
-            ),
+            RendererTableValue(schema=RendererSchema(type=RendererValueType.STRING), value="Value"),
         ]
 
         table = []
@@ -661,12 +694,12 @@ class ExpectColumnQuantileValuesToBeBetween(ColumnExpectation):
                     {
                         "content_block_type": "string_template",
                         "string_template": {
-                            "template": quantile_string
-                            if quantile_string
-                            else f"{quantile:3.2f}",
+                            "template": (
+                                quantile_string if quantile_string else f"{quantile:3.2f}"
+                            ),
                             "tooltip": {
-                                "content": "expect_column_quantile_values_to_be_between \n expect_column_median_to_be_between"
-                                if quantile == 0.50
+                                "content": "expect_column_quantile_values_to_be_between \n expect_column_median_to_be_between"  # noqa: E501 # FIXME CoP
+                                if quantile == 0.50  # noqa: PLR2004 # FIXME CoP
                                 else "expect_column_quantile_values_to_be_between"
                             },
                         },
@@ -696,32 +729,27 @@ class ExpectColumnQuantileValuesToBeBetween(ColumnExpectation):
 
     def get_validation_dependencies(
         self,
-        configuration: Optional[ExpectationConfiguration] = None,
         execution_engine: Optional[ExecutionEngine] = None,
         runtime_configuration: Optional[dict] = None,
     ) -> ValidationDependencies:
-        validation_dependencies: ValidationDependencies = (
-            super().get_validation_dependencies(
-                configuration, execution_engine, runtime_configuration
-            )
+        validation_dependencies: ValidationDependencies = super().get_validation_dependencies(
+            execution_engine, runtime_configuration
         )
+        configuration = self.configuration
         # column.quantile_values expects a "quantiles" key
         validation_dependencies.get_metric_configuration(
             metric_name="column.quantile_values"
-        ).metric_value_kwargs["quantiles"] = configuration.kwargs["quantile_ranges"][
-            "quantiles"
-        ]
+        ).metric_value_kwargs["quantiles"] = configuration.kwargs["quantile_ranges"]["quantiles"]
         return validation_dependencies
 
     def _validate(
         self,
-        configuration: ExpectationConfiguration,
         metrics: Dict,
         runtime_configuration: Optional[dict] = None,
         execution_engine: Optional[ExecutionEngine] = None,
     ):
         quantile_vals = metrics.get("column.quantile_values")
-        quantile_ranges = configuration.kwargs.get("quantile_ranges")
+        quantile_ranges = self.configuration.kwargs.get("quantile_ranges")
         quantiles = quantile_ranges["quantiles"]
         quantile_value_ranges = quantile_ranges["value_ranges"]
 
