@@ -1,13 +1,13 @@
-from typing import TYPE_CHECKING, Optional
+from __future__ import annotations
 
-from great_expectations.core import (
-    ExpectationConfiguration,  # noqa: TCH001
-    ExpectationValidationResult,  # noqa: TCH001
+from typing import TYPE_CHECKING, Optional, Union
+
+from great_expectations.core.suite_parameters import (
+    SuiteParameterDict,  # noqa: TC001 # FIXME CoP
 )
-from great_expectations.core._docs_decorators import public_api
 from great_expectations.expectations.expectation import (
     ColumnMapExpectation,
-    render_evaluation_parameter_string,
+    render_suite_parameter_string,
 )
 from great_expectations.render import LegacyRendererType, RenderedStringTemplateContent
 from great_expectations.render.renderer.renderer import renderer
@@ -22,20 +22,25 @@ from great_expectations.render.util import (
 )
 
 if TYPE_CHECKING:
+    from great_expectations.core import (
+        ExpectationValidationResult,
+    )
+    from great_expectations.expectations.expectation_configuration import (
+        ExpectationConfiguration,
+    )
     from great_expectations.render.renderer_configuration import AddParamArgs
 
 
 class ExpectColumnValuesToBeDecreasing(ColumnMapExpectation):
     """Expect the column values to be decreasing.
 
-    By default, this expectation only works for numeric or datetime data. \
-    When 'parse_strings_as_datetimes=True', it can also parse strings to datetimes.
+    By default, this expectation only works for numeric or datetime data.
 
     If 'strictly=True', then this expectation is only satisfied if each consecutive value \
     is strictly decreasing--equal values are treated as failures.
 
-    expect_column_values_to_be_decreasing is a \
-    [Column Map Expectation](https://docs.greatexpectations.io/docs/guides/expectations/creating_custom_expectations/how_to_create_custom_column_map_expectations)
+    ExpectColumnValuesToBeDecreasing is a \
+    Column Map Expectation
 
     Args:
         column (str): \
@@ -44,8 +49,6 @@ class ExpectColumnValuesToBeDecreasing(ColumnMapExpectation):
     Keyword Args:
         strictly (Boolean or None): \
             If True, values must be strictly greater than previous values
-        parse_strings_as_datetimes (boolean or None): \
-            If True, all non-null column values to datetimes before making comparisons
         mostly (None or a float between 0 and 1): \
             Successful if at least mostly fraction of values match the expectation. \
             For more detail, see [mostly](https://docs.greatexpectations.io/docs/reference/expectations/standard_arguments/#mostly).
@@ -54,8 +57,6 @@ class ExpectColumnValuesToBeDecreasing(ColumnMapExpectation):
         result_format (str or None): \
             Which output mode to use: BOOLEAN_ONLY, BASIC, COMPLETE, or SUMMARY. \
             For more detail, see [result_format](https://docs.greatexpectations.io/docs/reference/expectations/result_format).
-        include_config (boolean): \
-            If True, then include the expectation config as part of the result object.
         catch_exceptions (boolean or None): \
             If True, then catch exceptions and include them as part of the result object. \
             For more detail, see [catch_exceptions](https://docs.greatexpectations.io/docs/reference/expectations/standard_arguments/#catch_exceptions).
@@ -66,11 +67,13 @@ class ExpectColumnValuesToBeDecreasing(ColumnMapExpectation):
     Returns:
         An [ExpectationSuiteValidationResult](https://docs.greatexpectations.io/docs/terms/validation_result)
 
-        Exact fields vary depending on the values passed to result_format, include_config, catch_exceptions, and meta.
+        Exact fields vary depending on the values passed to result_format, catch_exceptions, and meta.
 
     See Also:
-        [expect_column_values_to_be_increasing](https://greatexpectations.io/expectations/expect_column_values_to_be_increasing)
-    """
+        [ExpectColumnValuesToBeIncreasing](https://greatexpectations.io/expectations/expect_column_values_to_be_increasing)
+    """  # noqa: E501 # FIXME CoP
+
+    strictly: Union[bool, SuiteParameterDict, None] = None
 
     # This dictionary contains metadata for display in the public gallery
     library_metadata = {
@@ -86,39 +89,9 @@ class ExpectColumnValuesToBeDecreasing(ColumnMapExpectation):
     success_keys = (
         "strictly",
         "mostly",
-        "parse_strings_as_datetimes",
     )
-    default_kwarg_values = {
-        "row_condition": None,
-        "condition_parser": None,
-        "strictly": None,
-        "mostly": 1,
-        "result_format": "BASIC",
-        "include_config": True,
-        "catch_exceptions": False,
-        "parse_strings_as_datetimes": False,
-    }
     args_keys = ("column",)
 
-    @public_api
-    def validate_configuration(
-        self, configuration: Optional[ExpectationConfiguration] = None
-    ) -> None:
-        """Validates the configuration of an Expectation.
-
-        The configuration will also be validated using each of the `validate_configuration` methods in its Expectation
-        superclass hierarchy.
-
-        Args:
-            configuration: An `ExpectationConfiguration` to validate. If no configuration is provided, it will be pulled
-                           from the configuration attribute of the Expectation instance.
-
-        Raises:
-            InvalidExpectationConfigurationError: The configuration does not contain the values required by the
-                                                  Expectation.
-        """
-        super().validate_configuration(configuration)
-
     @classmethod
     def _prescriptive_template(
         cls,
@@ -128,7 +101,6 @@ class ExpectColumnValuesToBeDecreasing(ColumnMapExpectation):
             ("column", RendererValueType.STRING),
             ("strictly", RendererValueType.BOOLEAN),
             ("mostly", RendererValueType.NUMBER),
-            ("parse_strings_as_datetimes", RendererValueType.BOOLEAN),
         )
         for name, param_type in add_param_args:
             renderer_configuration.add_param(name=name, param_type=param_type)
@@ -148,9 +120,6 @@ class ExpectColumnValuesToBeDecreasing(ColumnMapExpectation):
         else:
             template_str += "."
 
-        if params.parse_strings_as_datetimes:
-            template_str += " Values should be parsed as datetimes."
-
         if renderer_configuration.include_column_name:
             template_str = f"$column {template_str}"
 
@@ -160,7 +129,7 @@ class ExpectColumnValuesToBeDecreasing(ColumnMapExpectation):
 
     @classmethod
     @renderer(renderer_type=LegacyRendererType.PRESCRIPTIVE)
-    @render_evaluation_parameter_string
+    @render_suite_parameter_string
     def _prescriptive_renderer(
         cls,
         configuration: Optional[ExpectationConfiguration] = None,
@@ -169,9 +138,7 @@ class ExpectColumnValuesToBeDecreasing(ColumnMapExpectation):
         **kwargs,
     ):
         runtime_configuration = runtime_configuration or {}
-        include_column_name = (
-            False if runtime_configuration.get("include_column_name") is False else True
-        )
+        include_column_name = runtime_configuration.get("include_column_name") is not False
         styling = runtime_configuration.get("styling")
         params = substitute_none_for_missing(
             configuration.kwargs,
@@ -179,7 +146,6 @@ class ExpectColumnValuesToBeDecreasing(ColumnMapExpectation):
                 "column",
                 "strictly",
                 "mostly",
-                "parse_strings_as_datetimes",
                 "row_condition",
                 "condition_parser",
             ],
@@ -191,17 +157,12 @@ class ExpectColumnValuesToBeDecreasing(ColumnMapExpectation):
             template_str = "values must be less than or equal to previous values"
 
         if params["mostly"] is not None and params["mostly"] < 1.0:
-            params["mostly_pct"] = num_to_str(
-                params["mostly"] * 100, precision=15, no_scientific=True
-            )
+            params["mostly_pct"] = num_to_str(params["mostly"] * 100, no_scientific=True)
             # params["mostly_pct"] = "{:.14f}".format(params["mostly"]*100).rstrip("0").rstrip(".")
             template_str += ", at least $mostly_pct % of the time."
         else:
             template_str += "."
 
-        if params.get("parse_strings_as_datetimes"):
-            template_str += " Values should be parsed as datetimes."
-
         if include_column_name:
             template_str = f"$column {template_str}"
 
