@@ -1,13 +1,14 @@
-import json
-from typing import TYPE_CHECKING, Optional
+from __future__ import annotations
 
-from great_expectations.core import (
-    ExpectationConfiguration,  # noqa: TCH001
-    ExpectationValidationResult,  # noqa: TCH001
+import json
+from typing import TYPE_CHECKING, Optional, Union
+
+from great_expectations.core.suite_parameters import (
+    SuiteParameterDict,  # noqa: TC001 # FIXME CoP
 )
 from great_expectations.expectations.expectation import (
     ColumnMapExpectation,
-    render_evaluation_parameter_string,
+    render_suite_parameter_string,
 )
 from great_expectations.render import LegacyRendererType, RenderedStringTemplateContent
 from great_expectations.render.renderer.renderer import renderer
@@ -22,10 +23,16 @@ from great_expectations.render.util import (
 )
 
 if TYPE_CHECKING:
+    from great_expectations.core import (
+        ExpectationValidationResult,
+    )
+    from great_expectations.expectations.expectation_configuration import (
+        ExpectationConfiguration,
+    )
     from great_expectations.render.renderer_configuration import AddParamArgs
 
 try:
-    import sqlalchemy as sa  # noqa: F401
+    import sqlalchemy as sa  # noqa: F401, TID251 # FIXME CoP
 except ImportError:
     pass
 
@@ -33,14 +40,14 @@ except ImportError:
 class ExpectColumnValuesToMatchJsonSchema(ColumnMapExpectation):
     """Expect the column entries to be JSON objects matching a given JSON schema.
 
-    expect_column_values_to_match_json_schema is a \
-    [Column Map Expectation](https://docs.greatexpectations.io/docs/guides/expectations/creating_custom_expectations/how_to_create_custom_column_map_expectations).
+    ExpectColumnValuesToMatchJsonSchema is a \
+    Column Map Expectation.
 
     Args:
         column (str): \
             The column name.
-        json_schema  (str): \
-            The JSON schema (in string form) to match
+        json_schema  (dict): \
+            The JSON schema to match
 
     Keyword Args:
         mostly (None or a float between 0 and 1): \
@@ -51,8 +58,6 @@ class ExpectColumnValuesToMatchJsonSchema(ColumnMapExpectation):
         result_format (str or None): \
             Which output mode to use: BOOLEAN_ONLY, BASIC, COMPLETE, or SUMMARY. \
             For more detail, see [result_format](https://docs.greatexpectations.io/docs/reference/expectations/result_format).
-        include_config (boolean): \
-            If True, then include the expectation config as part of the result object.
         catch_exceptions (boolean or None): \
             If True, then catch exceptions and include them as part of the result object. \
             For more detail, see [catch_exceptions](https://docs.greatexpectations.io/docs/reference/expectations/standard_arguments/#catch_exceptions).
@@ -63,12 +68,14 @@ class ExpectColumnValuesToMatchJsonSchema(ColumnMapExpectation):
     Returns:
         An [ExpectationSuiteValidationResult](https://docs.greatexpectations.io/docs/terms/validation_result)
 
-        Exact fields vary depending on the values passed to result_format, include_config, catch_exceptions, and meta.
+        Exact fields vary depending on the values passed to result_format, catch_exceptions, and meta.
 
     See Also:
-        [expect_column_values_to_be_json_parseable](https://greatexpectations.io/expectations/expect_column_values_to_be_json_parseable)
+        [ExpectColumnValuesToBeJsonParseable](https://greatexpectations.io/expectations/expect_column_values_to_be_json_parseable)
         [The JSON-schema docs](https://json-schema.org)
-    """
+    """  # noqa: E501 # FIXME CoP
+
+    json_schema: Union[dict, SuiteParameterDict]
 
     # This dictionary contains metadata for display in the public gallery
     library_metadata = {
@@ -85,39 +92,11 @@ class ExpectColumnValuesToMatchJsonSchema(ColumnMapExpectation):
         "json_schema",
         "mostly",
     )
-
-    default_kwarg_values = {
-        "row_condition": None,
-        "condition_parser": None,  # we expect this to be explicitly set whenever a row_condition is passed
-        "mostly": 1,
-        "result_format": "BASIC",
-        "include_config": True,
-        "catch_exceptions": True,
-    }
     args_keys = (
         "column",
         "json_schema",
     )
 
-    def validate_configuration(
-        self, configuration: Optional[ExpectationConfiguration] = None
-    ) -> None:
-        """
-        Validate the configuration of an Expectation.
-
-        The configuration will also be validated using each of the `validate_configuration` methods in its Expectation
-        superclass hierarchy.
-
-        Args:
-            configuration: An `ExpectationConfiguration` to validate. If no configuration is provided, it will be pulled
-            from the configuration attribute of the Expectation instance.
-
-        Raises:
-            `InvalidExpectationConfigurationError`: The configuration does not contain the values required by the
-            Expectation
-        """
-        super().validate_configuration(configuration)
-
     @classmethod
     def _prescriptive_template(
         cls,
@@ -136,9 +115,7 @@ class ExpectColumnValuesToMatchJsonSchema(ColumnMapExpectation):
         if not params.json_schema:
             template_str = "values must match a JSON Schema but none was specified."
         else:
-            formatted_json = (
-                f"<pre>{json.dumps(params.json_schema.value, indent=4)}</pre>"
-            )
+            formatted_json = f"<pre>{json.dumps(params.json_schema.value, indent=4)}</pre>"
             renderer_configuration.add_param(
                 name="formatted_json",
                 param_type=RendererValueType.STRING,
@@ -149,11 +126,9 @@ class ExpectColumnValuesToMatchJsonSchema(ColumnMapExpectation):
                 renderer_configuration = cls._add_mostly_pct_param(
                     renderer_configuration=renderer_configuration
                 )
-                template_str = "values must match the following JSON Schema, at least $mostly_pct % of the time: $formatted_json"
+                template_str = "values must match the following JSON Schema, at least $mostly_pct % of the time: $formatted_json"  # noqa: E501 # FIXME CoP
             else:
-                template_str = (
-                    "values must match the following JSON Schema: $formatted_json"
-                )
+                template_str = "values must match the following JSON Schema: $formatted_json"
 
         if renderer_configuration.include_column_name:
             template_str = f"$column {template_str}"
@@ -164,7 +139,7 @@ class ExpectColumnValuesToMatchJsonSchema(ColumnMapExpectation):
 
     @classmethod
     @renderer(renderer_type=LegacyRendererType.PRESCRIPTIVE)
-    @render_evaluation_parameter_string
+    @render_suite_parameter_string
     def _prescriptive_renderer(
         cls,
         configuration: Optional[ExpectationConfiguration] = None,
@@ -173,9 +148,7 @@ class ExpectColumnValuesToMatchJsonSchema(ColumnMapExpectation):
         **kwargs,
     ):
         runtime_configuration = runtime_configuration or {}
-        include_column_name = (
-            False if runtime_configuration.get("include_column_name") is False else True
-        )
+        include_column_name = runtime_configuration.get("include_column_name") is not False
         _ = runtime_configuration.get("styling")
         params = substitute_none_for_missing(
             configuration.kwargs,
@@ -185,19 +158,16 @@ class ExpectColumnValuesToMatchJsonSchema(ColumnMapExpectation):
         if not params.get("json_schema"):
             template_str = "values must match a JSON Schema but none was specified."
         else:
-            params[
-                "formatted_json"
-            ] = f"<pre>{json.dumps(params.get('json_schema'), indent=4)}</pre>"
-            if params["mostly"] is not None and params["mostly"] < 1.0:
-                params["mostly_pct"] = num_to_str(
-                    params["mostly"] * 100, precision=15, no_scientific=True
-                )
-                # params["mostly_pct"] = "{:.14f}".format(params["mostly"]*100).rstrip("0").rstrip(".")
-                template_str = "values must match the following JSON Schema, at least $mostly_pct % of the time: $formatted_json"
+            params["formatted_json"] = (
+                f"<pre>{json.dumps(params.get('json_schema'), indent=4)}</pre>"
+            )
+            if params["mostly"] is not None:
+                if isinstance(params["mostly"], (int, float)) and params["mostly"] < 1.0:
+                    params["mostly_pct"] = num_to_str(params["mostly"] * 100, no_scientific=True)
+                    # params["mostly_pct"] = "{:.14f}".format(params["mostly"]*100).rstrip("0").rstrip(".")  # noqa: E501 # FIXME CoP
+                template_str = "values must match the following JSON Schema, at least $mostly_pct % of the time: $formatted_json"  # noqa: E501 # FIXME CoP
             else:
-                template_str = (
-                    "values must match the following JSON Schema: $formatted_json"
-                )
+                template_str = "values must match the following JSON Schema: $formatted_json"
 
         if include_column_name:
             template_str = f"$column {template_str}"
