@@ -1,12 +1,13 @@
-from typing import TYPE_CHECKING, Optional
+from __future__ import annotations
 
-from great_expectations.core import (
-    ExpectationConfiguration,  # noqa: TCH001
-    ExpectationValidationResult,  # noqa: TCH001
+from typing import TYPE_CHECKING, Optional, Union
+
+from great_expectations.core.suite_parameters import (
+    SuiteParameterDict,  # noqa: TC001 # FIXME CoP
 )
 from great_expectations.expectations.expectation import (
     ColumnMapExpectation,
-    render_evaluation_parameter_string,
+    render_suite_parameter_string,
 )
 from great_expectations.render import LegacyRendererType, RenderedStringTemplateContent
 from great_expectations.render.renderer.renderer import renderer
@@ -21,6 +22,12 @@ from great_expectations.render.util import (
 )
 
 if TYPE_CHECKING:
+    from great_expectations.core import (
+        ExpectationValidationResult,
+    )
+    from great_expectations.expectations.expectation_configuration import (
+        ExpectationConfiguration,
+    )
     from great_expectations.render.renderer_configuration import AddParamArgs
 
 
@@ -29,8 +36,8 @@ class ExpectMulticolumnValuesToBeUnique(ColumnMapExpectation):
 
      Note that all instances of any duplicates are considered failed
 
-     expect_multicolumnvalues_to_be_unique is a \
-     [Column Map Expectation](https://docs.greatexpectations.io/docs/guides/expectations/creating_custom_expectations/how_to_create_custom_column_map_expectations).
+     ExpectMulticolumnvaluesToBeUnique is a \
+     Column Map Expectation.
 
      For example:
      ::
@@ -52,8 +59,6 @@ class ExpectMulticolumnValuesToBeUnique(ColumnMapExpectation):
         result_format (str or None): \
             Which output mode to use: BOOLEAN_ONLY, BASIC, COMPLETE, or SUMMARY. \
             For more detail, see [result_format](https://docs.greatexpectations.io/docs/reference/expectations/result_format).
-        include_config (boolean): \
-            If True, then include the expectation config as part of the result object.
         catch_exceptions (boolean or None): \
             If True, then catch exceptions and include them as part of the result object. \
             For more detail, see [catch_exceptions](https://docs.greatexpectations.io/docs/reference/expectations/standard_arguments/#catch_exceptions).
@@ -64,8 +69,11 @@ class ExpectMulticolumnValuesToBeUnique(ColumnMapExpectation):
      Returns:
          An [ExpectationSuiteValidationResult](https://docs.greatexpectations.io/docs/terms/validation_result)
 
-         Exact fields vary depending on the values passed to result_format, include_config, catch_exceptions, and meta.
-    """
+         Exact fields vary depending on the values passed to result_format, catch_exceptions, and meta.
+    """  # noqa: E501 # FIXME CoP
+
+    column_list: Union[tuple, list]
+    ignore_row_if: Union[str, SuiteParameterDict] = "all_values_are_missing"
 
     library_metadata = {
         "maturity": "production",
@@ -88,14 +96,6 @@ class ExpectMulticolumnValuesToBeUnique(ColumnMapExpectation):
         "ignore_row_if",
         "mostly",
     )
-    default_kwarg_values = {
-        "column_list": None,
-        "ignore_row_if": "all_values_are_missing",
-        "mostly": 1,
-        "result_format": "BASIC",
-        "include_config": True,
-        "catch_exceptions": False,
-    }
     args_keys = ("column_list",)
 
     @classmethod
@@ -117,7 +117,9 @@ class ExpectMulticolumnValuesToBeUnique(ColumnMapExpectation):
             renderer_configuration = cls._add_mostly_pct_param(
                 renderer_configuration=renderer_configuration
             )
-            template_str = "Values must be unique across columns, at least $mostly_pct % of the time: "
+            template_str = (
+                "Values must be unique across columns, at least $mostly_pct % of the time: "
+            )
         else:
             template_str = "Values must always be unique across columns: "
 
@@ -141,7 +143,7 @@ class ExpectMulticolumnValuesToBeUnique(ColumnMapExpectation):
 
     @classmethod
     @renderer(renderer_type=LegacyRendererType.PRESCRIPTIVE)
-    @render_evaluation_parameter_string
+    @render_suite_parameter_string
     def _prescriptive_renderer(
         cls,
         configuration: Optional[ExpectationConfiguration] = None,
@@ -150,7 +152,7 @@ class ExpectMulticolumnValuesToBeUnique(ColumnMapExpectation):
         **kwargs,
     ):
         runtime_configuration = runtime_configuration or {}
-        _ = False if runtime_configuration.get("include_column_name") is False else True
+        _ = runtime_configuration.get("include_column_name") is not False
         styling = runtime_configuration.get("styling")
 
         # NOTE: This expectation is deprecated, please use
@@ -168,23 +170,17 @@ class ExpectMulticolumnValuesToBeUnique(ColumnMapExpectation):
         )
 
         if params["mostly"] is not None:
-            params["mostly_pct"] = num_to_str(
-                params["mostly"] * 100, precision=15, no_scientific=True
-            )
-        mostly_str = (
-            ""
-            if params.get("mostly") is None
-            else ", at least $mostly_pct % of the time"
-        )
+            params["mostly_pct"] = num_to_str(params["mostly"] * 100, no_scientific=True)
+        mostly_str = "" if params.get("mostly") is None else ", at least $mostly_pct % of the time"
 
         template_str = f"Values must always be unique across columns{mostly_str}: "
         for idx in range(len(params["column_list"]) - 1):
-            template_str += f"$column_list_{str(idx)}, "
-            params[f"column_list_{str(idx)}"] = params["column_list"][idx]
+            template_str += f"$column_list_{idx!s}, "
+            params[f"column_list_{idx!s}"] = params["column_list"][idx]
 
         last_idx = len(params["column_list"]) - 1
-        template_str += f"$column_list_{str(last_idx)}"
-        params[f"column_list_{str(last_idx)}"] = params["column_list"][last_idx]
+        template_str += f"$column_list_{last_idx!s}"
+        params[f"column_list_{last_idx!s}"] = params["column_list"][last_idx]
 
         if params["row_condition"] is not None:
             (
@@ -192,10 +188,7 @@ class ExpectMulticolumnValuesToBeUnique(ColumnMapExpectation):
                 conditional_params,
             ) = parse_row_condition_string_pandas_engine(params["row_condition"])
             template_str = (
-                conditional_template_str
-                + ", then "
-                + template_str[0].lower()
-                + template_str[1:]
+                conditional_template_str + ", then " + template_str[0].lower() + template_str[1:]
             )
             params.update(conditional_params)
 
