@@ -1,9 +1,12 @@
+from __future__ import annotations
+
 import logging
 from functools import wraps
-from typing import Any, Callable, Dict, Optional, Type, Union
+from typing import TYPE_CHECKING, Any, Callable, Dict, Optional, Type, Union
 
-from great_expectations.core import ExpectationConfiguration  # noqa: TCH001
-from great_expectations.core._docs_decorators import public_api
+from great_expectations.compatibility.pyspark import functions as F
+from great_expectations.compatibility.sqlalchemy import sqlalchemy as sa
+from great_expectations.compatibility.typing_extensions import override
 from great_expectations.core.metric_domain_types import MetricDomainTypes
 from great_expectations.core.metric_function_types import MetricPartialFunctionTypes
 from great_expectations.execution_engine import ExecutionEngine, PandasExecutionEngine
@@ -14,7 +17,6 @@ from great_expectations.execution_engine.sqlalchemy_execution_engine import (
     SqlAlchemyExecutionEngine,
 )
 from great_expectations.expectations.metrics import DeprecatedMetaMetricProvider
-from great_expectations.expectations.metrics.import_manager import quoted_name, sa
 from great_expectations.expectations.metrics.metric_provider import (
     metric_partial,
     metric_value,
@@ -23,14 +25,19 @@ from great_expectations.expectations.metrics.table_metric_provider import (
     TableMetricProvider,
 )
 from great_expectations.expectations.metrics.util import (
-    get_dbms_compatible_column_names,
+    get_dbms_compatible_metric_domain_kwargs,
 )
 from great_expectations.validator.metric_configuration import MetricConfiguration
 
 logger = logging.getLogger(__name__)
 
+if TYPE_CHECKING:
+    from great_expectations.compatibility import sqlalchemy
+    from great_expectations.expectations.expectation_configuration import (
+        ExpectationConfiguration,
+    )
+
 
-@public_api
 def column_aggregate_value(
     engine: Type[ExecutionEngine],
     **kwargs,
@@ -49,14 +56,14 @@ def column_aggregate_value(
 
     Returns:
         An annotated metric_function which will be called with a simplified signature.
-    """
+    """  # noqa: E501 # FIXME CoP
     domain_type: MetricDomainTypes = MetricDomainTypes.COLUMN
     if issubclass(engine, PandasExecutionEngine):
 
         def wrapper(metric_fn: Callable):
-            @metric_value(engine=PandasExecutionEngine)
+            @metric_value(engine=engine)
             @wraps(metric_fn)
-            def inner_func(
+            def inner_func(  # noqa: PLR0913 # FIXME CoP
                 cls,
                 execution_engine: PandasExecutionEngine,
                 metric_domain_kwargs: dict,
@@ -68,16 +75,16 @@ def column_aggregate_value(
                     "filter_column_isnull", getattr(cls, "filter_column_isnull", False)
                 )
 
+                metric_domain_kwargs = get_dbms_compatible_metric_domain_kwargs(
+                    metric_domain_kwargs=metric_domain_kwargs,
+                    batch_columns_list=metrics["table.columns"],
+                )
+
                 df, _, accessor_domain_kwargs = execution_engine.get_compute_domain(
                     domain_kwargs=metric_domain_kwargs, domain_type=domain_type
                 )
 
-                column_name: Union[str, quoted_name] = accessor_domain_kwargs["column"]
-
-                column_name = get_dbms_compatible_column_names(
-                    column_names=column_name,
-                    batch_columns_list=metrics["table.columns"],
-                )
+                column_name: Union[str, sqlalchemy.quoted_name] = accessor_domain_kwargs["column"]
 
                 if filter_column_isnull:
                     df = df[df[column_name].notnull()]
@@ -93,13 +100,10 @@ def column_aggregate_value(
 
         return wrapper
     else:
-        raise ValueError(
-            "column_aggregate_value decorator only supports PandasExecutionEngine"
-        )
+        raise ValueError("column_aggregate_value decorator only supports PandasExecutionEngine")  # noqa: TRY003, TRY004 # FIXME CoP
 
 
-@public_api
-def column_aggregate_partial(engine: Type[ExecutionEngine], **kwargs):
+def column_aggregate_partial(engine: Type[ExecutionEngine], **kwargs):  # noqa: C901 # FIXME CoP
     """Provides engine-specific support for authoring a metric_fn with a simplified signature.
 
     A column_aggregate_partial must provide an aggregate function; it will be executed with the specified engine
@@ -116,21 +120,19 @@ def column_aggregate_partial(engine: Type[ExecutionEngine], **kwargs):
 
     Returns:
         An annotated metric_function which will be called with a simplified signature.
-    """
-    partial_fn_type: MetricPartialFunctionTypes = (
-        MetricPartialFunctionTypes.AGGREGATE_FN
-    )
+    """  # noqa: E501 # FIXME CoP
+    partial_fn_type: MetricPartialFunctionTypes = MetricPartialFunctionTypes.AGGREGATE_FN
     domain_type: MetricDomainTypes = MetricDomainTypes.COLUMN
     if issubclass(engine, SqlAlchemyExecutionEngine):
 
         def wrapper(metric_fn: Callable):
             @metric_partial(
-                engine=SqlAlchemyExecutionEngine,
+                engine=engine,
                 partial_fn_type=partial_fn_type,
                 domain_type=domain_type,
             )
             @wraps(metric_fn)
-            def inner_func(
+            def inner_func(  # noqa: PLR0913 # FIXME CoP
                 cls,
                 execution_engine: SqlAlchemyExecutionEngine,
                 metric_domain_kwargs: dict,
@@ -141,12 +143,18 @@ def column_aggregate_partial(engine: Type[ExecutionEngine], **kwargs):
                 filter_column_isnull = kwargs.get(
                     "filter_column_isnull", getattr(cls, "filter_column_isnull", False)
                 )
+
+                metric_domain_kwargs = get_dbms_compatible_metric_domain_kwargs(
+                    metric_domain_kwargs=metric_domain_kwargs,
+                    batch_columns_list=metrics["table.columns"],
+                )
+
                 if filter_column_isnull:
                     compute_domain_kwargs = execution_engine.add_column_row_condition(
                         metric_domain_kwargs
                     )
                 else:
-                    # We do not copy here because if compute domain is different, it will be copied by get_compute_domain
+                    # We do not copy here because if compute domain is different, it will be copied by get_compute_domain  # noqa: E501 # FIXME CoP
                     compute_domain_kwargs = metric_domain_kwargs
                 (
                     selectable,
@@ -156,12 +164,7 @@ def column_aggregate_partial(engine: Type[ExecutionEngine], **kwargs):
                     compute_domain_kwargs, domain_type=domain_type
                 )
 
-                column_name: Union[str, quoted_name] = accessor_domain_kwargs["column"]
-
-                column_name = get_dbms_compatible_column_names(
-                    column_names=column_name,
-                    batch_columns_list=metrics["table.columns"],
-                )
+                column_name: Union[str, sqlalchemy.quoted_name] = accessor_domain_kwargs["column"]
 
                 sqlalchemy_engine: sa.engine.Engine = execution_engine.engine
 
@@ -186,12 +189,12 @@ def column_aggregate_partial(engine: Type[ExecutionEngine], **kwargs):
 
         def wrapper(metric_fn: Callable):
             @metric_partial(
-                engine=SparkDFExecutionEngine,
+                engine=engine,
                 partial_fn_type=partial_fn_type,
                 domain_type=domain_type,
             )
             @wraps(metric_fn)
-            def inner_func(
+            def inner_func(  # noqa: PLR0913 # FIXME CoP
                 cls,
                 execution_engine: SparkDFExecutionEngine,
                 metric_domain_kwargs: dict,
@@ -203,12 +206,17 @@ def column_aggregate_partial(engine: Type[ExecutionEngine], **kwargs):
                     "filter_column_isnull", getattr(cls, "filter_column_isnull", False)
                 )
 
+                metric_domain_kwargs = get_dbms_compatible_metric_domain_kwargs(
+                    metric_domain_kwargs=metric_domain_kwargs,
+                    batch_columns_list=metrics["table.columns"],
+                )
+
                 if filter_column_isnull:
                     compute_domain_kwargs = execution_engine.add_column_row_condition(
                         metric_domain_kwargs
                     )
                 else:
-                    # We do not copy here because if compute domain is different, it will be copied by get_compute_domain
+                    # We do not copy here because if compute domain is different, it will be copied by get_compute_domain  # noqa: E501 # FIXME CoP
                     compute_domain_kwargs = metric_domain_kwargs
 
                 (
@@ -219,14 +227,9 @@ def column_aggregate_partial(engine: Type[ExecutionEngine], **kwargs):
                     domain_kwargs=compute_domain_kwargs, domain_type=domain_type
                 )
 
-                column_name: Union[str, quoted_name] = accessor_domain_kwargs["column"]
+                column_name: Union[str, sqlalchemy.quoted_name] = accessor_domain_kwargs["column"]
 
-                column_name = get_dbms_compatible_column_names(
-                    column_names=column_name,
-                    batch_columns_list=metrics["table.columns"],
-                )
-
-                column = data[column_name]
+                column = F.col(column_name)
                 metric_aggregate = metric_fn(
                     cls,
                     column=column,
@@ -242,10 +245,9 @@ def column_aggregate_partial(engine: Type[ExecutionEngine], **kwargs):
         return wrapper
 
     else:
-        raise ValueError("Unsupported engine for column_aggregate_partial")
+        raise ValueError("Unsupported engine for column_aggregate_partial")  # noqa: TRY003, TRY004 # FIXME CoP
 
 
-@public_api
 class ColumnAggregateMetricProvider(TableMetricProvider):
     """Base class for all Column Aggregate Metrics,
     which define metrics to be calculated in aggregate from a given column.
@@ -276,6 +278,7 @@ class ColumnAggregateMetricProvider(TableMetricProvider):
     filter_column_isnull = False
 
     @classmethod
+    @override
     def _get_evaluation_dependencies(
         cls,
         metric: MetricConfiguration,
@@ -312,7 +315,5 @@ class ColumnAggregateMetricProvider(TableMetricProvider):
         return dependencies
 
 
-class ColumnMetricProvider(
-    ColumnAggregateMetricProvider, metaclass=DeprecatedMetaMetricProvider
-):
+class ColumnMetricProvider(ColumnAggregateMetricProvider, metaclass=DeprecatedMetaMetricProvider):
     _DeprecatedMetaMetricProvider__alias = ColumnAggregateMetricProvider
