@@ -1,15 +1,18 @@
+from __future__ import annotations
+
 import copy
 import logging
-from typing import Any, Dict
+from typing import TYPE_CHECKING, Any, Dict
 
 import numpy as np
-import pandas as pd
 
-from great_expectations.core.metric_domain_types import MetricDomainTypes
-from great_expectations.core.util import (
-    convert_to_json_serializable,
-    get_sql_dialect_floating_point_infinity_value,
+from great_expectations.compatibility import pyspark
+from great_expectations.compatibility.pyspark import (
+    functions as F,
 )
+from great_expectations.compatibility.sqlalchemy import sqlalchemy as sa
+from great_expectations.core.metric_domain_types import MetricDomainTypes
+from great_expectations.core.util import get_sql_dialect_floating_point_infinity_value
 from great_expectations.execution_engine import (
     PandasExecutionEngine,
     SparkDFExecutionEngine,
@@ -18,8 +21,11 @@ from great_expectations.execution_engine import (
 from great_expectations.expectations.metrics.column_aggregate_metric_provider import (
     ColumnAggregateMetricProvider,
 )
-from great_expectations.expectations.metrics.import_manager import Bucketizer, F, sa
 from great_expectations.expectations.metrics.metric_provider import metric_value
+from great_expectations.util import convert_to_json_serializable  # noqa: TID251 # FIXME CoP
+
+if TYPE_CHECKING:
+    import pandas as pd
 
 logger = logging.getLogger(__name__)
 
@@ -45,7 +51,7 @@ class ColumnHistogram(ColumnAggregateMetricProvider):
         column_series: pd.Series = df[column]
         column_null_elements_cond: pd.Series = column_series.isnull()
         column_nonnull_elements: pd.Series = column_series[~column_null_elements_cond]
-        hist, bin_edges = np.histogram(column_nonnull_elements, bins, density=False)
+        hist, _bin_edges = np.histogram(column_nonnull_elements, bins, density=False)
         return list(hist)
 
     @metric_value(engine=SqlAlchemyExecutionEngine)
@@ -62,7 +68,7 @@ class ColumnHistogram(ColumnAggregateMetricProvider):
         Args:
             column: the name of the column for which to get the histogram
             bins: tuple of bin edges for which to get histogram values; *must* be tuple to support caching
-        """
+        """  # noqa: E501 # FIXME CoP
         selectable, _, accessor_domain_kwargs = execution_engine.get_compute_domain(
             domain_kwargs=metric_domain_kwargs, domain_type=MetricDomainTypes.COLUMN
         )
@@ -78,120 +84,99 @@ class ColumnHistogram(ColumnAggregateMetricProvider):
         if len(bins) == 1 and not (
             (
                 bins[0]
-                == get_sql_dialect_floating_point_infinity_value(
-                    schema="api_np", negative=True
-                )
+                == get_sql_dialect_floating_point_infinity_value(schema="api_np", negative=True)
             )
             or (
                 bins[0]
-                == get_sql_dialect_floating_point_infinity_value(
-                    schema="api_cast", negative=True
-                )
+                == get_sql_dialect_floating_point_infinity_value(schema="api_cast", negative=True)
             )
             or (
                 bins[0]
-                == get_sql_dialect_floating_point_infinity_value(
-                    schema="api_np", negative=False
-                )
+                == get_sql_dialect_floating_point_infinity_value(schema="api_np", negative=False)
             )
             or (
                 bins[0]
-                == get_sql_dialect_floating_point_infinity_value(
-                    schema="api_cast", negative=False
-                )
+                == get_sql_dialect_floating_point_infinity_value(schema="api_cast", negative=False)
             )
         ):
-            # Single-valued column data are modeled using "impulse" (or "sample") distributions (on open interval).
+            # Single-valued column data are modeled using "impulse" (or "sample") distributions (on open interval).  # noqa: E501 # FIXME CoP
             case_conditions.append(
                 sa.func.sum(
                     sa.case(
-                        [
-                            (
-                                sa.and_(
-                                    float(bins[0] - np.finfo(float).eps)
-                                    < sa.column(column),
-                                    sa.column(column)
-                                    < float(bins[0] + np.finfo(float).eps),
-                                ),
-                                1,
-                            )
-                        ],
+                        (
+                            sa.and_(
+                                float(bins[0] - np.finfo(float).eps) < sa.column(column),
+                                sa.column(column) < float(bins[0] + np.finfo(float).eps),
+                            ),
+                            1,
+                        ),
                         else_=0,
                     )
                 ).label("bin_0")
             )
             query = (
-                sa.select(case_conditions)
+                sa.select(*case_conditions)
                 .where(
-                    sa.column(column) != None,  # noqa: E711
+                    sa.column(column) != None,  # noqa: E711 # FIXME CoP
                 )
-                .select_from(selectable)
+                .select_from(selectable)  # type: ignore[arg-type] # FIXME CoP
             )
 
-            # Run the data through convert_to_json_serializable to ensure we do not have Decimal types
+            # Run the data through convert_to_json_serializable to ensure we do not have Decimal types  # noqa: E501 # FIXME CoP
             return convert_to_json_serializable(
-                list(execution_engine.engine.execute(query).fetchone())
+                list(execution_engine.execute_query(query).fetchone())  # type: ignore[arg-type] # FIXME CoP
             )
 
         idx = 0
 
         # If we have an infinite lower bound, don't express that in sql
         if (
-            bins[0]
-            == get_sql_dialect_floating_point_infinity_value(
-                schema="api_np", negative=True
-            )
+            bins[0] == get_sql_dialect_floating_point_infinity_value(schema="api_np", negative=True)
         ) or (
             bins[0]
-            == get_sql_dialect_floating_point_infinity_value(
-                schema="api_cast", negative=True
-            )
+            == get_sql_dialect_floating_point_infinity_value(schema="api_cast", negative=True)
         ):
             case_conditions.append(
-                sa.func.sum(
-                    sa.case([(sa.column(column) < bins[idx + 1], 1)], else_=0)
-                ).label(f"bin_{str(idx)}")
+                sa.func.sum(sa.case((sa.column(column) < bins[idx + 1], 1), else_=0)).label(
+                    f"bin_{idx!s}"
+                )
             )
             idx += 1
 
         negative_boundary: float
         positive_boundary: float
-        for idx in range(idx, len(bins) - 2):
+        for idx in range(  # noqa: B020 # loop-variable-overrides-iterator
+            idx, len(bins) - 2
+        ):
             negative_boundary = float(bins[idx])
             positive_boundary = float(bins[idx + 1])
             case_conditions.append(
                 sa.func.sum(
                     sa.case(
-                        [
-                            (
-                                sa.and_(
-                                    negative_boundary <= sa.column(column),
-                                    sa.column(column) < positive_boundary,
-                                ),
-                                1,
-                            )
-                        ],
+                        (
+                            sa.and_(
+                                negative_boundary <= sa.column(column),
+                                sa.column(column) < positive_boundary,
+                            ),
+                            1,
+                        ),
                         else_=0,
                     )
-                ).label(f"bin_{str(idx)}")
+                ).label(f"bin_{idx!s}")
             )
 
         if (
             bins[-1]
-            == get_sql_dialect_floating_point_infinity_value(
-                schema="api_np", negative=False
-            )
+            == get_sql_dialect_floating_point_infinity_value(schema="api_np", negative=False)
         ) or (
             bins[-1]
-            == get_sql_dialect_floating_point_infinity_value(
-                schema="api_cast", negative=False
-            )
+            == get_sql_dialect_floating_point_infinity_value(schema="api_cast", negative=False)
         ):
             negative_boundary = float(bins[-2])
             case_conditions.append(
-                sa.func.sum(
-                    sa.case([(negative_boundary <= sa.column(column), 1)], else_=0)
-                ).label(f"bin_{str(len(bins) - 1)}")
+                sa.func.sum(sa.case((negative_boundary <= sa.column(column), 1), else_=0)).label(
+                    f"bin_{len(bins) - 1!s}"
+                )
             )
         else:
             negative_boundary = float(bins[-2])
@@ -199,35 +184,31 @@ class ColumnHistogram(ColumnAggregateMetricProvider):
             case_conditions.append(
                 sa.func.sum(
                     sa.case(
-                        [
-                            (
-                                sa.and_(
-                                    negative_boundary <= sa.column(column),
-                                    sa.column(column) <= positive_boundary,
-                                ),
-                                1,
-                            )
-                        ],
+                        (
+                            sa.and_(
+                                negative_boundary <= sa.column(column),
+                                sa.column(column) <= positive_boundary,
+                            ),
+                            1,
+                        ),
                         else_=0,
                     )
-                ).label(f"bin_{str(len(bins) - 1)}")
+                ).label(f"bin_{len(bins) - 1!s}")
             )
 
         query = (
-            sa.select(case_conditions)
+            sa.select(*case_conditions)
             .where(
-                sa.column(column) != None,  # noqa: E711
+                sa.column(column) != None,  # noqa: E711 # FIXME CoP
             )
-            .select_from(selectable)
+            .select_from(selectable)  # type: ignore[arg-type] # FIXME CoP
         )
 
         # Run the data through convert_to_json_serializable to ensure we do not have Decimal types
-        return convert_to_json_serializable(
-            list(execution_engine.engine.execute(query).fetchone())
-        )
+        return convert_to_json_serializable(list(execution_engine.execute_query(query).fetchone()))  # type: ignore[arg-type] # FIXME CoP
 
     @metric_value(engine=SparkDFExecutionEngine)
-    def _spark(
+    def _spark(  # noqa: C901 # FIXME CoP
         cls,
         execution_engine: SparkDFExecutionEngine,
         metric_domain_kwargs: dict,
@@ -235,16 +216,14 @@ class ColumnHistogram(ColumnAggregateMetricProvider):
         metrics: Dict[str, Any],
         runtime_configuration: dict,
     ):
-        df, _, accessor_domain_kwargs = execution_engine.get_compute_domain(
+        df, _, _accessor_domain_kwargs = execution_engine.get_compute_domain(
             domain_kwargs=metric_domain_kwargs, domain_type=MetricDomainTypes.COLUMN
         )
         bins = metric_value_kwargs["bins"]
         column = metric_domain_kwargs["column"]
 
         """return a list of counts corresponding to bins"""
-        bins = list(
-            copy.deepcopy(bins)
-        )  # take a copy since we are inserting and popping
+        bins = list(copy.deepcopy(bins))  # take a copy since we are inserting and popping
 
         if bins[0] == -np.inf or bins[0] == -float("inf"):
             added_min = False
@@ -261,7 +240,7 @@ class ColumnHistogram(ColumnAggregateMetricProvider):
             bins.append(float("inf"))
 
         temp_column = df.select(column).where(F.col(column).isNotNull())
-        bucketizer = Bucketizer(splits=bins, inputCol=column, outputCol="buckets")
+        bucketizer = pyspark.Bucketizer(splits=bins, inputCol=column, outputCol="buckets")
         bucketed = bucketizer.setHandleInvalid("skip").transform(temp_column)
 
         # This is painful to do, but: bucketizer cannot handle values outside of a range
@@ -275,9 +254,7 @@ class ColumnHistogram(ColumnAggregateMetricProvider):
 
         # We'll try for an optimization by asking for it at the same time
         if added_max:
-            upper_bound_count = (
-                temp_column.select(column).filter(F.col(column) == bins[-2]).count()
-            )
+            upper_bound_count = temp_column.select(column).filter(F.col(column) == bins[-2]).count()
         else:
             upper_bound_count = 0
 
