@@ -1,6 +1,8 @@
-from typing import Any, Dict, Optional
+from __future__ import annotations
 
-from great_expectations.core import ExpectationConfiguration  # noqa: TCH001
+from typing import TYPE_CHECKING, Any, Dict, Optional
+
+from great_expectations.compatibility.typing_extensions import override
 from great_expectations.execution_engine import (
     ExecutionEngine,
     PandasExecutionEngine,
@@ -14,6 +16,11 @@ from great_expectations.expectations.metrics.column_aggregate_metric_provider im
 from great_expectations.expectations.metrics.metric_provider import metric_value
 from great_expectations.validator.metric_configuration import MetricConfiguration
 
+if TYPE_CHECKING:
+    from great_expectations.expectations.expectation_configuration import (
+        ExpectationConfiguration,
+    )
+
 
 class ColumnMostCommonValue(ColumnAggregateMetricProvider):
     metric_name = "column.most_common_value"
@@ -32,10 +39,8 @@ class ColumnMostCommonValue(ColumnAggregateMetricProvider):
         metrics: Dict[str, Any],
         runtime_configuration: dict,
     ):
-        column_value_counts = metrics.get("column.value_counts")
-        return list(
-            column_value_counts[column_value_counts == column_value_counts.max()].index
-        )
+        column_value_counts = metrics["column.value_counts"]
+        return list(column_value_counts[column_value_counts == column_value_counts.max()].index)
 
     @metric_value(engine=SqlAlchemyExecutionEngine)
     def _sqlalchemy(
@@ -46,12 +51,11 @@ class ColumnMostCommonValue(ColumnAggregateMetricProvider):
         metrics: Dict[str, Any],
         runtime_configuration: dict,
     ):
-        column_value_counts = metrics.get("column.value_counts")
-        return list(
-            column_value_counts[column_value_counts == column_value_counts.max()].index
-        )
+        column_value_counts = metrics["column.value_counts"]
+        return list(column_value_counts[column_value_counts == column_value_counts.max()].index)
 
     @classmethod
+    @override
     def _get_evaluation_dependencies(
         cls,
         metric: MetricConfiguration,
@@ -68,9 +72,7 @@ class ColumnMostCommonValue(ColumnAggregateMetricProvider):
             runtime_configuration=runtime_configuration,
         )
 
-        if isinstance(
-            execution_engine, (SparkDFExecutionEngine, SqlAlchemyExecutionEngine)
-        ):
+        if isinstance(execution_engine, (SparkDFExecutionEngine, SqlAlchemyExecutionEngine)):
             dependencies["column.value_counts"] = MetricConfiguration(
                 metric_name="column.value_counts",
                 metric_domain_kwargs=metric.metric_domain_kwargs,
