@@ -1,10 +1,13 @@
+from __future__ import annotations
+
 import json
 
+from great_expectations.compatibility import pyspark
+from great_expectations.compatibility.pyspark import functions as F
 from great_expectations.execution_engine import (
     PandasExecutionEngine,
     SparkDFExecutionEngine,
 )
-from great_expectations.expectations.metrics.import_manager import F, sparktypes
 from great_expectations.expectations.metrics.map_metric_provider import (
     ColumnMapMetricProvider,
     column_condition_partial,
@@ -34,6 +37,6 @@ class ColumnValuesJsonParseable(ColumnMapMetricProvider):
             except Exception:
                 return False
 
-        is_json_udf = F.udf(is_json, sparktypes.BooleanType())
+        is_json_udf = F.udf(is_json, pyspark.types.BooleanType())
 
         return is_json_udf(column)
