@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import logging
 
 from great_expectations.execution_engine.sqlalchemy_execution_engine import (
@@ -24,9 +26,7 @@ class ColumnValuesMatchLikePattern(ColumnMapMetricProvider):
             column, _dialect, like_pattern
         )
         if like_pattern_expression is None:
-            logger.warning(
-                f"Like patterns are not supported for dialect {str(_dialect.name)}"
-            )
+            logger.warning(f"Like patterns are not supported for dialect {_dialect.name!s}")
             raise NotImplementedError
 
         return like_pattern_expression
