@@ -1,9 +1,11 @@
+from __future__ import annotations
+
 import logging
 
+from great_expectations.compatibility.sqlalchemy import sqlalchemy as sa
 from great_expectations.execution_engine.sqlalchemy_execution_engine import (
     SqlAlchemyExecutionEngine,
 )
-from great_expectations.expectations.metrics.import_manager import sa
 from great_expectations.expectations.metrics.map_metric_provider import (
     ColumnMapMetricProvider,
     column_condition_partial,
@@ -25,20 +27,16 @@ class ColumnValuesMatchLikePatternList(ColumnMapMetricProvider):
             match_on = "any"
 
         if match_on not in ["any", "all"]:
-            raise ValueError("match_on must be any or all")
+            raise ValueError("match_on must be any or all")  # noqa: TRY003 # FIXME CoP
 
         if len(like_pattern_list) == 0:
-            raise ValueError(
-                "At least one like_pattern must be supplied in the like_pattern_list."
-            )
+            raise ValueError("At least one like_pattern must be supplied in the like_pattern_list.")  # noqa: TRY003 # FIXME CoP
 
         like_pattern_expression = get_dialect_like_pattern_expression(
             column, _dialect, like_pattern_list[0]
         )
         if like_pattern_expression is None:
-            logger.warning(
-                f"Like patterns are not supported for dialect {str(_dialect.dialect.name)}"
-            )
+            logger.warning(f"Like patterns are not supported for dialect {_dialect.dialect.name!s}")
             raise NotImplementedError
 
         if match_on == "any":
