@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import numpy as np
 import pandas as pd
 
@@ -40,6 +42,6 @@ class ColumnValuesOfType(ColumnMapMetricProvider):
             comp_types.extend(native_type)
 
         if len(comp_types) < 1:
-            raise ValueError(f"Unrecognized numpy/python type: {type_}")
+            raise ValueError(f"Unrecognized numpy/python type: {type_}")  # noqa: TRY003 # FIXME CoP
 
         return column.map(lambda x: isinstance(x, tuple(comp_types)))
