@@ -1,6 +1,8 @@
-from typing import Any, Dict, Optional
+from __future__ import annotations
 
-from great_expectations.core import ExpectationConfiguration  # noqa: TCH001
+from typing import TYPE_CHECKING, Any, Dict, Optional
+
+from great_expectations.compatibility.typing_extensions import override
 from great_expectations.execution_engine import (
     ExecutionEngine,
     PandasExecutionEngine,
@@ -13,6 +15,11 @@ from great_expectations.expectations.metrics.table_metric_provider import (
 )
 from great_expectations.validator.metric_configuration import MetricConfiguration
 
+if TYPE_CHECKING:
+    from great_expectations.expectations.expectation_configuration import (
+        ExpectationConfiguration,
+    )
+
 
 class TableColumnCount(TableMetricProvider):
     metric_name = "table.column_count"
@@ -20,40 +27,41 @@ class TableColumnCount(TableMetricProvider):
     @metric_value(engine=PandasExecutionEngine)
     def _pandas(
         cls,
-        execution_engine: "ExecutionEngine",
+        execution_engine: ExecutionEngine,
         metric_domain_kwargs: dict,
         metric_value_kwargs: dict,
         metrics: Dict[str, Any],
         runtime_configuration: dict,
     ):
         columns = metrics.get("table.columns")
-        return len(columns)  # type: ignore[arg-type]
+        return len(columns)  # type: ignore[arg-type] # FIXME CoP
 
     @metric_value(engine=SqlAlchemyExecutionEngine)
     def _sqlalchemy(
         cls,
-        execution_engine: "ExecutionEngine",
+        execution_engine: ExecutionEngine,
         metric_domain_kwargs: dict,
         metric_value_kwargs: dict,
         metrics: Dict[str, Any],
         runtime_configuration: dict,
     ):
         columns = metrics.get("table.columns")
-        return len(columns)  # type: ignore[arg-type]
+        return len(columns)  # type: ignore[arg-type] # FIXME CoP
 
     @metric_value(engine=SparkDFExecutionEngine)
     def _spark(
         cls,
-        execution_engine: "ExecutionEngine",
+        execution_engine: ExecutionEngine,
         metric_domain_kwargs: dict,
         metric_value_kwargs: dict,
         metrics: Dict[str, Any],
         runtime_configuration: dict,
     ):
         columns = metrics.get("table.columns")
-        return len(columns)  # type: ignore[arg-type]
+        return len(columns)  # type: ignore[arg-type] # FIXME CoP
 
     @classmethod
+    @override
     def _get_evaluation_dependencies(
         cls,
         metric: MetricConfiguration,
