@@ -1,6 +1,8 @@
-from typing import Any, Dict, Optional
+from __future__ import annotations
 
-from great_expectations.core import ExpectationConfiguration  # noqa: TCH001
+from typing import TYPE_CHECKING, Any, Dict, Optional
+
+from great_expectations.compatibility.typing_extensions import override
 from great_expectations.execution_engine import (
     ExecutionEngine,
     PandasExecutionEngine,
@@ -13,10 +15,10 @@ from great_expectations.expectations.metrics.table_metric_provider import (
 )
 from great_expectations.validator.metric_configuration import MetricConfiguration
 
-try:
-    import pyspark.sql.types as sparktypes
-except ImportError:
-    sparktypes = None
+if TYPE_CHECKING:
+    from great_expectations.expectations.expectation_configuration import (
+        ExpectationConfiguration,
+    )
 
 
 class TableColumns(TableMetricProvider):
@@ -59,6 +61,7 @@ class TableColumns(TableMetricProvider):
         return [col["name"] for col in column_metadata]
 
     @classmethod
+    @override
     def _get_evaluation_dependencies(
         cls,
         metric: MetricConfiguration,
@@ -75,11 +78,12 @@ class TableColumns(TableMetricProvider):
         table_domain_kwargs: dict = {
             k: v for k, v in metric.metric_domain_kwargs.items() if k != "column"
         }
+        metric_value_kwargs = {
+            "include_nested": True,
+        }
         dependencies["table.column_types"] = MetricConfiguration(
             metric_name="table.column_types",
             metric_domain_kwargs=table_domain_kwargs,
-            metric_value_kwargs={
-                "include_nested": True,
-            },
+            metric_value_kwargs=metric.metric_value_kwargs or metric_value_kwargs,
         )
         return dependencies
