@@ -1,13 +1,17 @@
+from __future__ import annotations
+
 import logging
 import re
 import traceback
 
-from great_expectations.core.expectation_configuration import ExpectationConfiguration
 from great_expectations.core.expectation_validation_result import (
     ExpectationValidationResult,
 )
 from great_expectations.data_context.util import instantiate_class_from_config
 from great_expectations.exceptions import ClassInstantiationError
+from great_expectations.expectations.expectation_configuration import (
+    ExpectationConfiguration,
+)
 from great_expectations.expectations.registry import get_renderer_impl
 from great_expectations.render import (
     LegacyDescriptiveRendererType,
@@ -47,17 +51,15 @@ class ColumnSectionRenderer(Renderer):
             elif isinstance(candidate_object, ExpectationValidationResult):
                 return candidate_object.expectation_config.kwargs["column"]
             else:
-                raise ValueError(
-                    "Provide a column section renderer an expectation, list of expectations, evr, or list of evrs."
+                raise ValueError(  # noqa: TRY003, TRY004 # FIXME CoP
+                    "Provide a column section renderer an expectation, list of expectations, evr, or list of evrs."  # noqa: E501 # FIXME CoP
                 )
         except KeyError:
             return "Table-Level Expectations"
 
 
 class ProfilingResultsColumnSectionRenderer(ColumnSectionRenderer):
-    def __init__(
-        self, properties_table_renderer=None, runtime_environment=None
-    ) -> None:
+    def __init__(self, properties_table_renderer=None, runtime_environment=None) -> None:
         super().__init__()
         if properties_table_renderer is None:
             properties_table_renderer = {
@@ -89,7 +91,7 @@ class ProfilingResultsColumnSectionRenderer(ColumnSectionRenderer):
 
     # Note: Seems awkward to pass section_name and column_type into this renderer.
     # Can't we figure that out internally?
-    def render(self, evrs, section_name=None, column_type=None):
+    def render(self, evrs, section_name=None, column_type=None):  # type: ignore[explicit-override] # FIXME
         if section_name is None:
             column = self._get_column_name(evrs)
         else:
@@ -104,18 +106,18 @@ class ProfilingResultsColumnSectionRenderer(ColumnSectionRenderer):
                         getattr(self, content_block_function_name)(evrs, column_type)
                     )
                 else:
-                    content_blocks.append(
-                        getattr(self, content_block_function_name)(evrs)
-                    )
+                    content_blocks.append(getattr(self, content_block_function_name)(evrs))
             except Exception as e:
                 exception_message = """\
 An unexpected Exception occurred during data docs rendering.  Because of this error, certain parts of data docs will \
 not be rendered properly and/or may not appear altogether.  Please use the trace, included in this message, to \
 diagnose and repair the underlying issue.  Detailed information follows:
-                """
+                """  # noqa: E501 # FIXME CoP
                 exception_traceback = traceback.format_exc()
-                exception_message += f'{type(e).__name__}: "{str(e)}".  Traceback: "{exception_traceback}".'
-                logger.error(exception_message)
+                exception_message += (
+                    f'{type(e).__name__}: "{e!s}".  Traceback: "{exception_traceback}".'
+                )
+                logger.error(exception_message)  # noqa: TRY400 # FIXME CoP
 
         # NOTE : Some render* functions return None so we filter them out
         populated_content_blocks = list(filter(None, content_blocks))
@@ -158,7 +160,7 @@ diagnose and repair the underlying issue.  Detailed information follows:
                         "string_template": {
                             "template": f"Type: {column_type}",
                             "tooltip": {
-                                "content": "expect_column_values_to_be_of_type <br>expect_column_values_to_be_in_type_list",
+                                "content": "expect_column_values_to_be_of_type <br>expect_column_values_to_be_in_type_list",  # noqa: E501 # FIXME CoP
                             },
                             "tag": "h6",
                             "styling": {"classes": ["mt-1", "mb-0"]},
@@ -219,7 +221,7 @@ diagnose and repair the underlying issue.  Detailed information follows:
                 **{
                     "content_block_type": "bullet_list",
                     "header": RenderedStringTemplateContent(
-                        **{  # type: ignore[arg-type]
+                        **{  # type: ignore[arg-type] # FIXME CoP
                             "content_block_type": "string_template",
                             "string_template": {
                                 "template": 'Expectation types <span class="mr-3 triangle"></span>',
@@ -253,12 +255,8 @@ diagnose and repair the underlying issue.  Detailed information follows:
 
     def _render_properties_table(self, evrs):
         evr_list = [
-            self._find_evr_by_type(
-                evrs, "expect_column_unique_value_count_to_be_between"
-            ),
-            self._find_evr_by_type(
-                evrs, "expect_column_proportion_of_unique_values_to_be_between"
-            ),
+            self._find_evr_by_type(evrs, "expect_column_unique_value_count_to_be_between"),
+            self._find_evr_by_type(evrs, "expect_column_proportion_of_unique_values_to_be_between"),
             self._find_evr_by_type(evrs, "expect_column_values_to_not_be_null"),
             self._find_evr_by_type(evrs, "expect_column_values_to_not_match_regex"),
         ]
@@ -283,9 +281,7 @@ diagnose and repair the underlying issue.  Detailed information follows:
 
     @classmethod
     def _render_quantile_table(cls, evrs):
-        quantile_evr = cls._find_evr_by_type(
-            evrs, "expect_column_quantile_values_to_be_between"
-        )
+        quantile_evr = cls._find_evr_by_type(evrs, "expect_column_quantile_values_to_be_between")
 
         if not quantile_evr or quantile_evr.exception_info["raised_exception"]:
             return
@@ -397,17 +393,13 @@ class ValidationResultsColumnSectionRenderer(ColumnSectionRenderer):
     def __init__(self, table_renderer=None) -> None:
         super().__init__()
         if table_renderer is None:
-            table_renderer = {
-                "class_name": "ValidationResultsTableContentBlockRenderer"
-            }
+            table_renderer = {"class_name": "ValidationResultsTableContentBlockRenderer"}
         module_name = table_renderer.get(
             "module_name", "great_expectations.render.renderer.content_block"
         )
         verify_dynamic_loading_support(module_name=module_name)
         class_name = table_renderer.get("class_name")
-        self._table_renderer = load_class(
-            class_name=class_name, module_name=module_name
-        )
+        self._table_renderer = load_class(class_name=class_name, module_name=module_name)
 
     @classmethod
     def _render_header(cls, validation_results):
@@ -434,43 +426,35 @@ class ValidationResultsColumnSectionRenderer(ColumnSectionRenderer):
 
         return validation_results, new_block
 
-    def _render_table(self, validation_results, evaluation_parameters=None):
+    def _render_table(self, validation_results, suite_parameters=None):
         new_block = self._table_renderer.render(
             validation_results,
             include_column_name=False,
-            evaluation_parameters=evaluation_parameters,
+            suite_parameters=suite_parameters,
         )
         return [], new_block
 
-    def render(self, validation_results, evaluation_parameters=None):
+    def render(self, validation_results, suite_parameters=None):  # type: ignore[explicit-override] # FIXME
         column = self._get_column_name(validation_results)
         content_blocks = []
         remaining_evrs, content_block = self._render_header(validation_results)
         content_blocks.append(content_block)
-        remaining_evrs, content_block = self._render_table(
-            remaining_evrs, evaluation_parameters
-        )
+        remaining_evrs, content_block = self._render_table(remaining_evrs, suite_parameters)
         content_blocks.append(content_block)
-        return RenderedSectionContent(
-            **{"section_name": column, "content_blocks": content_blocks}
-        )
+        return RenderedSectionContent(**{"section_name": column, "content_blocks": content_blocks})
 
 
 class ExpectationSuiteColumnSectionRenderer(ColumnSectionRenderer):
     def __init__(self, bullet_list_renderer=None) -> None:
         super().__init__()
         if bullet_list_renderer is None:
-            bullet_list_renderer = {
-                "class_name": "ExpectationSuiteBulletListContentBlockRenderer"
-            }
+            bullet_list_renderer = {"class_name": "ExpectationSuiteBulletListContentBlockRenderer"}
         module_name = bullet_list_renderer.get(
             "module_name", "great_expectations.render.renderer.content_block"
         )
         verify_dynamic_loading_support(module_name=module_name)
         class_name = bullet_list_renderer.get("class_name")
-        self._bullet_list_renderer = load_class(
-            class_name=class_name, module_name=module_name
-        )
+        self._bullet_list_renderer = load_class(class_name=class_name, module_name=module_name)
 
     @classmethod
     def _render_header(cls, expectations):
@@ -498,7 +482,6 @@ class ExpectationSuiteColumnSectionRenderer(ColumnSectionRenderer):
         return expectations, new_block
 
     def _render_bullet_list(self, expectations):
-
         new_block = self._bullet_list_renderer.render(
             expectations,
             include_column_name=False,
@@ -506,7 +489,7 @@ class ExpectationSuiteColumnSectionRenderer(ColumnSectionRenderer):
 
         return [], new_block
 
-    def render(self, expectations):
+    def render(self, expectations):  # type: ignore[explicit-override] # FIXME
         column = self._get_column_name(expectations)
 
         content_blocks = []
@@ -514,13 +497,9 @@ class ExpectationSuiteColumnSectionRenderer(ColumnSectionRenderer):
         content_blocks.append(header_block)
         # remaining_expectations, content_blocks = cls._render_column_type(
         # remaining_expectations, content_blocks)
-        remaining_expectations, bullet_block = self._render_bullet_list(
-            remaining_expectations
-        )
+        remaining_expectations, bullet_block = self._render_bullet_list(remaining_expectations)
         content_blocks.append(bullet_block)
 
         # NOTE : Some render* functions return None so we filter them out
         populated_content_blocks = list(filter(None, content_blocks))
-        return RenderedSectionContent(
-            section_name=column, content_blocks=populated_content_blocks
-        )
+        return RenderedSectionContent(section_name=column, content_blocks=populated_content_blocks)
