@@ -1,4 +1,4 @@
-from great_expectations.render.renderer.content_block.validation_results_table_content_block import (
+from great_expectations.render.renderer.content_block.validation_results_table_content_block import (  # noqa: E501 # FIXME CoP
     ValidationResultsTableContentBlockRenderer,
 )
 
