@@ -1,18 +1,26 @@
-from typing import List, Optional
+from __future__ import annotations
 
-from great_expectations.core import (
-    ExpectationConfiguration,  # noqa: TCH001
-    ExpectationValidationResult,  # noqa: TCH001
-)
+from typing import TYPE_CHECKING, List, Optional
+
+from great_expectations.compatibility.typing_extensions import override
 from great_expectations.render import RenderedStringTemplateContent
 from great_expectations.render.renderer.content_block.content_block import (
     ContentBlockRenderer,
 )
 from great_expectations.render.renderer_configuration import RendererConfiguration
 
+if TYPE_CHECKING:
+    from great_expectations.core import (
+        ExpectationValidationResult,
+    )
+    from great_expectations.expectations.expectation_configuration import (
+        ExpectationConfiguration,
+    )
+
 
 class ExpectationStringRenderer(ContentBlockRenderer):
     @classmethod
+    @override
     def _missing_content_block_fn(
         cls,
         configuration: Optional[ExpectationConfiguration] = None,
@@ -27,7 +35,7 @@ class ExpectationStringRenderer(ContentBlockRenderer):
         )
         return [
             RenderedStringTemplateContent(
-                **{  # type: ignore[arg-type]
+                **{  # type: ignore[arg-type] # FIXME CoP
                     "content_block_type": "string_template",
                     "styling": {"parent": {"classes": ["alert", "alert-warning"]}},
                     "string_template": {
@@ -59,7 +67,7 @@ class ExpectationStringRenderer(ContentBlockRenderer):
         assert result, "Must provide a result object."
         if result.exception_info["raised_exception"]:
             return RenderedStringTemplateContent(
-                **{  # type: ignore[arg-type]
+                **{  # type: ignore[arg-type] # FIXME CoP
                     "content_block_type": "string_template",
                     "string_template": {
                         "template": "$icon",
@@ -82,7 +90,7 @@ class ExpectationStringRenderer(ContentBlockRenderer):
 
         if result.success:
             return RenderedStringTemplateContent(
-                **{  # type: ignore[arg-type]
+                **{  # type: ignore[arg-type] # FIXME CoP
                     "content_block_type": "string_template",
                     "string_template": {
                         "template": "$icon",
@@ -100,16 +108,12 @@ class ExpectationStringRenderer(ContentBlockRenderer):
                             }
                         },
                     },
-                    "styling": {
-                        "parent": {
-                            "classes": ["hide-succeeded-validation-target-child"]
-                        }
-                    },
+                    "styling": {"parent": {"classes": ["hide-succeeded-validation-target-child"]}},
                 }
             )
         else:
             return RenderedStringTemplateContent(
-                **{  # type: ignore[arg-type]
+                **{  # type: ignore[arg-type] # FIXME CoP
                     "content_block_type": "string_template",
                     "string_template": {
                         "template": "$icon",
