@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+from great_expectations.compatibility.typing_extensions import override
 from great_expectations.expectations.registry import get_renderer_impl
 from great_expectations.render import (
     LegacyDescriptiveRendererType,
@@ -26,6 +29,7 @@ class ProfilingColumnPropertiesTableContentBlockRenderer(ContentBlockRenderer):
     }
 
     @classmethod
+    @override
     def render(cls, ge_object, header_row=None):
         """Each expectation method should return a list of rows"""
         if header_row is None:
@@ -38,21 +42,15 @@ class ProfilingColumnPropertiesTableContentBlockRenderer(ContentBlockRenderer):
                 expectation_type = cls._get_expectation_type(sub_object)
                 if expectation_type in cls.expectation_renderers:
                     new_rows = [
-                        get_renderer_impl(expectation_type, renderer_type)[1](
-                            result=sub_object
-                        )
-                        for renderer_type in cls.expectation_renderers.get(
-                            expectation_type
-                        )
+                        get_renderer_impl(expectation_type, renderer_type)[1](result=sub_object)
+                        for renderer_type in cls.expectation_renderers.get(expectation_type)
                     ]
                     table_rows.extend(new_rows)
         else:
             expectation_type = cls._get_expectation_type(ge_object)
             if expectation_type in cls.expectation_renderers:
                 new_rows = [
-                    get_renderer_impl(expectation_type, renderer_type)[1](
-                        result=ge_object
-                    )
+                    get_renderer_impl(expectation_type, renderer_type)[1](result=ge_object)
                     for renderer_type in cls.expectation_renderers.get(expectation_type)
                 ]
                 table_rows.extend(new_rows)
