@@ -1,14 +1,13 @@
+from __future__ import annotations
+
 import logging
 import os
 from collections import OrderedDict, defaultdict
-from typing import Dict, List, Tuple, Union
+from typing import TYPE_CHECKING, Dict, List, Tuple, Union
 
 from dateutil.parser import parse
 
 from great_expectations.core import ExpectationSuite
-from great_expectations.core.expectation_validation_result import (
-    ExpectationSuiteValidationResult,  # noqa: TCH001
-)
 from great_expectations.core.run_identifier import RunIdentifier
 from great_expectations.data_context.util import instantiate_class_from_config
 from great_expectations.exceptions import ClassInstantiationError
@@ -26,9 +25,12 @@ from great_expectations.render import (
 )
 from great_expectations.render.renderer.renderer import Renderer
 from great_expectations.render.util import num_to_str
-from great_expectations.validation_operators.types.validation_operator_result import (
-    ValidationOperatorResult,  # noqa: TCH001
-)
+
+if TYPE_CHECKING:
+    from great_expectations.core.expectation_validation_result import (
+        ExpectationSuiteValidationResult,
+    )
+    from great_expectations.expectations.expectation_configuration import ExpectationConfiguration
 
 logger = logging.getLogger(__name__)
 
@@ -48,9 +50,7 @@ class ValidationResultsPageRenderer(Renderer):
         """
         super().__init__()
         if column_section_renderer is None:
-            column_section_renderer = {
-                "class_name": "ValidationResultsColumnSectionRenderer"
-            }
+            column_section_renderer = {"class_name": "ValidationResultsColumnSectionRenderer"}
         module_name = "great_expectations.render.renderer.column_section_renderer"
         self._column_section_renderer = instantiate_class_from_config(
             config=column_section_renderer,
@@ -68,32 +68,15 @@ class ValidationResultsPageRenderer(Renderer):
         self.run_info_at_end = run_info_at_end
         self._data_context = data_context
 
-    def render_validation_operator_result(
-        self, validation_operator_result: ValidationOperatorResult
-    ) -> List[RenderedDocumentContent]:
-        """
-        Render a ValidationOperatorResult which can have multiple ExpectationSuiteValidationResult
-
-        Args:
-            validation_operator_result: ValidationOperatorResult
-
-        Returns:
-            List[RenderedDocumentContent]
-        """
-        return [
-            self.render(validation_result)
-            for validation_result in validation_operator_result.list_validation_results()
-        ]
-
     # TODO: deprecate dual batch api support in 0.14
     def render(
         self,
         validation_results: ExpectationSuiteValidationResult,
-        evaluation_parameters=None,
+        suite_parameters=None,
     ):
         # Gather run identifiers
         run_name, run_time = self._parse_run_values(validation_results)
-        expectation_suite_name = validation_results.meta["expectation_suite_name"]
+        expectation_suite_name = validation_results.suite_name
         batch_kwargs = (
             validation_results.meta.get("batch_kwargs", {})
             or validation_results.meta.get("batch_spec", {})
@@ -101,9 +84,9 @@ class ValidationResultsPageRenderer(Renderer):
         )
 
         # Add datasource key to batch_kwargs if missing
-        if "datasource" not in batch_kwargs and "datasource" not in batch_kwargs:
-            # Check if expectation_suite_name follows datasource.batch_kwargs_generator.data_asset_name.suite_name pattern
-            if len(expectation_suite_name.split(".")) == 4:
+        if "datasource" not in batch_kwargs:
+            # Check if expectation_suite_name follows datasource.batch_kwargs_generator.data_asset_name.suite_name pattern  # noqa: E501 # FIXME CoP
+            if len(expectation_suite_name.split(".")) == 4:  # noqa: PLR2004 # FIXME CoP
                 batch_kwargs["datasource"] = expectation_suite_name.split(".")[0]
 
         columns = self._group_evrs_by_column(validation_results, expectation_suite_name)
@@ -139,12 +122,8 @@ class ValidationResultsPageRenderer(Renderer):
             **{
                 "renderer_type": "ValidationResultsPageRenderer",
                 "page_title": page_title,
-                "batch_kwargs": batch_kwargs
-                if "batch_kwargs" in validation_results.meta
-                else None,
-                "batch_spec": batch_kwargs
-                if "batch_spec" in validation_results.meta
-                else None,
+                "batch_kwargs": batch_kwargs if "batch_kwargs" in validation_results.meta else None,
+                "batch_spec": batch_kwargs if "batch_spec" in validation_results.meta else None,
                 "expectation_suite_name": expectation_suite_name,
                 "sections": sections,
                 "utm_medium": "validation-results-page",
@@ -182,7 +161,7 @@ class ValidationResultsPageRenderer(Renderer):
         columns = defaultdict(list)
         try:
             suite_meta = (
-                self._data_context.get_expectation_suite(expectation_suite_name).meta
+                self._data_context.suites.get(expectation_suite_name).meta
                 if self._data_context is not None
                 else None
             )
@@ -191,9 +170,9 @@ class ValidationResultsPageRenderer(Renderer):
         meta_properties_to_render = self._get_meta_properties_notes(suite_meta)
         for evr in validation_results.results:
             if meta_properties_to_render is not None:
-                evr.expectation_config.kwargs[
-                    "meta_properties_to_render"
-                ] = meta_properties_to_render
+                evr.expectation_config.kwargs["meta_properties_to_render"] = (
+                    meta_properties_to_render
+                )
             if "column" in evr.expectation_config.kwargs:
                 column = evr.expectation_config.kwargs["column"]
             else:
@@ -208,7 +187,6 @@ class ValidationResultsPageRenderer(Renderer):
         collapse_content_blocks: List[RenderedTableContent],
         validation_results: ExpectationSuiteValidationResult,
     ) -> CollapseContent:
-
         attrs = [
             ("batch_markers", "Batch Markers"),
             ("batch_kwargs", "Batch Kwargs"),
@@ -259,14 +237,14 @@ class ValidationResultsPageRenderer(Renderer):
             sections += [
                 self._column_section_renderer.render(
                     validation_results=columns["Table-Level Expectations"],
-                    evaluation_parameters=validation_results.evaluation_parameters,
+                    suite_parameters=validation_results.suite_parameters,
                 )
             ]
 
         sections += [
             self._column_section_renderer.render(
                 validation_results=columns[column],
-                evaluation_parameters=validation_results.evaluation_parameters,
+                suite_parameters=validation_results.suite_parameters,
             )
             for column in ordered_columns
         ]
@@ -299,7 +277,10 @@ class ValidationResultsPageRenderer(Renderer):
             run_time_datetime = None
 
         include_run_name: bool = False
-        if run_name_as_time != run_time_datetime and run_name_as_time != "__none__":
+        if (
+            run_name_as_time != run_time_datetime  # noqa: PLR1714 # FIXME CoP
+            and run_name_as_time != "__none__"
+        ):
             include_run_name = True
 
         page_title = f"Validations / {expectation_suite_name}"
@@ -347,8 +328,7 @@ class ValidationResultsPageRenderer(Renderer):
             suite_meta is not None
             and "notes" in suite_meta
             and "format" in suite_meta["notes"]
-            and suite_meta["notes"]["format"]
-            == LegacyDiagnosticRendererType.META_PROPERTIES
+            and suite_meta["notes"]["format"] == LegacyDiagnosticRendererType.META_PROPERTIES
         ):
             return suite_meta["notes"]["content"]
         else:
@@ -357,15 +337,13 @@ class ValidationResultsPageRenderer(Renderer):
     @classmethod
     def _render_validation_header(cls, validation_results):
         success = validation_results.success
-        expectation_suite_name = validation_results.meta["expectation_suite_name"]
+        expectation_suite_name = validation_results.suite_name
         expectation_suite_path_components = (
             [".." for _ in range(len(expectation_suite_name.split(".")) + 3)]
             + ["expectations"]
             + str(expectation_suite_name).split(".")
         )
-        expectation_suite_path = (
-            f"{os.path.join(*expectation_suite_path_components)}.html"
-        )
+        expectation_suite_path = f"{os.path.join(*expectation_suite_path_components)}.html"  # noqa: PTH118 # FIXME CoP
         # TODO: deprecate dual batch api support in 0.14
         batch_kwargs = (
             validation_results.meta.get("batch_kwargs", {})
@@ -381,9 +359,7 @@ class ValidationResultsPageRenderer(Renderer):
             )
         else:
             success = "Failed"
-            html_success_icon = (
-                '<i class="fas fa-times text-danger" aria-hidden="true"></i>'
-            )
+            html_success_icon = '<i class="fas fa-times text-danger" aria-hidden="true"></i>'
 
         return RenderedHeaderContent(
             **{
@@ -402,7 +378,7 @@ class ValidationResultsPageRenderer(Renderer):
                     **{
                         "content_block_type": "string_template",
                         "string_template": {
-                            "template": "${suite_title} ${expectation_suite_name}\n ${data_asset} ${data_asset_name}\n ${status_title} ${html_success_icon} ${success}",
+                            "template": "${suite_title} ${expectation_suite_name}\n ${data_asset} ${data_asset_name}\n ${status_title} ${html_success_icon} ${success}",  # noqa: E501 # FIXME CoP
                             "params": {
                                 "suite_title": "Expectation Suite:",
                                 "data_asset": "Data asset:",
@@ -445,9 +421,7 @@ class ValidationResultsPageRenderer(Renderer):
         elif isinstance(run_id, dict):
             run_name = run_id.get("run_name") or "__none__"
             try:
-                run_time = str(
-                    parse(run_id.get("run_time")).strftime("%Y-%m-%dT%H:%M:%SZ")
-                )
+                run_time = str(parse(run_id.get("run_time")).strftime("%Y-%m-%dT%H:%M:%SZ"))
             except (ValueError, TypeError):
                 run_time = "__none__"
         elif isinstance(run_id, RunIdentifier):
@@ -610,9 +584,7 @@ class ValidationResultsPageRenderer(Renderer):
             if statistics.get(key) is not None:
                 if key == "success_percent":
                     # table_rows.append([value, "{0:.2f}%".format(statistics[key])])
-                    table_rows.append(
-                        [value, f"{num_to_str(statistics[key], precision=4)}%"]
-                    )
+                    table_rows.append([value, f"{num_to_str(statistics[key], precision=4)}%"])
                 else:
                     table_rows.append([value, statistics[key]])
 
@@ -648,9 +620,7 @@ class ExpectationSuitePageRenderer(Renderer):
     def __init__(self, column_section_renderer=None) -> None:
         super().__init__()
         if column_section_renderer is None:
-            column_section_renderer = {
-                "class_name": "ExpectationSuiteColumnSectionRenderer"
-            }
+            column_section_renderer = {"class_name": "ExpectationSuiteColumnSectionRenderer"}
         module_name = "great_expectations.render.renderer.column_section_renderer"
         self._column_section_renderer = instantiate_class_from_config(
             config=column_section_renderer,
@@ -666,23 +636,61 @@ class ExpectationSuitePageRenderer(Renderer):
                 class_name=column_section_renderer["class_name"],
             )
 
+    @staticmethod
+    def _get_grouped_and_ordered_expectations_by_column(
+        expectation_suite: ExpectationSuite,
+    ) -> Tuple[Dict[str, List[ExpectationConfiguration]], List[str]]:
+        expectations_by_column: Dict[str, List[ExpectationConfiguration]] = {}
+        ordered_columns: List[str] = []
+
+        column: str
+        expectation: ExpectationConfiguration
+        expectation_configurations = [exp.configuration for exp in expectation_suite.expectations]
+        for expectation in expectation_configurations:
+            if "column" in expectation.kwargs:
+                column = expectation.kwargs["column"]
+            else:
+                column = "_nocolumn"
+
+            if column not in expectations_by_column:
+                expectations_by_column[column] = []
+
+            expectations_by_column[column].append(expectation)
+
+            # if possible, get the order of columns from expect_table_columns_to_match_ordered_list
+            if (
+                expectation.type == "expect_table_columns_to_match_ordered_list"
+                and expectation.kwargs.get("column_list")
+            ):
+                exp_column_list: List[str] = expectation.kwargs["column_list"]
+                if exp_column_list and len(exp_column_list) > 0:
+                    ordered_columns = exp_column_list
+
+        # Group items by column
+        sorted_columns = sorted(list(expectations_by_column.keys()))
+
+        # only return ordered columns from expect_table_columns_to_match_ordered_list evr if they match set of column  # noqa: E501 # FIXME CoP
+        # names from entire evr, else use alphabetic sort
+        if set(sorted_columns) == set(ordered_columns):
+            return expectations_by_column, ordered_columns
+
+        return expectations_by_column, sorted_columns
+
     def render(self, expectations):
         if isinstance(expectations, dict):
             expectations = ExpectationSuite(**expectations, data_context=None)
         (
             columns,
             ordered_columns,
-        ) = expectations.get_grouped_and_ordered_expectations_by_column()
-        expectation_suite_name = expectations.expectation_suite_name
+        ) = self._get_grouped_and_ordered_expectations_by_column(expectations)
 
+        expectation_suite_name = expectations.name
         overview_content_blocks = [
             self._render_expectation_suite_header(),
             self._render_expectation_suite_info(expectations),
         ]
 
-        table_level_expectations_content_block = self._render_table_level_expectations(
-            columns
-        )
+        table_level_expectations_content_block = self._render_table_level_expectations(columns)
         if table_level_expectations_content_block is not None:
             overview_content_blocks.append(table_level_expectations_content_block)
 
@@ -707,7 +715,7 @@ class ExpectationSuitePageRenderer(Renderer):
         return RenderedDocumentContent(
             **{
                 "renderer_type": "ExpectationSuitePageRenderer",
-                "page_title": f"Expectations / {str(expectation_suite_name)}",
+                "page_title": f"Expectations / {expectation_suite_name!s}",
                 "expectation_suite_name": expectation_suite_name,
                 "utm_medium": "expectation-suite-page",
                 "sections": sections,
@@ -758,11 +766,11 @@ class ExpectationSuitePageRenderer(Renderer):
 
     @classmethod
     def _render_expectation_suite_info(cls, expectations):
-        expectation_suite_name = expectations.expectation_suite_name
+        expectation_suite_name = expectations.name
         # TODO: Deprecate "great_expectations.__version__"
-        ge_version = expectations.meta.get(
-            "great_expectations_version"
-        ) or expectations.meta.get("great_expectations.__version__")
+        ge_version = expectations.meta.get("great_expectations_version") or expectations.meta.get(
+            "great_expectations.__version__"
+        )
 
         return RenderedTableContent(
             **{
@@ -796,76 +804,48 @@ class ExpectationSuitePageRenderer(Renderer):
 
     # TODO: Update tests
     @classmethod
-    def _render_expectation_suite_notes(cls, expectations):
-
+    def _render_expectation_suite_notes(cls, expectations: ExpectationSuite) -> TextContent:
         content = []
 
         total_expectations = len(expectations.expectations)
         columns = []
-        for exp in expectations.expectations:
+        for exp in expectations.expectation_configurations:
             if "column" in exp.kwargs:
                 columns.append(exp.kwargs["column"])
         total_columns = len(set(columns))
 
         content += [
             # TODO: Leaving these two paragraphs as placeholders for later development.
-            # "This Expectation suite was first generated by {BasicDatasetProfiler} on {date}, using version {xxx} of Great Expectations.",
+            # "This Expectation suite was first generated by {BasicDatasetProfiler} on {date}, using version {xxx} of Great Expectations.",  # noqa: E501 # FIXME CoP
             # "{name}, {name}, and {name} have also contributed additions and revisions.",
-            f"This Expectation suite currently contains {total_expectations} total Expectations across {total_columns} columns.",
+            f"This Expectation suite currently contains {total_expectations} total Expectations across {total_columns} columns.",  # noqa: E501 # FIXME CoP
         ]
 
-        if "notes" in expectations.meta:
-            notes = expectations.meta["notes"]
-            note_content = None
-
+        notes = expectations.notes
+        if notes:
             if isinstance(notes, str):
-                note_content = [notes]
-
-            elif isinstance(notes, list):
-                note_content = notes
-
-            elif isinstance(notes, dict):
-                if "format" in notes:
-                    if notes["format"] == "string":
-                        if isinstance(notes["content"], str):
-                            note_content = [notes["content"]]
-                        elif isinstance(notes["content"], list):
-                            note_content = notes["content"]
-                        else:
-                            logger.warning(
-                                "Unrecognized Expectation suite notes format. Skipping rendering."
-                            )
-
-                    elif notes["format"] == "markdown":
-                        if isinstance(notes["content"], str):
-                            note_content = [
-                                RenderedMarkdownContent(
-                                    **{
-                                        "content_block_type": "markdown",
-                                        "markdown": notes["content"],
-                                        "styling": {"parent": {}},
-                                    }
-                                )
-                            ]
-                        elif isinstance(notes["content"], list):
-                            note_content = [
-                                RenderedMarkdownContent(
-                                    **{
-                                        "content_block_type": "markdown",
-                                        "markdown": note,
-                                        "styling": {"parent": {}},
-                                    }
-                                )
-                                for note in notes["content"]
-                            ]
-                        else:
-                            logger.warning(
-                                "Unrecognized Expectation suite notes format. Skipping rendering."
-                            )
-                else:
-                    logger.warning(
-                        "Unrecognized Expectation suite notes format. Skipping rendering."
+                note_content = [
+                    RenderedMarkdownContent(
+                        **{
+                            "content_block_type": "markdown",
+                            "markdown": notes,
+                            "styling": {"parent": {}},
+                        }
                     )
+                ]
+            elif isinstance(notes, list):
+                note_content = [
+                    RenderedMarkdownContent(
+                        **{
+                            "content_block_type": "markdown",
+                            "markdown": note,
+                            "styling": {"parent": {}},
+                        }
+                    )
+                    for note in notes
+                ]
+            else:
+                note_content = None
 
             if note_content is not None:
                 content += note_content
@@ -893,19 +873,15 @@ class ExpectationSuitePageRenderer(Renderer):
 
 
 class ProfilingResultsPageRenderer(Renderer):
-    def __init__(
-        self, overview_section_renderer=None, column_section_renderer=None
-    ) -> None:
+    def __init__(self, overview_section_renderer=None, column_section_renderer=None) -> None:
         super().__init__()
         if overview_section_renderer is None:
-            overview_section_renderer = {
-                "class_name": "ProfilingResultsOverviewSectionRenderer"
-            }
+            overview_section_renderer = {"class_name": "ProfilingResultsOverviewSectionRenderer"}
         if column_section_renderer is None:
-            column_section_renderer = {
-                "class_name": "ProfilingResultsColumnSectionRenderer"
-            }
-        module_name = "great_expectations.render.renderer.profiling_results_overview_section_renderer"
+            column_section_renderer = {"class_name": "ProfilingResultsColumnSectionRenderer"}
+        module_name = (
+            "great_expectations.render.renderer.profiling_results_overview_section_renderer"
+        )
         self._overview_section_renderer = instantiate_class_from_config(
             config=overview_section_renderer,
             runtime_environment={},
@@ -934,7 +910,7 @@ class ProfilingResultsPageRenderer(Renderer):
                 class_name=column_section_renderer["class_name"],
             )
 
-    def render(self, validation_results):  # noqa: C901 - 16
+    def render(self, validation_results):  # noqa: C901, PLR0912 # FIXME CoP
         run_id = validation_results.meta["run_id"]
         if isinstance(run_id, str):
             try:
@@ -956,8 +932,8 @@ class ProfilingResultsPageRenderer(Renderer):
 
         # add datasource key to batch_kwargs if missing
         if "datasource" not in batch_kwargs and "datasource" not in batch_kwargs:
-            # check if expectation_suite_name follows datasource.batch_kwargs_generator.data_asset_name.suite_name pattern
-            if len(expectation_suite_name.split(".")) == 4:
+            # check if expectation_suite_name follows datasource.batch_kwargs_generator.data_asset_name.suite_name pattern  # noqa: E501 # FIXME CoP
+            if len(expectation_suite_name.split(".")) == 4:  # noqa: PLR2004 # FIXME CoP
                 if "batch_kwargs" in validation_results.meta:
                     batch_kwargs["datasource"] = expectation_suite_name.split(".")[0]
                 else:
@@ -968,9 +944,7 @@ class ProfilingResultsPageRenderer(Renderer):
         columns = self._group_evrs_by_column(validation_results)
 
         ordered_columns = Renderer._get_column_list_from_evrs(validation_results)
-        column_types = self._overview_section_renderer._get_column_types(
-            validation_results
-        )
+        column_types = self._overview_section_renderer._get_column_types(validation_results)
 
         data_asset_name = batch_kwargs.get("data_asset_name")
         # Determine whether we have a custom run_name
@@ -984,15 +958,18 @@ class ProfilingResultsPageRenderer(Renderer):
             run_time_datetime = None
 
         include_run_name: bool = False
-        if run_name_as_time != run_time_datetime and run_name_as_time != "__none__":
+        if (
+            run_name_as_time != run_time_datetime  # noqa: PLR1714 # FIXME CoP
+            and run_name_as_time != "__none__"
+        ):
             include_run_name = True
 
-        page_title = f"Profiling Results / {str(expectation_suite_name)}"
+        page_title = f"Profiling Results / {expectation_suite_name!s}"
         if data_asset_name:
-            page_title += f" / {str(data_asset_name)}"
+            page_title += f" / {data_asset_name!s}"
         if include_run_name:
-            page_title += f" / {str(run_name)}"
-        page_title += f" / {str(run_time)}"
+            page_title += f" / {run_name!s}"
+        page_title += f" / {run_time!s}"
 
         return RenderedDocumentContent(
             **{
@@ -1000,12 +977,8 @@ class ProfilingResultsPageRenderer(Renderer):
                 "page_title": page_title,
                 "expectation_suite_name": expectation_suite_name,
                 "utm_medium": "profiling-results-page",
-                "batch_kwargs": batch_kwargs
-                if "batch_kwargs" in validation_results.meta
-                else None,
-                "batch_spec": batch_kwargs
-                if "batch_spec" in validation_results.meta
-                else None,
+                "batch_kwargs": batch_kwargs if "batch_kwargs" in validation_results.meta else None,
+                "batch_spec": batch_kwargs if "batch_spec" in validation_results.meta else None,
                 "sections": [
                     self._overview_section_renderer.render(
                         validation_results, section_name="Overview"
