@@ -1,21 +1,34 @@
-from functools import wraps
-from typing import Any
+from __future__ import annotations
 
-from great_expectations.core._docs_decorators import public_api
-from great_expectations.core.expectation_configuration import ExpectationConfiguration
+from functools import wraps
+from typing import TYPE_CHECKING, Any, Callable, TypeVar
+
+from typing_extensions import ParamSpec
+
+from great_expectations._docs_decorators import public_api
+from great_expectations.compatibility.typing_extensions import override
 from great_expectations.core.expectation_validation_result import (
     ExpectationValidationResult,
 )
+from great_expectations.expectations.expectation_configuration import (
+    ExpectationConfiguration,
+)
+
+if TYPE_CHECKING:
+    from great_expectations.checkpoint.checkpoint import CheckpointResult
+
+P = ParamSpec("P")
+T = TypeVar("T")
 
 
-def renderer(renderer_type, **kwargs):
-    def wrapper(renderer_fn):
+def renderer(renderer_type: str, **kwargs) -> Callable[[Callable[P, T]], Callable[P, T]]:
+    def wrapper(renderer_fn: Callable[P, T]) -> Callable[P, T]:
         @wraps(renderer_fn)
-        def inner_func(*args, **kwargs):
+        def inner_func(*args: P.args, **kwargs: P.kwargs):
             return renderer_fn(*args, **kwargs)
 
-        inner_func._renderer_type = renderer_type
-        inner_func._renderer_definition_kwargs = kwargs
+        inner_func._renderer_type = renderer_type  # type: ignore[attr-defined] # FIXME CoP
+        inner_func._renderer_definition_kwargs = kwargs  # type: ignore[attr-defined] # FIXME CoP
         return inner_func
 
     return wrapper
@@ -25,25 +38,37 @@ def renderer(renderer_type, **kwargs):
 class Renderer:
     """A convenience class to provide an explicit mechanism to instantiate any Renderer."""
 
-    def __init__(self) -> None:
-        # This is purely a convenience to provide an explicit mechanism to instantiate any Renderer, even ones that
-        # used to be composed exclusively of classmethods
-        pass
+    @override
+    def __eq__(self, other: object) -> bool:
+        # Renderers do not have any state, so they are equal if they are the same class
+        return type(self) is type(other)
+
+    @override
+    def __hash__(self) -> int:
+        return hash(type(self))
+
+    def serialize(self) -> dict:
+        # Necessary to enable proper serialization within an Action (and additionally, within a Checkpoint)  # noqa: E501 # FIXME CoP
+        # TODO: Renderers should be ported over to Pydantic to prevent this fork in logic
+        return {
+            "module_name": self.__class__.__module__,
+            "class_name": self.__class__.__name__,
+        }
 
     @classmethod
     def _get_expectation_type(cls, ge_object):
         if isinstance(ge_object, ExpectationConfiguration):
-            return ge_object.expectation_type
+            return ge_object.type
 
         elif isinstance(ge_object, ExpectationValidationResult):
             # This is a validation
-            return ge_object.expectation_config.expectation_type
+            return ge_object.expectation_config.type
 
     # TODO: When we implement a ValidationResultSuite class, this method will move there.
     @classmethod
     def _find_evr_by_type(cls, evrs, type_):
         for evr in evrs:
-            if evr.expectation_config.expectation_type == type_:
+            if evr.expectation_config.type == type_:
                 return evr
 
     # TODO: When we implement a ValidationResultSuite class, this method will move there.
@@ -51,7 +76,7 @@ class Renderer:
     def _find_all_evrs_by_type(cls, evrs, type_, column_=None):
         ret = []
         for evr in evrs:
-            if evr.expectation_config.expectation_type == type_ and (
+            if evr.expectation_config.type == type_ and (
                 not column_ or column_ == evr.expectation_config.kwargs.get("column")
             ):
                 ret.append(evr)
@@ -70,7 +95,7 @@ class Renderer:
 
         :param evrs:
         :return: list of columns with best effort sorting
-        """
+        """  # noqa: E501 # FIXME CoP
         evrs_ = evrs if isinstance(evrs, list) else evrs.results
 
         expect_table_columns_to_match_ordered_list_evr = cls._find_evr_by_type(
@@ -94,7 +119,7 @@ class Renderer:
         else:
             ordered_columns = []
 
-        # only return ordered columns from expect_table_columns_to_match_ordered_list evr if they match set of column
+        # only return ordered columns from expect_table_columns_to_match_ordered_list evr if they match set of column  # noqa: E501 # FIXME CoP
         # names from entire evr
         if set(sorted_columns) == set(ordered_columns):
             return ordered_columns
@@ -117,7 +142,7 @@ class Renderer:
 
         return columns
 
-    def render(self, **kwargs: dict) -> Any:
+    def render(self, checkpoint_result: CheckpointResult) -> Any:
         """
         Render interface method.
         """
