@@ -1,10 +1,14 @@
+from __future__ import annotations
+
 import logging
 import os
+import pathlib
 import traceback
+import urllib
 from collections import OrderedDict
-from typing import Any, List, Optional, Tuple
+from typing import TYPE_CHECKING, Any, List, Optional, Tuple
 
-import great_expectations.exceptions as exceptions
+from great_expectations import exceptions
 from great_expectations.core import ExpectationSuite
 from great_expectations.core.util import nested_update
 from great_expectations.data_context.cloud_constants import GXCloudRESTResource
@@ -21,6 +25,12 @@ from great_expectations.data_context.types.resource_identifiers import (
 from great_expectations.data_context.util import instantiate_class_from_config
 from great_expectations.render.util import resource_key_passes_run_name_filter
 
+if TYPE_CHECKING:
+    from great_expectations.core.expectation_validation_result import (
+        ExpectationValidationResult,
+    )
+    from great_expectations.data_context import AbstractDataContext
+
 logger = logging.getLogger(__name__)
 
 FALSEY_YAML_STRINGS = [
@@ -110,9 +120,9 @@ class SiteBuilder:
                         class_name: DefaultJinjaIndexPageView
     """
 
-    def __init__(  # noqa: C901 - 16
+    def __init__(  # noqa: C901, PLR0912, PLR0913 # FIXME CoP
         self,
-        data_context,
+        data_context: AbstractDataContext,
         store_backend,
         site_name=None,
         site_index_builder=None,
@@ -133,33 +143,26 @@ class SiteBuilder:
         self.cloud_mode = cloud_mode
         self.ge_cloud_mode = cloud_mode
 
-        usage_statistics_config = data_context.anonymous_usage_statistics
-        data_context_id = None
-        if (
-            usage_statistics_config
-            and usage_statistics_config.enabled
-            and usage_statistics_config.data_context_id
-        ):
-            data_context_id = usage_statistics_config.data_context_id
-
-        self.data_context_id = data_context_id
+        self.data_context_id = data_context.variables.data_context_id
 
         # set custom_styles_directory if present
         custom_styles_directory = None
         plugins_directory = data_context.plugins_directory
-        if plugins_directory and os.path.isdir(
-            os.path.join(plugins_directory, "custom_data_docs", "styles")
+        if plugins_directory and os.path.isdir(  # noqa: PTH112 # FIXME CoP
+            os.path.join(  # noqa: PTH118 # FIXME CoP
+                plugins_directory, "custom_data_docs", "styles"
+            )
         ):
-            custom_styles_directory = os.path.join(
+            custom_styles_directory = os.path.join(  # noqa: PTH118 # FIXME CoP
                 plugins_directory, "custom_data_docs", "styles"
             )
 
         # set custom_views_directory if present
         custom_views_directory = None
-        if plugins_directory and os.path.isdir(
-            os.path.join(plugins_directory, "custom_data_docs", "views")
+        if plugins_directory and os.path.isdir(  # noqa: PTH112 # FIXME CoP
+            os.path.join(plugins_directory, "custom_data_docs", "views")  # noqa: PTH118 # FIXME CoP
         ):
-            custom_views_directory = os.path.join(
+            custom_views_directory = os.path.join(  # noqa: PTH118 # FIXME CoP
                 plugins_directory, "custom_data_docs", "views"
             )
 
@@ -187,15 +190,13 @@ class SiteBuilder:
             },
             "validations": {
                 "class_name": "DefaultSiteSectionBuilder",
-                "source_store_name": data_context.validations_store_name,
+                "source_store_name": data_context.validation_results_store_name,
                 "renderer": {"class_name": "ValidationResultsPageRenderer"},
-                "validation_results_limit": site_index_builder.get(
-                    "validation_results_limit"
-                ),
+                "validation_results_limit": site_index_builder.get("validation_results_limit"),
             },
             "profiling": {
                 "class_name": "DefaultSiteSectionBuilder",
-                "source_store_name": data_context.validations_store_name,
+                "source_store_name": data_context.validation_results_store_name,
                 "renderer": {"class_name": "ProfilingResultsPageRenderer"},
             },
         }
@@ -215,9 +216,7 @@ class SiteBuilder:
                 }
         if site_section_builders.get("profiling", "None") not in FALSEY_YAML_STRINGS:
             if site_section_builders["profiling"].get("run_name_filter") is None:
-                site_section_builders["profiling"]["run_name_filter"] = {
-                    "includes": "profiling"
-                }
+                site_section_builders["profiling"]["run_name_filter"] = {"includes": "profiling"}
 
         self.site_section_builders = {}
         for site_section_name, site_section_config in site_section_builders.items():
@@ -227,9 +226,7 @@ class SiteBuilder:
                 site_section_config.get("module_name")
                 or "great_expectations.render.renderer.site_builder"
             )
-            self.site_section_builders[
-                site_section_name
-            ] = instantiate_class_from_config(
+            self.site_section_builders[site_section_name] = instantiate_class_from_config(
                 config=site_section_config,
                 runtime_environment={
                     "data_context": data_context,
@@ -240,7 +237,10 @@ class SiteBuilder:
                     "show_how_to_buttons": self.show_how_to_buttons,
                     "cloud_mode": self.cloud_mode,
                 },
-                config_defaults={"name": site_section_name, "module_name": module_name},
+                config_defaults={
+                    "name": site_section_name,
+                    "module_name": module_name,
+                },
             )
             if not self.site_section_builders[site_section_name]:
                 raise exceptions.ClassInstantiationError(
@@ -322,7 +322,7 @@ class SiteBuilder:
             index_links_dict,
         )
 
-    def get_resource_url(self, resource_identifier=None, only_if_exists=True):
+    def get_resource_url(self, resource_identifier=None, only_if_exists=True) -> Optional[str]:
         """
         Return the URL of the HTML document that renders a resource
         (e.g., an expectation suite or a validation result).
@@ -340,10 +340,10 @@ class SiteBuilder:
 
 
 class DefaultSiteSectionBuilder:
-    def __init__(
+    def __init__(  # noqa: PLR0913 # FIXME CoP
         self,
         name,
-        data_context,
+        data_context: AbstractDataContext,
         target_store,
         source_store_name,
         custom_styles_directory=None,
@@ -372,13 +372,10 @@ class DefaultSiteSectionBuilder:
         self.cloud_mode = cloud_mode
         self.ge_cloud_mode = cloud_mode
         if renderer is None:
-            raise exceptions.InvalidConfigError(
-                "SiteSectionBuilder requires a renderer configuration "
-                "with a class_name key."
+            raise exceptions.InvalidConfigError(  # noqa: TRY003 # FIXME CoP
+                "SiteSectionBuilder requires a renderer configuration with a class_name key."
             )
-        module_name = (
-            renderer.get("module_name") or "great_expectations.render.renderer"
-        )
+        module_name = renderer.get("module_name") or "great_expectations.render.renderer"
         self.renderer_class = instantiate_class_from_config(
             config=renderer,
             runtime_environment={"data_context": data_context},
@@ -413,7 +410,7 @@ class DefaultSiteSectionBuilder:
                 class_name=view["class_name"],
             )
 
-    def build(self, resource_identifiers=None) -> None:
+    def build(self, resource_identifiers=None) -> None:  # noqa: C901, PLR0912 # FIXME CoP
         source_store_keys = self.source_store.list_keys()
         if self.name == "validations" and self.validation_results_limit:
             source_store_keys = sorted(
@@ -423,49 +420,40 @@ class DefaultSiteSectionBuilder:
         for resource_key in source_store_keys:
             # if no resource_identifiers are passed, the section
             # builder will build
-            # a page for every keys in its source store.
+            # a page for every key in its source store.
             # if the caller did pass resource_identifiers, the section builder
             # will build pages only for the specified resources
             if resource_identifiers and resource_key not in resource_identifiers:
                 continue
 
             if self.run_name_filter and not isinstance(resource_key, GXCloudIdentifier):
-                if not resource_key_passes_run_name_filter(
-                    resource_key, self.run_name_filter
-                ):
+                if not resource_key_passes_run_name_filter(resource_key, self.run_name_filter):
                     continue
             try:
                 resource = self.source_store.get(resource_key)
                 if isinstance(resource_key, ExpectationSuiteIdentifier):
-                    resource = ExpectationSuite(
-                        **resource, data_context=self.data_context
-                    )
+                    resource = ExpectationSuite(**resource)
             except exceptions.InvalidKeyError:
                 logger.warning(
-                    f"Object with Key: {str(resource_key)} could not be retrieved. Skipping..."
+                    f"Object with Key: {resource_key!s} could not be retrieved. Skipping..."
                 )
                 continue
 
             if isinstance(resource_key, ExpectationSuiteIdentifier):
-                expectation_suite_name = resource_key.expectation_suite_name
-                logger.debug(
-                    f"        Rendering expectation suite {expectation_suite_name}"
-                )
+                expectation_suite_name = resource_key.name
+                logger.debug(f"        Rendering expectation suite {expectation_suite_name}")
             elif isinstance(resource_key, ValidationResultIdentifier):
                 run_id = resource_key.run_id
                 run_name = run_id.run_name
                 run_time = run_id.run_time
-                expectation_suite_name = (
-                    resource_key.expectation_suite_identifier.expectation_suite_name
-                )
+                expectation_suite_name = resource_key.expectation_suite_identifier.name
                 if self.name == "profiling":
                     logger.debug(
                         f"        Rendering profiling for batch {resource_key.batch_identifier}"
                     )
                 else:
-
                     logger.debug(
-                        f"        Rendering validation: run name: {run_name}, run time: {run_time}, suite {expectation_suite_name} for batch {resource_key.batch_identifier}"
+                        f"        Rendering validation: run name: {run_name}, run time: {run_time}, suite {expectation_suite_name} for batch {resource_key.batch_identifier}"  # noqa: E501 # FIXME CoP
                     )
 
             try:
@@ -473,12 +461,10 @@ class DefaultSiteSectionBuilder:
 
                 if self.cloud_mode:
                     self.target_store.set(
-                        GXCloudIdentifier(
-                            resource_type=GXCloudRESTResource.RENDERED_DATA_DOC
-                        ),
+                        GXCloudIdentifier(resource_type=GXCloudRESTResource.RENDERED_DATA_DOC),
                         rendered_content,
                         source_type=resource_key.resource_type,
-                        source_id=resource_key.cloud_id,
+                        source_id=resource_key.id,
                     )
                 else:
                     viewable_content = self.view_class.render(
@@ -499,21 +485,20 @@ class DefaultSiteSectionBuilder:
 An unexpected Exception occurred during data docs rendering.  Because of this error, certain parts of data docs will \
 not be rendered properly and/or may not appear altogether.  Please use the trace, included in this message, to \
 diagnose and repair the underlying issue.  Detailed information follows:
-                """
+                """  # noqa: E501 # FIXME CoP
                 exception_traceback = traceback.format_exc()
                 exception_message += (
-                    f'{type(e).__name__}: "{str(e)}".  '
-                    f'Traceback: "{exception_traceback}".'
+                    f'{type(e).__name__}: "{e!s}".  Traceback: "{exception_traceback}".'
                 )
-                logger.error(exception_message)
+                logger.error(exception_message)  # noqa: TRY400 # FIXME CoP
 
 
 class DefaultSiteIndexBuilder:
-    def __init__(
+    def __init__(  # noqa: PLR0913 # FIXME CoP
         self,
         name,
         site_name,
-        data_context,
+        data_context: AbstractDataContext,
         target_store,
         site_section_builders_config,
         custom_styles_directory=None,
@@ -542,9 +527,7 @@ class DefaultSiteIndexBuilder:
                 "module_name": "great_expectations.render.renderer",
                 "class_name": "SiteIndexPageRenderer",
             }
-        module_name = (
-            renderer.get("module_name") or "great_expectations.render.renderer"
-        )
+        module_name = renderer.get("module_name") or "great_expectations.render.renderer"
         self.renderer_class = instantiate_class_from_config(
             config=renderer,
             runtime_environment={"data_context": data_context},
@@ -579,7 +562,7 @@ class DefaultSiteIndexBuilder:
                 class_name=view["class_name"],
             )
 
-    def add_resource_info_to_index_links_dict(
+    def add_resource_info_to_index_links_dict(  # noqa: PLR0913 # FIXME CoP
         self,
         index_links_dict,
         expectation_suite_name,
@@ -600,21 +583,25 @@ class DefaultSiteIndexBuilder:
 
         if run_id:
             filepath = (
-                os.path.join(
-                    "validations",
-                    *expectation_suite_name.split("."),
-                    *run_id.to_tuple(),
-                    batch_identifier,
-                )
+                pathlib.Path(
+                    *[
+                        "validations",
+                        *expectation_suite_name.split("."),
+                        *run_id.to_tuple(),
+                        batch_identifier,
+                    ]
+                ).as_posix()
                 + ".html"
             )
         else:
             filepath = (
-                os.path.join("expectations", *expectation_suite_name.split("."))
+                pathlib.Path(*["expectations", *expectation_suite_name.split(".")]).as_posix()
                 + ".html"
             )
 
-        expectation_suite_filepath = os.path.join(
+        url_encoded_filepath = urllib.parse.quote(filepath)
+
+        expectation_suite_filepath = os.path.join(  # noqa: PTH118 # FIXME CoP
             "expectations", *expectation_suite_name.split(".")
         )
         expectation_suite_filepath += ".html"
@@ -622,7 +609,7 @@ class DefaultSiteIndexBuilder:
         index_links_dict[f"{section_name}_links"].append(
             {
                 "expectation_suite_name": expectation_suite_name,
-                "filepath": filepath,
+                "filepath": url_encoded_filepath,
                 "run_id": run_id,
                 "batch_identifier": batch_identifier,
                 "validation_success": validation_success,
@@ -631,9 +618,7 @@ class DefaultSiteIndexBuilder:
                 "asset_name": asset_name,
                 "batch_kwargs": batch_kwargs,
                 "batch_spec": batch_spec,
-                "expectation_suite_filepath": expectation_suite_filepath
-                if run_id
-                else None,
+                "expectation_suite_filepath": expectation_suite_filepath if run_id else None,
             }
         )
 
@@ -671,7 +656,7 @@ class DefaultSiteIndexBuilder:
         #     )
 
         return {
-            "header": "To continue exploring Great Expectations check out one of these tutorials...",
+            "header": "To continue exploring Great Expectations check out one of these tutorials...",  # noqa: E501 # FIXME CoP
             "buttons": self._get_call_to_action_buttons(usage_statistics),
         }
 
@@ -730,7 +715,7 @@ class DefaultSiteIndexBuilder:
         be skipped and removed from the target store
         :param build_index: a flag if False, skips building the index page
         :return: tuple(index_page_url, index_links_dict)
-        """
+        """  # noqa: E501 # FIXME CoP
 
         # Loop over sections in the HtmlStore
         logger.debug("DefaultSiteIndexBuilder.build")
@@ -746,9 +731,7 @@ class DefaultSiteIndexBuilder:
 
         self._add_expectations_to_index_links(index_links_dict, skip_and_clean_missing)
         validation_and_profiling_result_site_keys = (
-            self._build_validation_and_profiling_result_site_keys(
-                skip_and_clean_missing
-            )
+            self._build_validation_and_profiling_result_site_keys(skip_and_clean_missing)
         )
         self._add_profiling_to_index_links(
             index_links_dict, validation_and_profiling_result_site_keys
@@ -770,12 +753,12 @@ class DefaultSiteIndexBuilder:
 An unexpected Exception occurred during data docs rendering.  Because of this error, certain parts of data docs will \
 not be rendered properly and/or may not appear altogether.  Please use the trace, included in this message, to \
 diagnose and repair the underlying issue.  Detailed information follows:
-            """
+            """  # noqa: E501 # FIXME CoP
             exception_traceback = traceback.format_exc()
             exception_message += (
-                f'{type(e).__name__}: "{str(e)}".  Traceback: "{exception_traceback}".'
+                f'{type(e).__name__}: "{e!s}".  Traceback: "{exception_traceback}".'
             )
-            logger.error(exception_message)
+            logger.error(exception_message)  # noqa: TRY400 # FIXME CoP
 
         return self.target_store.write_index_page(viewable_content), index_links_dict
 
@@ -785,9 +768,7 @@ diagnose and repair the underlying issue.  Detailed information follows:
         expectations = self.site_section_builders_config.get("expectations", "None")
         if expectations and expectations not in FALSEY_YAML_STRINGS:
             expectation_suite_source_keys = self.data_context.stores[
-                self.site_section_builders_config["expectations"].get(
-                    "source_store_name"
-                )
+                self.site_section_builders_config["expectations"].get("source_store_name")
             ].list_keys()
             expectation_suite_site_keys = [
                 ExpectationSuiteIdentifier.from_tuple(expectation_suite_tuple)
@@ -799,9 +780,9 @@ diagnose and repair the underlying issue.  Detailed information follows:
                 cleaned_keys = []
                 for expectation_suite_site_key in expectation_suite_site_keys:
                     if expectation_suite_site_key not in expectation_suite_source_keys:
-                        self.target_store.store_backends[
-                            ExpectationSuiteIdentifier
-                        ].remove_key(expectation_suite_site_key)
+                        self.target_store.store_backends[ExpectationSuiteIdentifier].remove_key(
+                            expectation_suite_site_key
+                        )
                     else:
                         cleaned_keys.append(expectation_suite_site_key)
                 expectation_suite_site_keys = cleaned_keys
@@ -809,7 +790,7 @@ diagnose and repair the underlying issue.  Detailed information follows:
             for expectation_suite_key in expectation_suite_site_keys:
                 self.add_resource_info_to_index_links_dict(
                     index_links_dict=index_links_dict,
-                    expectation_suite_name=expectation_suite_key.expectation_suite_name,
+                    expectation_suite_name=expectation_suite_key.name,
                     section_name="expectations",
                 )
 
@@ -829,9 +810,7 @@ diagnose and repair the underlying issue.  Detailed information follows:
             )
             validation_and_profiling_result_source_keys = set(
                 self.data_context.stores[
-                    self.site_section_builders_config[source_store].get(
-                        "source_store_name"
-                    )
+                    self.site_section_builders_config[source_store].get("source_store_name")
                 ].list_keys()
             )
             validation_and_profiling_result_site_keys = [
@@ -842,16 +821,14 @@ diagnose and repair the underlying issue.  Detailed information follows:
             ]
             if skip_and_clean_missing:
                 cleaned_keys = []
-                for (
-                    validation_result_site_key
-                ) in validation_and_profiling_result_site_keys:
+                for validation_result_site_key in validation_and_profiling_result_site_keys:
                     if (
                         validation_result_site_key
                         not in validation_and_profiling_result_source_keys
                     ):
-                        self.target_store.store_backends[
-                            ValidationResultIdentifier
-                        ].remove_key(validation_result_site_key)
+                        self.target_store.store_backends[ValidationResultIdentifier].remove_key(
+                            validation_result_site_key
+                        )
                     else:
                         cleaned_keys.append(validation_result_site_key)
                 validation_and_profiling_result_site_keys = cleaned_keys
@@ -879,9 +856,9 @@ diagnose and repair the underlying issue.  Detailed information follows:
                 try:
                     validation = self.data_context.get_validation_result(
                         batch_identifier=profiling_result_key.batch_identifier,
-                        expectation_suite_name=profiling_result_key.expectation_suite_identifier.expectation_suite_name,
+                        expectation_suite_name=profiling_result_key.expectation_suite_identifier.name,
                         run_id=profiling_result_key.run_id,
-                        validations_store_name=self.source_stores.get("profiling"),
+                        validation_results_store_name=self.source_stores.get("profiling"),
                     )
 
                     batch_kwargs = validation.meta.get("batch_kwargs", {})
@@ -889,19 +866,18 @@ diagnose and repair the underlying issue.  Detailed information follows:
 
                     self.add_resource_info_to_index_links_dict(
                         index_links_dict=index_links_dict,
-                        expectation_suite_name=profiling_result_key.expectation_suite_identifier.expectation_suite_name,
+                        expectation_suite_name=profiling_result_key.expectation_suite_identifier.name,
                         section_name="profiling",
                         batch_identifier=profiling_result_key.batch_identifier,
                         run_id=profiling_result_key.run_id,
                         run_time=profiling_result_key.run_id.run_time,
                         run_name=profiling_result_key.run_id.run_name,
-                        asset_name=batch_kwargs.get("data_asset_name")
-                        or batch_spec.get("data_asset_name"),
+                        asset_name=_resolve_asset_name(validation),
                         batch_kwargs=batch_kwargs,
                         batch_spec=batch_spec,
                     )
                 except Exception:
-                    error_msg = f"Profiling result not found: {str(profiling_result_key.to_tuple()):s} - skipping"
+                    error_msg = f"Profiling result not found: {profiling_result_key.to_tuple()!s:s} - skipping"  # noqa: E501 # FIXME CoP
                     logger.warning(error_msg)
 
     def _add_validations_to_index_links(
@@ -911,9 +887,9 @@ diagnose and repair the underlying issue.  Detailed information follows:
     ) -> None:
         validations = self.site_section_builders_config.get("validations", "None")
         if validations and validations not in FALSEY_YAML_STRINGS:
-            validations_run_name_filter = self.site_section_builders_config[
-                "validations"
-            ]["run_name_filter"]
+            validations_run_name_filter = self.site_section_builders_config["validations"][
+                "run_name_filter"
+            ]
             validation_result_site_keys = [
                 validation_result_key
                 for validation_result_key in validation_and_profiling_result_site_keys
@@ -934,9 +910,9 @@ diagnose and repair the underlying issue.  Detailed information follows:
                 try:
                     validation = self.data_context.get_validation_result(
                         batch_identifier=validation_result_key.batch_identifier,
-                        expectation_suite_name=validation_result_key.expectation_suite_identifier.expectation_suite_name,
+                        expectation_suite_name=validation_result_key.expectation_suite_identifier.name,
                         run_id=validation_result_key.run_id,
-                        validations_store_name=self.source_stores.get("validations"),
+                        validation_results_store_name=self.source_stores.get("validations"),
                     )
 
                     validation_success = validation.success
@@ -945,23 +921,39 @@ diagnose and repair the underlying issue.  Detailed information follows:
 
                     self.add_resource_info_to_index_links_dict(
                         index_links_dict=index_links_dict,
-                        expectation_suite_name=validation_result_key.expectation_suite_identifier.expectation_suite_name,
+                        expectation_suite_name=validation_result_key.expectation_suite_identifier.name,
                         section_name="validations",
                         batch_identifier=validation_result_key.batch_identifier,
                         run_id=validation_result_key.run_id,
                         validation_success=validation_success,
                         run_time=validation_result_key.run_id.run_time,
                         run_name=validation_result_key.run_id.run_name,
-                        asset_name=batch_kwargs.get("data_asset_name")
-                        or batch_spec.get("data_asset_name"),
+                        asset_name=_resolve_asset_name(validation),
                         batch_kwargs=batch_kwargs,
                         batch_spec=batch_spec,
                     )
                 except Exception:
-                    error_msg = f"Validation result not found: {str(validation_result_key.to_tuple()):s} - skipping"
+                    error_msg = f"Validation result not found: {validation_result_key.to_tuple()!s:s} - skipping"  # noqa: E501 # FIXME CoP
                     logger.warning(error_msg)
 
 
+def _resolve_asset_name(validation_results: ExpectationValidationResult) -> str | None:
+    """
+    Resolve the asset name from the validation results meta data.
+    FDS does not store data_asset_name in batch_kwargs or batch_spec and it must be
+    pulled from the active batch definition.
+    """
+    batch_kwargs = validation_results.meta.get("batch_kwargs", {})
+    batch_spec = validation_results.meta.get("batch_spec", {})
+
+    asset_name = batch_kwargs.get("data_asset_name") or batch_spec.get("data_asset_name")
+    if asset_name:
+        return asset_name
+    # FDS does not store data_asset_name in batch_kwargs or batch_spec
+    active_batch = validation_results.meta.get("active_batch_definition", {})
+    return active_batch.get("data_asset_name")
+
+
 class CallToActionButton:
     def __init__(self, title, link) -> None:
         self.title = title
