@@ -1,8 +1,11 @@
+from __future__ import annotations
+
 import datetime
 import json
 import re
 from collections import OrderedDict
 from string import Template as pTemplate
+from typing import TYPE_CHECKING, Any, ClassVar, Iterable, Mapping
 from uuid import uuid4
 
 import mistune
@@ -14,8 +17,10 @@ from jinja2 import (
     select_autoescape,
 )
 
+from great_expectations.compatibility.typing_extensions import override
+
 try:
-    from jinja2 import contextfilter
+    from jinja2 import contextfilter  # type: ignore[attr-defined] # for jinja 2.0
 except ImportError:
     from jinja2 import pass_context as contextfilter
 
@@ -26,10 +31,9 @@ from great_expectations.render import (
     RenderedDocumentContent,
 )
 
-
-class NoOpTemplate:
-    def render(self, document):
-        return document
+if TYPE_CHECKING:
+    from jinja2 import BaseLoader
+    from jinja2 import Template as jTemplate
 
 
 class PrettyPrintTemplate:
@@ -55,18 +59,16 @@ class DefaultJinjaView:
 
     """
 
-    _template = NoOpTemplate
+    _template: ClassVar[str]
 
-    def __init__(
-        self, custom_styles_directory=None, custom_views_directory=None
-    ) -> None:
+    def __init__(self, custom_styles_directory=None, custom_views_directory=None) -> None:
         self.custom_styles_directory = custom_styles_directory
         self.custom_views_directory = custom_views_directory
 
         templates_loader = PackageLoader("great_expectations", "render/view/templates")
         styles_loader = PackageLoader("great_expectations", "render/view/static/styles")
 
-        loaders = [templates_loader, styles_loader]
+        loaders: list[BaseLoader] = [templates_loader, styles_loader]
         if self.custom_styles_directory:
             loaders.append(FileSystemLoader(self.custom_styles_directory))
         if self.custom_views_directory:
@@ -79,22 +81,18 @@ class DefaultJinjaView:
         )
 
         self.env.filters["render_string_template"] = self.render_string_template
-        self.env.filters[
-            "render_styling_from_string_template"
-        ] = self.render_styling_from_string_template
+        self.env.filters["render_styling_from_string_template"] = (
+            self.render_styling_from_string_template
+        )
         self.env.filters["render_styling"] = self.render_styling
         self.env.filters["render_content_block"] = self.render_content_block
         self.env.filters["render_markdown"] = self.render_markdown
-        self.env.filters[
-            "get_html_escaped_json_string_from_dict"
-        ] = self.get_html_escaped_json_string_from_dict
+        self.env.filters["get_html_escaped_json_string_from_dict"] = (
+            self.get_html_escaped_json_string_from_dict
+        )
         self.env.filters["generate_html_element_uuid"] = self.generate_html_element_uuid
-        self.env.filters[
-            "attributes_dict_to_html_string"
-        ] = self.attributes_dict_to_html_string
-        self.env.filters[
-            "render_bootstrap_table_data"
-        ] = self.render_bootstrap_table_data
+        self.env.filters["attributes_dict_to_html_string"] = self.attributes_dict_to_html_string
+        self.env.filters["render_bootstrap_table_data"] = self.render_bootstrap_table_data
         self.env.globals["ge_version"] = ge_version
         self.env.filters["add_data_context_id_to_url"] = self.add_data_context_id_to_url
 
@@ -109,17 +107,16 @@ class DefaultJinjaView:
             document = document.to_json_dict()
         return t.render(document, **kwargs)
 
-    def _get_template(self, template):
-        if template is None:
-            return NoOpTemplate
-
-        template = self.env.get_template(template)
+    def _get_template(self, template_str: str) -> jTemplate:
+        template = self.env.get_template(template_str)
         template.globals["now"] = lambda: datetime.datetime.now(datetime.timezone.utc)
 
         return template
 
-    @contextfilter
-    def add_data_context_id_to_url(self, jinja_context, url, add_datetime=True):
+    @contextfilter  # type: ignore[misc] # untyped 3rd party decorator
+    def add_data_context_id_to_url(
+        self, jinja_context: Any, url: str, add_datetime: bool = True
+    ) -> str:
         data_context_id = jinja_context.get("data_context_id")
         if add_datetime:
             datetime_iso_string = datetime.datetime.now(datetime.timezone.utc).strftime(
@@ -128,18 +125,18 @@ class DefaultJinjaView:
             url += f"?d={datetime_iso_string}"
         if data_context_id:
             url = f"{url}&dataContextId=" if add_datetime else f"{url}?dataContextId="
-            url += data_context_id
+            url += str(data_context_id)
         return url
 
-    @contextfilter
-    def render_content_block(
+    @contextfilter  # type: ignore[misc] # untyped 3rd party decorator
+    def render_content_block(  # noqa: C901, PLR0911, PLR0912 # FIXME CoP
         self,
-        jinja_context,
-        content_block,
-        index=None,
-        content_block_id=None,
+        jinja_context: Any,
+        content_block: str | list | dict | RenderedComponentContent,
+        index: Any = None,
+        content_block_id: Any = None,
         render_to_markdown: bool = False,
-    ):
+    ) -> RenderedComponentContent | dict | str:
         """
 
         :param jinja_context:
@@ -148,34 +145,32 @@ class DefaultJinjaView:
         :param content_block_id:
         :param render_to_markdown: Whether this method should render the markdown version instead of HTML
         :return:
-        """
+        """  # noqa: E501 # FIXME CoP
         if isinstance(content_block, str):
             return content_block
         elif content_block is None:
             return ""
         elif isinstance(content_block, list):
-            # If the content_block item here is actually a list of content blocks then we want to recursively render
+            # If the content_block item here is actually a list of content blocks then we want to recursively render  # noqa: E501 # FIXME CoP
             rendered_block = ""
             for idx, content_block_el in enumerate(content_block):
-                if (
-                    isinstance(content_block_el, RenderedComponentContent)
-                    or isinstance(content_block_el, dict)
-                    and "content_block_type" in content_block_el
+                if isinstance(content_block_el, RenderedComponentContent) or (
+                    isinstance(content_block_el, dict) and "content_block_type" in content_block_el
                 ):
                     new_content_block_id = None
                     if content_block_id:
-                        new_content_block_id = f"{content_block_id}-{str(idx)}"
+                        new_content_block_id = f"{content_block_id}-{idx!s}"
                     rendered_block += self.render_content_block(
                         jinja_context,
                         content_block_el,
                         idx,
                         content_block_id=new_content_block_id,
                     )
-                else:
+                else:  # noqa: PLR5501 # FIXME CoP
                     if render_to_markdown:
                         rendered_block += str(content_block_el)
                     else:
-                        rendered_block += f"<span>{str(content_block_el)}</span>"
+                        rendered_block += f"<span>{content_block_el!s}</span>"
             return rendered_block
         elif not isinstance(content_block, dict):
             return content_block
@@ -187,7 +182,7 @@ class DefaultJinjaView:
             template_filename = f"markdown_{content_block_type}.j2"
         else:
             template_filename = f"{content_block_type}.j2"
-        template = self._get_template(template=template_filename)
+        template = self._get_template(template_str=template_filename)
         if content_block_id:
             return template.render(
                 jinja_context,
@@ -196,32 +191,32 @@ class DefaultJinjaView:
                 content_block_id=content_block_id,
             )
         else:
-            return template.render(
-                jinja_context, content_block=content_block, index=index
-            )
+            return template.render(jinja_context, content_block=content_block, index=index)
 
     def render_dict_values(
-        self, context, dict_, index=None, content_block_id=None
+        self, context: Any, dict_: dict, index: Any = None, content_block_id: Any = None
     ) -> None:
         for key, val in dict_.items():
             if key.startswith("_"):
                 continue
-            dict_[key] = self.render_content_block(
-                context, val, index, content_block_id
-            )
+            dict_[key] = self.render_content_block(context, val, index, content_block_id)
 
-    @contextfilter
+    @contextfilter  # type: ignore[misc] # untyped 3rd party decorator
     def render_bootstrap_table_data(
-        self, context, table_data, index=None, content_block_id=None
+        self,
+        context: Any,
+        table_data: Iterable[dict],
+        index: Any | None = None,
+        content_block_id: str | None = None,
     ):
         for table_data_dict in table_data:
             self.render_dict_values(context, table_data_dict, index, content_block_id)
         return table_data
 
-    def get_html_escaped_json_string_from_dict(self, source_dict):
+    def get_html_escaped_json_string_from_dict(self, source_dict: dict) -> str:
         return json.dumps(source_dict).replace('"', '\\"').replace('"', "&quot;")
 
-    def attributes_dict_to_html_string(self, attributes_dict, prefix=""):
+    def attributes_dict_to_html_string(self, attributes_dict: dict, prefix=""):
         attributes_string = ""
         if prefix:
             prefix += "-"
@@ -229,8 +224,7 @@ class DefaultJinjaView:
             attributes_string += f'{prefix}{attribute}="{value}" '
         return attributes_string
 
-    def render_styling(self, styling):
-
+    def render_styling(self, styling: Mapping) -> str:
         """Adds styling information suitable for an html tag.
 
         Example styling block::
@@ -255,15 +249,15 @@ class DefaultJinjaView:
         If they aren't present, they simply won't be rendered.
 
         Other dictionary keys are also allowed and ignored.
-        """
+        """  # noqa: E501 # FIXME CoP
 
         class_list = styling.get("classes", None)
         if class_list is None:
             class_str = ""
         else:
-            if type(class_list) == str:
-                raise TypeError("classes must be a list, not a string.")
-            class_str = f"class=\"{' '.join(class_list)}\" "
+            if type(class_list) == str:  # noqa: E721 # FIXME CoP
+                raise TypeError("classes must be a list, not a string.")  # noqa: TRY003 # FIXME CoP
+            class_str = f'class="{" ".join(class_list)}" '
 
         attribute_dict = styling.get("attributes", None)
         if attribute_dict is None:
@@ -291,9 +285,9 @@ class DefaultJinjaView:
 
         return styling_string
 
-    def render_styling_from_string_template(self, template):
+    def render_styling_from_string_template(self, template: dict | OrderedDict) -> str:
         # NOTE: We should add some kind of type-checking to template
-        """This method is a thin wrapper use to call `render_styling` from within jinja templates."""
+        """This method is a thin wrapper use to call `render_styling` from within jinja templates."""  # noqa: E501 # FIXME CoP
         if not isinstance(template, (dict, OrderedDict)):
             return template
 
@@ -315,7 +309,7 @@ class DefaultJinjaView:
         except OSError:
             return markdown
 
-    def render_string_template(self, template):
+    def render_string_template(self, template):  # noqa: C901, PLR0912 # FIXME CoP
         # NOTE: Using this line for debugging. This should probably be logged...?
         # print(template)
 
@@ -330,9 +324,7 @@ class DefaultJinjaView:
         )
 
         tag = template.get("tag", "span")
-        template["template"] = template.get("template", "").replace(
-            "$PARAMETER", "$$PARAMETER"
-        )
+        template["template"] = template.get("template", "").replace("$PARAMETER", "$$PARAMETER")
         template["template"] = template.get("template", "").replace("\n", "<br>")
 
         if "tooltip" in template:
@@ -348,24 +340,20 @@ class DefaultJinjaView:
             tooltip_content = template["tooltip"]["content"]
             tooltip_content.replace("\n", "<br>")
             placement = template["tooltip"].get("placement", "top")
-            base_template_string = """
+            base_template_string = f"""
                 <{tag} $styling>
                     $template
                     <span class={placement}>
                         {tooltip_content}
                     </span>
                 </{tag}>
-            """.format(
-                placement=placement, tooltip_content=tooltip_content, tag=tag
-            )
+            """
         else:
-            base_template_string = """
+            base_template_string = f"""
                 <{tag} $styling>
                     $template
                 </{tag}>
-            """.format(
-                tag=tag
-            )
+            """
 
         if "styling" in template:
             params = template.get("params", {})
@@ -375,21 +363,16 @@ class DefaultJinjaView:
                 default_parameter_styling = template["styling"]["default"]
                 default_param_tag = default_parameter_styling.get("tag", "span")
                 base_param_template_string = (
-                    "<{param_tag} $styling>$content</{param_tag}>".format(
-                        param_tag=default_param_tag
-                    )
+                    f"<{default_param_tag} $styling>$content</{default_param_tag}>"
                 )
 
-                for parameter in template["params"].keys():
-
-                    # If this param has styling that over-rides the default, skip it here and get it in the next loop.
+                for parameter in template["params"]:
+                    # If this param has styling that over-rides the default, skip it here and get it in the next loop.  # noqa: E501 # FIXME CoP
                     if "params" in template["styling"]:
                         if parameter in template["styling"]["params"]:
                             continue
 
-                    params[parameter] = pTemplate(
-                        base_param_template_string
-                    ).safe_substitute(
+                    params[parameter] = pTemplate(base_param_template_string).safe_substitute(
                         {
                             "styling": self.render_styling(default_parameter_styling),
                             "content": params[parameter],
@@ -399,20 +382,12 @@ class DefaultJinjaView:
             # Apply param-specific styling
             if "params" in template["styling"]:
                 # params = template["params"]
-                for parameter, parameter_styling in template["styling"][
-                    "params"
-                ].items():
+                for parameter, parameter_styling in template["styling"]["params"].items():
                     if parameter not in params:
                         continue
                     param_tag = parameter_styling.get("tag", "span")
-                    param_template_string = (
-                        "<{param_tag} $styling>$content</{param_tag}>".format(
-                            param_tag=param_tag
-                        )
-                    )
-                    params[parameter] = pTemplate(
-                        param_template_string
-                    ).safe_substitute(
+                    param_template_string = f"<{param_tag} $styling>$content</{param_tag}>"
+                    params[parameter] = pTemplate(param_template_string).safe_substitute(
                         {
                             "styling": self.render_styling(parameter_styling),
                             "content": params[parameter],
@@ -445,7 +420,8 @@ class DefaultJinjaView:
 class DefaultJinjaPageView(DefaultJinjaView):
     _template = "page.j2"
 
-    def _validate_document(self, document) -> None:
+    @override
+    def _validate_document(self, document: RenderedDocumentContent) -> None:
         assert isinstance(document, RenderedDocumentContent)
 
 
@@ -456,19 +432,17 @@ class DefaultJinjaIndexPageView(DefaultJinjaPageView):
 class DefaultJinjaSectionView(DefaultJinjaView):
     _template = "section.j2"
 
-    def _validate_document(self, document) -> None:
-        assert isinstance(
-            document["section"], dict
-        )  # For now low-level views take dicts
+    @override
+    def _validate_document(self, document: Mapping) -> None:
+        assert isinstance(document["section"], dict)  # For now low-level views take dicts
 
 
 class DefaultJinjaComponentView(DefaultJinjaView):
     _template = "component.j2"
 
-    def _validate_document(self, document) -> None:
-        assert isinstance(
-            document["content_block"], dict
-        )  # For now low-level views take dicts
+    @override
+    def _validate_document(self, document: Mapping) -> None:
+        assert isinstance(document["content_block"], dict)  # For now low-level views take dicts
 
 
 class DefaultMarkdownPageView(DefaultJinjaView):
@@ -476,7 +450,8 @@ class DefaultMarkdownPageView(DefaultJinjaView):
     Convert a document to markdown format.
     """
 
-    def _validate_document(self, document: RenderedDocumentContent) -> bool:
+    @override
+    def _validate_document(self, document: RenderedDocumentContent) -> None:
         """
         Validate that the document is of the appropriate type at runtime.
         """
@@ -484,23 +459,23 @@ class DefaultMarkdownPageView(DefaultJinjaView):
 
     _template = "markdown_validation_results_page.j2"
 
-    def render(self, document, template=None, **kwargs):
+    @override
+    def render(self, document: list, template=None, **kwargs) -> list[str] | str:
         """
         Handle list as well as single document
         """
         if isinstance(document, list):
-            # We need to keep this as super(DefaultMarkdownPageView, self); otherwise a wrong render will be called.
+            # We need to keep this as super(DefaultMarkdownPageView, self); otherwise a wrong render will be called.  # noqa: E501 # FIXME CoP
             return [
-                super(DefaultMarkdownPageView, self).render(
-                    document=d, template=template, **kwargs
-                )
+                super(DefaultMarkdownPageView, self).render(document=d, template=template, **kwargs)
                 for d in document
             ]
 
         else:
             return super().render(document=document, template=template, **kwargs)
 
-    def render_string_template(self, template: pTemplate) -> pTemplate:
+    @override
+    def render_string_template(self, template: pTemplate | dict | OrderedDict) -> pTemplate | str:
         """
         Render string for markdown rendering. Bold all parameters and perform substitution.
         Args:
@@ -535,7 +510,7 @@ class DefaultMarkdownPageView(DefaultJinjaView):
         if "markdown_status_icon" in template["params"]:
             return template["params"]["markdown_status_icon"]
 
-        for parameter in template["params"].keys():
+        for parameter in template["params"]:
             if parameter == "html_success_icon":
                 template["params"][parameter] = ""
                 continue
@@ -545,31 +520,26 @@ class DefaultMarkdownPageView(DefaultJinjaView):
                 template["params"][parameter] = "\\*"
                 continue
 
-            template["params"][parameter] = pTemplate(
-                base_param_template_string
-            ).safe_substitute(
+            template["params"][parameter] = pTemplate(base_param_template_string).safe_substitute(
                 {
                     "content": template["params"][parameter],
                 }
             )
 
-        template["template"] = template.get("template", "").replace(
-            "$PARAMETER", "$$PARAMETER"
-        )
+        template["template"] = template.get("template", "").replace("$PARAMETER", "$$PARAMETER")
 
-        return pTemplate(template.get("template")).safe_substitute(
-            template.get("params", {})
-        )
+        return pTemplate(template["template"]).safe_substitute(template.get("params", {}))
 
-    @contextfilter
+    @override
+    @contextfilter  # type: ignore[misc] # untyped 3rd party decorator
     def render_content_block(
         self,
-        jinja_context,
-        content_block,
-        index=None,
-        content_block_id=None,
+        jinja_context: Any,
+        content_block: Any,
+        index: Any | None = None,
+        content_block_id: str | None = None,
         render_to_markdown: bool = True,
-    ):
+    ) -> RenderedComponentContent | dict | str:
         """
         Render a content block to markdown using jinja templates.
         Args:
