@@ -1,8 +1,10 @@
+from __future__ import annotations
+
 from marshmallow import Schema, fields
 
 
 class ClassConfig:
-    """Defines information sufficient to identify a class to be (dynamically) loaded for a DataContext."""
+    """Defines information sufficient to identify a class to be (dynamically) loaded for a DataContext."""  # noqa: E501 # FIXME CoP
 
     def __init__(self, class_name, module_name=None) -> None:
         self._class_name = class_name
