@@ -1,27 +1,33 @@
 from __future__ import annotations
 
 import logging
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Set, Tuple, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Tuple
 
-from great_expectations.validator.computed_metric import MetricValue  # noqa: TCH001
-from great_expectations.validator.exception_info import ExceptionInfo  # noqa: TCH001
-from great_expectations.validator.metric_configuration import MetricConfiguration
-from great_expectations.validator.validation_graph import ValidationGraph
+from great_expectations.validator.computed_metric import MetricValue
+from great_expectations.validator.metric_configuration import (
+    MetricConfiguration,
+    MetricConfigurationID,
+)
+from great_expectations.validator.validation_graph import (
+    MetricsCalculatorErrorResultValue,
+    ValidationGraph,
+)
 
 if TYPE_CHECKING:
+    import pandas as pd
+    from typing_extensions import TypeAlias
+
     from great_expectations.execution_engine import ExecutionEngine
 
 logger = logging.getLogger(__name__)
 logging.captureWarnings(True)
 
-try:
-    import pandas as pd
-except ImportError:
-    pd = None
 
-    logger.debug(
-        "Unable to load pandas; install optional pandas dependency for support."
-    )
+_MetricsDict: TypeAlias = Dict[MetricConfigurationID, MetricValue]
+_AbortedMetricsInfoDict: TypeAlias = Dict[
+    MetricConfigurationID,
+    MetricsCalculatorErrorResultValue,
+]
 
 
 class MetricsCalculator:
@@ -51,11 +57,18 @@ class MetricsCalculator:
     def columns(self, domain_kwargs: Optional[Dict[str, Any]] = None) -> List[str]:
         """
         Convenience method to run "table.columns" metric.
+
+        Arguments:
+            domain_kwargs: Optional dictionary of domain kwargs (e.g., containing "batch_id").
+
+        Returns:
+            The list of Batch columns.
         """
         if domain_kwargs is None:
-            domain_kwargs = {
-                "batch_id": self._execution_engine.batch_manager.active_batch_data_id,
-            }
+            domain_kwargs = {}
+
+        if domain_kwargs.get("batch_id") is None:
+            domain_kwargs["batch_id"] = self._execution_engine.batch_manager.active_batch_id
 
         columns: List[str] = self.get_metric(
             metric=MetricConfiguration(
@@ -72,16 +85,21 @@ class MetricsCalculator:
         domain_kwargs: Optional[Dict[str, Any]] = None,
         fetch_all: bool = False,
     ) -> pd.DataFrame:
-        """
-        Convenience method to run "table.head" metric.
+        """Convenience method to return the first several rows or records from a Batch of data.
+
+        Args:
+            n_rows: The number of rows to return.
+            domain_kwargs: If provided, the domain for which to return records.
+            fetch_all: If True, ignore n_rows and return the entire batch.
+
+        Returns:
+            A Pandas DataFrame containing the records' data.
         """
         if domain_kwargs is None:
             domain_kwargs = {}
 
         if domain_kwargs.get("batch_id") is None:
-            domain_kwargs[
-                "batch_id"
-            ] = self._execution_engine.batch_manager.active_batch_id
+            domain_kwargs["batch_id"] = self._execution_engine.batch_manager.active_batch_id
 
         df: pd.DataFrame = self.get_metric(
             metric=MetricConfiguration(
@@ -115,10 +133,9 @@ class MetricsCalculator:
 
         Returns:
             Return Dictionary with requested metrics resolved, with metric_name as key and computed metric as value.
-        """
-        resolved_metrics: Dict[
-            Tuple[str, str, str], MetricValue
-        ] = self.compute_metrics(
+        """  # noqa: E501 # FIXME CoP
+        resolved_metrics: _MetricsDict
+        resolved_metrics, _ = self.compute_metrics(
             metric_configurations=list(metrics.values()),
             runtime_configuration=None,
             min_graph_edges_pbar_enable=0,
@@ -134,34 +151,33 @@ class MetricsCalculator:
         runtime_configuration: Optional[dict] = None,
         min_graph_edges_pbar_enable: int = 0,
         # Set to low number (e.g., 3) to suppress progress bar for small graphs.
-    ) -> Dict[Tuple[str, str, str], MetricValue]:
+    ) -> tuple[_MetricsDict, _AbortedMetricsInfoDict]:
         """
         Args:
             metric_configurations: List of desired MetricConfiguration objects to be resolved.
             runtime_configuration: Additional run-time settings (see "Validator.DEFAULT_RUNTIME_CONFIGURATION").
-            min_graph_edges_pbar_enable: Minumum number of graph edges to warrant showing progress bars.
+            min_graph_edges_pbar_enable: Minimum number of graph edges to warrant showing progress bars.
 
         Returns:
-            Dictionary with requested metrics resolved, with unique metric ID as key and computed metric as value.
-        """
+            Tuple of two elements, the first is a dictionary with requested metrics resolved,
+            with unique metric ID as key and computed metric as value. The second is a dictionary of the
+            aborted metrics information, with metric ID as key if any metrics were aborted.
+        """  # noqa: E501 # FIXME CoP
         graph: ValidationGraph = self.build_metric_dependency_graph(
             metric_configurations=metric_configurations,
             runtime_configuration=runtime_configuration,
         )
-        resolved_metrics: Dict[Tuple[str, str, str], MetricValue]
-        aborted_metrics_info: Dict[
-            Tuple[str, str, str],
-            Dict[str, Union[MetricConfiguration, Set[ExceptionInfo], int]],
-        ]
+        resolved_metrics: _MetricsDict
+        aborted_metrics: _AbortedMetricsInfoDict
         (
             resolved_metrics,
-            aborted_metrics_info,
+            aborted_metrics,
         ) = self.resolve_validation_graph_and_handle_aborted_metrics_info(
             graph=graph,
             runtime_configuration=runtime_configuration,
             min_graph_edges_pbar_enable=min_graph_edges_pbar_enable,
         )
-        return resolved_metrics
+        return resolved_metrics, aborted_metrics
 
     def build_metric_dependency_graph(
         self,
@@ -178,10 +194,8 @@ class MetricsCalculator:
 
         Returns:
             Resulting "ValidationGraph" object.
-        """
-        graph: ValidationGraph = ValidationGraph(
-            execution_engine=self._execution_engine
-        )
+        """  # noqa: E501 # FIXME CoP
+        graph: ValidationGraph = ValidationGraph(execution_engine=self._execution_engine)
 
         metric_configuration: MetricConfiguration
         for metric_configuration in metric_configurations:
@@ -198,28 +212,23 @@ class MetricsCalculator:
         runtime_configuration: Optional[dict] = None,
         min_graph_edges_pbar_enable: int = 0,
         # Set to low number (e.g., 3) to suppress progress bar for small graphs.
-    ) -> Tuple[
-        Dict[Tuple[str, str, str], MetricValue],
-        Dict[
-            Tuple[str, str, str],
-            Dict[str, Union[MetricConfiguration, Set[ExceptionInfo], int]],
-        ],
-    ]:
+    ) -> Tuple[_MetricsDict, _AbortedMetricsInfoDict]:
         """
         Args:
             graph: "ValidationGraph" object, containing "metric_edge" structures with "MetricConfiguration" objects.
             runtime_configuration: Additional run-time settings (see "Validator.DEFAULT_RUNTIME_CONFIGURATION").
-            min_graph_edges_pbar_enable: Minumum number of graph edges to warrant showing progress bars.
+            min_graph_edges_pbar_enable: Minimum number of graph edges to warrant showing progress bars.
 
         Returns:
             Dictionary with requested metrics resolved, with unique metric ID as key and computed metric as value.
-        """
-        resolved_metrics: Dict[Tuple[str, str, str], MetricValue]
-        aborted_metrics_info: Dict[
-            Tuple[str, str, str],
-            Dict[str, Union[MetricConfiguration, Set[ExceptionInfo], int]],
-        ]
-        (resolved_metrics, aborted_metrics_info,) = self.resolve_validation_graph(
+            Dictionary with aborted metrics information, with metric ID as key.
+        """  # noqa: E501 # FIXME CoP
+        resolved_metrics: _MetricsDict
+        aborted_metrics_info: _AbortedMetricsInfoDict
+        (
+            resolved_metrics,
+            aborted_metrics_info,
+        ) = self.resolve_validation_graph(
             graph=graph,
             runtime_configuration=runtime_configuration,
             min_graph_edges_pbar_enable=min_graph_edges_pbar_enable,
@@ -227,7 +236,7 @@ class MetricsCalculator:
 
         if aborted_metrics_info:
             logger.warning(
-                f"Exceptions\n{str(aborted_metrics_info)}\noccurred while resolving metrics."
+                f"Exceptions\n{aborted_metrics_info!s}\noccurred while resolving metrics."
             )
 
         return (
@@ -241,30 +250,21 @@ class MetricsCalculator:
         runtime_configuration: Optional[dict] = None,
         min_graph_edges_pbar_enable: int = 0,
         # Set to low number (e.g., 3) to suppress progress bar for small graphs.
-    ) -> Tuple[
-        Dict[Tuple[str, str, str], MetricValue],
-        Dict[
-            Tuple[str, str, str],
-            Dict[str, Union[MetricConfiguration, Set[ExceptionInfo], int]],
-        ],
-    ]:
+    ) -> Tuple[_MetricsDict, _AbortedMetricsInfoDict]:
         """
         Calls "ValidationGraph.resolve()" method with supplied arguments.
 
         Args:
             graph: "ValidationGraph" object, containing "metric_edge" structures with "MetricConfiguration" objects.
             runtime_configuration: Additional run-time settings (see "Validator.DEFAULT_RUNTIME_CONFIGURATION").
-            min_graph_edges_pbar_enable: Minumum number of graph edges to warrant showing progress bars.
+            min_graph_edges_pbar_enable: Minimum number of graph edges to warrant showing progress bars.
 
         Returns:
             Dictionary with requested metrics resolved, with unique metric ID as key and computed metric as value.
-            Aborted metrics information, with metric ID as key.
-        """
-        resolved_metrics: Dict[Tuple[str, str, str], MetricValue]
-        aborted_metrics_info: Dict[
-            Tuple[str, str, str],
-            Dict[str, Union[MetricConfiguration, Set[ExceptionInfo], int]],
-        ]
+            Dictionary with aborted metrics information, with metric ID as key.
+        """  # noqa: E501 # FIXME CoP
+        resolved_metrics: _MetricsDict
+        aborted_metrics_info: _AbortedMetricsInfoDict
         resolved_metrics, aborted_metrics_info = graph.resolve(
             runtime_configuration=runtime_configuration,
             min_graph_edges_pbar_enable=min_graph_edges_pbar_enable,
