@@ -10,27 +10,47 @@ from typing import (
     Optional,
     Set,
     Tuple,
+    TypedDict,
     Union,
-    cast,
 )
 
 from tqdm.auto import tqdm
 
 import great_expectations.exceptions as gx_exceptions
-from great_expectations.core import IDDict  # noqa: TCH001
-from great_expectations.core.expectation_configuration import (
-    ExpectationConfiguration,  # noqa: TCH001
-)
-from great_expectations.execution_engine import ExecutionEngine  # noqa: TCH001
+from great_expectations.compatibility.typing_extensions import override
 from great_expectations.expectations.registry import get_metric_provider
-from great_expectations.validator.computed_metric import MetricValue  # noqa: TCH001
 from great_expectations.validator.exception_info import ExceptionInfo
 from great_expectations.validator.metric_configuration import (
-    MetricConfiguration,  # noqa: TCH001
+    MetricConfiguration,
+    MetricConfigurationID,
 )
 
 if TYPE_CHECKING:
+    from great_expectations.core import IDDict
+    from great_expectations.execution_engine import ExecutionEngine
+    from great_expectations.expectations.expectation_configuration import (
+        ExpectationConfiguration,
+    )
     from great_expectations.expectations.metrics.metric_provider import MetricProvider
+    from great_expectations.validator.computed_metric import MetricValue
+    from great_expectations.validator.metrics_calculator import (
+        _AbortedMetricsInfoDict,
+    )
+
+
+class MetricsCalculatorErrorResultValue(TypedDict):
+    metric_configuration: MetricConfiguration
+    exception_info: ExceptionInfo
+    num_failures: int
+
+
+__all__ = [
+    "ExpectationValidationGraph",
+    "MetricConfiguration",
+    "MetricEdge",
+    "MetricValue",
+    "ValidationGraph",
+]
 
 logger = logging.getLogger(__name__)
 logging.captureWarnings(True)
@@ -60,7 +80,7 @@ class MetricEdge:
 
         return self.left.id, None
 
-    def __repr__(self):
+    def __repr__(self):  # type: ignore[explicit-override] # FIXME
         return f"<{self._left.__repr__()}|{self._right.__repr__()}>"
 
 
@@ -79,22 +99,27 @@ class ValidationGraph:
 
         self._edge_ids = {edge.id for edge in self._edges}
 
+    @override
     def __eq__(self, other) -> bool:
         """Supports comparing two "ValidationGraph" objects."""
         return self.edge_ids == other.edge_ids
 
+    @override
+    def __hash__(self) -> int:
+        return hash(frozenset(self.edge_ids))
+
     @property
     def edges(self) -> List[MetricEdge]:
-        """Returns "MetricEdge" objects, contained within this "ValidationGraph" object (as list)."""
+        """Returns "MetricEdge" objects, contained within this "ValidationGraph" object (as list)."""  # noqa: E501 # FIXME CoP
         return self._edges
 
     @property
     def edge_ids(self) -> Set[Tuple[str, str]]:
-        """Returns "MetricEdge" objects, contained within this "ValidationGraph" object (as set of two-tuples)."""
+        """Returns "MetricEdge" objects, contained within this "ValidationGraph" object (as set of two-tuples)."""  # noqa: E501 # FIXME CoP
         return {edge.id for edge in self._edges}
 
     def add(self, edge: MetricEdge) -> None:
-        """Adds supplied "MetricEdge" object to this "ValidationGraph" object (if not already present)."""
+        """Adds supplied "MetricEdge" object to this "ValidationGraph" object (if not already present)."""  # noqa: E501 # FIXME CoP
         if edge.id not in self._edge_ids:
             self._edges.append(edge)
             self._edge_ids.add(edge.id)
@@ -111,13 +136,13 @@ class ValidationGraph:
         Args:
             metric_configuration: Desired MetricConfiguration object to be resolved.
             runtime_configuration: Additional run-time settings (see "Validator.DEFAULT_RUNTIME_CONFIGURATION").
-        """
+        """  # noqa: E501 # FIXME CoP
 
         metric_impl_klass: MetricProvider
         metric_provider: Callable
         (
             metric_impl_klass,
-            metric_provider,
+            _metric_provider,
         ) = self.set_metric_configuration_default_kwargs_if_absent(
             metric_configuration=metric_configuration
         )
@@ -140,7 +165,7 @@ class ValidationGraph:
                 # TODO: <Alex>In the future, provide a more robust cycle detection mechanism.</Alex>
                 if metric_dependency.id == metric_configuration.id:
                     logger.warning(
-                        f"Metric {str(metric_configuration.id)} has created a circular dependency"
+                        f"Metric {metric_configuration.id!s} has created a circular dependency"
                     )
                     continue
                 self.add(
@@ -159,7 +184,7 @@ class ValidationGraph:
     ) -> Tuple[MetricProvider, Callable]:
         """
         Updates "metric_domain_kwargs" and/or "metric_value_kwargs" of "MetricConfiguration" with defualts (if needed).
-        """
+        """  # noqa: E501 # FIXME CoP
         metric_impl_klass: MetricProvider
         metric_provider: Callable
         metric_impl_klass, metric_provider = get_metric_provider(
@@ -185,19 +210,13 @@ class ValidationGraph:
         # Set to low number (e.g., 3) to suppress progress bar for small graphs.
         show_progress_bars: bool = True,
     ) -> Tuple[
-        Dict[Tuple[str, str, str], MetricValue],
-        Dict[
-            Tuple[str, str, str],
-            Dict[str, Union[MetricConfiguration, Set[ExceptionInfo], int]],
-        ],
+        Dict[MetricConfigurationID, MetricValue],
+        _AbortedMetricsInfoDict,
     ]:
-        resolved_metrics: Dict[Tuple[str, str, str], MetricValue] = {}
+        resolved_metrics: Dict[MetricConfigurationID, MetricValue] = {}
 
         # updates graph with aborted metrics
-        aborted_metrics_info: Dict[
-            Tuple[str, str, str],
-            Dict[str, Union[MetricConfiguration, Set[ExceptionInfo], int]],
-        ] = self._resolve(
+        aborted_metrics_info: _AbortedMetricsInfoDict = self._resolve(
             metrics=resolved_metrics,
             runtime_configuration=runtime_configuration,
             min_graph_edges_pbar_enable=min_graph_edges_pbar_enable,
@@ -206,16 +225,13 @@ class ValidationGraph:
 
         return resolved_metrics, aborted_metrics_info
 
-    def _resolve(  # noqa: C901 - complexity 16
+    def _resolve(  # noqa: C901, PLR0912, PLR0915 # FIXME CoP
         self,
-        metrics: Dict[Tuple[str, str, str], MetricValue],
+        metrics: Dict[MetricConfigurationID, MetricValue],
         runtime_configuration: Optional[dict] = None,
-        min_graph_edges_pbar_enable: int = 0,  # Set to low number (e.g., 3) to suppress progress bar for small graphs.
+        min_graph_edges_pbar_enable: int = 0,  # Set to low number (e.g., 3) to suppress progress bar for small graphs.  # noqa: E501 # FIXME CoP
         show_progress_bars: bool = True,
-    ) -> Dict[
-        Tuple[str, str, str],
-        Dict[str, Union[MetricConfiguration, Set[ExceptionInfo], int]],
-    ]:
+    ) -> _AbortedMetricsInfoDict:
         if metrics is None:
             metrics = {}
 
@@ -227,14 +243,8 @@ class ValidationGraph:
         else:
             catch_exceptions = False
 
-        failed_metric_info: Dict[
-            Tuple[str, str, str],
-            Dict[str, Union[MetricConfiguration, Set[ExceptionInfo], int]],
-        ] = {}
-        aborted_metrics_info: Dict[
-            Tuple[str, str, str],
-            Dict[str, Union[MetricConfiguration, Set[ExceptionInfo], int]],
-        ] = {}
+        failed_metric_info: _AbortedMetricsInfoDict = {}
+        aborted_metrics_info: _AbortedMetricsInfoDict = {}
 
         ready_metrics: Set[MetricConfiguration]
         needed_metrics: Set[MetricConfiguration]
@@ -265,13 +275,17 @@ class ValidationGraph:
             computable_metrics = set()
 
             for metric in ready_metrics:
-                if metric.id in failed_metric_info and failed_metric_info[metric.id]["num_failures"] >= MAX_METRIC_COMPUTATION_RETRIES:  # type: ignore[operator]  # Incorrect flagging of 'Unsupported operand types for <= ("int" and "MetricConfiguration") and for >= ("Set[ExceptionInfo]" and "int")' in deep "Union" structure.
+                if (
+                    metric.id in failed_metric_info
+                    and failed_metric_info[metric.id]["num_failures"]
+                    >= MAX_METRIC_COMPUTATION_RETRIES
+                ):
                     aborted_metrics_info[metric.id] = failed_metric_info[metric.id]
                 else:
                     computable_metrics.add(metric)
 
             try:
-                # Access "ExecutionEngine.resolve_metrics()" method, to resolve missing "MetricConfiguration" objects.
+                # Access "ExecutionEngine.resolve_metrics()" method, to resolve missing "MetricConfiguration" objects.  # noqa: E501 # FIXME CoP
                 metrics.update(
                     self._execution_engine.resolve_metrics(
                         metrics_to_resolve=computable_metrics,
@@ -291,27 +305,27 @@ class ValidationGraph:
                     )
                     for failed_metric in err.failed_metrics:
                         if failed_metric.id in failed_metric_info:
-                            failed_metric_info[failed_metric.id]["num_failures"] += 1  # type: ignore[operator]  # Incorrect flagging of 'Unsupported operand types for <= ("int" and "MetricConfiguration") and for >= ("Set[ExceptionInfo]" and "int")' in deep "Union" structure.
-                            failed_metric_info[failed_metric.id]["exception_info"].add(exception_info)  # type: ignore[union-attr]  # Incorrect flagging of 'Item "MetricConfiguration" of "Union[MetricConfiguration, Set[ExceptionInfo], int]" has no attribute "add" and Item "int" of "Union[MetricConfiguration, Set[ExceptionInfo], int]" has no attribute "add"' in deep "Union" structure.
+                            failed_metric_info[failed_metric.id]["num_failures"] += 1
+                            failed_metric_info[failed_metric.id]["exception_info"] = exception_info
                         else:
-                            failed_metric_info[failed_metric.id] = {}
-                            failed_metric_info[failed_metric.id][
-                                "metric_configuration"
-                            ] = failed_metric
-                            failed_metric_info[failed_metric.id]["num_failures"] = 1
-                            failed_metric_info[failed_metric.id]["exception_info"] = {
-                                exception_info
-                            }
+                            failed_metric_info[failed_metric.id] = (
+                                MetricsCalculatorErrorResultValue(
+                                    metric_configuration=failed_metric,
+                                    exception_info=exception_info,
+                                    num_failures=1,
+                                )
+                            )
+
                 else:
-                    raise err
+                    raise err  # noqa: TRY201 # FIXME CoP
             except Exception as e:
                 if catch_exceptions:
-                    logger.error(
-                        f"""Caught exception {str(e)} while trying to resolve a set of {len(ready_metrics)} metrics; aborting graph resolution."""
+                    logger.error(  # noqa: TRY400 # FIXME CoP
+                        f"""Caught exception {e!s} while trying to resolve a set of {len(ready_metrics)} metrics; aborting graph resolution."""  # noqa: E501 # FIXME CoP
                     )
                     done = True
                 else:
-                    raise e
+                    raise e  # noqa: TRY201 # FIXME CoP
 
             if (len(ready_metrics) + len(needed_metrics) == 0) or (
                 len(ready_metrics) == len(aborted_metrics_info)
@@ -324,10 +338,10 @@ class ValidationGraph:
 
     def _parse(
         self,
-        metrics: Dict[Tuple[str, str, str], MetricValue],
+        metrics: Dict[MetricConfigurationID, MetricValue],
     ) -> Tuple[Set[MetricConfiguration], Set[MetricConfiguration]]:
         """Given validation graph, returns the ready and needed metrics necessary for validation using a traversal of
-        validation graph (a graph structure of metric ids) edges"""
+        validation graph (a graph structure of metric ids) edges"""  # noqa: E501 # FIXME CoP
         unmet_dependency_ids = set()
         unmet_dependency = set()
         maybe_ready_ids = set()
@@ -339,7 +353,7 @@ class ValidationGraph:
                     if edge.left.id not in maybe_ready_ids:
                         maybe_ready_ids.add(edge.left.id)
                         maybe_ready.add(edge.left)
-                else:
+                else:  # noqa: PLR5501 # FIXME CoP
                     if edge.left.id not in unmet_dependency_ids:
                         unmet_dependency_ids.add(edge.left.id)
                         unmet_dependency.add(edge.left)
@@ -361,7 +375,7 @@ class ValidationGraph:
             ):
                 metric_kwargs[key] = default_kwarg_values[key]
 
-    def __repr__(self):
+    def __repr__(self):  # type: ignore[explicit-override] # FIXME
         edge: MetricEdge
         return ", ".join([edge.__repr__() for edge in self._edges])
 
@@ -373,13 +387,13 @@ class ExpectationValidationGraph:
         graph: ValidationGraph,
     ) -> None:
         if configuration is None:
-            raise ValueError(
-                """Instantiation of "ExpectationValidationGraph" requires valid "ExpectationConfiguration" object."""
+            raise ValueError(  # noqa: TRY003 # FIXME CoP
+                """Instantiation of "ExpectationValidationGraph" requires valid "ExpectationConfiguration" object."""  # noqa: E501 # FIXME CoP
             )
 
         if graph is None:
-            raise ValueError(
-                """Instantiation of "ExpectationValidationGraph" requires valid "ValidationGraph" object."""
+            raise ValueError(  # noqa: TRY003 # FIXME CoP
+                """Instantiation of "ExpectationValidationGraph" requires valid "ValidationGraph" object."""  # noqa: E501 # FIXME CoP
             )
 
         self._configuration = configuration
@@ -400,34 +414,22 @@ class ExpectationValidationGraph:
 
     def get_exception_info(
         self,
-        metric_info: Dict[
-            Tuple[str, str, str],
-            Dict[str, Union[MetricConfiguration, Set[ExceptionInfo], int]],
-        ],
-    ) -> Set[ExceptionInfo]:
+        metric_info: _AbortedMetricsInfoDict,
+    ) -> Dict[str, Union[MetricConfiguration, ExceptionInfo, int]]:
         metric_info = self._filter_metric_info_in_graph(metric_info=metric_info)
-        metric_exception_info: Set[ExceptionInfo] = set()
-        metric_id: Tuple[str, str, str]
-        metric_info_item: Union[MetricConfiguration, Set[ExceptionInfo], int]
-        for metric_id, metric_info_item in metric_info.items():  # type: ignore[assignment]  # Incorrect flagging of 'Incompatible types in assignment (expression has type "Dict[str, Union[MetricConfiguration, Set[ExceptionInfo], int]]", variable has type "Union[MetricConfiguration, Set[ExceptionInfo], int]")' in deep "Union" structure.
-            # noinspection PyUnresolvedReferences
-            metric_exception_info.update(
-                cast(Set[ExceptionInfo], metric_info_item["exception_info"])  # type: ignore[index]  # Incorrect flagging of 'Value of type "Union[MetricConfiguration, Set[ExceptionInfo], int]" is not indexable' in deep "Union" structure.
-            )
+        metric_exception_info: Dict[str, Union[MetricConfiguration, ExceptionInfo, int]] = {}
+        metric_id: MetricConfigurationID
+        metric_info_item: MetricsCalculatorErrorResultValue
+        for metric_id, metric_info_item in metric_info.items():
+            metric_exception_info[str(metric_id)] = metric_info_item["exception_info"]
 
         return metric_exception_info
 
     def _filter_metric_info_in_graph(
         self,
-        metric_info: Dict[
-            Tuple[str, str, str],
-            Dict[str, Union[MetricConfiguration, Set[ExceptionInfo], int]],
-        ],
-    ) -> Dict[
-        Tuple[str, str, str],
-        Dict[str, Union[MetricConfiguration, Set[ExceptionInfo], int]],
-    ]:
-        graph_metric_ids: List[Tuple[str, str, str]] = []
+        metric_info: _AbortedMetricsInfoDict,
+    ) -> _AbortedMetricsInfoDict:
+        graph_metric_ids: List[MetricConfigurationID] = []
         edge: MetricEdge
         vertex: MetricConfiguration
         for edge in self.graph.edges:
@@ -435,10 +437,20 @@ class ExpectationValidationGraph:
                 if vertex is not None:
                     graph_metric_ids.append(vertex.id)
 
-        metric_id: Tuple[str, str, str]
+        metric_id: MetricConfigurationID
         metric_info_item: Dict[str, Union[MetricConfiguration, Set[ExceptionInfo], int]]
         return {
             metric_id: metric_info_item
             for metric_id, metric_info_item in metric_info.items()
             if metric_id in graph_metric_ids
         }
+
+    @override
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, ExpectationValidationGraph):
+            return False
+        return self.configuration == other.configuration and self.graph == other.graph
+
+    @override
+    def __hash__(self) -> int:
+        return hash((self.configuration, self.graph))
