@@ -1,11 +1,14 @@
+from pprint import pformat as pf
+
 import pytest
 
-from great_expectations.core._docs_decorators import (
+from great_expectations._docs_decorators import (
     deprecated_argument,
     deprecated_method_or_class,
     new_argument,
     new_method_or_class,
     public_api,
+    public_api_introspector,
 )
 
 # @public_api
@@ -48,10 +51,7 @@ class TestPublicAPI:
             "        other_arg: describe other_arg\n"
             "    "
         )
-        assert (
-            _func_full_docstring_public_api.__name__
-            == "_func_full_docstring_public_api"
-        )
+        assert _func_full_docstring_public_api.__name__ == "_func_full_docstring_public_api"
 
     @pytest.mark.unit
     def test_public_api_decorator_only_summary(self):
@@ -63,6 +63,41 @@ class TestPublicAPI:
         assert _func_no_docstring_public_api.__doc__ == "--Public API--"
         assert _func_no_docstring_public_api.__name__ == "_func_no_docstring_public_api"
 
+    @pytest.mark.unit
+    def test_public_api_methods_have_decorated_parent_class(self):
+        """
+        In order for the public_api decorator to work and result in rendered docs,
+        the parent class of a decorated method must also be decorated.
+
+        Example:
+
+            # Failure to decorate this class means that `my_method` won't be rendered in the docs.
+            class MyClass:
+
+                @public_api
+                def my_method(self):
+                    pass
+        """
+        class_registry = public_api_introspector.class_registry
+        classes_that_need_public_api_decorator: dict[str, list[str]] = {}
+
+        for class_, methods in class_registry.items():
+            if public_api_introspector.CLASS_DEFINITION not in methods:
+                classes_that_need_public_api_decorator[class_] = sorted(methods)
+
+        print(f"Classes missing @public_api ->\n{pf(classes_that_need_public_api_decorator)}")
+        assert sorted(classes_that_need_public_api_decorator.keys()) == []
+
+    @pytest.mark.unit
+    def test_public_api_objects_have_docstrings(self):
+        """
+        All objects that are decorated with @public_api should have a docstring.
+        """
+        violations = public_api_introspector.docstring_violations
+        assert len(violations) == 0, (
+            f"Public API decorated objects without docstrings: {pf(violations)}"
+        )
+
 
 # @deprecated
 
@@ -107,7 +142,6 @@ def _func_no_docstring_deprecated(some_arg, other_arg):
 class TestDeprecatedMethod:
     @pytest.mark.unit
     def test_deprecated_decorator_full_docstring(self):
-
         assert _func_full_docstring_deprecated.__doc__ == (
             "My docstring.\n"
             "\n"
@@ -121,14 +155,10 @@ class TestDeprecatedMethod:
             "    some_arg: describe some_arg\n"
             "    other_arg: describe other_arg\n"
         )
-        assert (
-            _func_full_docstring_deprecated.__name__
-            == "_func_full_docstring_deprecated"
-        )
+        assert _func_full_docstring_deprecated.__name__ == "_func_full_docstring_deprecated"
 
     @pytest.mark.unit
     def test_deprecated_decorator_full_docstring_no_message(self):
-
         assert _func_full_docstring_deprecated_no_message.__doc__ == (
             "My docstring.\n"
             "\n"
@@ -145,19 +175,14 @@ class TestDeprecatedMethod:
 
     @pytest.mark.unit
     def test_deprecated_decorator_only_summary(self):
-
         assert _func_only_summary_deprecated.__doc__ == (
-            "My docstring.\n"
-            "\n"
-            ".. deprecated:: 1.2.3\n"
-            "    This is deprecated!!\n"
+            "My docstring.\n\n.. deprecated:: 1.2.3\n    This is deprecated!!\n"
         )
 
     @pytest.mark.unit
     def test_deprecated_decorator_no_docstring(self):
-
         assert _func_no_docstring_deprecated.__doc__ == (
-            "\n" "\n" ".. deprecated:: 1.2.3\n" "    This is deprecated!!\n"
+            "\n\n.. deprecated:: 1.2.3\n    This is deprecated!!\n"
         )
 
 
@@ -204,7 +229,6 @@ def _func_no_docstring_new_method(some_arg, other_arg):
 class TestNewMethod:
     @pytest.mark.unit
     def test_new_method_decorator_full_docstring(self):
-
         assert _func_full_docstring_new_method.__doc__ == (
             "My docstring.\n"
             "\n"
@@ -221,7 +245,6 @@ class TestNewMethod:
 
     @pytest.mark.unit
     def test_new_method_decorator_full_docstring_no_message(self):
-
         assert _func_full_docstring_new_method_no_message.__doc__ == (
             "My docstring.\n"
             "\n"
@@ -238,19 +261,14 @@ class TestNewMethod:
 
     @pytest.mark.unit
     def test_new_method_decorator_only_summary(self):
-
         assert _func_only_summary_new_method.__doc__ == (
-            "My docstring.\n"
-            "\n"
-            ".. versionadded:: 1.2.3\n"
-            "    Added in version 1.2.3\n"
+            "My docstring.\n\n.. versionadded:: 1.2.3\n    Added in version 1.2.3\n"
         )
 
     @pytest.mark.unit
     def test_new_method_decorator_no_docstring(self):
-
         assert _func_no_docstring_new_method.__doc__ == (
-            "\n" "\n" ".. versionadded:: 1.2.3\n" "    Added in version 1.2.3\n"
+            "\n\n.. versionadded:: 1.2.3\n    Added in version 1.2.3\n"
         )
 
 
@@ -274,7 +292,6 @@ def _func_full_docstring_all_method_decorators(some_arg, other_arg):
 
 @pytest.mark.unit
 def test_all_method_decorators_full_docstring():
-
     assert _func_full_docstring_all_method_decorators.__doc__ == (
         "--Public API--My docstring.\n"
         "\n"
@@ -392,9 +409,8 @@ class TestDeprecatedArgument:
                 """
                 pass
 
-        assert (
-            "Please specify an existing argument, you specified this_arg_doesnt_exist."
-            in str(e.value)
+        assert "Please specify an existing argument, you specified this_arg_doesnt_exist." in str(
+            e.value
         )
 
 
@@ -516,9 +532,8 @@ class TestNewArgument:
                 """
                 pass
 
-        assert (
-            "Please specify an existing argument, you specified this_arg_doesnt_exist."
-            in str(e.value)
+        assert "Please specify an existing argument, you specified this_arg_doesnt_exist." in str(
+            e.value
         )
 
 
@@ -544,7 +559,6 @@ def _func_full_docstring_all_decorators(some_arg, other_arg):
 
 @pytest.mark.unit
 def test_all_decorators_full_docstring():
-
     assert _func_full_docstring_all_decorators.__doc__ == (
         "--Public API--My docstring.\n"
         "\n"
@@ -605,7 +619,7 @@ def _func_full_docstring_all_decorators_all_sections(
 
 @pytest.mark.unit
 def test_all_decorators_full_docstring_all_sections():
-    """Makes sure that Returns and Raises are rendered correctly in the context of a full docstring."""
+    """Makes sure that Returns and Raises are rendered correctly in the context of a full docstring."""  # noqa: E501 # FIXME CoP
 
     assert _func_full_docstring_all_decorators_all_sections.__doc__ == (
         "--Public API--My docstring.\n"
@@ -652,10 +666,7 @@ def test_all_decorators_full_docstring_all_sections():
 
 @pytest.mark.unit
 def test_all_decorators_do_not_change_function_name():
-    assert (
-        _func_full_docstring_all_decorators.__name__
-        == "_func_full_docstring_all_decorators"
-    )
+    assert _func_full_docstring_all_decorators.__name__ == "_func_full_docstring_all_decorators"
 
 
 # Class level decorators
@@ -694,12 +705,8 @@ class _ClassFullDocstringDeprecatedAndNewAtClassLevel:
         self.other_arg = other_arg
 
 
-@deprecated_argument(
-    argument_name="some_arg", version="1.2.3", message="This is deprecated!!"
-)
-@new_argument(
-    argument_name="other_arg", version="1.2.3", message="Added in version 1.2.3"
-)
+@deprecated_argument(argument_name="some_arg", version="1.2.3", message="This is deprecated!!")
+@new_argument(argument_name="other_arg", version="1.2.3", message="Added in version 1.2.3")
 class _ClassFullDocstringDeprecatedAndNewAtArgumentLevel:
     """Docstring summary.
 
