@@ -1,12 +1,10 @@
 import pytest
 
-from great_expectations.core.serializer import JsonConfigSerializer
 from great_expectations.data_context.cloud_constants import GXCloudRESTResource
 from great_expectations.data_context.store import DatasourceStore
 from great_expectations.data_context.store.gx_cloud_store_backend import (
     GXCloudStoreBackend,
 )
-from great_expectations.data_context.types.base import datasourceConfigSchema
 
 
 @pytest.fixture
@@ -30,6 +28,5 @@ def datasource_store_ge_cloud_backend(
     store = DatasourceStore(
         store_name=datasource_store_name,
         store_backend=ge_cloud_store_backend_config,
-        serializer=JsonConfigSerializer(schema=datasourceConfigSchema),
     )
     return store
