@@ -3,18 +3,18 @@ import os
 
 import pytest
 
-import tests.test_utils as test_utils
 from great_expectations.data_context.store import DatabaseStoreBackend
 from great_expectations.data_context.util import instantiate_class_from_config
 from great_expectations.exceptions import StoreBackendError
+from tests import test_utils
 
-try:
-    sqlalchemy = pytest.importorskip("sqlalchemy")
-except ImportError:
-    sqlalchemy = None
+# module level markers
+pytestmark = [
+    pytest.mark.postgresql,
+    pytest.mark.sqlalchemy_version_compatibility,
+]
 
 
-@pytest.mark.integration
 def test_database_store_backend_schema_spec(caplog, sa, test_backends):
     if "postgresql" not in test_backends:
         pytest.skip("test_database_store_backend_get_url_for_key requires postgresql")
@@ -37,13 +37,13 @@ def test_database_store_backend_schema_spec(caplog, sa, test_backends):
     key = ("2",)
 
     store_backend.set(key, "hello")
-    assert "hello" == store_backend.get(key)
+    assert store_backend.get(key) == "hello"
 
     # clean up values
-    store_backend.engine.execute(f"DROP TABLE {store_backend._table};")
+    with store_backend.engine.begin() as connection:
+        connection.execute(sa.text(f"DROP TABLE {store_backend._table};"))
 
 
-@pytest.mark.integration
 def test_database_store_backend_get_url_for_key(caplog, sa, test_backends):
     if "postgresql" not in test_backends:
         pytest.skip("test_database_store_backend_get_url_for_key requires postgresql")
@@ -63,19 +63,16 @@ def test_database_store_backend_get_url_for_key(caplog, sa, test_backends):
 
     # existing key
     key = ("1",)
-    assert "postgresql://test_ci/1" == store_backend.get_url_for_key(key)
+    assert store_backend.get_url_for_key(key) == "postgresql://test_ci/1"
 
     # non-existing key : should still work
     key = ("not_here",)
-    assert "postgresql://test_ci/not_here" == store_backend.get_url_for_key(key)
+    assert store_backend.get_url_for_key(key) == "postgresql://test_ci/not_here"
 
 
-@pytest.mark.integration
 def test_database_store_backend_duplicate_key_violation(caplog, sa, test_backends):
     if "postgresql" not in test_backends:
-        pytest.skip(
-            "test_database_store_backend_duplicate_key_violation requires postgresql"
-        )
+        pytest.skip("test_database_store_backend_duplicate_key_violation requires postgresql")
 
     store_backend = DatabaseStoreBackend(
         credentials={
@@ -92,18 +89,16 @@ def test_database_store_backend_duplicate_key_violation(caplog, sa, test_backend
     key = ("1", "2", "3")
 
     store_backend.set(key, "hello")
-    assert "hello" == store_backend.get(key)
+    assert store_backend.get(key) == "hello"
 
     # default behavior doesn't throw an error because the key is updated
     store_backend.set(key, "hello")
-    assert "hello" == store_backend.get(key)
+    assert store_backend.get(key) == "hello"
 
     assert len(caplog.messages) == 0
     caplog.set_level(logging.INFO, "great_expectations")
 
-    store_backend.set(
-        key, "hello", allow_update=False
-    )  # the only place we are testing this flag
+    store_backend.set(key, "hello", allow_update=False)  # the only place we are testing this flag
     assert len(caplog.messages) == 1
     assert "already exists with the same value" in caplog.messages[0]
 
@@ -113,7 +108,6 @@ def test_database_store_backend_duplicate_key_violation(caplog, sa, test_backend
     assert "Integrity error" in str(exc.value)
 
 
-@pytest.mark.integration
 def test_database_store_backend_url_instantiation(caplog, sa, test_backends):
     if "postgresql" not in test_backends:
         pytest.skip("test_database_store_backend_get_url_for_key requires postgresql")
@@ -127,11 +121,11 @@ def test_database_store_backend_url_instantiation(caplog, sa, test_backends):
 
     # existing key
     key = ("1",)
-    assert "postgresql://test_ci/1" == store_backend.get_url_for_key(key)
+    assert store_backend.get_url_for_key(key) == "postgresql://test_ci/1"
 
     # non-existing key : should still work
     key = ("not_here",)
-    assert "postgresql://test_ci/not_here" == store_backend.get_url_for_key(key)
+    assert store_backend.get_url_for_key(key) == "postgresql://test_ci/not_here"
 
     db_hostname = os.getenv("GE_TEST_LOCAL_DB_HOSTNAME", "localhost")
     store_backend = DatabaseStoreBackend(
@@ -142,14 +136,13 @@ def test_database_store_backend_url_instantiation(caplog, sa, test_backends):
 
     # existing key
     key = ("1",)
-    assert "postgresql://test_ci/1" == store_backend.get_url_for_key(key)
+    assert store_backend.get_url_for_key(key) == "postgresql://test_ci/1"
 
     # non-existing key : should still work
     key = ("not_here",)
-    assert "postgresql://test_ci/not_here" == store_backend.get_url_for_key(key)
+    assert store_backend.get_url_for_key(key) == "postgresql://test_ci/not_here"
 
 
-@pytest.mark.integration
 def test_database_store_backend_id_initialization(caplog, sa, test_backends):
     """
     What does this test and why?
@@ -167,7 +160,7 @@ def test_database_store_backend_id_initialization(caplog, sa, test_backends):
     Note: StoreBackend & TupleStoreBackend are abstract classes, so we will test the
     concrete classes that inherit from them.
     See also test_store_backends::test_StoreBackend_id_initialization
-    """
+    """  # noqa: E501 # FIXME CoP
 
     if "postgresql" not in test_backends:
         pytest.skip("test_database_store_backend_id_initialization requires postgresql")
