@@ -1,21 +1,21 @@
+import uuid
 from typing import Dict, Optional, Set
 
 import boto3
 import pyparsing as pp
+import pytest
 from moto import mock_s3
 
+from great_expectations.data_context import get_context
 from great_expectations.data_context.store import StoreBackend, TupleS3StoreBackend
 from great_expectations.data_context.types.base import DataContextConfig
-from great_expectations.util import get_context
-from tests.integration.usage_statistics.test_integration_usage_statistics import (
-    USAGE_STATISTICS_QA_URL,
-)
 
 
 def build_in_code_data_context_project_config(
     bucket: str = "leakybucket",
     expectations_store_prefix: str = "expectations_store_prefix",
-    validations_store_prefix: str = "validations_store_prefix",
+    checkpoint_store_prefix: str = "checkpoint_store_prefix",
+    validation_results_store_prefix: str = "validation_results_store_prefix",
     data_docs_store_prefix: str = "data_docs_store_prefix",
     stores: Optional[Dict] = None,
 ) -> DataContextConfig:
@@ -24,7 +24,8 @@ def build_in_code_data_context_project_config(
     Not a fixture because we want to control when this is built (after the expectation store).
     Args:
         expectations_store_prefix: prefix for expectations store
-        validations_store_prefix: prefix for validations store
+        checkpoint_store_prefix: prefix for checkpoint store
+        validation_results_store_prefix: prefix for validations store
         data_docs_store_prefix: prefix for data docs
         bucket: name of the s3 bucket
         stores: optional overwrite of the default stores
@@ -42,35 +43,24 @@ def build_in_code_data_context_project_config(
                     "prefix": expectations_store_prefix,
                 },
             },
-            "validations_S3_store": {
-                "class_name": "ValidationsStore",
+            "validation_results_S3_store": {
+                "class_name": "ValidationResultsStore",
                 "store_backend": {
                     "class_name": "TupleS3StoreBackend",
                     "bucket": bucket,
-                    "prefix": validations_store_prefix,
+                    "prefix": validation_results_store_prefix,
                 },
             },
-            "evaluation_parameter_store": {"class_name": "EvaluationParameterStore"},
+            "checkpoint_store": {"class_name": "CheckpointStore"},
         }
     project_config = DataContextConfig(
         config_version=2,
         plugins_directory=None,
         config_variables_file_path=None,
-        datasources={
-            "my_spark_datasource": {
-                "data_asset_type": {
-                    "class_name": "SparkDFDataset",
-                    "module_name": "great_expectations.dataset",
-                },
-                "class_name": "SparkDFDatasource",
-                "module_name": "great_expectations.datasource",
-                "batch_kwargs_generators": {},
-            }
-        },
         stores=stores,
+        checkpoint_store_name="checkpoint_store",
         expectations_store_name="expectations_S3_store",
-        validations_store_name="validations_S3_store",
-        evaluation_parameter_store_name="evaluation_parameter_store",
+        validation_results_store_name="validation_results_S3_store",
         data_docs_sites={
             "s3_site": {
                 "class_name": "SiteBuilder",
@@ -84,35 +74,11 @@ def build_in_code_data_context_project_config(
                 },
             }
         },
-        validation_operators={
-            "action_list_operator": {
-                "class_name": "ActionListValidationOperator",
-                "action_list": [
-                    {
-                        "name": "store_validation_result",
-                        "action": {"class_name": "StoreValidationResultAction"},
-                    },
-                    {
-                        "name": "store_evaluation_params",
-                        "action": {"class_name": "StoreEvaluationParametersAction"},
-                    },
-                    {
-                        "name": "update_data_docs",
-                        "action": {"class_name": "UpdateDataDocsAction"},
-                    },
-                ],
-            }
-        },
-        anonymous_usage_statistics={
-            "enabled": True,
-            # NOTE: No data_context_id set here
-            "usage_statistics_url": USAGE_STATISTICS_QA_URL,
-        },
     )
     return project_config
 
 
-def get_store_backend_id_from_s3(bucket: str, prefix: str, key: str) -> str:
+def get_store_backend_id_from_s3(bucket: str, prefix: str, key: str) -> uuid.UUID:
     """
     Return the UUID store_backend_id from a given s3 file
     Args:
@@ -123,22 +89,14 @@ def get_store_backend_id_from_s3(bucket: str, prefix: str, key: str) -> str:
     Returns:
 
     """
-    s3_response_object = boto3.client("s3").get_object(
-        Bucket=bucket, Key=f"{prefix}/{key}"
-    )
-    ge_store_backend_id_file_contents = (
-        s3_response_object["Body"]
-        .read()
-        .decode(s3_response_object.get("ContentEncoding", "utf-8"))
-    )
+    s3_response_object = boto3.client("s3").get_object(Bucket=bucket, Key=f"{prefix}/{key}")
+    ge_store_backend_id_file_contents = s3_response_object["Body"].read().decode("utf-8")
 
-    store_backend_id_file_parser = StoreBackend.STORE_BACKEND_ID_PREFIX + pp.Word(
-        pp.hexnums + "-"
-    )
+    store_backend_id_file_parser = StoreBackend.STORE_BACKEND_ID_PREFIX + pp.Word(pp.hexnums + "-")
     parsed_store_backend_id = store_backend_id_file_parser.parseString(
         ge_store_backend_id_file_contents
     )
-    return parsed_store_backend_id[1]
+    return uuid.UUID(parsed_store_backend_id[1])
 
 
 def list_s3_bucket_contents(bucket: str, prefix: str) -> Set[str]:
@@ -153,14 +111,17 @@ def list_s3_bucket_contents(bucket: str, prefix: str) -> Set[str]:
     """
     return {
         s3_object_info["Key"]
-        for s3_object_info in boto3.client("s3").list_objects_v2(
-            Bucket=bucket, Prefix=prefix
-        )["Contents"]
+        for s3_object_info in boto3.client("s3").list_objects_v2(Bucket=bucket, Prefix=prefix)[
+            "Contents"
+        ]
     }
 
 
+@pytest.mark.aws_deps
 @mock_s3
-def test_DataContext_construct_data_context_id_uses_id_of_currently_configured_expectations_store():
+def test_DataContext_construct_data_context_id_uses_id_of_currently_configured_expectations_store(
+    aws_credentials,
+):
     """
     What does this test and why?
 
@@ -176,7 +137,7 @@ def test_DataContext_construct_data_context_id_uses_id_of_currently_configured_e
     store_backend_id_filename = StoreBackend.STORE_BACKEND_ID_KEY[0]
     bucket = "leakybucket"
     expectations_store_prefix = "expectations_store_prefix"
-    validations_store_prefix = "validations_store_prefix"
+    validation_results_store_prefix = "validation_results_store_prefix"
     data_docs_store_prefix = "data_docs_store_prefix"
     data_context_prefix = ""
 
@@ -192,7 +153,7 @@ def test_DataContext_construct_data_context_id_uses_id_of_currently_configured_e
         prefix=expectations_store_prefix,
     )
     # Make sure store_backend_id is not the error string
-    store_error_uuid = "00000000-0000-0000-0000-00000000e003"
+    store_error_uuid = uuid.UUID("00000000-0000-0000-0000-00000000e003")
     s3_expectations_store_backend_id = s3_expectations_store_backend.store_backend_id
     assert s3_expectations_store_backend_id != store_error_uuid
 
@@ -210,32 +171,28 @@ def test_DataContext_construct_data_context_id_uses_id_of_currently_configured_e
         prefix=expectations_store_prefix,
         key=store_backend_id_filename,
     )
-    assert (
-        expectations_store_backend_id_from_s3_file == s3_expectations_store_backend_id
-    )
+    assert expectations_store_backend_id_from_s3_file == s3_expectations_store_backend_id
 
     # Create a DataContext (note existing expectations store already set up)
     in_code_data_context_project_config = build_in_code_data_context_project_config(
         bucket="leakybucket",
         expectations_store_prefix=expectations_store_prefix,
-        validations_store_prefix=validations_store_prefix,
+        validation_results_store_prefix=validation_results_store_prefix,
         data_docs_store_prefix=data_docs_store_prefix,
     )
-    in_code_data_context = get_context(
-        project_config=in_code_data_context_project_config
-    )
+    in_code_data_context = get_context(project_config=in_code_data_context_project_config)
     bucket_contents_after_instantiating_get_context = list_s3_bucket_contents(
         bucket=bucket, prefix=data_context_prefix
     )
     assert bucket_contents_after_instantiating_get_context == {
         f"{expectations_store_prefix}/{store_backend_id_filename}",
-        f"{validations_store_prefix}/{store_backend_id_filename}",
+        f"{validation_results_store_prefix}/{store_backend_id_filename}",
     }
 
     # Make sure ids are consistent
-    in_code_data_context_expectations_store_store_backend_id = (
-        in_code_data_context.stores["expectations_S3_store"].store_backend_id
-    )
+    in_code_data_context_expectations_store_store_backend_id = in_code_data_context.stores[
+        "expectations_S3_store"
+    ].store_backend_id
     in_code_data_context_data_context_id = in_code_data_context.data_context_id
     constructed_data_context_id = in_code_data_context._construct_data_context_id()
     assert (
@@ -247,9 +204,10 @@ def test_DataContext_construct_data_context_id_uses_id_of_currently_configured_e
     )
 
 
+@pytest.mark.aws_deps
 @mock_s3
-def test_DataContext_construct_data_context_id_uses_id_stored_in_DataContextConfig_if_no_configured_expectations_store(
-    monkeypatch,
+def test_DataContext_construct_data_context_id_uses_id_stored_in_DataContextConfig_if_no_configured_expectations_store(  # noqa: E501 # FIXME CoP
+    monkeypatch, aws_credentials
 ):
     """
     What does this test and why?
@@ -263,15 +221,11 @@ def test_DataContext_construct_data_context_id_uses_id_stored_in_DataContextConf
     when instantiating the DataContext,
     and also that this data_context_id is used to configure the expectations_store.store_backend_id
     """
-    monkeypatch.delenv(
-        "GE_USAGE_STATS", raising=False
-    )  # Undo the project-wide test default
-
     bucket = "leakybucket"
     expectations_store_prefix = "expectations_store_prefix"
-    validations_store_prefix = "validations_store_prefix"
+    validation_results_store_prefix = "validation_results_store_prefix"
     data_docs_store_prefix = "data_docs_store_prefix"
-    manually_created_uuid = "00000000-0000-0000-0000-000000000eee"
+    manually_created_uuid = uuid.UUID("00000000-0000-0000-0000-000000000eee")
 
     # Create a bucket in Moto's mock AWS environment
     conn = boto3.resource("s3", region_name="us-east-1")
@@ -281,64 +235,12 @@ def test_DataContext_construct_data_context_id_uses_id_stored_in_DataContextConf
     in_code_data_context_project_config = build_in_code_data_context_project_config(
         bucket="leakybucket",
         expectations_store_prefix=expectations_store_prefix,
-        validations_store_prefix=validations_store_prefix,
+        validation_results_store_prefix=validation_results_store_prefix,
         data_docs_store_prefix=data_docs_store_prefix,
     )
     # Manually set the data_context_id in the project_config
-    in_code_data_context_project_config.anonymous_usage_statistics.data_context_id = (
-        manually_created_uuid
-    )
-    in_code_data_context = get_context(
-        project_config=in_code_data_context_project_config
-    )
-
-    # Make sure the manually set data_context_id is propagated to all the appropriate places
-    assert (
-        manually_created_uuid
-        == in_code_data_context.data_context_id
-        == in_code_data_context.stores[
-            in_code_data_context.expectations_store_name
-        ].store_backend_id
-    )
-
-
-@mock_s3
-def test_DataContext_construct_data_context_id_uses_id_stored_in_env_var_GE_DATA_CONTEXT_ID_if_no_configured_expectations_store(
-    monkeypatch,
-):
-    """
-    What does this test and why?
-
-    A DataContext should have an id. This ID should come from either:
-    1. configured expectations store store_backend_id
-    2. great_expectations.yml
-    3. new generated id from DataContextConfig
-    This test verifies that DataContext._construct_data_context_id
-    uses the store_backend_id from the env variable GE_DATA_CONTEXT_ID
-    when there is no configured expectations store
-    when instantiating the DataContext
-    """
-    bucket = "leakybucket"
-    expectations_store_prefix = "expectations_store_prefix"
-    validations_store_prefix = "validations_store_prefix"
-    data_docs_store_prefix = "data_docs_store_prefix"
-    manually_created_uuid = "00000000-0000-0000-0000-000000000fff"
-    monkeypatch.setenv("GE_DATA_CONTEXT_ID", manually_created_uuid)
-
-    # Create a bucket in Moto's mock AWS environment
-    conn = boto3.resource("s3", region_name="us-east-1")
-    conn.create_bucket(Bucket=bucket)
-
-    # Create a DataContext (note NO existing expectations store already set up)
-    in_code_data_context_project_config = build_in_code_data_context_project_config(
-        bucket="leakybucket",
-        expectations_store_prefix=expectations_store_prefix,
-        validations_store_prefix=validations_store_prefix,
-        data_docs_store_prefix=data_docs_store_prefix,
-    )
-    in_code_data_context = get_context(
-        project_config=in_code_data_context_project_config
-    )
+    in_code_data_context_project_config.data_context_id = manually_created_uuid
+    in_code_data_context = get_context(project_config=in_code_data_context_project_config)
 
     # Make sure the manually set data_context_id is propagated to all the appropriate places
     assert (
@@ -350,6 +252,7 @@ def test_DataContext_construct_data_context_id_uses_id_stored_in_env_var_GE_DATA
     )
 
 
+@pytest.mark.big
 @mock_s3
 def test_suppress_store_backend_id_is_true_for_inactive_stores():
     """
@@ -357,11 +260,11 @@ def test_suppress_store_backend_id_is_true_for_inactive_stores():
 
     Trying to read / set the store_backend_id for inactive stores should not be attempted during DataContext initialization. This test ensures that the _suppress_store_backend_id parameter is set to True for inactive stores.
 
-    """
+    """  # noqa: E501 # FIXME CoP
 
     bucket = "leakybucket"
     expectations_store_prefix = "expectations_store_prefix"
-    validations_store_prefix = "validations_store_prefix"
+    validation_results_store_prefix = "validation_results_store_prefix"
     data_docs_store_prefix = "data_docs_store_prefix"
 
     # Create a bucket in Moto's mock AWS environment
@@ -380,15 +283,14 @@ def test_suppress_store_backend_id_is_true_for_inactive_stores():
                 "prefix": expectations_store_prefix,
             },
         },
-        "validations_S3_store": {
-            "class_name": "ValidationsStore",
+        "validation_results_S3_store": {
+            "class_name": "ValidationResultsStore",
             "store_backend": {
                 "class_name": "TupleS3StoreBackend",
                 "bucket": bucket,
-                "prefix": validations_store_prefix,
+                "prefix": validation_results_store_prefix,
             },
         },
-        "evaluation_parameter_store": {"class_name": "EvaluationParameterStore"},
         "inactive_expectations_S3_store": {
             "class_name": "ExpectationsStore",
             "store_backend": {
@@ -397,28 +299,23 @@ def test_suppress_store_backend_id_is_true_for_inactive_stores():
                 "prefix": expectations_store_prefix,
             },
         },
-        "inactive_validations_S3_store": {
-            "class_name": "ValidationsStore",
+        "inactive_validation_results_S3_store": {
+            "class_name": "ValidationResultsStore",
             "store_backend": {
                 "class_name": "TupleS3StoreBackend",
                 "bucket": inactive_bucket,
-                "prefix": validations_store_prefix,
+                "prefix": validation_results_store_prefix,
             },
         },
-        "inactive_evaluation_parameter_store": {
-            "class_name": "EvaluationParameterStore"
-        },
     }
     in_code_data_context_project_config = build_in_code_data_context_project_config(
         bucket="leakybucket",
         expectations_store_prefix=expectations_store_prefix,
-        validations_store_prefix=validations_store_prefix,
+        validation_results_store_prefix=validation_results_store_prefix,
         data_docs_store_prefix=data_docs_store_prefix,
         stores=stores,
     )
-    in_code_data_context = get_context(
-        project_config=in_code_data_context_project_config
-    )
+    in_code_data_context = get_context(project_config=in_code_data_context_project_config)
 
     # Check here that suppress_store_backend_id == True for inactive stores
     # and False for active stores
@@ -430,7 +327,7 @@ def test_suppress_store_backend_id_is_true_for_inactive_stores():
     )
     assert (
         in_code_data_context.stores.get(
-            "inactive_validations_S3_store"
+            "inactive_validation_results_S3_store"
         ).store_backend._suppress_store_backend_id
         is True
     )
@@ -442,39 +339,27 @@ def test_suppress_store_backend_id_is_true_for_inactive_stores():
     )
     assert (
         in_code_data_context.stores.get(
-            "validations_S3_store"
-        ).store_backend._suppress_store_backend_id
-        is False
-    )
-    # InMemoryStoreBackend created for evaluation_parameters_store & inactive_evaluation_parameters_store
-    assert (
-        in_code_data_context.stores.get(
-            "inactive_evaluation_parameter_store"
-        ).store_backend._suppress_store_backend_id
-        is False
-    )
-    assert (
-        in_code_data_context.stores.get(
-            "evaluation_parameter_store"
+            "validation_results_S3_store"
         ).store_backend._suppress_store_backend_id
         is False
     )
 
 
+@pytest.mark.aws_deps
 @mock_s3
-def test_inaccessible_active_bucket_warning_messages(caplog):
+def test_inaccessible_active_bucket_warning_messages(caplog, aws_credentials):
     """
     What does this test do and why?
 
     Trying to create a data context with unreachable ACTIVE stores should show a warning message once per store
     e.g. Invalid store configuration: Please check the configuration of your TupleS3StoreBackend named expectations_S3_store
     Active stores are those named in:
-    "expectations_store_name", "validations_store_name", "evaluation_parameter_store_name"
-    """
+    "expectations_store_name", "validation_results_store_name"
+    """  # noqa: E501 # FIXME CoP
 
     bucket = "leakybucket"
     expectations_store_prefix = "expectations_store_prefix"
-    validations_store_prefix = "validations_store_prefix"
+    validation_results_store_prefix = "validation_results_store_prefix"
     data_docs_store_prefix = "data_docs_store_prefix"
 
     # Create a bucket in Moto's mock AWS environment
@@ -493,38 +378,38 @@ def test_inaccessible_active_bucket_warning_messages(caplog):
                 "prefix": expectations_store_prefix,
             },
         },
-        "validations_S3_store": {
-            "class_name": "ValidationsStore",
+        "validation_results_S3_store": {
+            "class_name": "ValidationResultsStore",
             "store_backend": {
                 "class_name": "TupleS3StoreBackend",
                 "bucket": inactive_bucket,
-                "prefix": validations_store_prefix,
+                "prefix": validation_results_store_prefix,
             },
         },
-        "evaluation_parameter_store": {"class_name": "EvaluationParameterStore"},
     }
     in_code_data_context_project_config = build_in_code_data_context_project_config(
         bucket="leakybucket",
         expectations_store_prefix=expectations_store_prefix,
-        validations_store_prefix=validations_store_prefix,
+        validation_results_store_prefix=validation_results_store_prefix,
         data_docs_store_prefix=data_docs_store_prefix,
         stores=stores,
     )
     _ = get_context(project_config=in_code_data_context_project_config)
     assert (
         caplog.messages.count(
-            "Invalid store configuration: Please check the configuration of your TupleS3StoreBackend named expectations_S3_store"
+            "Invalid store configuration: Please check the configuration of your TupleS3StoreBackend named expectations_S3_store. Exception was: \n Unable to set object in s3."  # noqa: E501 # FIXME CoP
         )
         == 1
     )
     assert (
         caplog.messages.count(
-            "Invalid store configuration: Please check the configuration of your TupleS3StoreBackend named validations_S3_store"
+            "Invalid store configuration: Please check the configuration of your TupleS3StoreBackend named validation_results_S3_store. Exception was: \n Unable to set object in s3."  # noqa: E501 # FIXME CoP
         )
         == 1
     )
 
 
+@pytest.mark.big
 @mock_s3
 def test_inaccessible_inactive_bucket_no_warning_messages(caplog):
     """
@@ -532,12 +417,12 @@ def test_inaccessible_inactive_bucket_no_warning_messages(caplog):
 
     Trying to create a data context with unreachable INACTIVE stores should show no warning messages
     Inactive stores are those NOT named in:
-    "expectations_store_name", "validations_store_name", "evaluation_parameter_store_name"
+    "expectations_store_name", "validation_results_store_name"
     """
 
     bucket = "leakybucket"
     expectations_store_prefix = "expectations_store_prefix"
-    validations_store_prefix = "validations_store_prefix"
+    validation_results_store_prefix = "validation_results_store_prefix"
     data_docs_store_prefix = "data_docs_store_prefix"
 
     # Create a bucket in Moto's mock AWS environment
@@ -556,15 +441,14 @@ def test_inaccessible_inactive_bucket_no_warning_messages(caplog):
                 "prefix": expectations_store_prefix,
             },
         },
-        "validations_S3_store": {
-            "class_name": "ValidationsStore",
+        "validation_results_S3_store": {
+            "class_name": "ValidationResultsStore",
             "store_backend": {
                 "class_name": "TupleS3StoreBackend",
                 "bucket": bucket,
-                "prefix": validations_store_prefix,
+                "prefix": validation_results_store_prefix,
             },
         },
-        "evaluation_parameter_store": {"class_name": "EvaluationParameterStore"},
         "inactive_expectations_S3_store": {
             "class_name": "ExpectationsStore",
             "store_backend": {
@@ -573,35 +457,32 @@ def test_inaccessible_inactive_bucket_no_warning_messages(caplog):
                 "prefix": expectations_store_prefix,
             },
         },
-        "inactive_validations_S3_store": {
-            "class_name": "ValidationsStore",
+        "inactive_validation_results_S3_store": {
+            "class_name": "ValidationResultsStore",
             "store_backend": {
                 "class_name": "TupleS3StoreBackend",
                 "bucket": inactive_bucket,
-                "prefix": validations_store_prefix,
+                "prefix": validation_results_store_prefix,
             },
         },
-        "inactive_evaluation_parameter_store": {
-            "class_name": "EvaluationParameterStore"
-        },
     }
     in_code_data_context_project_config = build_in_code_data_context_project_config(
         bucket="leakybucket",
         expectations_store_prefix=expectations_store_prefix,
-        validations_store_prefix=validations_store_prefix,
+        validation_results_store_prefix=validation_results_store_prefix,
         data_docs_store_prefix=data_docs_store_prefix,
         stores=stores,
     )
     _ = get_context(project_config=in_code_data_context_project_config)
     assert (
         caplog.messages.count(
-            "Invalid store configuration: Please check the configuration of your TupleS3StoreBackend named expectations_S3_store"
+            "Invalid store configuration: Please check the configuration of your TupleS3StoreBackend named expectations_S3_store"  # noqa: E501 # FIXME CoP
         )
         == 0
     )
     assert (
         caplog.messages.count(
-            "Invalid store configuration: Please check the configuration of your TupleS3StoreBackend named validations_S3_store"
+            "Invalid store configuration: Please check the configuration of your TupleS3StoreBackend named validation_results_S3_store"  # noqa: E501 # FIXME CoP
         )
         == 0
     )
