@@ -4,39 +4,19 @@ import random
 from pathlib import Path
 from typing import List
 
-import boto3
 import pandas as pd
 import pytest
 from moto import mock_s3
 
+from great_expectations.compatibility import aws, pyspark
+from great_expectations.compatibility.pyspark import functions as F
 from great_expectations.core.batch_spec import AzureBatchSpec, GCSBatchSpec
 
-try:
-    import pyspark
-
-    # noinspection PyPep8Naming
-    import pyspark.sql.functions as F
-    from pyspark.sql.types import IntegerType, StringType
-except ImportError:
-    pyspark = None
-    F = None
-    IntegerType = None
-    StringType = None
-
-
-@pytest.fixture(scope="function")
-def aws_credentials():
-    """Mocked AWS Credentials for moto."""
-    os.environ["AWS_ACCESS_KEY_ID"] = "testing"
-    os.environ["AWS_SECRET_ACCESS_KEY"] = "testing"
-    os.environ["AWS_SECURITY_TOKEN"] = "testing"
-    os.environ["AWS_SESSION_TOKEN"] = "testing"
-
 
 @pytest.fixture
 def s3(aws_credentials):
     with mock_s3():
-        yield boto3.client("s3", region_name="us-east-1")
+        yield aws.boto3.client("s3", region_name="us-east-1")
 
 
 @pytest.fixture
@@ -116,12 +96,14 @@ def azure_batch_spec() -> AzureBatchSpec:
         "alpha-2.csv",
     ]
     path = keys[0]
-    full_path = os.path.join("mock_account.blob.core.windows.net", container, path)
+    full_path = os.path.join(  # noqa: PTH118 # FIXME CoP
+        "mock_account.blob.core.windows.net", container, path
+    )
 
     batch_spec = AzureBatchSpec(
         path=full_path,
         reader_method="read_csv",
-        splitter_method="_split_on_whole_table",
+        partitioner_method="_partition_on_whole_table",
     )
     return batch_spec
 
@@ -138,29 +120,26 @@ def gcs_batch_spec() -> GCSBatchSpec:
         "alpha-2.csv",
     ]
     path = keys[0]
-    full_path = os.path.join("gs://", bucket, path)
+    full_path = os.path.join("gs://", bucket, path)  # noqa: PTH118 # FIXME CoP
 
     batch_spec = GCSBatchSpec(
         path=full_path,
         reader_method="read_csv",
-        splitter_method="_split_on_whole_table",
+        partitioner_method="_partition_on_whole_table",
     )
     return batch_spec
 
 
 @pytest.fixture
-def test_sparkdf(spark_session) -> "pyspark.sql.DataFrame":  # noqa: F821
+def test_sparkdf(spark_session) -> pyspark.DataFrame:
     def generate_ascending_list_of_datetimes(
         n, start_date=datetime.date(2020, 1, 1), end_date=datetime.date(2020, 12, 31)
     ) -> List[datetime.datetime]:
-        start_time = datetime.datetime(
-            start_date.year, start_date.month, start_date.day
-        )
+        start_time = datetime.datetime(start_date.year, start_date.month, start_date.day)  # noqa: DTZ001 # FIXME CoP
         seconds_between_dates = (end_date - start_date).total_seconds()
         # noinspection PyUnusedLocal
         datetime_list = [
-            start_time
-            + datetime.timedelta(seconds=random.randrange(int(seconds_between_dates)))
+            start_time + datetime.timedelta(seconds=random.randrange(int(seconds_between_dates)))
             for i in range(n)
         ]
         datetime_list.sort()
@@ -184,7 +163,7 @@ def test_sparkdf(spark_session) -> "pyspark.sql.DataFrame":  # noqa: F821
     session_ids.sort()
 
     # noinspection PyUnusedLocal
-    spark_df: "pyspark.sql.DataFrame" = spark_session.createDataFrame(  # noqa: F821
+    spark_df: pyspark.DataFrame = spark_session.createDataFrame(
         data=pd.DataFrame(
             {
                 "id": range(k),
@@ -195,21 +174,17 @@ def test_sparkdf(spark_session) -> "pyspark.sql.DataFrame":  # noqa: F821
                 "d": [d.day for d in date_list],
                 "timestamp": timestamp_list,
                 "session_ids": session_ids,
-                "event_type": [
-                    random.choice(["start", "stop", "continue"]) for i in range(k)
-                ],
+                "event_type": [random.choice(["start", "stop", "continue"]) for i in range(k)],
                 "favorite_color": [
-                    "#"
-                    + "".join(
-                        [random.choice(list("0123456789ABCDEF")) for j in range(6)]
-                    )
+                    "#" + "".join([random.choice(list("0123456789ABCDEF")) for j in range(6)])
                     for i in range(k)
                 ],
             }
         )
     )
     spark_df = spark_df.withColumn(
-        "timestamp", F.col("timestamp").cast(IntegerType()).cast(StringType())
+        "timestamp",
+        F.col("timestamp").cast(pyspark.types.IntegerType()).cast(pyspark.types.StringType()),
     )
     return spark_df
 
@@ -218,7 +193,11 @@ def test_sparkdf(spark_session) -> "pyspark.sql.DataFrame":  # noqa: F821
 def test_folder_connection_path_tsv(tmp_path_factory) -> str:
     df1 = pd.DataFrame({"col_1": [1, 2, 3, 4, 5], "col_2": ["a", "b", "c", "d", "e"]})
     path = str(tmp_path_factory.mktemp("test_folder_connection_path_tsv"))
-    df1.to_csv(path_or_buf=os.path.join(path, "test.tsv"), sep="\t", index=False)
+    df1.to_csv(
+        path_or_buf=os.path.join(path, "test.tsv"),  # noqa: PTH118 # FIXME CoP
+        sep="\t",
+        index=False,
+    )
     return str(path)
 
 
@@ -226,5 +205,5 @@ def test_folder_connection_path_tsv(tmp_path_factory) -> str:
 def test_folder_connection_path_parquet(tmp_path_factory) -> str:
     df1 = pd.DataFrame({"col_1": [1, 2, 3, 4, 5], "col_2": ["a", "b", "c", "d", "e"]})
     path = str(tmp_path_factory.mktemp("test_folder_connection_path_parquet"))
-    df1.to_parquet(path=os.path.join(path, "test.parquet"))
+    df1.to_parquet(path=os.path.join(path, "test.parquet"))  # noqa: PTH118 # FIXME CoP
     return str(path)
