@@ -5,28 +5,22 @@ from unittest import mock
 import pandas as pd
 import pytest
 
+import great_expectations.exceptions as gx_exceptions
+from great_expectations.compatibility import aws, azure, google
+from great_expectations.core.batch_spec import RuntimeDataBatchSpec, S3BatchSpec
+
 # noinspection PyBroadException
 from great_expectations.core.metric_domain_types import MetricDomainTypes
-from great_expectations.validator.computed_metric import MetricValue
-
-try:
-    # noinspection PyUnresolvedReferences
-    from azure.storage.blob import BlobServiceClient
-except:
-    azure = None
-
-
-import great_expectations.exceptions as gx_exceptions
-from great_expectations.core.batch_spec import RuntimeDataBatchSpec, S3BatchSpec
 from great_expectations.execution_engine.pandas_execution_engine import (
     PandasExecutionEngine,
-    storage,
 )
 from great_expectations.util import is_library_loadable
+from great_expectations.validator.computed_metric import MetricValue
 from great_expectations.validator.metric_configuration import MetricConfiguration
 from tests.expectations.test_util import get_table_columns_metric
 
 
+@pytest.mark.unit
 def test_constructor_with_boto3_options():
     # default instantiation
     PandasExecutionEngine()
@@ -41,6 +35,7 @@ def test_constructor_with_boto3_options():
     assert engine.config.get("boto3_options")["region_name"] == "us-east-1"
 
 
+@pytest.mark.unit
 def test_reader_fn():
     engine = PandasExecutionEngine()
 
@@ -61,11 +56,10 @@ def test_reader_fn():
     assert "<function" in str(fn_new)
 
 
+@pytest.mark.unit
 def test_get_domain_records_with_column_domain():
     engine = PandasExecutionEngine()
-    df = pd.DataFrame(
-        {"a": [1, 2, 3, 4, 5], "b": [2, 3, 4, 5, None], "c": [1, 2, 3, 4, None]}
-    )
+    df = pd.DataFrame({"a": [1, 2, 3, 4, 5], "b": [2, 3, 4, 5, None], "c": [1, 2, 3, 4, None]})
     # Loading batch data
     engine.load_batch_data(batch_data=df, batch_id="1234")
 
@@ -79,11 +73,12 @@ def test_get_domain_records_with_column_domain():
 
     expected_column_df = df.iloc[:3]
 
-    assert data.equals(
-        expected_column_df
-    ), "Data does not match after getting full access compute domain"
+    assert data.equals(expected_column_df), (
+        "Data does not match after getting full access compute domain"
+    )
 
 
+@pytest.mark.unit
 def test_get_domain_records_with_column_pair_domain():
     engine = PandasExecutionEngine()
     df = pd.DataFrame(
@@ -114,9 +109,9 @@ def test_get_domain_records_with_column_pair_domain():
         },
         index=[1, 2, 3, 5],
     )
-    assert data.equals(
-        expected_column_pair_df
-    ), "Data does not match after getting full access compute domain"
+    assert data.equals(expected_column_pair_df), (
+        "Data does not match after getting full access compute domain"
+    )
 
     data = engine.get_domain_records(
         domain_kwargs={
@@ -133,9 +128,9 @@ def test_get_domain_records_with_column_pair_domain():
         {"a": [2, 3, 4], "b": [3, 4, 5], "c": [2, 3, 4]}, index=[1, 2, 3]
     )
 
-    assert data.equals(
-        expected_column_pair_df
-    ), "Data does not match after getting full access compute domain"
+    assert data.equals(expected_column_pair_df), (
+        "Data does not match after getting full access compute domain"
+    )
 
     data = engine.get_domain_records(
         domain_kwargs={
@@ -155,11 +150,12 @@ def test_get_domain_records_with_column_pair_domain():
         }
     )
 
-    assert data.equals(
-        expected_column_pair_df
-    ), "Data does not match after getting full access compute domain"
+    assert data.equals(expected_column_pair_df), (
+        "Data does not match after getting full access compute domain"
+    )
 
 
+@pytest.mark.unit
 def test_get_domain_records_with_multicolumn_domain():
     engine = PandasExecutionEngine()
     df = pd.DataFrame(
@@ -186,9 +182,9 @@ def test_get_domain_records_with_multicolumn_domain():
         {"a": [2, 3, 4, 5], "b": [3, 4, 5, 7], "c": [2, 3, 4, 6]}, index=[1, 2, 3, 5]
     )
 
-    assert data.equals(
-        expected_multicolumn_df
-    ), "Data does not match after getting full access compute domain"
+    assert data.equals(expected_multicolumn_df), (
+        "Data does not match after getting full access compute domain"
+    )
 
     data = engine.get_domain_records(
         domain_kwargs={
@@ -204,9 +200,9 @@ def test_get_domain_records_with_multicolumn_domain():
         {"a": [1, 2, 3, 4], "b": [2, 3, 4, 5], "c": [1, 2, 3, 4]}, index=[0, 1, 2, 3]
     )
 
-    assert data.equals(
-        expected_multicolumn_df
-    ), "Data does not match after getting full access compute domain"
+    assert data.equals(expected_multicolumn_df), (
+        "Data does not match after getting full access compute domain"
+    )
 
     engine = PandasExecutionEngine()
     df = pd.DataFrame(
@@ -235,11 +231,12 @@ def test_get_domain_records_with_multicolumn_domain():
         index=[0, 1, 2, 3, 4, 5],
     )
 
-    assert data.equals(
-        expected_multicolumn_df
-    ), "Data does not match after getting full access compute domain"
+    assert data.equals(expected_multicolumn_df), (
+        "Data does not match after getting full access compute domain"
+    )
 
 
+@pytest.mark.unit
 def test_get_compute_domain_with_no_domain_kwargs():
     engine = PandasExecutionEngine()
     df = pd.DataFrame({"a": [1, 2, 3, 4], "b": [2, 3, 4, None]})
@@ -262,6 +259,7 @@ def test_get_compute_domain_with_no_domain_kwargs():
     assert accessor_kwargs == {}, "Accessor kwargs have been modified"
 
 
+@pytest.mark.unit
 def test_get_compute_domain_with_column_pair_domain():
     engine = PandasExecutionEngine()
     df = pd.DataFrame({"a": [1, 2, 3, 4], "b": [2, 3, 4, 5], "c": [1, 2, 3, 4]})
@@ -279,6 +277,7 @@ def test_get_compute_domain_with_column_pair_domain():
     }, "Accessor kwargs have been modified"
 
 
+@pytest.mark.unit
 def test_get_compute_domain_with_multicolumn_domain():
     engine = PandasExecutionEngine()
     df = pd.DataFrame(
@@ -292,11 +291,10 @@ def test_get_compute_domain_with_multicolumn_domain():
     )
     assert data.equals(df), "Data does not match after getting compute domain"
     assert compute_kwargs == {}, "Compute domain kwargs should be existent"
-    assert accessor_kwargs == {
-        "column_list": ["a", "b", "c"]
-    }, "Accessor kwargs have been modified"
+    assert accessor_kwargs == {"column_list": ["a", "b", "c"]}, "Accessor kwargs have been modified"
 
 
+@pytest.mark.unit
 def test_get_compute_domain_with_column_domain():
     engine = PandasExecutionEngine()
     df = pd.DataFrame({"a": [1, 2, 3, 4], "b": [2, 3, 4, None]})
@@ -311,6 +309,7 @@ def test_get_compute_domain_with_column_domain():
     assert accessor_kwargs == {"column": "a"}, "Accessor kwargs have been modified"
 
 
+@pytest.mark.unit
 def test_get_compute_domain_with_row_condition():
     engine = PandasExecutionEngine()
     df = pd.DataFrame({"a": [1, 2, 3, 4], "b": [2, 3, 4, None]})
@@ -324,18 +323,17 @@ def test_get_compute_domain_with_row_condition():
         domain_type="table",
     )
     # Ensuring data has been properly queried
-    assert data["b"].equals(
-        expected_df["b"]
-    ), "Data does not match after getting compute domain"
+    assert data["b"].equals(expected_df["b"]), "Data does not match after getting compute domain"
 
     # Ensuring compute kwargs have not been modified
-    assert (
-        "row_condition" in compute_kwargs.keys()
-    ), "Row condition should be located within compute kwargs"
+    assert "row_condition" in compute_kwargs, (
+        "Row condition should be located within compute kwargs"
+    )
     assert accessor_kwargs == {}, "Accessor kwargs have been modified"
 
 
 # What happens when we filter such that no value meets the condition?
+@pytest.mark.unit
 def test_get_compute_domain_with_unmeetable_row_condition():
     engine = PandasExecutionEngine()
     df = pd.DataFrame({"a": [1, 2, 3, 4], "b": [2, 3, 4, None]})
@@ -353,18 +351,17 @@ def test_get_compute_domain_with_unmeetable_row_condition():
         domain_type="column",
     )
     # Ensuring data has been properly queried
-    assert data["b"].equals(
-        expected_df["b"]
-    ), "Data does not match after getting compute domain"
+    assert data["b"].equals(expected_df["b"]), "Data does not match after getting compute domain"
 
     # Ensuring compute kwargs have not been modified
-    assert (
-        "row_condition" in compute_kwargs.keys()
-    ), "Row condition should be located within compute kwargs"
+    assert "row_condition" in compute_kwargs, (
+        "Row condition should be located within compute kwargs"
+    )
     assert accessor_kwargs == {"column": "a"}, "Accessor kwargs have been modified"
 
 
 # Just checking that the Pandas Execution Engine can perform these in sequence
+@pytest.mark.unit
 def test_resolve_metric_bundle():
     df = pd.DataFrame({"a": [1, 2, 3, None]})
 
@@ -376,7 +373,7 @@ def test_resolve_metric_bundle():
     table_columns_metric: MetricConfiguration
     results: Dict[Tuple[str, str, str], MetricValue]
 
-    table_columns_metric, results = get_table_columns_metric(engine=engine)
+    table_columns_metric, results = get_table_columns_metric(execution_engine=engine)
     metrics.update(results)
 
     mean = MetricConfiguration(
@@ -396,21 +393,18 @@ def test_resolve_metric_bundle():
         "table.columns": table_columns_metric,
     }
     desired_metrics = (mean, stdev)
-    results = engine.resolve_metrics(
-        metrics_to_resolve=desired_metrics, metrics=metrics
-    )
+    results = engine.resolve_metrics(metrics_to_resolve=desired_metrics, metrics=metrics)
     metrics.update(results)
 
     # Ensuring metrics have been properly resolved
-    assert (
-        metrics[("column.mean", "column=a", ())] == 2.0
-    ), "mean metric not properly computed"
+    assert metrics[("column.mean", "column=a", ())] == 2.0, "mean metric not properly computed"
     assert metrics[("column.standard_deviation", "column=a", ())] == 1.0, (
-        "standard deviation " "metric not properly computed"
+        "standard deviation metric not properly computed"
     )
 
 
-# Ensuring that we can properly inform user when metric doesn't exist - should get a metric provider error
+# Ensuring that we can properly inform user when metric doesn't exist - should get a metric provider error  # noqa: E501 # FIXME CoP
+@pytest.mark.unit
 def test_resolve_metric_bundle_with_nonexistent_metric():
     df = pd.DataFrame({"a": [1, 2, 3, None]})
 
@@ -429,12 +423,13 @@ def test_resolve_metric_bundle_with_nonexistent_metric():
     desired_metrics = (mean, stdev)
 
     # noinspection PyUnusedLocal
-    with pytest.raises(gx_exceptions.MetricProviderError) as e:
+    with pytest.raises(gx_exceptions.MetricProviderError):
         # noinspection PyUnusedLocal
-        metrics = engine.resolve_metrics(metrics_to_resolve=desired_metrics)
+        engine.resolve_metrics(metrics_to_resolve=desired_metrics)
 
 
 # Making sure dataframe property is functional
+@pytest.mark.unit
 def test_dataframe_property_given_loaded_batch():
     engine = PandasExecutionEngine()
     df = pd.DataFrame({"a": [1, 2, 3, 4]})
@@ -446,23 +441,29 @@ def test_dataframe_property_given_loaded_batch():
     assert engine.dataframe.equals(df)
 
 
+@pytest.mark.unit
 def test_get_batch_data(test_df):
-    split_df = PandasExecutionEngine().get_batch_data(
+    partitioned_df = PandasExecutionEngine().get_batch_data(
         RuntimeDataBatchSpec(
             batch_data=test_df,
         )
     )
-    assert split_df.dataframe.shape == (120, 10)
+    assert partitioned_df.dataframe.shape == (120, 10)
 
     # No dataset passed to RuntimeDataBatchSpec
     with pytest.raises(gx_exceptions.InvalidBatchSpecError):
         PandasExecutionEngine().get_batch_data(RuntimeDataBatchSpec())
 
 
+@pytest.mark.skipif(
+    not aws.boto3,
+    reason="Unable to load AWS connection object. Please install boto3 and botocore.",
+)
+@pytest.mark.big
 def test_get_batch_s3_compressed_files(test_s3_files_compressed, test_df_small):
     bucket, keys = test_s3_files_compressed
     path = keys[0]
-    full_path = f"s3a://{os.path.join(bucket, path)}"
+    full_path = f"s3a://{os.path.join(bucket, path)}"  # noqa: PTH118 # FIXME CoP
 
     batch_spec = S3BatchSpec(path=full_path, reader_method="read_csv")
     df = PandasExecutionEngine().get_batch_data(batch_spec=batch_spec)
@@ -470,25 +471,34 @@ def test_get_batch_s3_compressed_files(test_s3_files_compressed, test_df_small):
 
 
 @pytest.mark.skipif(
-    not is_library_loadable(library_name="pyarrow")
-    and not is_library_loadable(library_name="fastparquet"),
+    not aws.boto3
+    or (
+        not is_library_loadable(library_name="pyarrow")
+        and not is_library_loadable(library_name="fastparquet")
+    ),
     reason="pyarrow and fastparquet are not installed",
 )
+@pytest.mark.big
 def test_get_batch_s3_parquet(test_s3_files_parquet, test_df_small):
     bucket, keys = test_s3_files_parquet
     path = [key for key in keys if key.endswith(".parquet")][0]
-    full_path = f"s3a://{os.path.join(bucket, path)}"
+    full_path = f"s3a://{os.path.join(bucket, path)}"  # noqa: PTH118 # FIXME CoP
 
     batch_spec = S3BatchSpec(path=full_path, reader_method="read_parquet")
     df = PandasExecutionEngine().get_batch_data(batch_spec=batch_spec)
     assert df.dataframe.shape == test_df_small.shape
 
 
+@pytest.mark.skipif(
+    not aws.boto3,
+    reason="Unable to load AWS connection object. Please install boto3 and botocore.",
+)
+@pytest.mark.big
 def test_get_batch_with_no_s3_configured():
     batch_spec = S3BatchSpec(
         path="s3a://i_dont_exist",
         reader_method="read_csv",
-        splitter_method="_split_on_whole_table",
+        partitioner_method="_partition_on_whole_table",
     )
     # if S3 was not configured
     execution_engine_no_s3 = PandasExecutionEngine()
@@ -497,12 +507,13 @@ def test_get_batch_with_no_s3_configured():
         execution_engine_no_s3.get_batch_data(batch_spec=batch_spec)
 
 
-def test_get_batch_with_split_on_divided_integer_and_sample_on_list(test_df):
-    split_df = PandasExecutionEngine().get_batch_data(
+@pytest.mark.big
+def test_get_batch_with_partition_on_divided_integer_and_sample_on_list(test_df):
+    partitioned_df = PandasExecutionEngine().get_batch_data(
         RuntimeDataBatchSpec(
             batch_data=test_df,
-            splitter_method="_split_on_divided_integer",
-            splitter_kwargs={
+            partitioner_method="_partition_on_divided_integer",
+            partitioner_kwargs={
                 "column_name": "id",
                 "divisor": 10,
                 "batch_identifiers": {"id": 5},
@@ -515,15 +526,20 @@ def test_get_batch_with_split_on_divided_integer_and_sample_on_list(test_df):
             },
         )
     )
-    assert split_df.dataframe.shape == (2, 10)
-    assert split_df.dataframe.id.min() == 54
-    assert split_df.dataframe.id.max() == 59
+    assert partitioned_df.dataframe.shape == (2, 10)
+    assert partitioned_df.dataframe.id.min() == 54
+    assert partitioned_df.dataframe.id.max() == 59
 
 
 # noinspection PyUnusedLocal
-@mock.patch(
-    "great_expectations.execution_engine.pandas_execution_engine.BlobServiceClient",
+@pytest.mark.skipif(
+    not (azure.storage and azure.BlobServiceClient),
+    reason='Could not import "azure.storage.blob" from Microsoft Azure cloud',
 )
+@mock.patch(
+    "great_expectations.execution_engine.pandas_execution_engine.azure.BlobServiceClient",
+)
+@pytest.mark.big
 def test_constructor_with_azure_options(mock_azure_conn):
     # default instantiation
     PandasExecutionEngine()
@@ -538,9 +554,14 @@ def test_constructor_with_azure_options(mock_azure_conn):
     assert engine.config.get("azure_options")["account_url"] == "my_account_url"
 
 
-@mock.patch(
-    "great_expectations.execution_engine.pandas_execution_engine.BlobServiceClient",
+@pytest.mark.skipif(
+    not (azure.storage and azure.BlobServiceClient),
+    reason='Could not import "azure.storage.blob" from Microsoft Azure cloud',
 )
+@mock.patch(
+    "great_expectations.execution_engine.pandas_execution_engine.azure.BlobServiceClient",
+)
+@pytest.mark.big
 def test_get_batch_data_with_azure_batch_spec(
     mock_azure_conn,
     azure_batch_spec,
@@ -561,6 +582,7 @@ def test_get_batch_data_with_azure_batch_spec(
     assert df.dataframe.shape == (3, 3)
 
 
+@pytest.mark.big
 def test_get_batch_with_no_azure_configured(azure_batch_spec):
     # if Azure BlobServiceClient was not configured
     execution_engine_no_azure = PandasExecutionEngine()
@@ -572,15 +594,16 @@ def test_get_batch_with_no_azure_configured(azure_batch_spec):
 
 
 @pytest.mark.skipif(
-    storage is None,
+    not google.storage,
     reason="Could not import 'storage' from google.cloud in pandas_execution_engine.py",
 )
 @mock.patch(
-    "great_expectations.execution_engine.pandas_execution_engine.service_account",
+    "great_expectations.execution_engine.pandas_execution_engine.google.service_account",
 )
 @mock.patch(
-    "great_expectations.execution_engine.pandas_execution_engine.storage.Client",
+    "great_expectations.execution_engine.pandas_execution_engine.google.storage.Client",
 )
+@pytest.mark.big
 def test_constructor_with_gcs_options(mock_gcs_conn, mock_auth_method):
     # default instantiation
     PandasExecutionEngine()
@@ -596,12 +619,13 @@ def test_constructor_with_gcs_options(mock_gcs_conn, mock_auth_method):
 
 
 @pytest.mark.skipif(
-    storage is None,
+    not google.storage,
     reason="Could not import 'storage' from google.cloud in pandas_execution_engine.py",
 )
 @mock.patch(
-    "great_expectations.execution_engine.pandas_execution_engine.storage.Client",
+    "great_expectations.execution_engine.pandas_execution_engine.google.storage.Client",
 )
+@pytest.mark.big
 def test_get_batch_data_with_gcs_batch_spec(
     mock_gcs_conn,
     gcs_batch_spec,
@@ -623,20 +647,26 @@ def test_get_batch_data_with_gcs_batch_spec(
     assert df.dataframe.shape == (3, 3)
 
 
+@pytest.mark.skipif(
+    not google.storage,
+    reason="Could not import 'storage' from google.cloud in pandas_execution_engine.py",
+)
+@pytest.mark.big
 def test_get_batch_data_with_gcs_batch_spec_no_credentials(gcs_batch_spec, monkeypatch):
-    # If PandasExecutionEngine contains no credentials for GCS, we will still instantiate _gcs engine,
-    # but will raise Exception when trying get_batch_data(). The only situation where it would work is if we are running in a Google Cloud container.
-    # TODO : Determine how we can test the scenario where we are running PandasExecutionEngine from within Google Cloud env.
+    # If PandasExecutionEngine contains no credentials for GCS, we will still instantiate _gcs engine,  # noqa: E501 # FIXME CoP
+    # but will raise Exception when trying get_batch_data(). The only situation where it would work is if we are running in a Google Cloud container.  # noqa: E501 # FIXME CoP
+    # TODO : Determine how we can test the scenario where we are running PandasExecutionEngine from within Google Cloud env.  # noqa: E501 # FIXME CoP
 
     monkeypatch.delenv("GOOGLE_APPLICATION_CREDENTIALS", raising=False)
-    with pytest.raises(Exception):
+    with pytest.raises(gx_exceptions.ExecutionEngineError):
         PandasExecutionEngine().get_batch_data(batch_spec=gcs_batch_spec)
 
 
 @pytest.mark.skipif(
-    storage is None,
+    not google.storage,
     reason="Could not import 'storage' from google.cloud in pandas_execution_engine.py",
 )
+@pytest.mark.big
 def test_get_batch_with_gcs_misconfigured(gcs_batch_spec):
     # gcs_batchspec point to data that the ExecutionEngine does not have access to
     execution_engine_no_gcs = PandasExecutionEngine()
