@@ -7,6 +7,8 @@ import pandas as pd
 import pytest
 
 import great_expectations.exceptions as gx_exceptions
+from great_expectations.compatibility import pyspark
+from great_expectations.compatibility.pyspark import functions as F
 from great_expectations.core.batch_spec import PathBatchSpec, RuntimeDataBatchSpec
 from great_expectations.core.metric_domain_types import MetricDomainTypes
 from great_expectations.core.metric_function_types import MetricPartialFunctionTypes
@@ -21,58 +23,7 @@ from great_expectations.validator.metric_configuration import MetricConfiguratio
 from tests.expectations.test_util import get_table_columns_metric
 from tests.test_utils import create_files_in_directory
 
-try:
-    pyspark = pytest.importorskip("pyspark")
-    # noinspection PyPep8Naming
-    import pyspark.sql.functions as F
-    from pyspark.sql.types import (
-        DoubleType,
-        IntegerType,
-        LongType,
-        Row,
-        StringType,
-        StructField,
-        StructType,
-    )
-except ImportError:
-    pyspark = None
-    F = None
-    IntegerType = None
-    LongType = None
-    StringType = None
-    Row = None
-    DoubleType = None
-    StructType = None
-    StructField = None
-
-
-@pytest.fixture
-def spark_df_from_pandas_df():
-    """
-    Construct a spark dataframe from pandas dataframe.
-    Returns:
-        Function that can be used in your test e.g.:
-        spark_df = spark_df_from_pandas_df(spark_session, pandas_df)
-    """
-
-    def _construct_spark_df_from_pandas(
-        spark_session,
-        pandas_df,
-    ):
-
-        spark_df = spark_session.createDataFrame(
-            [
-                tuple(
-                    None if isinstance(x, (float, int)) and np.isnan(x) else x
-                    for x in record.tolist()
-                )
-                for record in pandas_df.to_records(index=False)
-            ],
-            pandas_df.columns.tolist(),
-        )
-        return spark_df
-
-    return _construct_spark_df_from_pandas
+pytestmark = pytest.mark.spark
 
 
 def test_reader_fn(spark_session, basic_spark_df_execution_engine):
@@ -86,10 +37,7 @@ def test_reader_fn(spark_session, basic_spark_df_execution_engine):
     assert "<bound method DataFrameReader.csv" in str(fn_new)
 
 
-@pytest.mark.integration
-def test_reader_fn_parameters(
-    spark_session, basic_spark_df_execution_engine, tmp_path_factory
-):
+def test_reader_fn_parameters(spark_session, basic_spark_df_execution_engine, tmp_path_factory):
     base_directory = str(tmp_path_factory.mktemp("test_csv"))
     create_files_in_directory(
         directory=base_directory,
@@ -105,7 +53,7 @@ def test_reader_fn_parameters(
     test_sparkdf_with_no_header_param = basic_spark_df_execution_engine.get_batch_data(
         PathBatchSpec(path=test_df_small_csv_path, data_asset_name="DATA_ASSET")
     ).dataframe
-    assert test_sparkdf_with_no_header_param.head() == Row(_c0="x", _c1="y")
+    assert test_sparkdf_with_no_header_param.head() == pyspark.Row(_c0="x", _c1="y")
 
     test_sparkdf_with_header_param = basic_spark_df_execution_engine.get_batch_data(
         PathBatchSpec(
@@ -114,41 +62,37 @@ def test_reader_fn_parameters(
             reader_options={"header": True},
         )
     ).dataframe
-    assert test_sparkdf_with_header_param.head() == Row(x="1", y="2")
+    assert test_sparkdf_with_header_param.head() == pyspark.Row(x="1", y="2")
 
     test_sparkdf_with_no_header_param = basic_spark_df_execution_engine.get_batch_data(
         PathBatchSpec(path=test_df_small_csv_path, data_asset_name="DATA_ASSET")
     ).dataframe
-    assert test_sparkdf_with_no_header_param.head() == Row(_c0="x", _c1="y")
+    assert test_sparkdf_with_no_header_param.head() == pyspark.Row(_c0="x", _c1="y")
 
     # defining schema
-    schema: pyspark.sql.types.StructType = StructType(
+    schema: pyspark.types.StructType = pyspark.types.StructType(
         [
-            StructField("x", IntegerType(), True),
-            StructField("y", IntegerType(), True),
+            pyspark.types.StructField("x", pyspark.types.IntegerType(), True),
+            pyspark.types.StructField("y", pyspark.types.IntegerType(), True),
         ]
     )
     schema_dict: dict = schema
 
-    test_sparkdf_with_header_param_and_schema = (
-        basic_spark_df_execution_engine.get_batch_data(
-            PathBatchSpec(
-                path=test_df_small_csv_path,
-                data_asset_name="DATA_ASSET",
-                reader_options={"header": True, "schema": schema_dict},
-            )
-        ).dataframe
-    )
-    assert test_sparkdf_with_header_param_and_schema.head() == Row(x=1, y=2)
+    test_sparkdf_with_header_param_and_schema = basic_spark_df_execution_engine.get_batch_data(
+        PathBatchSpec(
+            path=test_df_small_csv_path,
+            data_asset_name="DATA_ASSET",
+            reader_options={"header": True, "schema": schema_dict},
+        )
+    ).dataframe
+    assert test_sparkdf_with_header_param_and_schema.head() == pyspark.Row(x=1, y=2)
     assert test_sparkdf_with_header_param_and_schema.schema == schema_dict
 
 
 def test_get_domain_records_with_column_domain(
     spark_session, basic_spark_df_execution_engine, spark_df_from_pandas_df
 ):
-    pd_df = pd.DataFrame(
-        {"a": [1, 2, 3, 4, 5], "b": [2, 3, 4, 5, None], "c": [1, 2, 3, 4, None]}
-    )
+    pd_df = pd.DataFrame({"a": [1, 2, 3, 4, 5], "b": [2, 3, 4, 5, None], "c": [1, 2, 3, 4, None]})
     df = spark_df_from_pandas_df(spark_session, pd_df)
     engine = basic_spark_df_execution_engine
     engine.load_batch_data(batch_id="1234", batch_data=df)
@@ -156,24 +100,22 @@ def test_get_domain_records_with_column_domain(
         domain_kwargs={
             "column": "a",
             "row_condition": 'col("b")<5',
-            "condition_parser": "great_expectations__experimental__",
+            "condition_parser": "great_expectations",
         }
     )
 
     expected_column_pd_df = pd_df.iloc[:3]
     expected_column_df = spark_df_from_pandas_df(spark_session, expected_column_pd_df)
 
-    assert dataframes_equal(
-        data, expected_column_df
-    ), "Data does not match after getting full access compute domain"
+    assert dataframes_equal(data, expected_column_df), (
+        "Data does not match after getting full access compute domain"
+    )
 
 
 def test_get_domain_records_with_column_domain_and_filter_conditions(
     spark_session, basic_spark_df_execution_engine, spark_df_from_pandas_df
 ):
-    pd_df = pd.DataFrame(
-        {"a": [1, 2, 3, 4, 5], "b": [2, 3, 4, 5, None], "c": [1, 2, 3, 4, None]}
-    )
+    pd_df = pd.DataFrame({"a": [1, 2, 3, 4, 5], "b": [2, 3, 4, 5, None], "c": [1, 2, 3, 4, None]})
     df = spark_df_from_pandas_df(spark_session, pd_df)
     engine = basic_spark_df_execution_engine
     engine.load_batch_data(batch_id="1234", batch_data=df)
@@ -181,7 +123,7 @@ def test_get_domain_records_with_column_domain_and_filter_conditions(
         domain_kwargs={
             "column": "a",
             "row_condition": 'col("b")<5',
-            "condition_parser": "great_expectations__experimental__",
+            "condition_parser": "great_expectations",
             "filter_conditions": [
                 RowCondition(
                     condition="b IS NOT NULL",
@@ -194,17 +136,15 @@ def test_get_domain_records_with_column_domain_and_filter_conditions(
     expected_column_pd_df = pd_df.iloc[:3]
     expected_column_df = spark_df_from_pandas_df(spark_session, expected_column_pd_df)
 
-    assert dataframes_equal(
-        data, expected_column_df
-    ), "Data does not match after getting full access compute domain"
+    assert dataframes_equal(data, expected_column_df), (
+        "Data does not match after getting full access compute domain"
+    )
 
 
 def test_get_domain_records_with_different_column_domain_and_filter_conditions(
     spark_session, basic_spark_df_execution_engine, spark_df_from_pandas_df
 ):
-    pd_df = pd.DataFrame(
-        {"a": [1, 2, 3, 4, 5], "b": [2, 3, 4, 5, None], "c": [1, 2, 3, 4, None]}
-    )
+    pd_df = pd.DataFrame({"a": [1, 2, 3, 4, 5], "b": [2, 3, 4, 5, None], "c": [1, 2, 3, 4, None]})
     df = spark_df_from_pandas_df(spark_session, pd_df)
     engine = basic_spark_df_execution_engine
     engine.load_batch_data(batch_id="1234", batch_data=df)
@@ -212,7 +152,7 @@ def test_get_domain_records_with_different_column_domain_and_filter_conditions(
         domain_kwargs={
             "column": "a",
             "row_condition": 'col("a")<2',
-            "condition_parser": "great_expectations__experimental__",
+            "condition_parser": "great_expectations",
             "filter_conditions": [
                 RowCondition(
                     condition="b IS NOT NULL",
@@ -225,17 +165,15 @@ def test_get_domain_records_with_different_column_domain_and_filter_conditions(
     expected_column_pd_df = pd_df.iloc[:1]
     expected_column_df = spark_df_from_pandas_df(spark_session, expected_column_pd_df)
 
-    assert dataframes_equal(
-        data, expected_column_df
-    ), "Data does not match after getting full access compute domain"
+    assert dataframes_equal(data, expected_column_df), (
+        "Data does not match after getting full access compute domain"
+    )
 
 
 def test_get_domain_records_with_different_column_domain_and_multiple_filter_conditions(
     spark_session, basic_spark_df_execution_engine, spark_df_from_pandas_df
 ):
-    pd_df = pd.DataFrame(
-        {"a": [1, 2, 3, 4, 5], "b": [2, 3, 4, 5, None], "c": [1, 2, 3, 4, None]}
-    )
+    pd_df = pd.DataFrame({"a": [1, 2, 3, 4, 5], "b": [2, 3, 4, 5, None], "c": [1, 2, 3, 4, None]})
     df = spark_df_from_pandas_df(spark_session, pd_df)
     engine = basic_spark_df_execution_engine
     engine.load_batch_data(batch_id="1234", batch_data=df)
@@ -243,7 +181,7 @@ def test_get_domain_records_with_different_column_domain_and_multiple_filter_con
         domain_kwargs={
             "column": "a",
             "row_condition": 'col("a")<10',
-            "condition_parser": "great_expectations__experimental__",
+            "condition_parser": "great_expectations",
             "filter_conditions": [
                 RowCondition(
                     condition="b IS NOT NULL",
@@ -260,9 +198,9 @@ def test_get_domain_records_with_different_column_domain_and_multiple_filter_con
     expected_column_pd_df = pd_df.iloc[:4]
     expected_column_df = spark_df_from_pandas_df(spark_session, expected_column_pd_df)
 
-    assert dataframes_equal(
-        data, expected_column_df
-    ), "Data does not match after getting full access compute domain"
+    assert dataframes_equal(data, expected_column_df), (
+        "Data does not match after getting full access compute domain"
+    )
 
 
 def test_get_domain_records_with_column_pair_domain(
@@ -283,7 +221,7 @@ def test_get_domain_records_with_column_pair_domain(
             "column_A": "a",
             "column_B": "b",
             "row_condition": 'col("b")>2',
-            "condition_parser": "great_expectations__experimental__",
+            "condition_parser": "great_expectations",
             "ignore_row_if": "both_values_are_missing",
         }
     )
@@ -291,13 +229,11 @@ def test_get_domain_records_with_column_pair_domain(
     expected_column_pair_pd_df = pd.DataFrame(
         {"a": [2, 3, 4, 6], "b": [3.0, 4.0, 5.0, 6.0], "c": [2.0, 3.0, 4.0, None]}
     )
-    expected_column_pair_df = spark_df_from_pandas_df(
-        spark_session, expected_column_pair_pd_df
-    )
+    expected_column_pair_df = spark_df_from_pandas_df(spark_session, expected_column_pair_pd_df)
 
-    assert dataframes_equal(
-        data, expected_column_pair_df
-    ), "Data does not match after getting full access compute domain"
+    assert dataframes_equal(data, expected_column_pair_df), (
+        "Data does not match after getting full access compute domain"
+    )
 
     pd_df = pd.DataFrame(
         {
@@ -314,23 +250,19 @@ def test_get_domain_records_with_column_pair_domain(
             "column_A": "b",
             "column_B": "c",
             "row_condition": 'col("b")>2',
-            "condition_parser": "great_expectations__experimental__",
+            "condition_parser": "great_expectations",
             "ignore_row_if": "either_value_is_missing",
         }
     )
     for column_name in data.columns:
-        data = data.withColumn(column_name, data[column_name].cast(LongType()))
+        data = data.withColumn(column_name, data[column_name].cast(pyspark.types.LongType()))
 
-    expected_column_pair_pd_df = pd.DataFrame(
-        {"a": [2, 3, 4], "b": [3, 4, 5], "c": [2, 3, 4]}
-    )
-    expected_column_pair_df = spark_df_from_pandas_df(
-        spark_session, expected_column_pair_pd_df
-    )
+    expected_column_pair_pd_df = pd.DataFrame({"a": [2, 3, 4], "b": [3, 4, 5], "c": [2, 3, 4]})
+    expected_column_pair_df = spark_df_from_pandas_df(spark_session, expected_column_pair_pd_df)
 
-    assert dataframes_equal(
-        data, expected_column_pair_df
-    ), "Data does not match after getting full access compute domain"
+    assert dataframes_equal(data, expected_column_pair_df), (
+        "Data does not match after getting full access compute domain"
+    )
 
     pd_df = pd.DataFrame(
         {
@@ -347,7 +279,7 @@ def test_get_domain_records_with_column_pair_domain(
             "column_A": "b",
             "column_B": "c",
             "row_condition": 'col("a")<6',
-            "condition_parser": "great_expectations__experimental__",
+            "condition_parser": "great_expectations",
             "ignore_row_if": "neither",
         }
     )
@@ -359,13 +291,11 @@ def test_get_domain_records_with_column_pair_domain(
             "c": [1.0, 2.0, 3.0, 4.0, 5.0],
         }
     )
-    expected_column_pair_df = spark_df_from_pandas_df(
-        spark_session, expected_column_pair_pd_df
-    )
+    expected_column_pair_df = spark_df_from_pandas_df(spark_session, expected_column_pair_pd_df)
 
-    assert dataframes_equal(
-        data, expected_column_pair_df
-    ), "Data does not match after getting full access compute domain"
+    assert dataframes_equal(data, expected_column_pair_df), (
+        "Data does not match after getting full access compute domain"
+    )
 
 
 def test_get_domain_records_with_multicolumn_domain(
@@ -385,26 +315,24 @@ def test_get_domain_records_with_multicolumn_domain(
         domain_kwargs={
             "column_list": ["a", "c"],
             "row_condition": 'col("b")>2',
-            "condition_parser": "great_expectations__experimental__",
+            "condition_parser": "great_expectations",
             "ignore_row_if": "all_values_are_missing",
         }
     )
     for column_name in data.columns:
-        data = data.withColumn(column_name, data[column_name].cast(LongType()))
+        data = data.withColumn(column_name, data[column_name].cast(pyspark.types.LongType()))
 
     expected_multicolumn_pd_df = pd.DataFrame(
         {"a": [2, 3, 4, 5], "b": [3, 4, 5, 7], "c": [2, 3, 4, 6]}, index=[0, 1, 2, 4]
     )
-    expected_multicolumn_df = spark_df_from_pandas_df(
-        spark_session, expected_multicolumn_pd_df
-    )
+    expected_multicolumn_df = spark_df_from_pandas_df(spark_session, expected_multicolumn_pd_df)
 
     engine = basic_spark_df_execution_engine
     engine.load_batch_data(batch_id="1234", batch_data=expected_multicolumn_df)
 
-    assert dataframes_equal(
-        data, expected_multicolumn_df
-    ), "Data does not match after getting full access compute domain"
+    assert dataframes_equal(data, expected_multicolumn_df), (
+        "Data does not match after getting full access compute domain"
+    )
 
     pd_df = pd.DataFrame(
         {
@@ -420,24 +348,22 @@ def test_get_domain_records_with_multicolumn_domain(
         domain_kwargs={
             "column_list": ["b", "c"],
             "row_condition": 'col("a")<5',
-            "condition_parser": "great_expectations__experimental__",
+            "condition_parser": "great_expectations",
             "ignore_row_if": "any_value_is_missing",
         }
     )
     for column_name in data.columns:
-        data = data.withColumn(column_name, data[column_name].cast(LongType()))
+        data = data.withColumn(column_name, data[column_name].cast(pyspark.types.LongType()))
 
     expected_multicolumn_pd_df = pd.DataFrame(
         {"a": [1, 2, 3, 4], "b": [2, 3, 4, 5], "c": [1, 2, 3, 4]}, index=[0, 1, 2, 3]
     )
 
-    expected_multicolumn_df = spark_df_from_pandas_df(
-        spark_session, expected_multicolumn_pd_df
-    )
+    expected_multicolumn_df = spark_df_from_pandas_df(spark_session, expected_multicolumn_pd_df)
 
-    assert dataframes_equal(
-        data, expected_multicolumn_df
-    ), "Data does not match after getting full access compute domain"
+    assert dataframes_equal(data, expected_multicolumn_df), (
+        "Data does not match after getting full access compute domain"
+    )
 
     pd_df = pd.DataFrame(
         {
@@ -465,13 +391,11 @@ def test_get_domain_records_with_multicolumn_domain(
         index=[0, 1, 2, 3, 4, 5],
     )
 
-    expected_multicolumn_df = spark_df_from_pandas_df(
-        spark_session, expected_multicolumn_pd_df
-    )
+    expected_multicolumn_df = spark_df_from_pandas_df(spark_session, expected_multicolumn_pd_df)
 
-    assert dataframes_equal(
-        data, expected_multicolumn_df
-    ), "Data does not match after getting full access compute domain"
+    assert dataframes_equal(data, expected_multicolumn_df), (
+        "Data does not match after getting full access compute domain"
+    )
 
 
 def test_get_compute_domain_with_no_domain_kwargs(
@@ -525,9 +449,9 @@ def test_get_compute_domain_with_row_condition(
     assert data.collect() == expected_df.collect()
 
     # Ensuring compute kwargs have not been modified
-    assert (
-        "row_condition" in compute_kwargs.keys()
-    ), "Row condition should be located within compute kwargs"
+    assert "row_condition" in compute_kwargs, (
+        "Row condition should be located within compute kwargs"
+    )
     assert accessor_kwargs == {}
 
 
@@ -551,13 +475,11 @@ def test_get_compute_domain_with_unmeetable_row_condition(
     assert data.collect() == expected_df.collect()
 
     # Ensuring compute kwargs have not been modified
-    assert "row_condition" in compute_kwargs.keys()
+    assert "row_condition" in compute_kwargs
     assert accessor_kwargs == {}
 
 
-def test_basic_setup(
-    spark_session, basic_spark_df_execution_engine, spark_df_from_pandas_df
-):
+def test_basic_setup(spark_session, basic_spark_df_execution_engine, spark_df_from_pandas_df):
     pd_df = pd.DataFrame({"x": range(10)})
     df = spark_df_from_pandas_df(spark_session, pd_df)
     batch_data = basic_spark_df_execution_engine.get_batch_data(
@@ -577,14 +499,14 @@ def test_get_batch_data(test_sparkdf, basic_spark_df_execution_engine):
     assert len(test_sparkdf.columns) == 10
 
 
-def test_split_on_multi_column_values_and_sample_using_random(
+def test_partition_on_multi_column_values_and_sample_using_random(
     test_sparkdf, basic_spark_df_execution_engine
 ):
     returned_df = basic_spark_df_execution_engine.get_batch_data(
         RuntimeDataBatchSpec(
             batch_data=test_sparkdf,
-            splitter_method="_split_on_multi_column_values",
-            splitter_kwargs={
+            partitioner_method="_partition_on_multi_column_values",
+            partitioner_kwargs={
                 "column_names": ["y", "m", "d"],
                 "batch_identifiers": {
                     "y": 2020,
@@ -603,12 +525,12 @@ def test_split_on_multi_column_values_and_sample_using_random(
     assert len(returned_df.columns) == 10
     # The number of returned rows corresponding to the value of "batch_identifiers" above is 4.
     assert 0 <= returned_df.count() <= 4
-    # The sampling probability "p" used in "SparkDFExecutionEngine._sample_using_random()" is 0.5 (the equivalent of a
-    # fair coin with the 50% chance of coming up as "heads").  Hence, on average we should get 50% of the rows, which is
-    # 2; however, for such a small sample (of 4 rows), the number of rows returned by an individual run can deviate from
-    # this average.  Still, in the majority of trials, the number of rows should not be fewer than 2 or greater than 3.
-    # The assertion in the next line, supporting this reasoning, is commented out to insure zero failures.  Developers
-    # are encouraged to uncomment it, whenever the "_sample_using_random" feature is the main focus of a given effort.
+    # The sampling probability "p" used in "SparkDFExecutionEngine._sample_using_random()" is 0.5 (the equivalent of a  # noqa: E501 # FIXME CoP
+    # fair coin with the 50% chance of coming up as "heads").  Hence, on average we should get 50% of the rows, which is  # noqa: E501 # FIXME CoP
+    # 2; however, for such a small sample (of 4 rows), the number of rows returned by an individual run can deviate from  # noqa: E501 # FIXME CoP
+    # this average.  Still, in the majority of trials, the number of rows should not be fewer than 2 or greater than 3.  # noqa: E501 # FIXME CoP
+    # The assertion in the next line, supporting this reasoning, is commented out to insure zero failures.  Developers  # noqa: E501 # FIXME CoP
+    # are encouraged to uncomment it, whenever the "_sample_using_random" feature is the main focus of a given effort.  # noqa: E501 # FIXME CoP
     # assert 2 <= returned_df.count() <= 3
 
     for val in returned_df.collect():
@@ -620,8 +542,7 @@ def test_add_column_row_condition(spark_session, basic_spark_df_execution_engine
     df = spark_session.createDataFrame(
         [
             tuple(
-                None if isinstance(x, (float, int)) and np.isnan(x) else x
-                for x in record.tolist()
+                None if isinstance(x, (float, int)) and np.isnan(x) else x for x in record.tolist()
             )
             for record in df.to_records(index=False)
         ],
@@ -635,11 +556,9 @@ def test_add_column_row_condition(spark_session, basic_spark_df_execution_engine
         domain_kwargs, filter_null=True, filter_nan=False
     )
     assert new_domain_kwargs["filter_conditions"] == [
-        RowCondition(
-            condition="foo IS NOT NULL", condition_type=RowConditionParserType.SPARK_SQL
-        )
+        RowCondition(condition="foo IS NOT NULL", condition_type=RowConditionParserType.SPARK_SQL)
     ]
-    df, cd, ad = engine.get_compute_domain(new_domain_kwargs, domain_type="table")
+    df, _cd, _ad = engine.get_compute_domain(new_domain_kwargs, domain_type="table")
     res = df.collect()
     assert res == [(1,), (2,), (3,), (3,), (2,), (3,), (4,), (5,), (6,)]
 
@@ -647,14 +566,10 @@ def test_add_column_row_condition(spark_session, basic_spark_df_execution_engine
         domain_kwargs, filter_null=True, filter_nan=True
     )
     assert new_domain_kwargs["filter_conditions"] == [
-        RowCondition(
-            condition="foo IS NOT NULL", condition_type=RowConditionParserType.SPARK_SQL
-        ),
-        RowCondition(
-            condition="NOT isnan(foo)", condition_type=RowConditionParserType.SPARK_SQL
-        ),
+        RowCondition(condition="foo IS NOT NULL", condition_type=RowConditionParserType.SPARK_SQL),
+        RowCondition(condition="NOT isnan(foo)", condition_type=RowConditionParserType.SPARK_SQL),
     ]
-    df, cd, ad = engine.get_compute_domain(new_domain_kwargs, domain_type="table")
+    df, _cd, _ad = engine.get_compute_domain(new_domain_kwargs, domain_type="table")
     res = df.collect()
     assert res == [(1,), (2,), (3,), (3,), (2,), (3,), (4,), (5,), (6,)]
 
@@ -662,11 +577,9 @@ def test_add_column_row_condition(spark_session, basic_spark_df_execution_engine
         domain_kwargs, filter_null=False, filter_nan=True
     )
     assert new_domain_kwargs["filter_conditions"] == [
-        RowCondition(
-            condition="NOT isnan(foo)", condition_type=RowConditionParserType.SPARK_SQL
-        )
+        RowCondition(condition="NOT isnan(foo)", condition_type=RowConditionParserType.SPARK_SQL)
     ]
-    df, cd, ad = engine.get_compute_domain(new_domain_kwargs, domain_type="table")
+    df, _cd, _ad = engine.get_compute_domain(new_domain_kwargs, domain_type="table")
     res = df.collect()
     assert res == [(1,), (2,), (3,), (3,), (None,), (2,), (3,), (4,), (5,), (6,)]
 
@@ -680,11 +593,9 @@ def test_add_column_row_condition(spark_session, basic_spark_df_execution_engine
         domain_kwargs, filter_null=False, filter_nan=True
     )
     assert new_domain_kwargs["filter_conditions"] == [
-        RowCondition(
-            condition="NOT isnan(foo)", condition_type=RowConditionParserType.SPARK_SQL
-        )
+        RowCondition(condition="NOT isnan(foo)", condition_type=RowConditionParserType.SPARK_SQL)
     ]
-    df, cd, ad = engine.get_compute_domain(new_domain_kwargs, domain_type="table")
+    df, _cd, _ad = engine.get_compute_domain(new_domain_kwargs, domain_type="table")
     res = df.collect()
     assert res == [(1,), (2,), (3,), (3,), (2,), (3,), (4,), (5,), (6,)]
 
@@ -692,11 +603,9 @@ def test_add_column_row_condition(spark_session, basic_spark_df_execution_engine
         domain_kwargs, filter_null=True, filter_nan=False
     )
     assert new_domain_kwargs["filter_conditions"] == [
-        RowCondition(
-            condition="foo IS NOT NULL", condition_type=RowConditionParserType.SPARK_SQL
-        ),
+        RowCondition(condition="foo IS NOT NULL", condition_type=RowConditionParserType.SPARK_SQL),
     ]
-    df, cd, ad = engine.get_compute_domain(new_domain_kwargs, domain_type="table")
+    df, _cd, _ad = engine.get_compute_domain(new_domain_kwargs, domain_type="table")
     res = df.collect()
     expected = [(1,), (2,), (3,), (3,), (np.nan,), (2,), (3,), (4,), (5,), (6,)]
     # since nan != nan by default
@@ -707,9 +616,7 @@ def test_add_column_row_condition(spark_session, basic_spark_df_execution_engine
 def dataframes_equal(first_table, second_table):
     if first_table.schema != second_table.schema:
         return False
-    if first_table.collect() != second_table.collect():
-        return False
-    return True
+    return not first_table.collect() != second_table.collect()
 
 
 # Ensuring that, given aggregate metrics, they can be properly bundled together
@@ -729,7 +636,7 @@ def test_sparkdf_batch_aggregate_metrics(caplog, spark_session):
     table_columns_metric: MetricConfiguration
     results: Dict[Tuple[str, str, str], MetricValue]
 
-    table_columns_metric, results = get_table_columns_metric(engine=engine)
+    table_columns_metric, results = get_table_columns_metric(execution_engine=engine)
 
     metrics.update(results)
 
@@ -812,7 +719,7 @@ def test_sparkdf_batch_aggregate_metrics(caplog, spark_session):
         "metric_partial_fn": desired_aggregate_fn_metric_4,
         "table.columns": table_columns_metric,
     }
-    start = datetime.datetime.now()
+    start = datetime.datetime.now()  # noqa: DTZ005 # FIXME CoP
     caplog.clear()
     caplog.set_level(logging.DEBUG, logger="great_expectations")
     results = engine.resolve_metrics(
@@ -825,7 +732,7 @@ def test_sparkdf_batch_aggregate_metrics(caplog, spark_session):
         metrics=metrics,
     )
     metrics.update(results)
-    end = datetime.datetime.now()
+    end = datetime.datetime.now()  # noqa: DTZ005 # FIXME CoP
     print(end - start)
     assert metrics[desired_metric_1.id] == 3
     assert metrics[desired_metric_2.id] == 1
@@ -835,10 +742,7 @@ def test_sparkdf_batch_aggregate_metrics(caplog, spark_session):
     # Check that all four of these metrics were computed on a single domain
     found_message = False
     for record in caplog.records:
-        if (
-            record.message
-            == "SparkDFExecutionEngine computed 4 metrics on domain_id ()"
-        ):
+        if record.message == "SparkDFExecutionEngine computed 4 metrics on domain_id ()":
             found_message = True
     assert found_message
 
@@ -859,9 +763,7 @@ def test_get_compute_domain_with_no_domain_kwargs_alt(spark_session):
     )
 
     # Ensuring that with no domain nothing happens to the data itself
-    assert dataframes_equal(
-        data, df
-    ), "Data does not match after getting compute domain"
+    assert dataframes_equal(data, df), "Data does not match after getting compute domain"
     assert compute_kwargs == {}, "Compute domain kwargs should be existent"
     assert accessor_kwargs == {}, "Accessor kwargs have been modified"
 
@@ -882,9 +784,7 @@ def test_get_compute_domain_with_column_pair(spark_session):
     )
 
     # Ensuring that with no domain nothing happens to the data itself
-    assert dataframes_equal(
-        data, df
-    ), "Data does not match after getting compute domain"
+    assert dataframes_equal(data, df), "Data does not match after getting compute domain"
     assert compute_kwargs == {}, "Compute domain kwargs should be existent"
     assert accessor_kwargs == {
         "column_A": "a",
@@ -908,13 +808,9 @@ def test_get_compute_domain_with_multicolumn(spark_session):
     )
 
     # Ensuring that with no domain nothing happens to the data itself
-    assert dataframes_equal(
-        data, df
-    ), "Data does not match after getting compute domain"
+    assert dataframes_equal(data, df), "Data does not match after getting compute domain"
     assert compute_kwargs == {}, "Compute domain kwargs should be empty"
-    assert accessor_kwargs == {
-        "column_list": ["a", "b", "c"]
-    }, "Accessor kwargs have been modified"
+    assert accessor_kwargs == {"column_list": ["a", "b", "c"]}, "Accessor kwargs have been modified"
 
 
 # Testing whether compute domain is properly calculated, but this time obtaining a column
@@ -933,9 +829,7 @@ def test_get_compute_domain_with_column_domain_alt(spark_session):
     )
 
     # Ensuring that column domain is now an accessor kwarg, and data remains unmodified
-    assert dataframes_equal(
-        data, df
-    ), "Data does not match after getting compute domain"
+    assert dataframes_equal(data, df), "Data does not match after getting compute domain"
     assert compute_kwargs == {}, "Compute domain kwargs should be empty"
     assert accessor_kwargs == {"column": "a"}, "Accessor kwargs have been modified"
 
@@ -963,9 +857,7 @@ def test_get_domain_records_with_row_condition_alt(spark_session):
     )
 
     # Ensuring data has been properly queried
-    assert dataframes_equal(
-        data, expected_df
-    ), "Data does not match after getting compute domain"
+    assert dataframes_equal(data, expected_df), "Data does not match after getting compute domain"
 
 
 # What happens when we filter such that no value meets the condition?
@@ -990,23 +882,21 @@ def test_get_domain_records_with_unmeetable_row_condition_alt(spark_session):
         }
     )
     # Ensuring data has been properly queried
-    assert dataframes_equal(
-        data, expected_df
-    ), "Data does not match after getting compute domain"
+    assert dataframes_equal(data, expected_df), "Data does not match after getting compute domain"
 
     # Ensuring errors for column and column_ pair domains are caught
     with pytest.raises(gx_exceptions.GreatExpectationsError):
         # noinspection PyUnusedLocal
-        data, compute_kwargs, accessor_kwargs = engine.get_compute_domain(
+        data, _compute_kwargs, _accessor_kwargs = engine.get_compute_domain(
             domain_kwargs={
                 "row_condition": "b > 24",
                 "condition_parser": "spark",
             },
             domain_type="column",
         )
-    with pytest.raises(gx_exceptions.GreatExpectationsError) as g:
+    with pytest.raises(gx_exceptions.GreatExpectationsError):
         # noinspection PyUnusedLocal
-        data, compute_kwargs, accessor_kwargs = engine.get_compute_domain(
+        data, _compute_kwargs, _accessor_kwargs = engine.get_compute_domain(
             domain_kwargs={
                 "row_condition": "b > 24",
                 "condition_parser": "spark",
@@ -1015,8 +905,8 @@ def test_get_domain_records_with_unmeetable_row_condition_alt(spark_session):
         )
 
 
-# Testing to ensure that great expectation experimental parser also works in terms of defining a compute domain
-def test_get_compute_domain_with_ge_experimental_condition_parser(spark_session):
+# Testing to ensure that great expectation parser also works in terms of defining a compute domain  # noqa: E501 # FIXME CoP
+def test_get_compute_domain_with_gx_condition_parser(spark_session):
     engine: SparkDFExecutionEngine = build_spark_engine(
         spark=spark_session,
         df=pd.DataFrame(
@@ -1037,19 +927,17 @@ def test_get_compute_domain_with_ge_experimental_condition_parser(spark_session)
         domain_kwargs={
             "column": "b",
             "row_condition": 'col("b") == 2',
-            "condition_parser": "great_expectations__experimental__",
+            "condition_parser": "great_expectations",
         },
         domain_type="column",
     )
     # Ensuring data has been properly queried
-    assert dataframes_equal(
-        data, expected_df
-    ), "Data does not match after getting compute domain"
+    assert dataframes_equal(data, expected_df), "Data does not match after getting compute domain"
 
     # Ensuring compute kwargs have not been modified
-    assert (
-        "row_condition" in compute_kwargs.keys()
-    ), "Row condition should be located within compute kwargs"
+    assert "row_condition" in compute_kwargs, (
+        "Row condition should be located within compute kwargs"
+    )
     assert accessor_kwargs == {"column": "b"}, "Accessor kwargs have been modified"
 
     # Should react same for get_domain_records()
@@ -1057,13 +945,11 @@ def test_get_compute_domain_with_ge_experimental_condition_parser(spark_session)
         domain_kwargs={
             "column": "b",
             "row_condition": 'col("b") == 2',
-            "condition_parser": "great_expectations__experimental__",
+            "condition_parser": "great_expectations",
         }
     )
     # Ensuring data has been properly queried
-    assert dataframes_equal(
-        data, expected_df
-    ), "Data does not match after getting compute domain"
+    assert dataframes_equal(data, expected_df), "Data does not match after getting compute domain"
 
 
 def test_get_compute_domain_with_nonexistent_condition_parser(spark_session):
@@ -1082,7 +968,7 @@ def test_get_compute_domain_with_nonexistent_condition_parser(spark_session):
     # Expect GreatExpectationsError because parser doesn't exist
     with pytest.raises(gx_exceptions.GreatExpectationsError):
         # noinspection PyUnusedLocal
-        data = engine.get_domain_records(
+        engine.get_domain_records(
             domain_kwargs={
                 "row_condition": "b > 24",
                 "condition_parser": "nonexistent",
@@ -1090,7 +976,7 @@ def test_get_compute_domain_with_nonexistent_condition_parser(spark_session):
         )
 
 
-# Ensuring that we can properly inform user when metric doesn't exist - should get a metric provider error
+# Ensuring that we can properly inform user when metric doesn't exist - should get a metric provider error  # noqa: E501 # FIXME CoP
 def test_resolve_metric_bundle_with_nonexistent_metric(spark_session):
     engine: SparkDFExecutionEngine = build_spark_engine(
         spark=spark_session,
@@ -1124,7 +1010,7 @@ def test_resolve_metric_bundle_with_nonexistent_metric(spark_session):
     # Ensuring a metric provider error is raised if metric does not exist
     with pytest.raises(gx_exceptions.MetricProviderError) as e:
         # noinspection PyUnusedLocal
-        res = engine.resolve_metrics(
+        engine.resolve_metrics(
             metrics_to_resolve=(
                 desired_metric_1,
                 desired_metric_2,
@@ -1140,7 +1026,7 @@ def test_resolve_metric_bundle_with_compute_domain_kwargs_json_serialization(
 ):
     """
     Insures that even when "compute_domain_kwargs" has multiple keys, it will be JSON-serialized for "IDDict.to_id()".
-    """
+    """  # noqa: E501 # FIXME CoP
     engine = build_spark_engine(
         spark=spark_session,
         df=pd.DataFrame(
@@ -1165,7 +1051,7 @@ def test_resolve_metric_bundle_with_compute_domain_kwargs_json_serialization(
     table_columns_metric: MetricConfiguration
     results: Dict[Tuple[str, str, str], MetricValue]
 
-    table_columns_metric, results = get_table_columns_metric(engine=engine)
+    table_columns_metric, results = get_table_columns_metric(execution_engine=engine)
     metrics.update(results)
 
     aggregate_fn_metric = MetricConfiguration(
@@ -1197,9 +1083,7 @@ def test_resolve_metric_bundle_with_compute_domain_kwargs_json_serialization(
     }
 
     try:
-        results = engine.resolve_metrics(
-            metrics_to_resolve=(desired_metric,), metrics=results
-        )
+        results = engine.resolve_metrics(metrics_to_resolve=(desired_metric,), metrics=results)
         assert results == {desired_metric.id: 16}
     except gx_exceptions.MetricProviderError as e:
         assert False, str(e)
@@ -1220,12 +1104,10 @@ def test_dataframe_property_given_loaded_batch(spark_session):
     assert engine.dataframe == df
 
 
-@pytest.mark.integration
 def test_schema_properly_added(spark_session):
-
-    schema: pyspark.sql.types.StructType = StructType(
+    schema: pyspark.types.StructType = pyspark.types.StructType(
         [
-            StructField("a", IntegerType(), True),
+            pyspark.types.StructField("a", pyspark.types.IntegerType(), True),
         ]
     )
     engine: SparkDFExecutionEngine = build_spark_engine(
