@@ -1,7 +1,10 @@
-from unittest.mock import Mock
+from unittest.mock import Mock  # noqa: TID251 # FIXME CoP
 
 import pytest
 
+from great_expectations.compatibility.sqlalchemy_compatibility_wrappers import (
+    add_dataframe_to_db,
+)
 from great_expectations.core.batch_spec import SqlAlchemyDatasourceBatchSpec
 from great_expectations.execution_engine import SqlAlchemyExecutionEngine
 from great_expectations.execution_engine.sqlalchemy_dialect import GXSqlDialect
@@ -14,9 +17,13 @@ except ImportError:
 from great_expectations.execution_engine.sqlalchemy_batch_data import (
     SqlAlchemyBatchData,
 )
-from tests.test_utils import get_sqlite_temp_table_names
+from tests.sqlalchemy_test_doubles import Dialect, MockSaEngine
+from tests.test_utils import get_sqlite_temp_table_names_from_engine
+
+pytestmark = pytest.mark.sqlalchemy_version_compatibility
 
 
+@pytest.mark.sqlite
 def test_instantiation_with_table_name(sqlite_view_engine):
     execution_engine: SqlAlchemyExecutionEngine = SqlAlchemyExecutionEngine(
         engine=sqlite_view_engine
@@ -28,30 +35,26 @@ def test_instantiation_with_table_name(sqlite_view_engine):
 
     # This is a very hacky type check.
     # A better way would be to figure out the proper parent class for dialects within SQLAlchemy
-    assert (
-        str(type(batch_data.sql_engine_dialect))[:28] == "<class 'sqlalchemy.dialects."
-    )
+    assert str(type(batch_data.sql_engine_dialect))[:28] == "<class 'sqlalchemy.dialects."
 
     assert isinstance(batch_data.selectable, sqlalchemy.Table)
 
-    assert type(batch_data.record_set_name) == str
-    assert batch_data.record_set_name == "great_expectations_sub_selection"
-
     assert batch_data.use_quoted_name is False
 
 
+@pytest.mark.sqlite
 def test_instantiation_with_query(sqlite_view_engine, test_df):
-    test_df.to_sql("test_table_0", con=sqlite_view_engine)
+    add_dataframe_to_db(df=test_df, name="test_table_0", con=sqlite_view_engine)
 
     query: str = "SELECT * FROM test_table_0"
     # If create_temp_table=False, a new temp table should NOT be created
     # noinspection PyUnusedLocal
-    batch_data = SqlAlchemyBatchData(
+    SqlAlchemyBatchData(
         execution_engine=sqlite_view_engine,
         query=query,
         create_temp_table=False,
     )
-    assert len(get_sqlite_temp_table_names(sqlite_view_engine)) == 1
+    assert len(get_sqlite_temp_table_names_from_engine(sqlite_view_engine)) == 1
 
 
 # REMOVING PENDING READ OF table.head metric
@@ -75,21 +78,22 @@ def test_instantiation_with_query(sqlite_view_engine, test_df):
 #     assert validator.head(n_rows=20, fetch_all=True).shape == (100, 2)
 
 
+@pytest.mark.sqlite
 def test_instantiation_with_and_without_temp_table(sqlite_view_engine, sa):
-    print(get_sqlite_temp_table_names(sqlite_view_engine))
-    assert len(get_sqlite_temp_table_names(sqlite_view_engine)) == 1
-    assert get_sqlite_temp_table_names(sqlite_view_engine) == {"test_temp_view"}
+    print(get_sqlite_temp_table_names_from_engine(sqlite_view_engine))
+    assert len(get_sqlite_temp_table_names_from_engine(sqlite_view_engine)) == 1
+    assert get_sqlite_temp_table_names_from_engine(sqlite_view_engine) == {"test_temp_view"}
 
     execution_engine: SqlAlchemyExecutionEngine = SqlAlchemyExecutionEngine(
         engine=sqlite_view_engine
     )
-    # When the SqlAlchemyBatchData object is based on a table, a new temp table is NOT created, even if create_temp_table=True
+    # When the SqlAlchemyBatchData object is based on a table, a new temp table is NOT created, even if create_temp_table=True  # noqa: E501 # FIXME CoP
     SqlAlchemyBatchData(
         execution_engine=execution_engine,
         table_name="test_table",
         create_temp_table=True,
     )
-    assert len(get_sqlite_temp_table_names(sqlite_view_engine)) == 1
+    assert len(get_sqlite_temp_table_names_from_engine(sqlite_view_engine)) == 1
 
     selectable = sa.select("*").select_from(sa.text("main.test_table"))
 
@@ -99,7 +103,7 @@ def test_instantiation_with_and_without_temp_table(sqlite_view_engine, sa):
         selectable=selectable,
         create_temp_table=False,
     )
-    assert len(get_sqlite_temp_table_names(sqlite_view_engine)) == 1
+    assert len(get_sqlite_temp_table_names_from_engine(sqlite_view_engine)) == 1
 
     # If create_temp_table=True, a new temp table should be created
     SqlAlchemyBatchData(
@@ -107,7 +111,7 @@ def test_instantiation_with_and_without_temp_table(sqlite_view_engine, sa):
         selectable=selectable,
         create_temp_table=True,
     )
-    assert len(get_sqlite_temp_table_names(sqlite_view_engine)) == 2
+    assert len(get_sqlite_temp_table_names_from_engine(sqlite_view_engine)) == 2
 
     # If create_temp_table=True, a new temp table should be created
     SqlAlchemyBatchData(
@@ -115,7 +119,7 @@ def test_instantiation_with_and_without_temp_table(sqlite_view_engine, sa):
         selectable=selectable,
         # create_temp_table defaults to True
     )
-    assert len(get_sqlite_temp_table_names(sqlite_view_engine)) == 3
+    assert len(get_sqlite_temp_table_names_from_engine(sqlite_view_engine)) == 3
 
     # testing whether schema is supported
     selectable = sa.select("*").select_from(sa.table(name="test_table", schema="main"))
@@ -124,10 +128,10 @@ def test_instantiation_with_and_without_temp_table(sqlite_view_engine, sa):
         selectable=selectable,
         # create_temp_table defaults to True
     )
-    assert len(get_sqlite_temp_table_names(sqlite_view_engine)) == 4
+    assert len(get_sqlite_temp_table_names_from_engine(sqlite_view_engine)) == 4
 
     # test schema with execution engine
-    # TODO : Will20210222 Add tests for specifying schema with non-sqlite backend that actually supports new schema creation
+    # TODO : Will20210222 Add tests for specifying schema with non-sqlite backend that actually supports new schema creation  # noqa: E501 # FIXME CoP
     my_batch_spec = SqlAlchemyDatasourceBatchSpec(
         **{
             "table_name": "test_table",
@@ -139,7 +143,7 @@ def test_instantiation_with_and_without_temp_table(sqlite_view_engine, sa):
     assert len(res) == 2
 
 
-@pytest.mark.unit
+@pytest.mark.sqlite
 def test_instantiation_with_unknown_dialect(sqlite_view_engine):
     execution_engine: SqlAlchemyExecutionEngine = SqlAlchemyExecutionEngine(
         engine=sqlite_view_engine
@@ -153,28 +157,70 @@ def test_instantiation_with_unknown_dialect(sqlite_view_engine):
     assert batch_data.dialect == GXSqlDialect.OTHER
 
 
-@pytest.mark.unit
+@pytest.mark.sqlite
 def test_instantiation_with_temp_table_schema():
-    engine = Mock(spec=["dialect", "execute"])
-    execution_engine = Mock(spec=SqlAlchemyExecutionEngine, engine=engine)
-
     # not supported
-    engine.dialect.name = "sqlite"
-    SqlAlchemyBatchData(
+    engine = MockSaEngine(dialect=Dialect(dialect="sqlite"))
+    execution_engine = Mock(spec=SqlAlchemyExecutionEngine, engine=engine)
+    batch_data = SqlAlchemyBatchData(
         execution_engine=execution_engine,
         query="test_query",
         create_temp_table=True,
         temp_table_schema_name="test_schema",
     )
-    assert "test_schema" not in engine.execute.call_args[0][0]
+    (query_to_create_temp_table, _temp_table_name) = batch_data._create_temporary_table(
+        dialect=GXSqlDialect.SQLITE,
+        query="test_query",
+        temp_table_schema_name="test_schema",
+    )
+    assert "test_schema" not in query_to_create_temp_table
 
     # supported
     for dialect in ["bigquery", "snowflake", "vertica"]:
         engine.dialect.name = dialect
-        SqlAlchemyBatchData(
+        batch_data = SqlAlchemyBatchData(
             execution_engine=execution_engine,
             query="test_query",
             create_temp_table=True,
             temp_table_schema_name="test_schema",
         )
-        assert "test_schema" in engine.execute.call_args[0][0]
+        (
+            query_to_create_temp_table,
+            _temp_table_name,
+        ) = batch_data._create_temporary_table(
+            dialect=GXSqlDialect.SQLITE,
+            query="test_query",
+            temp_table_schema_name="test_schema",
+        )
+        assert "test_schema" in query_to_create_temp_table
+
+
+@pytest.mark.sqlite
+def test_instantiation_with_selectable_only_and_no_temp_table(sqlite_view_engine, sa):
+    """
+    What does this test and why?
+
+    In cases where we create a validator but explicitly set `create_temp_table`=False, we directly use the
+    selectable created by SqlAlchemyExecutionEngine's _build_selectable_from_batch_spec() method.
+    """  # noqa: E501 # FIXME CoP
+
+    selectable = sa.select("*").select_from(sa.text("main.test_table"))
+    # only have the view that is created by the `sqlite_view_engine` fixture
+    assert len(get_sqlite_temp_table_names_from_engine(sqlite_view_engine)) == 1
+
+    execution_engine: SqlAlchemyExecutionEngine = SqlAlchemyExecutionEngine(
+        engine=sqlite_view_engine
+    )
+    SqlAlchemyBatchData(
+        execution_engine=execution_engine,
+        selectable=selectable,
+        create_temp_table=False,
+    )
+    # No new views were created
+    assert len(get_sqlite_temp_table_names_from_engine(sqlite_view_engine)) == 1
+
+    SqlAlchemyBatchData(
+        execution_engine=execution_engine, selectable=selectable, create_temp_table=True
+    )
+    # One new temp_table was created
+    assert len(get_sqlite_temp_table_names_from_engine(sqlite_view_engine)) == 2
