@@ -1,29 +1,32 @@
 import pandas as pd
 import pytest
 
+import great_expectations.expectations as gxe
+from great_expectations.compatibility import sqlalchemy
+from great_expectations.compatibility.pydantic import ValidationError
+from great_expectations.compatibility.sqlalchemy_compatibility_wrappers import (
+    add_dataframe_to_db,
+)
 from great_expectations.core import (
-    ExpectationConfiguration,
     ExpectationValidationResult,
     IDDict,
 )
-from great_expectations.core.batch import Batch, BatchDefinition, BatchRequest
-from great_expectations.core.batch_spec import SqlAlchemyDatasourceBatchSpec
+from great_expectations.core.batch import Batch, LegacyBatchDefinition
 from great_expectations.core.metric_function_types import (
     MetricPartialFunctionTypes,
     MetricPartialFunctionTypeSuffixes,
     SummarizationMetricNameSuffixes,
 )
-from great_expectations.core.util import convert_to_json_serializable
 from great_expectations.data_context import AbstractDataContext
 from great_expectations.data_context.util import file_relative_path
-from great_expectations.datasource import Datasource
-from great_expectations.datasource.data_connector import ConfiguredAssetSqlDataConnector
 from great_expectations.execution_engine import (
     PandasExecutionEngine,
     SparkDFExecutionEngine,
     SqlAlchemyExecutionEngine,
 )
-from great_expectations.expectations.core import ExpectColumnValuesToBeInSet
+from great_expectations.expectations.expectation_configuration import (
+    ExpectationConfiguration,
+)
 from great_expectations.expectations.metrics import (
     ColumnMax,
     ColumnValuesNonNull,
@@ -33,6 +36,7 @@ from great_expectations.expectations.metrics.map_metric_provider import (
     ColumnMapMetricProvider,
     MapMetricProvider,
 )
+from great_expectations.util import convert_to_json_serializable
 from great_expectations.validator.validation_graph import MetricConfiguration
 from great_expectations.validator.validator import Validator
 
@@ -40,14 +44,12 @@ from great_expectations.validator.validator import Validator
 @pytest.fixture
 def sqlite_table_for_unexpected_rows_with_index(
     test_backends,
-) -> "sqlalchemy.engine.Engine":  # noqa: F821
+) -> sqlalchemy.Engine:
     if "sqlite" in test_backends:
         try:
-            import sqlalchemy as sa
+            from great_expectations.compatibility.sqlalchemy import sqlalchemy as sa
 
-            sqlite_path = file_relative_path(
-                __file__, "../../test_sets/metrics_test.db"
-            )
+            sqlite_path = file_relative_path(__file__, "../../test_sets/metrics_test.db")
             sqlite_engine = sa.create_engine(f"sqlite:///{sqlite_path}")
             df = pd.DataFrame(
                 {
@@ -66,7 +68,8 @@ def sqlite_table_for_unexpected_rows_with_index(
             # use try-except block to ensure we don't keep modifying the database
             # adapted from https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_sql.html
             try:
-                df.to_sql(
+                add_dataframe_to_db(
+                    df=df,
                     name="animal_names",
                     con=sqlite_engine,
                     index=False,
@@ -107,7 +110,7 @@ def expected_evr_without_unexpected_rows():
             "partial_unexpected_list": ["giraffe", "lion", "zebra"],
             "unexpected_count": 3,
             "unexpected_index_list": [3, 4, 5],
-            "unexpected_index_query": [3, 4, 5],
+            "unexpected_index_query": "df.filter(items=[3, 4, 5], axis=0)",
             "unexpected_list": ["giraffe", "lion", "zebra"],
             "unexpected_percent": 50.0,
             "unexpected_percent_nonmissing": 50.0,
@@ -134,9 +137,9 @@ def _expecation_configuration_to_validation_result_pandas(
     Args:
         expectation_configuration (ExpectationConfiguration): configuration that is being tested
 
-    """
-    expectation = ExpectColumnValuesToBeInSet(expectation_configuration)
-    batch_definition = BatchDefinition(
+    """  # noqa: E501 # FIXME CoP
+    expectation = gxe.ExpectColumnValuesToBeInSet(**expectation_configuration.kwargs)
+    batch_definition = LegacyBatchDefinition(
         datasource_name="pandas_datasource",
         data_connector_name="runtime_data_connector",
         data_asset_name="my_asset",
@@ -155,7 +158,7 @@ def _expecation_configuration_to_validation_result_pandas(
             batch,
         ],
     )
-    result = expectation.validate(validator)
+    result = expectation.validate_(validator)
     return result
 
 
@@ -170,71 +173,31 @@ def _expecation_configuration_to_validation_result_sql(
     Args:
         expectation_configuration (ExpectationConfiguration): configuration that is being tested
 
-    """
-    expectation = ExpectColumnValuesToBeInSet(expectation_configuration)
+    """  # noqa: E501 # FIXME CoP
+    expectation = gxe.ExpectColumnValuesToBeInSet(**expectation_configuration.kwargs)
     sqlite_path = file_relative_path(__file__, "../../test_sets/metrics_test.db")
     connection_string = f"sqlite:///{sqlite_path}"
     engine = SqlAlchemyExecutionEngine(
         connection_string=connection_string,
         create_temp_table=False,
     )
-    execution_engine = engine
-    my_data_connector: ConfiguredAssetSqlDataConnector = (
-        ConfiguredAssetSqlDataConnector(
-            name="my_sql_data_connector",
-            datasource_name="my_test_datasource",
-            execution_engine=execution_engine,
-            assets={
-                "my_asset": {
-                    "table_name": "animal_names",
-                },
-            },
-        )
+    datasource = context.data_sources.add_sqlite(
+        "my_test_datasource", connection_string=connection_string
     )
-
-    context.datasources["my_test_datasource"] = Datasource(
-        name="my_test_datasource",
-        execution_engine=execution_engine.config,
-        data_connectors={
-            "my_sql_data_connector": {
-                "class_name": "ConfiguredAssetSqlDataConnector",
-                "assets": {
-                    "my_asset": {
-                        "table_name": "animal_names",
-                    },
-                },
-            },
-        },
-    )
-
-    batch_definition_list = (
-        my_data_connector.get_batch_definition_list_from_batch_request(
-            batch_request=BatchRequest(
-                datasource_name="my_test_datasource",
-                data_connector_name="my_sql_data_connector",
-                data_asset_name="my_asset",
-            )
-        )
-    )
-    assert len(batch_definition_list) == 1
-    batch_spec: SqlAlchemyDatasourceBatchSpec = my_data_connector.build_batch_spec(
-        batch_definition=batch_definition_list[0]
-    )
-    batch_data, batch_markers = execution_engine.get_batch_data_and_markers(
-        batch_spec=batch_spec
-    )
-    batch = Batch(data=batch_data, batch_definition=batch_definition_list[0])
+    asset = datasource.add_table_asset("my_asset", table_name="animal_names")
+    batch_definition = asset.add_batch_definition_whole_table("all of it")
     validator = Validator(
         execution_engine=engine,
         data_context=context,
         batches=[
-            batch,
+            batch_definition.get_batch(),
         ],
     )
-    result = expectation.validate(validator)
+    result = expectation.validate_(validator)
     return result
 
 
+@pytest.mark.sqlite
 def test_get_table_metric_provider_metric_dependencies(empty_sqlite_db):
     mp = ColumnMax()
     metric = MetricConfiguration(
@@ -252,9 +215,7 @@ def test_get_table_metric_provider_metric_dependencies(empty_sqlite_db):
     metric = MetricConfiguration(
         metric_name="column.max", metric_domain_kwargs={}, metric_value_kwargs=None
     )
-    dependencies = mp.get_evaluation_dependencies(
-        metric, execution_engine=PandasExecutionEngine()
-    )
+    dependencies = mp.get_evaluation_dependencies(metric, execution_engine=PandasExecutionEngine())
 
     table_column_types_metric: MetricConfiguration = dependencies["table.column_types"]
     table_columns_metric: MetricConfiguration = dependencies["table.columns"]
@@ -271,6 +232,7 @@ def test_get_table_metric_provider_metric_dependencies(empty_sqlite_db):
     )
 
 
+@pytest.mark.spark
 def test_get_aggregate_count_aware_metric_dependencies(basic_spark_df_execution_engine):
     mp = ColumnValuesNonNull()
     metric = MetricConfiguration(
@@ -278,9 +240,7 @@ def test_get_aggregate_count_aware_metric_dependencies(basic_spark_df_execution_
         metric_domain_kwargs={},
         metric_value_kwargs=None,
     )
-    dependencies = mp.get_evaluation_dependencies(
-        metric, execution_engine=PandasExecutionEngine()
-    )
+    dependencies = mp.get_evaluation_dependencies(metric, execution_engine=PandasExecutionEngine())
     assert (
         dependencies["unexpected_condition"].id[0]
         == f"column_values.nonnull.{MetricPartialFunctionTypeSuffixes.CONDITION.value}"
@@ -296,7 +256,7 @@ def test_get_aggregate_count_aware_metric_dependencies(basic_spark_df_execution_
     )
     assert (
         dependencies["metric_partial_fn"].id[0]
-        == f"column_values.nonnull.{SummarizationMetricNameSuffixes.UNEXPECTED_COUNT.value}.{MetricPartialFunctionTypes.AGGREGATE_FN.metric_suffix}"
+        == f"column_values.nonnull.{SummarizationMetricNameSuffixes.UNEXPECTED_COUNT.value}.{MetricPartialFunctionTypes.AGGREGATE_FN.metric_suffix}"  # noqa: E501 # FIXME CoP
     )
 
     metric = MetricConfiguration(
@@ -311,6 +271,7 @@ def test_get_aggregate_count_aware_metric_dependencies(basic_spark_df_execution_
     )
 
 
+@pytest.mark.unit
 def test_get_map_metric_dependencies():
     mp = ColumnMapMetricProvider()
     metric = MetricConfiguration(
@@ -369,22 +330,34 @@ def test_get_map_metric_dependencies():
     )
 
 
+@pytest.mark.unit
 def test_is_sqlalchemy_metric_selectable():
-    assert MapMetricProvider.is_sqlalchemy_metric_selectable(
-        map_metric_provider=CompoundColumnsUnique
+    with pytest.warns(DeprecationWarning) as record:
+        assert MapMetricProvider.is_sqlalchemy_metric_selectable(
+            map_metric_provider=CompoundColumnsUnique
+        )
+
+    assert "MapMetricProvider.is_sqlalchemy_metric_selectable is deprecated." in str(
+        record.list[0].message
     )
 
-    assert not MapMetricProvider.is_sqlalchemy_metric_selectable(
-        map_metric_provider=ColumnValuesNonNull
+    with pytest.warns(DeprecationWarning) as record:
+        assert not MapMetricProvider.is_sqlalchemy_metric_selectable(
+            map_metric_provider=ColumnValuesNonNull
+        )
+
+    assert "MapMetricProvider.is_sqlalchemy_metric_selectable is deprecated." in str(
+        record.list[0].message
     )
 
 
+@pytest.mark.unit
 def test_pandas_unexpected_rows_basic_result_format(
     in_memory_runtime_context,
     pandas_animals_dataframe_for_unexpected_rows_and_index,
 ):
     expectation_configuration = ExpectationConfiguration(
-        expectation_type="expect_column_values_to_be_in_set",
+        type="expect_column_values_to_be_in_set",
         kwargs={
             "column": "animals",
             "mostly": 0.9,
@@ -395,12 +368,10 @@ def test_pandas_unexpected_rows_basic_result_format(
             },
         },
     )
-    result: ExpectationValidationResult = (
-        _expecation_configuration_to_validation_result_pandas(
-            expectation_configuration=expectation_configuration,
-            dataframe=pandas_animals_dataframe_for_unexpected_rows_and_index,
-            context=in_memory_runtime_context,
-        )
+    result: ExpectationValidationResult = _expecation_configuration_to_validation_result_pandas(
+        expectation_configuration=expectation_configuration,
+        dataframe=pandas_animals_dataframe_for_unexpected_rows_and_index,
+        context=in_memory_runtime_context,
     )
     assert convert_to_json_serializable(result.result) == {
         "element_count": 6,
@@ -419,28 +390,27 @@ def test_pandas_unexpected_rows_basic_result_format(
     }
 
 
+@pytest.mark.unit
 def test_pandas_unexpected_rows_summary_result_format_unexpected_rows_explicitly_false(
     in_memory_runtime_context,
     pandas_animals_dataframe_for_unexpected_rows_and_index,
 ):
     expectation_configuration = ExpectationConfiguration(
-        expectation_type="expect_column_values_to_be_in_set",
+        type="expect_column_values_to_be_in_set",
         kwargs={
             "column": "animals",
             "mostly": 0.9,
             "value_set": ["cat", "fish", "dog"],
             "result_format": {
                 "result_format": "SUMMARY",  # SUMMARY will include partial_unexpected* values only
-                "include_unexpected_rows": False,  # this is the default value, but making explicit for testing purposes
+                "include_unexpected_rows": False,  # this is the default value, but making explicit for testing purposes  # noqa: E501 # FIXME CoP
             },
         },
     )
-    result: ExpectationValidationResult = (
-        _expecation_configuration_to_validation_result_pandas(
-            expectation_configuration=expectation_configuration,
-            dataframe=pandas_animals_dataframe_for_unexpected_rows_and_index,
-            context=in_memory_runtime_context,
-        )
+    result: ExpectationValidationResult = _expecation_configuration_to_validation_result_pandas(
+        expectation_configuration=expectation_configuration,
+        dataframe=pandas_animals_dataframe_for_unexpected_rows_and_index,
+        context=in_memory_runtime_context,
     )
     assert convert_to_json_serializable(result.result) == {
         "element_count": 6,
@@ -460,12 +430,13 @@ def test_pandas_unexpected_rows_summary_result_format_unexpected_rows_explicitly
     }
 
 
+@pytest.mark.unit
 def test_pandas_unexpected_rows_summary_result_format_unexpected_rows_including_unexpected_rows(
     in_memory_runtime_context,
     pandas_animals_dataframe_for_unexpected_rows_and_index,
 ):
     expectation_configuration = ExpectationConfiguration(
-        expectation_type="expect_column_values_to_be_in_set",
+        type="expect_column_values_to_be_in_set",
         kwargs={
             "column": "animals",
             "mostly": 0.9,
@@ -476,12 +447,10 @@ def test_pandas_unexpected_rows_summary_result_format_unexpected_rows_including_
             },
         },
     )
-    result: ExpectationValidationResult = (
-        _expecation_configuration_to_validation_result_pandas(
-            expectation_configuration=expectation_configuration,
-            dataframe=pandas_animals_dataframe_for_unexpected_rows_and_index,
-            context=in_memory_runtime_context,
-        )
+    result: ExpectationValidationResult = _expecation_configuration_to_validation_result_pandas(
+        expectation_configuration=expectation_configuration,
+        dataframe=pandas_animals_dataframe_for_unexpected_rows_and_index,
+        context=in_memory_runtime_context,
     )
     assert convert_to_json_serializable(result.result) == {
         "element_count": 6,
@@ -506,12 +475,13 @@ def test_pandas_unexpected_rows_summary_result_format_unexpected_rows_including_
     }
 
 
+@pytest.mark.unit
 def test_pandas_unexpected_rows_complete_result_format(
     in_memory_runtime_context,
     pandas_animals_dataframe_for_unexpected_rows_and_index,
 ):
     expectation_configuration = ExpectationConfiguration(
-        expectation_type="expect_column_values_to_be_in_set",
+        type="expect_column_values_to_be_in_set",
         kwargs={
             "column": "animals",
             "value_set": ["cat", "fish", "dog"],
@@ -521,12 +491,10 @@ def test_pandas_unexpected_rows_complete_result_format(
             },
         },
     )
-    result: ExpectationValidationResult = (
-        _expecation_configuration_to_validation_result_pandas(
-            expectation_configuration=expectation_configuration,
-            dataframe=pandas_animals_dataframe_for_unexpected_rows_and_index,
-            context=in_memory_runtime_context,
-        )
+    result: ExpectationValidationResult = _expecation_configuration_to_validation_result_pandas(
+        expectation_configuration=expectation_configuration,
+        dataframe=pandas_animals_dataframe_for_unexpected_rows_and_index,
+        context=in_memory_runtime_context,
     )
     assert convert_to_json_serializable(result.result) == {
         "element_count": 6,
@@ -541,7 +509,7 @@ def test_pandas_unexpected_rows_complete_result_format(
         "partial_unexpected_list": ["giraffe", "lion", "zebra"],
         "unexpected_count": 3,
         "unexpected_index_list": [3, 4, 5],
-        "unexpected_index_query": [3, 4, 5],
+        "unexpected_index_query": "df.filter(items=[3, 4, 5], axis=0)",
         "unexpected_list": ["giraffe", "lion", "zebra"],
         "unexpected_percent": 50.0,
         "unexpected_percent_nonmissing": 50.0,
@@ -554,12 +522,13 @@ def test_pandas_unexpected_rows_complete_result_format(
     }
 
 
+@pytest.mark.unit
 def test_expectation_configuration_has_result_format(
     in_memory_runtime_context,
     pandas_animals_dataframe_for_unexpected_rows_and_index: pd.DataFrame,
 ):
     expectation_configuration = ExpectationConfiguration(
-        expectation_type="expect_column_values_to_be_in_set",
+        type="expect_column_values_to_be_in_set",
         kwargs={
             "column": "animals",
             "value_set": ["cat", "fish", "dog"],
@@ -569,7 +538,7 @@ def test_expectation_configuration_has_result_format(
         },
     )
     with pytest.warns(UserWarning) as config_warning:
-        result: ExpectationValidationResult = (
+        result: ExpectationValidationResult = (  # noqa: F841 # FIXME CoP
             _expecation_configuration_to_validation_result_pandas(
                 expectation_configuration=expectation_configuration,
                 dataframe=pandas_animals_dataframe_for_unexpected_rows_and_index,
@@ -577,18 +546,18 @@ def test_expectation_configuration_has_result_format(
             )
         )
 
-    assert (
-        "`result_format` configured at the Expectation-level will not be persisted."
-        in str(config_warning.list[0].message)
+    assert "`result_format` configured at the Expectation-level will not be persisted." in str(
+        config_warning.list[0].message
     )
 
 
+@pytest.mark.unit
 def test_pandas_default_complete_result_format(
     in_memory_runtime_context,
     pandas_animals_dataframe_for_unexpected_rows_and_index: pd.DataFrame,
 ):
     expectation_configuration = ExpectationConfiguration(
-        expectation_type="expect_column_values_to_be_in_set",
+        type="expect_column_values_to_be_in_set",
         kwargs={
             "column": "animals",
             "value_set": ["cat", "fish", "dog"],
@@ -597,12 +566,10 @@ def test_pandas_default_complete_result_format(
             },
         },
     )
-    result: ExpectationValidationResult = (
-        _expecation_configuration_to_validation_result_pandas(
-            expectation_configuration=expectation_configuration,
-            dataframe=pandas_animals_dataframe_for_unexpected_rows_and_index,
-            context=in_memory_runtime_context,
-        )
+    result: ExpectationValidationResult = _expecation_configuration_to_validation_result_pandas(
+        expectation_configuration=expectation_configuration,
+        dataframe=pandas_animals_dataframe_for_unexpected_rows_and_index,
+        context=in_memory_runtime_context,
     )
     assert convert_to_json_serializable(result.result) == {
         "element_count": 6,
@@ -617,7 +584,7 @@ def test_pandas_default_complete_result_format(
         "partial_unexpected_list": ["giraffe", "lion", "zebra"],
         "unexpected_count": 3,
         "unexpected_index_list": [3, 4, 5],
-        "unexpected_index_query": [3, 4, 5],
+        "unexpected_index_query": "df.filter(items=[3, 4, 5], axis=0)",
         "unexpected_list": ["giraffe", "lion", "zebra"],
         "unexpected_percent": 50.0,
         "unexpected_percent_nonmissing": 50.0,
@@ -625,12 +592,13 @@ def test_pandas_default_complete_result_format(
     }
 
 
+@pytest.mark.unit
 def test_pandas_unexpected_rows_complete_result_format_with_id_pk(
     in_memory_runtime_context,
     pandas_animals_dataframe_for_unexpected_rows_and_index: pd.DataFrame,
 ):
     expectation_configuration = ExpectationConfiguration(
-        expectation_type="expect_column_values_to_be_in_set",
+        type="expect_column_values_to_be_in_set",
         kwargs={
             "column": "animals",
             "value_set": ["cat", "fish", "dog"],
@@ -642,12 +610,10 @@ def test_pandas_unexpected_rows_complete_result_format_with_id_pk(
     )
     # result_format configuration at ExpectationConfiguration-level will emit warning
     with pytest.warns(UserWarning):
-        result: ExpectationValidationResult = (
-            _expecation_configuration_to_validation_result_pandas(
-                expectation_configuration=expectation_configuration,
-                dataframe=pandas_animals_dataframe_for_unexpected_rows_and_index,
-                context=in_memory_runtime_context,
-            )
+        result: ExpectationValidationResult = _expecation_configuration_to_validation_result_pandas(
+            expectation_configuration=expectation_configuration,
+            dataframe=pandas_animals_dataframe_for_unexpected_rows_and_index,
+            context=in_memory_runtime_context,
         )
     assert convert_to_json_serializable(result.result) == {
         "element_count": 6,
@@ -671,7 +637,7 @@ def test_pandas_unexpected_rows_complete_result_format_with_id_pk(
             {"animals": "lion", "pk_1": 4},
             {"animals": "zebra", "pk_1": 5},
         ],
-        "unexpected_index_query": [3, 4, 5],
+        "unexpected_index_query": "df.filter(items=[3, 4, 5], axis=0)",
         "unexpected_list": ["giraffe", "lion", "zebra"],
         "unexpected_percent": 50.0,
         "unexpected_percent_nonmissing": 50.0,
@@ -679,13 +645,14 @@ def test_pandas_unexpected_rows_complete_result_format_with_id_pk(
     }
 
 
+@pytest.mark.unit
 def test_pandas_default_to_not_include_unexpected_rows(
     in_memory_runtime_context,
     pandas_animals_dataframe_for_unexpected_rows_and_index,
     expected_evr_without_unexpected_rows,
 ):
     expectation_configuration = ExpectationConfiguration(
-        expectation_type="expect_column_values_to_be_in_set",
+        type="expect_column_values_to_be_in_set",
         kwargs={
             "column": "animals",
             "value_set": ["cat", "fish", "dog"],
@@ -694,23 +661,22 @@ def test_pandas_default_to_not_include_unexpected_rows(
             },
         },
     )
-    result: ExpectationValidationResult = (
-        _expecation_configuration_to_validation_result_pandas(
-            expectation_configuration=expectation_configuration,
-            dataframe=pandas_animals_dataframe_for_unexpected_rows_and_index,
-            context=in_memory_runtime_context,
-        )
+    result: ExpectationValidationResult = _expecation_configuration_to_validation_result_pandas(
+        expectation_configuration=expectation_configuration,
+        dataframe=pandas_animals_dataframe_for_unexpected_rows_and_index,
+        context=in_memory_runtime_context,
     )
     assert result.result == expected_evr_without_unexpected_rows.result
 
 
+@pytest.mark.unit
 def test_pandas_specify_not_include_unexpected_rows(
     in_memory_runtime_context,
     pandas_animals_dataframe_for_unexpected_rows_and_index,
     expected_evr_without_unexpected_rows,
 ):
     expectation_configuration = ExpectationConfiguration(
-        expectation_type="expect_column_values_to_be_in_set",
+        type="expect_column_values_to_be_in_set",
         kwargs={
             "column": "animals",
             "value_set": ["cat", "fish", "dog"],
@@ -720,22 +686,18 @@ def test_pandas_specify_not_include_unexpected_rows(
             },
         },
     )
-    result: ExpectationValidationResult = (
-        _expecation_configuration_to_validation_result_pandas(
-            expectation_configuration=expectation_configuration,
-            dataframe=pandas_animals_dataframe_for_unexpected_rows_and_index,
-            context=in_memory_runtime_context,
-        )
+    result: ExpectationValidationResult = _expecation_configuration_to_validation_result_pandas(
+        expectation_configuration=expectation_configuration,
+        dataframe=pandas_animals_dataframe_for_unexpected_rows_and_index,
+        context=in_memory_runtime_context,
     )
     assert result.result == expected_evr_without_unexpected_rows.result
 
 
-def test_include_unexpected_rows_without_explicit_result_format_raises_error(
-    in_memory_runtime_context,
-    pandas_animals_dataframe_for_unexpected_rows_and_index,
-):
+@pytest.mark.unit
+def test_include_unexpected_rows_without_explicit_result_format_raises_error():
     expectation_configuration = ExpectationConfiguration(
-        expectation_type="expect_column_values_to_be_in_set",
+        type="expect_column_values_to_be_in_set",
         kwargs={
             "column": "animals",
             "value_set": ["cat", "fish", "dog"],
@@ -745,37 +707,18 @@ def test_include_unexpected_rows_without_explicit_result_format_raises_error(
         },
     )
 
-    expectation = ExpectColumnValuesToBeInSet(expectation_configuration)
-    batch_definition = BatchDefinition(
-        datasource_name="pandas_datasource",
-        data_connector_name="runtime_data_connector",
-        data_asset_name="my_asset",
-        batch_identifiers=IDDict({}),
-        batch_spec_passthrough=None,
-    )
-    batch = Batch(
-        data=pandas_animals_dataframe_for_unexpected_rows_and_index,
-        batch_definition=batch_definition,
-    )
-    engine = PandasExecutionEngine()
-    validator = Validator(
-        execution_engine=engine,
-        data_context=in_memory_runtime_context,
-        batches=[
-            batch,
-        ],
-    )
-    with pytest.raises(ValueError):
-        expectation.validate(validator)
+    with pytest.raises(ValidationError):
+        gxe.ExpectColumnValuesToBeInSet(**expectation_configuration.kwargs)
 
 
 # Spark
+@pytest.mark.spark
 def test_spark_single_column_complete_result_format(
     in_memory_runtime_context,
     spark_dataframe_for_unexpected_rows_with_index,
 ):
     expectation_configuration = ExpectationConfiguration(
-        expectation_type="expect_column_values_to_be_in_set",
+        type="expect_column_values_to_be_in_set",
         kwargs={
             "column": "animals",
             "value_set": ["cat", "fish", "dog"],
@@ -784,8 +727,8 @@ def test_spark_single_column_complete_result_format(
             },
         },
     )
-    expectation = ExpectColumnValuesToBeInSet(expectation_configuration)
-    batch_definition = BatchDefinition(
+    expectation = gxe.ExpectColumnValuesToBeInSet(**expectation_configuration.kwargs)
+    batch_definition = LegacyBatchDefinition(
         datasource_name="spark_datasource",
         data_connector_name="runtime_data_connector",
         data_asset_name="my_asset",
@@ -804,7 +747,7 @@ def test_spark_single_column_complete_result_format(
             batch,
         ],
     )
-    result = expectation.validate(validator)
+    result = expectation.validate_(validator)
     assert convert_to_json_serializable(result.result) == {
         "element_count": 6,
         "missing_count": 0,
@@ -825,12 +768,13 @@ def test_spark_single_column_complete_result_format(
     }
 
 
+@pytest.mark.spark
 def test_spark_single_column_complete_result_format_with_id_pk(
     in_memory_runtime_context,
     spark_dataframe_for_unexpected_rows_with_index,
 ):
     expectation_configuration = ExpectationConfiguration(
-        expectation_type="expect_column_values_to_be_in_set",
+        type="expect_column_values_to_be_in_set",
         kwargs={
             "column": "animals",
             "value_set": ["cat", "fish", "dog"],
@@ -840,8 +784,8 @@ def test_spark_single_column_complete_result_format_with_id_pk(
             },
         },
     )
-    expectation = ExpectColumnValuesToBeInSet(expectation_configuration)
-    batch_definition = BatchDefinition(
+    expectation = gxe.ExpectColumnValuesToBeInSet(**expectation_configuration.kwargs)
+    batch_definition = LegacyBatchDefinition(
         datasource_name="spark_datasource",
         data_connector_name="runtime_data_connector",
         data_asset_name="my_asset",
@@ -863,7 +807,7 @@ def test_spark_single_column_complete_result_format_with_id_pk(
 
     # result_format configuration at ExpectationConfiguration-level will emit warning
     with pytest.warns(UserWarning):
-        result = expectation.validate(validator)
+        result = expectation.validate_(validator)
 
     assert convert_to_json_serializable(result.result) == {
         "element_count": 6,
@@ -896,12 +840,13 @@ def test_spark_single_column_complete_result_format_with_id_pk(
     }
 
 
+@pytest.mark.spark
 def test_spark_single_column_summary_result_format(
     in_memory_runtime_context,
     spark_dataframe_for_unexpected_rows_with_index,
 ):
     expectation_configuration = ExpectationConfiguration(
-        expectation_type="expect_column_values_to_be_in_set",
+        type="expect_column_values_to_be_in_set",
         kwargs={
             "column": "animals",
             "value_set": ["cat", "fish", "dog"],
@@ -910,8 +855,8 @@ def test_spark_single_column_summary_result_format(
             },
         },
     )
-    expectation = ExpectColumnValuesToBeInSet(expectation_configuration)
-    batch_definition = BatchDefinition(
+    expectation = gxe.ExpectColumnValuesToBeInSet(**expectation_configuration.kwargs)
+    batch_definition = LegacyBatchDefinition(
         datasource_name="spark_datasource",
         data_connector_name="runtime_data_connector",
         data_asset_name="my_asset",
@@ -930,7 +875,7 @@ def test_spark_single_column_summary_result_format(
             batch,
         ],
     )
-    result = expectation.validate(validator)
+    result = expectation.validate_(validator)
     assert convert_to_json_serializable(result.result) == {
         "element_count": 6,
         "missing_count": 0,
@@ -948,12 +893,13 @@ def test_spark_single_column_summary_result_format(
     }
 
 
+@pytest.mark.spark
 def test_spark_single_column_basic_result_format(
     in_memory_runtime_context,
     spark_dataframe_for_unexpected_rows_with_index,
 ):
     expectation_configuration = ExpectationConfiguration(
-        expectation_type="expect_column_values_to_be_in_set",
+        type="expect_column_values_to_be_in_set",
         kwargs={
             "column": "animals",
             "value_set": ["cat", "fish", "dog"],
@@ -962,8 +908,8 @@ def test_spark_single_column_basic_result_format(
             },
         },
     )
-    expectation = ExpectColumnValuesToBeInSet(expectation_configuration)
-    batch_definition = BatchDefinition(
+    expectation = gxe.ExpectColumnValuesToBeInSet(**expectation_configuration.kwargs)
+    batch_definition = LegacyBatchDefinition(
         datasource_name="spark_datasource",
         data_connector_name="runtime_data_connector",
         data_asset_name="my_asset",
@@ -982,7 +928,7 @@ def test_spark_single_column_basic_result_format(
             batch,
         ],
     )
-    result = expectation.validate(validator)
+    result = expectation.validate_(validator)
     assert convert_to_json_serializable(result.result) == {
         "element_count": 6,
         "missing_count": 0,
@@ -995,13 +941,14 @@ def test_spark_single_column_basic_result_format(
     }
 
 
+@pytest.mark.sqlite
 def test_sqlite_single_column_complete_result_format(
     sa,
     in_memory_runtime_context,
     sqlite_table_for_unexpected_rows_with_index,
 ):
     expectation_configuration = ExpectationConfiguration(
-        expectation_type="expect_column_values_to_be_in_set",
+        type="expect_column_values_to_be_in_set",
         kwargs={
             "column": "animals",
             "value_set": ["cat", "fish", "dog"],
@@ -1010,11 +957,9 @@ def test_sqlite_single_column_complete_result_format(
             },
         },
     )
-    result: ExpectationValidationResult = (
-        _expecation_configuration_to_validation_result_sql(
-            expectation_configuration=expectation_configuration,
-            context=in_memory_runtime_context,
-        )
+    result: ExpectationValidationResult = _expecation_configuration_to_validation_result_sql(
+        expectation_configuration=expectation_configuration,
+        context=in_memory_runtime_context,
     )
     assert convert_to_json_serializable(result.result) == {
         "element_count": 6,
@@ -1038,13 +983,14 @@ def test_sqlite_single_column_complete_result_format(
     }
 
 
+@pytest.mark.sqlite
 def test_sqlite_single_column_complete_result_format_id_pk(
     sa,
     in_memory_runtime_context,
     sqlite_table_for_unexpected_rows_with_index,
 ):
     expectation_configuration = ExpectationConfiguration(
-        expectation_type="expect_column_values_to_be_in_set",
+        type="expect_column_values_to_be_in_set",
         kwargs={
             "column": "animals",
             "value_set": ["cat", "fish", "dog"],
@@ -1057,11 +1003,9 @@ def test_sqlite_single_column_complete_result_format_id_pk(
 
     # result_format configuration at ExpectationConfiguration-level will emit warning
     with pytest.warns(UserWarning):
-        result: ExpectationValidationResult = (
-            _expecation_configuration_to_validation_result_sql(
-                expectation_configuration=expectation_configuration,
-                context=in_memory_runtime_context,
-            )
+        result: ExpectationValidationResult = _expecation_configuration_to_validation_result_sql(
+            expectation_configuration=expectation_configuration,
+            context=in_memory_runtime_context,
         )
     assert convert_to_json_serializable(result.result) == {
         "element_count": 6,
@@ -1096,11 +1040,12 @@ def test_sqlite_single_column_complete_result_format_id_pk(
     }
 
 
+@pytest.mark.sqlite
 def test_sqlite_single_column_summary_result_format(
     sa, in_memory_runtime_context, sqlite_table_for_unexpected_rows_with_index
 ):
     expectation_configuration = ExpectationConfiguration(
-        expectation_type="expect_column_values_to_be_in_set",
+        type="expect_column_values_to_be_in_set",
         kwargs={
             "column": "animals",
             "value_set": ["cat", "fish", "dog"],
@@ -1109,11 +1054,9 @@ def test_sqlite_single_column_summary_result_format(
             },
         },
     )
-    result: ExpectationValidationResult = (
-        _expecation_configuration_to_validation_result_sql(
-            expectation_configuration=expectation_configuration,
-            context=in_memory_runtime_context,
-        )
+    result: ExpectationValidationResult = _expecation_configuration_to_validation_result_sql(
+        expectation_configuration=expectation_configuration,
+        context=in_memory_runtime_context,
     )
     assert convert_to_json_serializable(result.result) == {
         "element_count": 6,
@@ -1132,11 +1075,12 @@ def test_sqlite_single_column_summary_result_format(
     }
 
 
+@pytest.mark.sqlite
 def test_sqlite_single_column_basic_result_format(
     sa, in_memory_runtime_context, sqlite_table_for_unexpected_rows_with_index
 ):
     expectation_configuration = ExpectationConfiguration(
-        expectation_type="expect_column_values_to_be_in_set",
+        type="expect_column_values_to_be_in_set",
         kwargs={
             "column": "animals",
             "value_set": ["cat", "fish", "dog"],
@@ -1145,11 +1089,9 @@ def test_sqlite_single_column_basic_result_format(
             },
         },
     )
-    result: ExpectationValidationResult = (
-        _expecation_configuration_to_validation_result_sql(
-            expectation_configuration=expectation_configuration,
-            context=in_memory_runtime_context,
-        )
+    result: ExpectationValidationResult = _expecation_configuration_to_validation_result_sql(
+        expectation_configuration=expectation_configuration,
+        context=in_memory_runtime_context,
     )
     assert convert_to_json_serializable(result.result) == {
         "element_count": 6,
