@@ -1,11 +1,16 @@
+from __future__ import annotations
+
 import logging
 from typing import Dict, List, cast
 
 import pandas as pd
 import pytest
 
+from great_expectations.compatibility import sqlalchemy
+from great_expectations.compatibility.sqlalchemy import (
+    sqlalchemy as sa,
+)
 from great_expectations.core import (
-    ExpectationConfiguration,
     ExpectationValidationResult,
 )
 from great_expectations.core.expectation_diagnostics.expectation_test_data_cases import (
@@ -23,42 +28,31 @@ from great_expectations.execution_engine import (
     SqlAlchemyExecutionEngine,
 )
 from great_expectations.expectations.expectation import (
-    render_evaluation_parameter_string,
+    render_suite_parameter_string,
+)
+from great_expectations.expectations.expectation_configuration import (
+    ExpectationConfiguration,
 )
 from great_expectations.expectations.metrics.util import column_reflection_fallback
 from great_expectations.render import RenderedStringTemplateContent
-from great_expectations.self_check.util import build_sa_validator_with_data
-from great_expectations.self_check.util import (
-    build_test_backends_list as build_test_backends_list_v3,
-)
 from great_expectations.self_check.util import (
+    build_sa_validator_with_data,
     generate_expectation_tests,
     generate_test_table_name,
     should_we_generate_this_test,
 )
+from great_expectations.self_check.util import (
+    build_test_backends_list as build_test_backends_list_v3,
+)
 from great_expectations.validator.metric_configuration import MetricConfiguration
 from great_expectations.validator.validator import Validator
 
 logger = logging.getLogger(__name__)
 
-try:
-    import sqlalchemy as sqlalchemy
-    from sqlalchemy import create_engine
 
-    # noinspection PyProtectedMember
-    from sqlalchemy.engine import Engine
-    from sqlalchemy.exc import SQLAlchemyError
-    from sqlalchemy.sql import Select
-except ImportError:
-    sqlalchemy = None
-    create_engine = None
-    Engine = None
-    Select = None
-    SQLAlchemyError = None
-    logger.debug("Unable to load SqlAlchemy or one of its subclasses.")
-
-
-def get_table_columns_metric(engine: ExecutionEngine) -> [MetricConfiguration, dict]:
+def get_table_columns_metric(
+    execution_engine: ExecutionEngine,
+) -> tuple[MetricConfiguration, dict]:
     resolved_metrics: dict = {}
 
     results: dict
@@ -70,7 +64,7 @@ def get_table_columns_metric(engine: ExecutionEngine) -> [MetricConfiguration, d
             "include_nested": True,
         },
     )
-    results = engine.resolve_metrics(metrics_to_resolve=(table_column_types_metric,))
+    results = execution_engine.resolve_metrics(metrics_to_resolve=(table_column_types_metric,))
     resolved_metrics.update(results)
 
     table_columns_metric: MetricConfiguration = MetricConfiguration(
@@ -81,7 +75,7 @@ def get_table_columns_metric(engine: ExecutionEngine) -> [MetricConfiguration, d
     table_columns_metric.metric_dependencies = {
         "table.column_types": table_column_types_metric,
     }
-    results = engine.resolve_metrics(
+    results = execution_engine.resolve_metrics(
         metrics_to_resolve=(table_columns_metric,), metrics=resolved_metrics
     )
     resolved_metrics.update(results)
@@ -90,9 +84,9 @@ def get_table_columns_metric(engine: ExecutionEngine) -> [MetricConfiguration, d
 
 
 @pytest.fixture(scope="module")
-def expectation_and_runtime_configuration_with_evaluation_parameters():
+def expectation_and_runtime_configuration_with_suite_parameters():
     configuration = ExpectationConfiguration(
-        expectation_type="expect_column_min_to_be_between",
+        type="expect_column_min_to_be_between",
         kwargs={
             "column": "live",
             "min_value": {"$PARAMETER": "MIN_VAL_PARAM"},
@@ -101,25 +95,26 @@ def expectation_and_runtime_configuration_with_evaluation_parameters():
         },
         meta={"BasicDatasetProfiler": {"confidence": "very low"}},
     )
-    # runtime configuration with evaluation_parameters loaded
+    # runtime configuration with suite_parameters loaded
     runtime_configuration_with_eval = {
         "styling": {
             "default": {"classes": ["badge", "badge-secondary"]},
             "params": {"column": {"classes": ["badge", "badge-primary"]}},
         },
         "include_column_name": None,
-        "evaluation_parameters": {"MIN_VAL_PARAM": 15, "MAX_VAL_PARAM": 20},
+        "suite_parameters": {"MIN_VAL_PARAM": 15, "MAX_VAL_PARAM": 20},
     }
     return configuration, runtime_configuration_with_eval
 
 
+@pytest.mark.unit
 def test_prescriptive_renderer_no_decorator(
-    expectation_and_runtime_configuration_with_evaluation_parameters,
+    expectation_and_runtime_configuration_with_suite_parameters,
 ):
     (
         configuration,
         runtime_configuration_with_eval,
-    ) = expectation_and_runtime_configuration_with_evaluation_parameters
+    ) = expectation_and_runtime_configuration_with_suite_parameters
 
     # noinspection PyShadowingNames
     def bare_bones_prescriptive_renderer(
@@ -129,7 +124,7 @@ def test_prescriptive_renderer_no_decorator(
         runtime_configuration = runtime_configuration or {}
         styling = runtime_configuration.get("styling")
         params = configuration.kwargs
-        template_str = "$column minimum value must be greater than or equal to $min_value and less than or equal to $max_value"
+        template_str = "$column minimum value must be greater than or equal to $min_value and less than or equal to $max_value"  # noqa: E501 # FIXME CoP
         return [
             RenderedStringTemplateContent(
                 **{
@@ -151,22 +146,18 @@ def test_prescriptive_renderer_no_decorator(
     # string template should remain constant
     assert (
         res[0].string_template["template"]
-        == "$column minimum value must be greater than or equal to $min_value and less than or equal to $max_value"
+        == "$column minimum value must be greater than or equal to $min_value and less than or equal to $max_value"  # noqa: E501 # FIXME CoP
     )
 
-    # params should contain our evaluation parameters
-    assert res[0].string_template["params"]["min_value"] == {
-        "$PARAMETER": "MIN_VAL_PARAM"
-    }
-    assert res[0].string_template["params"]["max_value"] == {
-        "$PARAMETER": "MAX_VAL_PARAM"
-    }
+    # params should contain our suite parameters
+    assert res[0].string_template["params"]["min_value"] == {"$PARAMETER": "MIN_VAL_PARAM"}
+    assert res[0].string_template["params"]["max_value"] == {"$PARAMETER": "MAX_VAL_PARAM"}
 
     # full json dict comparison
     assert res[0].to_json_dict() == {
         "content_block_type": "string_template",
         "string_template": {
-            "template": "$column minimum value must be greater than or equal to $min_value and less than or equal to $max_value",
+            "template": "$column minimum value must be greater than or equal to $min_value and less than or equal to $max_value",  # noqa: E501 # FIXME CoP
             "params": {
                 "column": "live",
                 "min_value": {"$PARAMETER": "MIN_VAL_PARAM"},
@@ -181,16 +172,17 @@ def test_prescriptive_renderer_no_decorator(
     }
 
 
+@pytest.mark.big
 def test_prescriptive_renderer_with_decorator(
-    expectation_and_runtime_configuration_with_evaluation_parameters,
+    expectation_and_runtime_configuration_with_suite_parameters,
 ):
     (
         configuration,
         runtime_configuration_with_eval,
-    ) = expectation_and_runtime_configuration_with_evaluation_parameters
+    ) = expectation_and_runtime_configuration_with_suite_parameters
 
     # noinspection PyShadowingNames
-    @render_evaluation_parameter_string
+    @render_suite_parameter_string
     def bare_bones_prescriptive_renderer(
         configuration=None,
         runtime_configuration=None,
@@ -198,7 +190,7 @@ def test_prescriptive_renderer_with_decorator(
         runtime_configuration = runtime_configuration or {}
         styling = runtime_configuration.get("styling")
         params = configuration.kwargs
-        template_str = "$column minimum value must be greater than or equal to $min_value and less than or equal to $max_value"
+        template_str = "$column minimum value must be greater than or equal to $min_value and less than or equal to $max_value"  # noqa: E501 # FIXME CoP
         return [
             RenderedStringTemplateContent(
                 **{
@@ -221,20 +213,16 @@ def test_prescriptive_renderer_with_decorator(
     # string template should remain constant
     assert (
         res[0].string_template["template"]
-        == "$column minimum value must be greater than or equal to $min_value and less than or equal to $max_value"
+        == "$column minimum value must be greater than or equal to $min_value and less than or equal to $max_value"  # noqa: E501 # FIXME CoP
     )
 
-    # params should contain our evaluation parameters
-    assert res[0].string_template["params"]["min_value"] == {
-        "$PARAMETER": "MIN_VAL_PARAM"
-    }
-    assert res[0].string_template["params"]["max_value"] == {
-        "$PARAMETER": "MAX_VAL_PARAM"
-    }
+    # params should contain our suite parameters
+    assert res[0].string_template["params"]["min_value"] == {"$PARAMETER": "MIN_VAL_PARAM"}
+    assert res[0].string_template["params"]["max_value"] == {"$PARAMETER": "MAX_VAL_PARAM"}
     assert res[0].to_json_dict() == {
         "content_block_type": "string_template",
         "string_template": {
-            "template": "$column minimum value must be greater than or equal to $min_value and less than or equal to $max_value",
+            "template": "$column minimum value must be greater than or equal to $min_value and less than or equal to $max_value",  # noqa: E501 # FIXME CoP
             "params": {
                 "column": "live",
                 "min_value": {"$PARAMETER": "MIN_VAL_PARAM"},
@@ -252,7 +240,7 @@ def test_prescriptive_renderer_with_decorator(
         res[1].string_template["template"]
         == "\n - $eval_param = $eval_param_value (at time of validation)."
     )
-    # params should contain our evaluation parameters
+    # params should contain our suite parameters
     assert res[1].string_template["params"]["eval_param"] == "MIN_VAL_PARAM"
     assert res[1].string_template["params"]["eval_param_value"] == 15
     assert res[1].to_json_dict() == {
@@ -271,7 +259,7 @@ def test_prescriptive_renderer_with_decorator(
         res[2].string_template["template"]
         == "\n - $eval_param = $eval_param_value (at time of validation)."
     )
-    # params should contain our evaluation parameters
+    # params should contain our suite parameters
     assert res[2].string_template["params"]["eval_param"] == "MAX_VAL_PARAM"
     assert res[2].string_template["params"]["eval_param_value"] == 20
     assert res[2].to_json_dict() == {
@@ -296,18 +284,16 @@ def test_prescriptive_renderer_with_decorator(
     # configuration should always be of ExpectationConfiguration-type
     with pytest.raises(AttributeError):
         # noinspection PyUnusedLocal,PyTypeChecker
-        res = bare_bones_prescriptive_renderer(
-            configuration={}, runtime_configuration={}
-        )
+        res = bare_bones_prescriptive_renderer(configuration={}, runtime_configuration={})
 
-    # extra evaluation parameters will not have an effect
+    # extra suite parameters will not have an effect
     runtime_configuration_with_extra = {
         "styling": {
             "default": {"classes": ["badge", "badge-secondary"]},
             "params": {"column": {"classes": ["badge", "badge-primary"]}},
         },
         "include_column_name": None,
-        "evaluation_parameters": {
+        "suite_parameters": {
             "MIN_VAL_PARAM": 15,
             "MAX_VAL_PARAM": 20,
             "IAMEXTRA": "EXTRA",
@@ -320,14 +306,14 @@ def test_prescriptive_renderer_with_decorator(
     )
     assert len(res) == 3
 
-    # missing evaluation_parameters will not render (MAX_VAL_PARAM is missing)
+    # missing suite_parameters will not render (MAX_VAL_PARAM is missing)
     runtime_configuration_with_missing = {
         "styling": {
             "default": {"classes": ["badge", "badge-secondary"]},
             "params": {"column": {"classes": ["badge", "badge-primary"]}},
         },
         "include_column_name": None,
-        "evaluation_parameters": {"MIN_VAL_PARAM": 15},
+        "suite_parameters": {"MIN_VAL_PARAM": 15},
     }
     res = bare_bones_prescriptive_renderer(
         configuration=configuration,
@@ -337,6 +323,7 @@ def test_prescriptive_renderer_with_decorator(
 
 
 # noinspection PyUnusedLocal
+@pytest.mark.all_backends
 def test_table_column_reflection_fallback(test_backends, sa):
     include_sqlalchemy: bool = "sqlite" in test_backends
     include_postgresql: bool = "postgresql" in test_backends
@@ -344,8 +331,9 @@ def test_table_column_reflection_fallback(test_backends, sa):
     include_mssql: bool = "mssql" in test_backends
     include_bigquery: bool = "bigquery" in test_backends
     include_trino: bool = "trino" in test_backends
+    include_clickhouse: bool = "clickhouse" in test_backends
 
-    if not create_engine:
+    if not sa.create_engine:
         pytest.skip("Unable to import sqlalchemy.create_engine() -- skipping.")
 
     test_backend_names: List[str] = build_test_backends_list_v3(
@@ -357,6 +345,7 @@ def test_table_column_reflection_fallback(test_backends, sa):
         include_mssql=include_mssql,
         include_bigquery=include_bigquery,
         include_trino=include_trino,
+        include_clickhouse=include_clickhouse,
     )
 
     df: pd.DataFrame = pd.DataFrame(
@@ -385,7 +374,7 @@ def test_table_column_reflection_fallback(test_backends, sa):
             if validator is not None:
                 validators_config[table_name] = validator
 
-    engine: Engine
+    engine: sqlalchemy.Engine
 
     metrics: dict = {}
 
@@ -402,24 +391,23 @@ def test_table_column_reflection_fallback(test_backends, sa):
 
     for table_name, validator in validators_config.items():
         table_columns_metric, results = get_table_columns_metric(
-            engine=validator.execution_engine
+            execution_engine=validator.execution_engine
         )
         metrics.update(results)
         assert set(metrics[table_columns_metric.id]) == {"name", "age", "pet"}
-        selectable: Select = sqlalchemy.Table(
+        selectable: sqlalchemy.Select = sa.Table(
             table_name,
-            sqlalchemy.MetaData(),
+            sa.MetaData(),
             schema=None,
         )
-        sqlalchemy_engine = cast(SqlAlchemyExecutionEngine, validator.execution_engine)
+        sqlalchemy_engine = cast("SqlAlchemyExecutionEngine", validator.execution_engine)
         reflected_columns_list = column_reflection_fallback(
             selectable=selectable,
             dialect=sqlalchemy_engine.engine.dialect,
             sqlalchemy_engine=sqlalchemy_engine.engine,
         )
         for column_name in [
-            reflected_column_config["name"]
-            for reflected_column_config in reflected_columns_list
+            reflected_column_config["name"] for reflected_column_config in reflected_columns_list
         ]:
             validation_result = validator.expect_column_to_exist(column=column_name)
             assert validation_result.success
@@ -427,9 +415,7 @@ def test_table_column_reflection_fallback(test_backends, sa):
     if validators_config:
         validator = list(validators_config.values())[0]
 
-        validation_result = validator.expect_column_mean_to_be_between(
-            column="age", min_value=10
-        )
+        validation_result = validator.expect_column_mean_to_be_between(column="age", min_value=10)
         assert validation_result.success
 
         validation_result = validator.expect_table_row_count_to_equal(value=5)
@@ -439,110 +425,15 @@ def test_table_column_reflection_fallback(test_backends, sa):
         assert not validation_result.success
 
 
-@pytest.mark.skipif(
-    sqlalchemy is None,
-    reason="sqlalchemy is not installed",
-)
-def test__generate_expectation_tests__with_test_backends():
-    expectation_type = "whatever"
-    data = TestData(stuff=[1, 2, 3, 4, 5])
-    test_case = ExpectationTestCase(
-        title="",
-        input={},
-        output={},
-        exact_match_out=False,
-        include_in_gallery=False,
-        suppress_test_for=[],
-        only_for=[],
-    )
-    test_backends = [
-        TestBackend(
-            backend="sqlalchemy",
-            dialects=["sqlite"],
-        ),
-    ]
-    test_data_cases = [
-        ExpectationTestDataCases(
-            data=data,
-            tests=[test_case],
-            test_backends=test_backends,
-        )
-    ]
-    engines = ExpectationExecutionEngineDiagnostics(
-        PandasExecutionEngine=True,
-        SqlAlchemyExecutionEngine=True,
-        SparkDFExecutionEngine=False,
-    )
-
-    results = generate_expectation_tests(
-        expectation_type=expectation_type,
-        test_data_cases=test_data_cases,
-        execution_engine_diagnostics=engines,
-        raise_exceptions_for_backends=False,
-    )
-    backends_to_use = [r["backend"] for r in results]
-    assert backends_to_use == ["sqlite"] or backends_to_use == []
-
-
-@pytest.mark.skipif(
-    sqlalchemy is None,
-    reason="sqlalchemy is not installed",
-)
-def test__generate_expectation_tests__with_test_backends2():
-    expectation_type = "whatever"
-    data = TestData(stuff=[1, 2, 3, 4, 5])
-    test_case = ExpectationTestCase(
-        title="",
-        input={},
-        output={},
-        exact_match_out=False,
-        include_in_gallery=False,
-        suppress_test_for=[],
-        only_for=[],
-    )
-    test_backends = [
-        TestBackend(
-            backend="sqlalchemy",
-            dialects=["sqlite"],
-        ),
-        TestBackend(
-            backend="pandas",
-            dialects=None,
-        ),
-    ]
-    test_data_cases = [
-        ExpectationTestDataCases(
-            data=data,
-            tests=[test_case],
-            test_backends=test_backends,
-        )
-    ]
-    engines = ExpectationExecutionEngineDiagnostics(
-        PandasExecutionEngine=True,
-        SqlAlchemyExecutionEngine=True,
-        SparkDFExecutionEngine=False,
-    )
-
-    results = generate_expectation_tests(
-        expectation_type=expectation_type,
-        test_data_cases=test_data_cases,
-        execution_engine_diagnostics=engines,
-        raise_exceptions_for_backends=False,
-    )
-    backends_to_use = [r["backend"] for r in results]
-    assert sorted(backends_to_use) == ["pandas", "sqlite"] or backends_to_use == [
-        "pandas"
-    ]
-
-
 @pytest.mark.skip(
     reason="Timeout of 30 seconds reached trying to connect to localhost:8088 (trino port)"
 )
 @pytest.mark.skipif(
-    sqlalchemy is None,
+    sa is None,
     reason="sqlalchemy is not installed",
 )
-def test__generate_expectation_tests__with_no_test_backends():
+@pytest.mark.all_backends
+def test__generate_expectation_tests():
     expectation_type = "whatever"
     data = TestData(stuff=[1, 2, 3, 4, 5])
     test_case = ExpectationTestCase(
@@ -581,6 +472,7 @@ def test__generate_expectation_tests__with_no_test_backends():
     assert "spark" not in backends_to_use
 
 
+@pytest.mark.unit
 def test__TestBackend__bad_backends():
     with pytest.raises(AssertionError):
         TestBackend(
@@ -589,6 +481,7 @@ def test__TestBackend__bad_backends():
         )
 
 
+@pytest.mark.unit
 def test__TestBackend__bad_dialects():
     with pytest.raises(AssertionError):
         TestBackend(
@@ -632,23 +525,25 @@ def test__TestBackend__bad_dialects():
     )
 
 
+@pytest.mark.unit
 def test__TestBackend__good_backends_and_dialects():
-    tb1 = TestBackend(
+    tb1 = TestBackend(  # noqa: F841 # FIXME CoP
         backend="pandas",
         dialects=None,
     )
 
-    tb2 = TestBackend(
+    tb2 = TestBackend(  # noqa: F841 # FIXME CoP
         backend="spark",
         dialects=None,
     )
 
-    tb3 = TestBackend(
+    tb3 = TestBackend(  # noqa: F841 # FIXME CoP
         backend="sqlalchemy",
         dialects=["sqlite", "postgresql", "mysql"],
     )
 
 
+@pytest.mark.unit
 def test__should_we_generate_this_test__obvious():
     test_case = ExpectationTestCase(
         title="",
@@ -661,7 +556,7 @@ def test__should_we_generate_this_test__obvious():
     )
     backend = "spark"
 
-    assert should_we_generate_this_test(backend, test_case) == True
+    assert should_we_generate_this_test(backend, test_case) is True
 
     test_case2 = ExpectationTestCase(
         title="",
@@ -674,7 +569,7 @@ def test__should_we_generate_this_test__obvious():
     )
     backend2 = "sqlite"
 
-    assert should_we_generate_this_test(backend2, test_case2) == False
+    assert should_we_generate_this_test(backend2, test_case2) is False
 
     test_case3 = ExpectationTestCase(
         title="",
@@ -687,7 +582,7 @@ def test__should_we_generate_this_test__obvious():
     )
     backend3 = "sqlite"
 
-    assert should_we_generate_this_test(backend3, test_case3) == True
+    assert should_we_generate_this_test(backend3, test_case3) is True
 
     test_case4 = ExpectationTestCase(
         title="",
@@ -700,7 +595,7 @@ def test__should_we_generate_this_test__obvious():
     )
     backend4 = "sqlite"
 
-    assert should_we_generate_this_test(backend4, test_case4) == False
+    assert should_we_generate_this_test(backend4, test_case4) is False
 
     test_case5 = ExpectationTestCase(
         title="",
@@ -713,9 +608,11 @@ def test__should_we_generate_this_test__obvious():
     )
     backend5 = "pandas"
 
-    assert should_we_generate_this_test(backend5, test_case5) == True
+    assert should_we_generate_this_test(backend5, test_case5) is True
 
 
+# this is really a series of unit tests
+@pytest.mark.unit
 def test__should_we_generate_this_test__sqlalchemy():
     test_case = ExpectationTestCase(
         title="",
@@ -728,7 +625,7 @@ def test__should_we_generate_this_test__sqlalchemy():
     )
     backend = "mysql"
 
-    assert should_we_generate_this_test(backend, test_case) == True
+    assert should_we_generate_this_test(backend, test_case) is True
 
     test_case2 = ExpectationTestCase(
         title="",
@@ -741,7 +638,7 @@ def test__should_we_generate_this_test__sqlalchemy():
     )
     backend2 = "postgresql"
 
-    assert should_we_generate_this_test(backend2, test_case2) == True
+    assert should_we_generate_this_test(backend2, test_case2) is True
 
     test_case3 = ExpectationTestCase(
         title="",
@@ -754,7 +651,7 @@ def test__should_we_generate_this_test__sqlalchemy():
     )
     backend3 = "mysql"
 
-    assert should_we_generate_this_test(backend3, test_case3) == False
+    assert should_we_generate_this_test(backend3, test_case3) is False
 
     test_case4 = ExpectationTestCase(
         title="",
@@ -767,7 +664,7 @@ def test__should_we_generate_this_test__sqlalchemy():
     )
     backend4 = "sqlite"
 
-    assert should_we_generate_this_test(backend4, test_case4) == False
+    assert should_we_generate_this_test(backend4, test_case4) is False
 
     test_case5 = ExpectationTestCase(
         title="",
@@ -780,9 +677,10 @@ def test__should_we_generate_this_test__sqlalchemy():
     )
     backend5 = "spark"
 
-    assert should_we_generate_this_test(backend5, test_case5) == True
+    assert should_we_generate_this_test(backend5, test_case5) is True
 
 
+@pytest.mark.unit
 def test__should_we_generate_this_test__pandas():
     """
     Our CI/CD runs tests against pandas versions 0.23.4, 0.25.3, and latest (1.x currently)
@@ -802,7 +700,7 @@ def test__should_we_generate_this_test__pandas():
     )
     backend = "pandas"
 
-    assert should_we_generate_this_test(backend, test_case) == True
+    assert should_we_generate_this_test(backend, test_case) is True
 
     test_case2 = ExpectationTestCase(
         title="",
@@ -815,7 +713,7 @@ def test__should_we_generate_this_test__pandas():
     )
     backend2 = "pandas"
 
-    assert should_we_generate_this_test(backend2, test_case2) == True
+    assert should_we_generate_this_test(backend2, test_case2) is True
 
     test_case3 = ExpectationTestCase(
         title="",
@@ -862,4 +760,4 @@ def test__should_we_generate_this_test__pandas():
     )
     backend5 = "pandas"
 
-    assert should_we_generate_this_test(backend5, test_case5) == False
+    assert should_we_generate_this_test(backend5, test_case5) is False
