@@ -2,11 +2,13 @@ from typing import List
 
 import pytest
 
-from great_expectations.core.expectation_configuration import ExpectationConfiguration
 from great_expectations.core.expectation_suite import ExpectationSuite
 from great_expectations.core.expectation_validation_result import (
     ExpectationValidationResult,
 )
+from great_expectations.expectations.expectation_configuration import (
+    ExpectationConfiguration,
+)
 from great_expectations.render import (
     AtomicDiagnosticRendererType,
     AtomicPrescriptiveRendererType,
@@ -16,6 +18,9 @@ from great_expectations.render.exceptions import InlineRendererError
 from great_expectations.render.renderer.inline_renderer import InlineRenderer
 from great_expectations.render.renderer_configuration import MetaNotesFormat
 
+# module level markers
+pytestmark = pytest.mark.unit
+
 
 def clean_serialized_rendered_atomic_content_graphs(
     serialized_rendered_atomic_content: List[dict],
@@ -29,26 +34,24 @@ def clean_serialized_rendered_atomic_content_graphs(
     return serialized_rendered_atomic_content
 
 
-@pytest.mark.unit
 def test_inline_renderer_instantiation_error_message(
     basic_expectation_suite: ExpectationSuite,
 ):
     expectation_suite: ExpectationSuite = basic_expectation_suite
     with pytest.raises(InlineRendererError) as e:
-        InlineRenderer(render_object=expectation_suite)  # type: ignore
+        InlineRenderer(render_object=expectation_suite)  # type: ignore # FIXME CoP
     assert (
         str(e.value)
-        == "InlineRenderer can only be used with an ExpectationConfiguration or ExpectationValidationResult, but <class 'great_expectations.core.expectation_suite.ExpectationSuite'> was used."
+        == "InlineRenderer can only be used with an ExpectationConfiguration or ExpectationValidationResult, but <class 'great_expectations.core.expectation_suite.ExpectationSuite'> was used."  # noqa: E501 # FIXME CoP
     )
 
 
-@pytest.mark.unit
 @pytest.mark.parametrize(
     "expectation_configuration,fake_result,expected_serialized_expectation_validation_result_rendered_atomic_content",
     [
         pytest.param(
             ExpectationConfiguration(
-                expectation_type="expect_table_row_count_to_equal",
+                type="expect_table_row_count_to_equal",
                 kwargs={"value": 3},
             ),
             {"observed_value": 3},
@@ -56,9 +59,9 @@ def test_inline_renderer_instantiation_error_message(
                 {
                     "name": AtomicDiagnosticRendererType.OBSERVED_VALUE,
                     "value": {
-                        "params": {},
+                        "params": {"observed_value": {"schema": {"type": "number"}, "value": 3}},
                         "schema": {"type": "com.superconductive.rendered.string"},
-                        "template": "3",
+                        "template": "$observed_value",
                     },
                     "value_type": "StringValueType",
                 },
@@ -78,7 +81,7 @@ def test_inline_renderer_instantiation_error_message(
         ),
         pytest.param(
             ExpectationConfiguration(
-                expectation_type="expect_column_min_to_be_between",
+                type="expect_column_min_to_be_between",
                 kwargs={"column": "event_type", "min_value": 3, "max_value": 20},
             ),
             {"observed_value": 19},
@@ -86,9 +89,9 @@ def test_inline_renderer_instantiation_error_message(
                 {
                     "name": AtomicDiagnosticRendererType.OBSERVED_VALUE,
                     "value": {
-                        "params": {},
+                        "params": {"observed_value": {"schema": {"type": "number"}, "value": 19}},
                         "schema": {"type": "com.superconductive.rendered.string"},
-                        "template": "19",
+                        "template": "$observed_value",
                     },
                     "value_type": "StringValueType",
                 },
@@ -114,7 +117,7 @@ def test_inline_renderer_instantiation_error_message(
         ),
         pytest.param(
             ExpectationConfiguration(
-                expectation_type="expect_column_quantile_values_to_be_between",
+                type="expect_column_quantile_values_to_be_between",
                 kwargs={
                     "column": "user_id",
                     "quantile_ranges": {
@@ -207,7 +210,7 @@ def test_inline_renderer_instantiation_error_message(
         ),
         pytest.param(
             ExpectationConfiguration(
-                expectation_type="expect_column_values_to_be_in_set",
+                type="expect_column_values_to_be_in_set",
                 kwargs={"column": "event_type", "value_set": [19, 22, 73]},
             ),
             {
@@ -224,9 +227,14 @@ def test_inline_renderer_instantiation_error_message(
                 {
                     "name": AtomicDiagnosticRendererType.OBSERVED_VALUE,
                     "value": {
-                        "params": {},
+                        "params": {
+                            "observed_value": {
+                                "schema": {"type": "string"},
+                                "value": "0% unexpected",
+                            }
+                        },
                         "schema": {"type": "com.superconductive.rendered.string"},
-                        "template": "0% unexpected",
+                        "template": "$observed_value",
                     },
                     "value_type": "StringValueType",
                 },
@@ -247,8 +255,7 @@ def test_inline_renderer_instantiation_error_message(
                             },
                         },
                         "schema": {"type": "com.superconductive.rendered.string"},
-                        "template": "$column values must belong to this set: $v__0 $v__1 "
-                        "$v__2.",
+                        "template": "$column values must belong to this set: $v__0 $v__1 $v__2.",
                     },
                     "value_type": "StringValueType",
                 },
@@ -257,7 +264,7 @@ def test_inline_renderer_instantiation_error_message(
         ),
         pytest.param(
             ExpectationConfiguration(
-                expectation_type="expect_column_kl_divergence_to_be_less_than",
+                type="expect_column_kl_divergence_to_be_less_than",
                 kwargs={
                     "column": "user_id",
                     "partition_object": {
@@ -377,7 +384,6 @@ def test_inline_renderer_expectation_validation_result_serialization(
     fake_result: dict,
     expected_serialized_expectation_validation_result_rendered_atomic_content: dict,
 ):
-
     expectation_validation_result = ExpectationValidationResult(
         exception_info={
             "raised_exception": False,
@@ -389,21 +395,19 @@ def test_inline_renderer_expectation_validation_result_serialization(
         success=True,
     )
 
-    inline_renderer: InlineRenderer = InlineRenderer(
-        render_object=expectation_validation_result
+    inline_renderer: InlineRenderer = InlineRenderer(render_object=expectation_validation_result)
+
+    expectation_validation_result_rendered_atomic_content: List[RenderedAtomicContent] = (
+        inline_renderer.get_rendered_content()
     )
 
-    expectation_validation_result_rendered_atomic_content: List[
-        RenderedAtomicContent
-    ] = inline_renderer.get_rendered_content()
-
-    actual_serialized_expectation_validation_result_rendered_atomic_content: List[
-        dict
-    ] = clean_serialized_rendered_atomic_content_graphs(
-        serialized_rendered_atomic_content=[
-            rendered_atomic_content.to_json_dict()
-            for rendered_atomic_content in expectation_validation_result_rendered_atomic_content
-        ]
+    actual_serialized_expectation_validation_result_rendered_atomic_content: List[dict] = (
+        clean_serialized_rendered_atomic_content_graphs(
+            serialized_rendered_atomic_content=[
+                rendered_atomic_content.to_json_dict()
+                for rendered_atomic_content in expectation_validation_result_rendered_atomic_content
+            ]
+        )
     )
 
     assert (
@@ -412,13 +416,12 @@ def test_inline_renderer_expectation_validation_result_serialization(
     )
 
 
-@pytest.mark.unit
 @pytest.mark.parametrize(
     "expectation_configuration,expected_serialized_expectation_configuration_rendered_atomic_content",
     [
         pytest.param(
             ExpectationConfiguration(
-                expectation_type="expect_table_row_count_to_equal",
+                type="expect_table_row_count_to_equal",
                 kwargs={"value": 3},
             ),
             [
@@ -438,7 +441,7 @@ def test_inline_renderer_expectation_validation_result_serialization(
         ),
         pytest.param(
             ExpectationConfiguration(
-                expectation_type="expect_column_min_to_be_between",
+                type="expect_column_min_to_be_between",
                 kwargs={"column": "event_type", "min_value": 3, "max_value": 20},
             ),
             [
@@ -464,7 +467,7 @@ def test_inline_renderer_expectation_validation_result_serialization(
         ),
         pytest.param(
             ExpectationConfiguration(
-                expectation_type="expect_column_quantile_values_to_be_between",
+                type="expect_column_quantile_values_to_be_between",
                 kwargs={
                     "column": "user_id",
                     "quantile_ranges": {
@@ -525,7 +528,7 @@ def test_inline_renderer_expectation_validation_result_serialization(
         ),
         pytest.param(
             ExpectationConfiguration(
-                expectation_type="expect_column_values_to_be_in_set",
+                type="expect_column_values_to_be_in_set",
                 kwargs={"column": "event_type", "value_set": [19, 22, 73]},
             ),
             [
@@ -546,8 +549,7 @@ def test_inline_renderer_expectation_validation_result_serialization(
                             },
                         },
                         "schema": {"type": "com.superconductive.rendered.string"},
-                        "template": "$column values must belong to this set: $v__0 $v__1 "
-                        "$v__2.",
+                        "template": "$column values must belong to this set: $v__0 $v__1 $v__2.",
                     },
                     "value_type": "StringValueType",
                 }
@@ -556,7 +558,7 @@ def test_inline_renderer_expectation_validation_result_serialization(
         ),
         pytest.param(
             ExpectationConfiguration(
-                expectation_type="expect_column_kl_divergence_to_be_less_than",
+                type="expect_column_kl_divergence_to_be_less_than",
                 kwargs={
                     "column": "user_id",
                     "partition_object": {
@@ -613,7 +615,7 @@ def test_inline_renderer_expectation_validation_result_serialization(
         ),
         pytest.param(
             ExpectationConfiguration(
-                expectation_type="expect_table_row_count_to_equal",
+                type="expect_table_row_count_to_equal",
                 kwargs={"value": 3},
                 meta={
                     "notes": {
@@ -639,7 +641,143 @@ def test_inline_renderer_expectation_validation_result_serialization(
                     },
                 }
             ],
-            id="meta_notes",
+            id="meta_notes content list",
+        ),
+        pytest.param(
+            ExpectationConfiguration(
+                type="expect_table_row_count_to_equal",
+                kwargs={"value": 3},
+                meta={
+                    "notes": {
+                        "format": MetaNotesFormat.STRING,
+                        "content": "This is the most important Expectation!!",
+                    }
+                },
+            ),
+            [
+                {
+                    "value_type": "StringValueType",
+                    "name": AtomicPrescriptiveRendererType.SUMMARY,
+                    "value": {
+                        "template": "Must have exactly $value rows.",
+                        "schema": {"type": "com.superconductive.rendered.string"},
+                        "params": {
+                            "value": {"schema": {"type": "number"}, "value": 3},
+                        },
+                        "meta_notes": {
+                            "content": ["This is the most important Expectation!!"],
+                            "format": MetaNotesFormat.STRING,
+                        },
+                    },
+                }
+            ],
+            id="meta_notes content string",
+        ),
+        pytest.param(
+            ExpectationConfiguration(
+                type="expect_table_row_count_to_equal",
+                kwargs={"value": 3},
+                meta={
+                    "notes": "This is the most important Expectation!!",
+                },
+            ),
+            [
+                {
+                    "value_type": "StringValueType",
+                    "name": AtomicPrescriptiveRendererType.SUMMARY,
+                    "value": {
+                        "template": "Must have exactly $value rows.",
+                        "schema": {"type": "com.superconductive.rendered.string"},
+                        "params": {
+                            "value": {"schema": {"type": "number"}, "value": 3},
+                        },
+                        "meta_notes": {
+                            "content": ["This is the most important Expectation!!"],
+                            "format": MetaNotesFormat.STRING,
+                        },
+                    },
+                }
+            ],
+            id="meta_notes string",
+        ),
+        pytest.param(
+            ExpectationConfiguration(
+                type="expect_table_row_count_to_equal",
+                description="Row count must be equal to "
+                "the meaning of life, the universe, and everything.",
+                kwargs={"value": 42},
+            ),
+            [
+                {
+                    "value_type": "StringValueType",
+                    "name": AtomicPrescriptiveRendererType.SUMMARY,
+                    "value": {
+                        "template": "Row count must be equal to "
+                        "the meaning of life, the universe, and everything.",
+                        "schema": {"type": "com.superconductive.rendered.string"},
+                        "params": {
+                            "value": {"schema": {"type": "number"}, "value": 42},
+                        },
+                    },
+                }
+            ],
+            id="description",
+        ),
+        pytest.param(
+            ExpectationConfiguration(
+                type="expect_column_values_to_be_between",
+                kwargs={
+                    "column": "column_a",
+                    "min_value": 0,
+                    "max_value": 10,
+                    "row_condition": 'col("column_b")==5',
+                    "condition_parser": "great_expectations",
+                },
+            ),
+            [
+                {
+                    "value_type": "StringValueType",
+                    "name": AtomicPrescriptiveRendererType.SUMMARY,
+                    "value": {
+                        "template": "If "
+                        'col("$row_condition__0")$row_condition__1, '
+                        "then $column values must be greater than or equal to "
+                        "$min_value and less than or equal to $max_value.",
+                        "schema": {"type": "com.superconductive.rendered.string"},
+                        "params": {
+                            "column": {"schema": {"type": "string"}, "value": "column_a"},
+                            "min_value": {"schema": {"type": "number"}, "value": 0},
+                            "max_value": {"schema": {"type": "number"}, "value": 10},
+                            "row_condition__0": {"schema": {"type": "string"}, "value": "column_b"},
+                            "row_condition__1": {"schema": {"type": "string"}, "value": "==5"},
+                        },
+                    },
+                }
+            ],
+            id="row_condition",
+        ),
+        pytest.param(
+            ExpectationConfiguration(
+                type="expect_column_value_z_scores_to_be_less_than",
+                kwargs={"column": "column_a", "threshold": 4, "double_sided": True},
+            ),
+            [
+                {
+                    "name": "atomic.prescriptive.summary",
+                    "value": {
+                        "params": {
+                            "column": {"schema": {"type": "string"}, "value": "column_a"},
+                            "threshold": {"schema": {"type": "number"}, "value": 4},
+                            "inverse_threshold": {"schema": {"type": "number"}, "value": -4},
+                        },
+                        "schema": {"type": "com.superconductive.rendered.string"},
+                        "template": "$column value z-scores must be greater "
+                        "than $inverse_threshold and less than $threshold.",
+                    },
+                    "value_type": "StringValueType",
+                }
+            ],
+            id="z_score_double_sided",
         ),
     ],
 )
@@ -647,22 +785,19 @@ def test_inline_renderer_expectation_configuration_serialization(
     expectation_configuration: ExpectationConfiguration,
     expected_serialized_expectation_configuration_rendered_atomic_content: dict,
 ):
+    inline_renderer: InlineRenderer = InlineRenderer(render_object=expectation_configuration)
 
-    inline_renderer: InlineRenderer = InlineRenderer(
-        render_object=expectation_configuration
+    expectation_configuration_rendered_atomic_content: List[RenderedAtomicContent] = (
+        inline_renderer.get_rendered_content()
     )
 
-    expectation_configuration_rendered_atomic_content: List[
-        RenderedAtomicContent
-    ] = inline_renderer.get_rendered_content()
-
-    actual_serialized_expectation_configuration_rendered_atomic_content: List[
-        dict
-    ] = clean_serialized_rendered_atomic_content_graphs(
-        serialized_rendered_atomic_content=[
-            rendered_atomic_content.to_json_dict()
-            for rendered_atomic_content in expectation_configuration_rendered_atomic_content
-        ]
+    actual_serialized_expectation_configuration_rendered_atomic_content: List[dict] = (
+        clean_serialized_rendered_atomic_content_graphs(
+            serialized_rendered_atomic_content=[
+                rendered_atomic_content.to_json_dict()
+                for rendered_atomic_content in expectation_configuration_rendered_atomic_content
+            ]
+        )
     )
 
     assert (
