@@ -1,14 +1,10 @@
 import json
-import warnings
 from collections import OrderedDict
 
 import pytest
 
-import great_expectations as gx
-from great_expectations import DataContext
 from great_expectations.core import ExpectationSuite
 from great_expectations.data_context.util import file_relative_path
-from great_expectations.profile.basic_dataset_profiler import BasicDatasetProfiler
 from great_expectations.render.renderer import (
     ExpectationSuiteColumnSectionRenderer,
     ExpectationSuitePageRenderer,
@@ -20,19 +16,19 @@ from great_expectations.render.renderer import (
 from great_expectations.render.renderer.content_block import (
     ValidationResultsTableContentBlockRenderer,
 )
-from great_expectations.render.types import CollapseContent, RenderedContent
 from great_expectations.render.view import DefaultJinjaPageView
 from great_expectations.self_check.util import (
     expectationSuiteSchema,
     expectationSuiteValidationResultSchema,
 )
 
+# module level markers
+pytestmark = pytest.mark.big
+
 
 @pytest.fixture(scope="module")
 def titanic_profiler_evrs():
-    with open(
-        file_relative_path(__file__, "./fixtures/BasicDatasetProfiler_evrs.json")
-    ) as infile:
+    with open(file_relative_path(__file__, "./fixtures/BasicDatasetProfiler_evrs.json")) as infile:
         return expectationSuiteValidationResultSchema.load(
             json.load(infile, object_pairs_hook=OrderedDict)
         )
@@ -41,32 +37,24 @@ def titanic_profiler_evrs():
 @pytest.fixture(scope="module")
 def titanic_profiler_evrs_with_exception():
     with open(
-        file_relative_path(
-            __file__, "./fixtures/BasicDatasetProfiler_evrs_with_exception.json"
-        ),
+        file_relative_path(__file__, "./fixtures/BasicDatasetProfiler_evrs_with_exception.json"),
     ) as infile:
         return expectationSuiteValidationResultSchema.load(json.load(infile))
 
 
 @pytest.fixture(scope="module")
-def titanic_dataset_profiler_expectations(empty_data_context_module_scoped):
-    context: DataContext = empty_data_context_module_scoped
+def titanic_dataset_profiler_expectations():
     with open(
-        file_relative_path(
-            __file__, "./fixtures/BasicDatasetProfiler_expectations.json"
-        ),
+        file_relative_path(__file__, "./fixtures/BasicDatasetProfiler_expectations.json"),
     ) as infile:
         expectations_dict: dict = expectationSuiteSchema.load(
             json.load(fp=infile, object_pairs_hook=OrderedDict)
         )
-        return ExpectationSuite(**expectations_dict, data_context=context)
+        return ExpectationSuite(**expectations_dict)
 
 
 @pytest.fixture(scope="module")
-def titanic_dataset_profiler_expectations_with_distribution(
-    empty_data_context_module_scoped,
-):
-    context: DataContext = empty_data_context_module_scoped
+def titanic_dataset_profiler_expectations_with_distribution():
     with open(
         file_relative_path(
             __file__,
@@ -76,23 +64,18 @@ def titanic_dataset_profiler_expectations_with_distribution(
         expectations_dict: dict = expectationSuiteSchema.load(
             json.load(fp=infile, object_pairs_hook=OrderedDict)
         )
-        return ExpectationSuite(**expectations_dict, data_context=context)
+        return ExpectationSuite(**expectations_dict)
 
 
 @pytest.fixture
-def titanic_profiled_expectations_1(empty_data_context_stats_enabled):
-    context: DataContext = empty_data_context_stats_enabled
+def titanic_profiled_expectations_1():
     with open(
-        file_relative_path(
-            __file__, "./fixtures/BasicDatasetProfiler_expectations.json"
-        ),
+        file_relative_path(__file__, "./fixtures/BasicDatasetProfiler_expectations.json"),
     ) as infile:
         expectation_suite_dict: dict = expectationSuiteSchema.load(json.load(infile))
-        return ExpectationSuite(**expectation_suite_dict, data_context=context)
+        return ExpectationSuite(**expectation_suite_dict)
 
 
-@pytest.mark.smoketest
-@pytest.mark.rendered_output
 def test_smoke_render_profiling_results_page_renderer(titanic_profiled_evrs_1):
     rendered = ProfilingResultsPageRenderer().render(titanic_profiled_evrs_1)
     with open(
@@ -108,8 +91,6 @@ def test_smoke_render_profiling_results_page_renderer(titanic_profiled_evrs_1):
     assert len(rendered.sections) > 5
 
 
-@pytest.mark.smoketest
-@pytest.mark.rendered_output
 def test_render_profiling_results_column_section_renderer(titanic_profiled_evrs_1):
     # Group EVRs by column
     evrs = {}
@@ -122,7 +103,7 @@ def test_render_profiling_results_column_section_renderer(titanic_profiled_evrs_
         except KeyError:
             pass
 
-    for column in evrs.keys():
+    for column, evr in evrs.items():
         with open(
             file_relative_path(
                 __file__,
@@ -134,16 +115,12 @@ def test_render_profiling_results_column_section_renderer(titanic_profiled_evrs_
             "w",
         ) as outfile:
             json.dump(
-                ProfilingResultsColumnSectionRenderer()
-                .render(evrs[column])
-                .to_json_dict(),
+                ProfilingResultsColumnSectionRenderer().render(evr).to_json_dict(),
                 outfile,
                 indent=2,
             )
 
 
-@pytest.mark.smoketest
-@pytest.mark.rendered_output
 def test_smoke_render_validation_results_page_renderer(titanic_profiler_evrs):
     rendered = ValidationResultsPageRenderer().render(titanic_profiler_evrs)
     with open(
@@ -158,8 +135,6 @@ def test_smoke_render_validation_results_page_renderer(titanic_profiler_evrs):
     assert len(rendered.sections) > 5
 
 
-@pytest.mark.smoketest
-@pytest.mark.rendered_output
 def test_render_validation_results_column_section_renderer(titanic_profiler_evrs):
     # Group EVRs by column
     evrs = {}
@@ -172,7 +147,7 @@ def test_render_validation_results_column_section_renderer(titanic_profiler_evrs
         except KeyError:
             pass
 
-    for column in evrs.keys():
+    for column, evr in evrs.items():
         with open(
             file_relative_path(
                 __file__,
@@ -184,23 +159,18 @@ def test_render_validation_results_column_section_renderer(titanic_profiler_evrs
             "w",
         ) as outfile:
             json.dump(
-                ValidationResultsColumnSectionRenderer()
-                .render(evrs[column])
-                .to_json_dict(),
+                ValidationResultsColumnSectionRenderer().render(evr).to_json_dict(),
                 outfile,
                 indent=2,
             )
 
 
-@pytest.mark.smoketest
-@pytest.mark.rendered_output
 def test_render_expectation_suite_column_section_renderer(
     titanic_profiled_expectations_1,
 ):
     # Group expectations by column
     exp_groups = {}
-    # print(json.dumps(titanic_profiled_expectations_1, indent=2))
-    for exp in titanic_profiled_expectations_1.expectations:
+    for exp in titanic_profiled_expectations_1.expectation_configurations:
         try:
             column = exp.kwargs["column"]
             if column not in exp_groups:
@@ -209,21 +179,17 @@ def test_render_expectation_suite_column_section_renderer(
         except KeyError:
             pass
 
-    for column in exp_groups.keys():
+    for column, exp_group in exp_groups.items():
         with open(
             file_relative_path(
                 __file__,
-                "./output/test_render_expectation_suite_column_section_renderer"
-                + column
-                + ".json",
+                "./output/test_render_expectation_suite_column_section_renderer" + column + ".json",
                 strict=False,
             ),
             "w",
         ) as outfile:
             json.dump(
-                ExpectationSuiteColumnSectionRenderer()
-                .render(exp_groups[column])
-                .to_json_dict(),
+                ExpectationSuiteColumnSectionRenderer().render(exp_group).to_json_dict(),
                 outfile,
                 indent=2,
             )
@@ -276,24 +242,15 @@ def test_content_block_list_available_expectations():
         "expect_table_columns_to_match_set",
         "expect_table_row_count_to_be_between",
         "expect_table_row_count_to_equal",
-        "expect_column_pair_cramers_phi_value_to_be_less_than",
     }
-    assert known_validation_results_implemented_expectations <= set(
-        available_expectations
-    )
-    assert len(available_expectations) >= len(
-        known_validation_results_implemented_expectations
-    )
+    assert known_validation_results_implemented_expectations <= set(available_expectations)
+    assert len(available_expectations) >= len(known_validation_results_implemented_expectations)
 
 
-@pytest.mark.smoketest
-@pytest.mark.rendered_output
 def test_render_profiled_fixture_expectation_suite(
     titanic_dataset_profiler_expectations,
 ):
-    rendered_content = ExpectationSuitePageRenderer().render(
-        titanic_dataset_profiler_expectations
-    )
+    rendered_content = ExpectationSuitePageRenderer().render(titanic_dataset_profiler_expectations)
     rendered_page = DefaultJinjaPageView().render(rendered_content)
 
     with open(
@@ -310,8 +267,6 @@ def test_render_profiled_fixture_expectation_suite(
     assert rendered_page[-7:] == "</html>"
 
 
-@pytest.mark.smoketest
-@pytest.mark.rendered_output
 def test_render_profiled_fixture_expectation_suite_with_distribution(
     titanic_dataset_profiler_expectations_with_distribution,
 ):
@@ -335,16 +290,12 @@ def test_render_profiled_fixture_expectation_suite_with_distribution(
     assert rendered_page[-7:] == "</html>"
 
 
-@pytest.mark.smoketest
-@pytest.mark.rendered_output
 def test_render_profiling_results(titanic_profiled_evrs_1):
     rendered_content = ProfilingResultsPageRenderer().render(titanic_profiled_evrs_1)
     rendered_page = DefaultJinjaPageView().render(rendered_content)
 
     with open(
-        file_relative_path(
-            __file__, "./output/test_render_profiling_results.html", strict=False
-        ),
+        file_relative_path(__file__, "./output/test_render_profiling_results.html", strict=False),
         "wb",
     ) as f:
         f.write(rendered_page.encode("utf-8"))
@@ -353,16 +304,12 @@ def test_render_profiling_results(titanic_profiled_evrs_1):
     assert rendered_page[-7:] == "</html>"
 
 
-@pytest.mark.smoketest
-@pytest.mark.rendered_output
 def test_render_validation_results(titanic_profiled_evrs_1):
     rendered_content = ValidationResultsPageRenderer().render(titanic_profiled_evrs_1)
     rendered_page = DefaultJinjaPageView().render(rendered_content)
 
     with open(
-        file_relative_path(
-            __file__, "./output/test_render_validation_results.html", strict=False
-        ),
+        file_relative_path(__file__, "./output/test_render_validation_results.html", strict=False),
         "wb",
     ) as f:
         f.write(rendered_page.encode("utf-8"))
@@ -374,18 +321,14 @@ def test_render_validation_results(titanic_profiled_evrs_1):
         'Must have greater than or equal to <span class="badge badge-secondary" >0</span> rows.'
         in rendered_page
     )
-    # assert 'This table should have a list of columns in a specific order, but that order is not specified.' \
+    # assert 'This table should have a list of columns in a specific order, but that order is not specified.' \  # noqa: E501 # FIXME CoP
     #        in rendered_page
 
 
-@pytest.mark.smoketest
-@pytest.mark.rendered_output
 def test_smoke_render_profiling_results_page_renderer_with_exception(
     titanic_profiler_evrs_with_exception,
 ):
-    rendered_content = ProfilingResultsPageRenderer().render(
-        titanic_profiler_evrs_with_exception
-    )
+    rendered_content = ProfilingResultsPageRenderer().render(titanic_profiler_evrs_with_exception)
     rendered_page = DefaultJinjaPageView().render(rendered_content)
 
     with open(
@@ -403,30 +346,9 @@ def test_smoke_render_profiling_results_page_renderer_with_exception(
     assert "exception" in rendered_page
 
 
-@pytest.mark.smoketest
-@pytest.mark.rendered_output
-def test_full_oobe_flow():
-    df = gx.read_csv(file_relative_path(__file__, "../../examples/data/Titanic.csv"))
-    df.data_asset_name = "my_datasource/my_generator/my_asset"
-    df.profile(BasicDatasetProfiler)
-    evrs = df.validate()  # results
-
-    rendered_content = ProfilingResultsPageRenderer().render(evrs)
-    rendered_page = DefaultJinjaPageView().render(rendered_content)
-
-    with open(
-        file_relative_path(__file__, "./output/test_full_oobe_flow.html", strict=False),
-        "wb",
-    ) as f:
-        f.write(rendered_page.encode("utf-8"))
-
-    assert rendered_page[:15] == "<!DOCTYPE html>"
-    assert rendered_page[-7:] == "</html>"
-
-
 def test_render_string_template():
     template = {
-        "template": "$column Kullback-Leibler (KL) divergence with respect to the following distribution must be lower than $threshold: $sparklines_histogram",
+        "template": "$column Kullback-Leibler (KL) divergence with respect to the following distribution must be lower than $threshold: $sparklines_histogram",  # noqa: E501 # FIXME CoP
         "params": {
             "column": "categorical_fixed",
             "partition_object": {
@@ -452,16 +374,14 @@ def test_render_string_template():
     expected = (
         """<span>
                 <span class="badge badge-secondary" >categorical_fixed</span> Kullback-Leibler (KL) divergence with respect to the following distribution must be lower than <span class="badge badge-secondary" >0.1</span>: <span style="font-family:serif;" >█▄▁</span>
-            </span>""".replace(
-            " ", ""
-        )
+            </span>""".replace(" ", "")  # noqa: E501 # FIXME CoP
         .replace("\t", "")
         .replace("\n", "")
     )
     assert res == expected
 
     template = {
-        "template": "$column Kullback-Leibler (KL) divergence with respect to the following distribution must be lower than $threshold: $sparklines_histogram",
+        "template": "$column Kullback-Leibler (KL) divergence with respect to the following distribution must be lower than $threshold: $sparklines_histogram",  # noqa: E501 # FIXME CoP
         "params": {
             "column": "categorical_fixed",
             "partition_object": {
@@ -487,9 +407,7 @@ def test_render_string_template():
     expected = (
         """<span>
                 <span class="badge badge-secondary" >categorical_fixed</span> Kullback-Leibler (KL) divergence with respect to the following distribution must be lower than <span class="badge badge-secondary" >0.1</span>: <span style="font-family:serif;" >▃▆▁█</span>
-            </span>""".replace(
-            " ", ""
-        )
+            </span>""".replace(" ", "")  # noqa: E501 # FIXME CoP
         .replace("\t", "")
         .replace("\n", "")
     )
@@ -497,18 +415,50 @@ def test_render_string_template():
     assert res == expected
 
 
-def test_render_types_module_deprecation_warning():
-    with warnings.catch_warnings(record=True) as w:
-        CollapseContent(collapse=True)
-        RenderedContent()
-    assert len(w) == 2
-    assert str(w[0].message) == (
-        "Importing the class CollapseContent from great_expectations.render.types is "
-        "deprecated as of v0.15.32 in v0.18. Please import class CollapseContent from "
-        "great_expectations.render."
-    )
-    assert str(w[1].message) == (
-        "Importing the class RenderedContent from great_expectations.render.types is "
-        "deprecated as of v0.15.32 in v0.18. Please import class RenderedContent from "
-        "great_expectations.render."
-    )
+def test_rendered_content_hash_consistency_with_equality():
+    from great_expectations.render.components import RenderedContent
+
+    content1 = RenderedContent()
+    content2 = RenderedContent()
+
+    assert content1 == content2
+    assert hash(content1) == hash(content2)
+
+
+def test_rendered_string_template_content_hash_consistency_with_equality():
+    from great_expectations.render.components import RenderedStringTemplateContent
+
+    template1 = {"template": "Hello $name", "params": {"name": "World"}}
+    template2 = {"params": {"name": "World"}, "template": "Hello $name"}
+
+    content1 = RenderedStringTemplateContent(string_template=template1)
+    content2 = RenderedStringTemplateContent(string_template=template2)
+
+    assert content1 == content2
+    assert hash(content1) == hash(content2)
+
+
+def test_rendered_string_template_content_hash_different_for_different_templates():
+    from great_expectations.render.components import RenderedStringTemplateContent
+
+    template1 = {"template": "Hello $name", "params": {"name": "World"}}
+    template2 = {"template": "Hello $name", "params": {"name": "Universe"}}
+
+    content1 = RenderedStringTemplateContent(string_template=template1)
+    content2 = RenderedStringTemplateContent(string_template=template2)
+
+    assert content1 != content2
+    assert hash(content1) != hash(content2)
+
+
+def test_rendered_string_template_content_hash_stable_across_runs():
+    from great_expectations.render.components import RenderedStringTemplateContent
+
+    template = {"template": "Hello $name", "params": {"name": "World"}}
+    content = RenderedStringTemplateContent(string_template=template)
+
+    hash1 = hash(content)
+    hash2 = hash(content)
+    hash3 = hash(content)
+
+    assert hash1 == hash2 == hash3
