@@ -1,50 +1,24 @@
 import pytest
 
-from great_expectations.core.expectation_configuration import ExpectationConfiguration
 from great_expectations.core.expectation_validation_result import (
     ExpectationValidationResult,
 )
+from great_expectations.expectations.expectation_configuration import (
+    ExpectationConfiguration,
+)
 from great_expectations.render.renderer.renderer import Renderer
 
 
-def test_render():
-    # noinspection PyUnusedLocal
-    with pytest.raises(NotImplementedError):
-        Renderer().render(**{})
-
-    # noinspection PyUnusedLocal
-    with pytest.raises(TypeError):
-        # noinspection PyArgumentList
-        Renderer().render({})
-
-    # noinspection PyUnusedLocal
-    with pytest.raises(TypeError):
-        # noinspection PyArgumentList
-        Renderer().render("wowza")
-
-
-# TODO: Implement this test thoughtfully
-# def test__id_from_configuration():
-#     Renderer()._id_from_configuration(expectation_type, expectation_kwargs, data_asset_name=None)
-
-# TODO: Implement this test thoughtfully
-# def test__get_expectation_type():
-#     Renderer()._get_expectation_type(ge_object)
-
-# TODO: Implement this test thoughtfully
-# def test__find_ge_object_type():
-#     Renderer()._find_ge_object_type(ge_object)
-
-
+@pytest.mark.unit
 def test__find_evr_by_type(titanic_profiled_evrs_1):
-    # TODO: _find_all_evrs_by_type should accept an ValidationResultSuite, not ValidationResultSuite.results
+    # TODO: _find_all_evrs_by_type should accept an ValidationResultSuite, not ValidationResultSuite.results  # noqa: E501 # FIXME CoP
     found_evr = Renderer()._find_evr_by_type(
         titanic_profiled_evrs_1.results, "expect_column_to_exist"
     )
     print(found_evr)
     assert found_evr is None
 
-    # TODO: _find_all_evrs_by_type should accept an ValidationResultSuite, not ValidationResultSuite.results
+    # TODO: _find_all_evrs_by_type should accept an ValidationResultSuite, not ValidationResultSuite.results  # noqa: E501 # FIXME CoP
     found_evr = Renderer()._find_evr_by_type(
         titanic_profiled_evrs_1.results, "expect_column_distinct_values_to_be_in_set"
     )
@@ -71,28 +45,29 @@ def test__find_evr_by_type(titanic_profiled_evrs_1):
             "exception_traceback": None,
         },
         expectation_config=ExpectationConfiguration(
-            expectation_type="expect_column_distinct_values_to_be_in_set",
-            kwargs={"column": "PClass", "value_set": None, "result_format": "SUMMARY"},
+            type="expect_column_distinct_values_to_be_in_set",
+            kwargs={"column": "PClass", "value_set": ["a", "b", "c"], "result_format": "SUMMARY"},
         ),
     )
 
 
+@pytest.mark.unit
 def test__find_all_evrs_by_type(titanic_profiled_evrs_1):
-    # TODO: _find_all_evrs_by_type should accept an ValidationResultSuite, not ValidationResultSuite.results
+    # TODO: _find_all_evrs_by_type should accept an ValidationResultSuite, not ValidationResultSuite.results  # noqa: E501 # FIXME CoP
     found_evrs = Renderer()._find_all_evrs_by_type(
         titanic_profiled_evrs_1.results, "expect_column_to_exist", column_=None
     )
     print(found_evrs)
     assert found_evrs == []
 
-    # TODO: _find_all_evrs_by_type should accept an ValidationResultSuite, not ValidationResultSuite.results
+    # TODO: _find_all_evrs_by_type should accept an ValidationResultSuite, not ValidationResultSuite.results  # noqa: E501 # FIXME CoP
     found_evrs = Renderer()._find_all_evrs_by_type(
         titanic_profiled_evrs_1.results, "expect_column_to_exist", column_="SexCode"
     )
     print(found_evrs)
     assert found_evrs == []
 
-    # TODO: _find_all_evrs_by_type should accept an ValidationResultSuite, not ValidationResultSuite.results
+    # TODO: _find_all_evrs_by_type should accept an ValidationResultSuite, not ValidationResultSuite.results  # noqa: E501 # FIXME CoP
     found_evrs = Renderer()._find_all_evrs_by_type(
         titanic_profiled_evrs_1.results,
         "expect_column_distinct_values_to_be_in_set",
@@ -101,7 +76,7 @@ def test__find_all_evrs_by_type(titanic_profiled_evrs_1):
     print(found_evrs)
     assert len(found_evrs) == 4
 
-    # TODO: _find_all_evrs_by_type should accept an ValidationResultSuite, not ValidationResultSuite.results
+    # TODO: _find_all_evrs_by_type should accept an ValidationResultSuite, not ValidationResultSuite.results  # noqa: E501 # FIXME CoP
     found_evrs = Renderer()._find_all_evrs_by_type(
         titanic_profiled_evrs_1.results,
         "expect_column_distinct_values_to_be_in_set",
@@ -111,6 +86,7 @@ def test__find_all_evrs_by_type(titanic_profiled_evrs_1):
     assert len(found_evrs) == 1
 
 
+@pytest.mark.unit
 def test__get_column_list_from_evrs(titanic_profiled_evrs_1):
     column_list = Renderer()._get_column_list_from_evrs(titanic_profiled_evrs_1)
     print(column_list)
@@ -123,3 +99,35 @@ def test__get_column_list_from_evrs(titanic_profiled_evrs_1):
         "Survived",
         "SexCode",
     ]
+
+
+@pytest.mark.unit
+def test_renderer_hash_consistency_with_equality():
+    renderer1 = Renderer()
+    renderer2 = Renderer()
+
+    assert renderer1 == renderer2
+    assert hash(renderer1) == hash(renderer2)
+
+
+@pytest.mark.unit
+def test_renderer_hash_different_for_different_types():
+    class TestRenderer(Renderer):
+        pass
+
+    renderer1 = Renderer()
+    renderer2 = TestRenderer()
+
+    assert renderer1 != renderer2
+    assert hash(renderer1) != hash(renderer2)
+
+
+@pytest.mark.unit
+def test_renderer_hash_stable_across_runs():
+    renderer = Renderer()
+
+    hash1 = hash(renderer)
+    hash2 = hash(renderer)
+    hash3 = hash(renderer)
+
+    assert hash1 == hash2 == hash3
