@@ -3,20 +3,24 @@ import pathlib
 from typing import List, Union
 
 import pytest
-
-from scripts.public_api_report import (
+from docs.sphinx_api_docs_source.include_exclude_definition import (
+    IncludeExcludeDefinition,
+)
+from docs.sphinx_api_docs_source.public_api_report import (
     CodeParser,
     CodeReferenceFilter,
     Definition,
     DocsExampleParser,
     FileContents,
-    IncludeExcludeDefinition,
     PublicAPIChecker,
     PublicAPIReport,
     _get_import_names,
     get_shortest_dotted_path,
+    parse_docs_contents_for_class_names,
 )
 
+pytestmark = pytest.mark.filesystem
+
 
 @pytest.fixture
 def sample_docs_example_python_file_string() -> str:
@@ -51,7 +55,13 @@ example_public_api_module_level_function()
 epub = ExamplePublicAPIClass()
 
 assert d
-"""
+
+some_yaml_contents = \"\"\"
+name: {datasource_name}
+class_name: Something
+\"\"\"
+
+"""  # noqa: E501 # FIXME CoP
 
 
 @pytest.fixture
@@ -120,32 +130,50 @@ class ExamplePublicAPIClass:
 
 
 @pytest.fixture
-def repo_root() -> pathlib.Path:
-    return pathlib.Path("/some/absolute/path/repo_root/")
+def sample_markdown_doc_with_yaml() -> str:
+    return """# Title
+
+Content.
+
+More content.
+
+Some yaml:
+
+yaml_contents = \"\"\"
+name: {datasource_name}
+class_name: Something
+\"\"\"
+
+End of content.
+"""
+
+
+@pytest.fixture
+def repo_root(tmp_path) -> pathlib.Path:
+    return tmp_path
 
 
 @pytest.fixture
 def sample_docs_example_python_file_string_filepath(
     repo_root: pathlib.Path,
 ) -> pathlib.Path:
-    return (
+    path = (
         repo_root
-        / pathlib.Path(
-            "tests/integration/docusaurus/sample_docs_example_python_file_string.py"
-        )
+        / pathlib.Path("tests/integration/docusaurus/sample_docs_example_python_file_string.py")
     ).relative_to(repo_root)
+    path.touch()
+    return path
 
 
 @pytest.fixture
 def sample_with_definitions_python_file_string_filepath(
     repo_root: pathlib.Path,
 ) -> pathlib.Path:
-    return (
+    path = (repo_root / pathlib.Path("sample_with_definitions_python_file_string.py")).relative_to(
         repo_root
-        / pathlib.Path(
-            "great_expectations/sample_with_definitions_python_file_string.py"
-        )
-    ).relative_to(repo_root)
+    )
+    path.touch()
+    return path
 
 
 @pytest.fixture
@@ -170,24 +198,34 @@ def sample_with_definitions_file_contents(
     )
 
 
+@pytest.fixture
+def sample_markdown_doc_with_yaml_file_contents(
+    sample_markdown_doc_with_yaml: str,
+) -> FileContents:
+    return FileContents(
+        filepath=pathlib.Path("some/random/filepath/markdown.md"),
+        contents=sample_markdown_doc_with_yaml,
+    )
+
+
 @pytest.fixture
 def docs_example_parser(
     sample_docs_example_file_contents: FileContents,
 ) -> DocsExampleParser:
-    docs_example_parser = DocsExampleParser(
-        file_contents={sample_docs_example_file_contents}
-    )
+    docs_example_parser = DocsExampleParser(file_contents={sample_docs_example_file_contents})
+    return docs_example_parser
+
+
+@pytest.fixture
+def empty_docs_example_parser(
+    sample_docs_example_file_contents: FileContents,
+) -> DocsExampleParser:
+    docs_example_parser = DocsExampleParser(file_contents=set())
     return docs_example_parser
 
 
 class TestDocExampleParser:
-    @pytest.mark.unit
-    def test_instantiate(self, docs_example_parser: DocsExampleParser):
-        assert isinstance(docs_example_parser, DocsExampleParser)
-
-    @pytest.mark.unit
     def test_retrieve_all_usages_in_files(self, docs_example_parser: DocsExampleParser):
-
         usages = docs_example_parser.get_names_from_usage_in_docs_examples()
         assert usages == {
             "ExampleClass",
@@ -202,6 +240,7 @@ class TestDocExampleParser:
             "example_public_classmethod",
             "example_public_staticmethod",
             "example_staticmethod",
+            "Something",
         }
 
 
@@ -212,11 +251,6 @@ def code_parser(sample_with_definitions_file_contents: FileContents) -> CodePars
 
 
 class TestCodeParser:
-    @pytest.mark.unit
-    def test_instantiate(self, code_parser: CodeParser):
-        assert isinstance(code_parser, CodeParser)
-
-    @pytest.mark.unit
     def test_get_all_class_method_and_function_names(self, code_parser: CodeParser):
         names = code_parser.get_all_class_method_and_function_names()
         assert names == {
@@ -238,10 +272,7 @@ class TestCodeParser:
             "example_staticmethod",
         }
 
-    @pytest.mark.unit
-    def test_get_all_class_method_and_function_definitions(
-        self, code_parser: CodeParser
-    ):
+    def test_get_all_class_method_and_function_definitions(self, code_parser: CodeParser):
         definitions = code_parser.get_all_class_method_and_function_definitions()
 
         assert len(definitions) == 16
@@ -264,12 +295,18 @@ class TestCodeParser:
             "example_staticmethod",
         }
         assert {d.filepath for d in definitions} == {
-            pathlib.Path(
-                "great_expectations/sample_with_definitions_python_file_string.py"
-            )
+            pathlib.Path("sample_with_definitions_python_file_string.py")
         }
 
 
+def test_parse_docs_contents_for_class_names(
+    sample_markdown_doc_with_yaml_file_contents: FileContents,
+):
+    assert parse_docs_contents_for_class_names(
+        file_contents={sample_markdown_doc_with_yaml_file_contents}
+    ) == {"Something"}
+
+
 def test_get_shortest_dotted_path(monkeypatch):
     """Test path traversal using an example file.
 
@@ -293,7 +330,7 @@ def test_get_shortest_dotted_path(monkeypatch):
     # This is the shortest path
     assert (
         get_shortest_dotted_path(definition=definition, repo_root_path=repo_root)
-        == "great_expectations.core.ExpectationSuite"
+        == "great_expectations.ExpectationSuite"
     )
 
 
@@ -317,7 +354,7 @@ def test__get_import_names(various_imports: str):
 
     for node in ast.walk(tree):
         if isinstance(node, (ast.Import, ast.ImportFrom)):
-            import_names.extend(_get_import_names(node))
+            import_names.extend(_get_import_names(node))  # type: ignore[arg-type] # FIXME CoP
 
     assert import_names == [
         "some_module",
@@ -332,18 +369,11 @@ def test__get_import_names(various_imports: str):
 
 
 @pytest.fixture
-def public_api_checker(
-    docs_example_parser: DocsExampleParser, code_parser: CodeParser
-) -> PublicAPIChecker:
+def public_api_checker(code_parser: CodeParser) -> PublicAPIChecker:
     return PublicAPIChecker(code_parser=code_parser)
 
 
 class TestPublicAPIChecker:
-    @pytest.mark.unit
-    def test_instantiate(self, public_api_checker: PublicAPIChecker):
-        assert isinstance(public_api_checker, PublicAPIChecker)
-
-    @pytest.mark.integration
     def test_get_all_public_api_definitions(self, public_api_checker: PublicAPIChecker):
         observed = public_api_checker.get_all_public_api_definitions()
         assert len(observed) == 6
@@ -356,9 +386,7 @@ class TestPublicAPIChecker:
             "example_public_staticmethod",
         }
         assert {d.filepath for d in observed} == {
-            pathlib.Path(
-                "great_expectations/sample_with_definitions_python_file_string.py"
-            )
+            pathlib.Path("sample_with_definitions_python_file_string.py")
         }
 
     def _class_and_function_definitions(
@@ -367,18 +395,13 @@ class TestPublicAPIChecker:
         """Helper function to find class and function definitions from ast tree for tests."""
         definitions = []
         for node in ast.walk(tree):
-            if (
-                isinstance(node, ast.ClassDef)
-                or isinstance(node, ast.FunctionDef)
-                or isinstance(node, ast.AsyncFunctionDef)
-            ):
+            if isinstance(node, (ast.ClassDef, ast.FunctionDef, ast.AsyncFunctionDef)):
                 definitions.append(node)
 
         return definitions
 
-    @pytest.mark.integration
     def test_is_definition_marked_public_api_yes(
-        self, public_api_checker: PublicAPIChecker
+        self, public_api_checker: PublicAPIChecker, tmp_path: pathlib.Path
     ):
         file_string = """
 @public_api
@@ -408,13 +431,12 @@ class ExamplePublicAPIClass:
         pass
 
 """
-        ast_definitions = self._class_and_function_definitions(
-            tree=ast.parse(file_string)
-        )
+        test_path = tmp_path / "test_path.py"
+        ast_definitions = self._class_and_function_definitions(tree=ast.parse(file_string))
         definitions = [
             Definition(
                 name="test_name",
-                filepath=pathlib.Path("test_path"),
+                filepath=pathlib.Path(test_path),
                 ast_definition=ast_definition,
             )
             for ast_definition in ast_definitions
@@ -424,9 +446,8 @@ class ExamplePublicAPIClass:
             for definition in definitions
         )
 
-    @pytest.mark.integration
     def test_is_definition_marked_public_api_no(
-        self, public_api_checker: PublicAPIChecker
+        self, public_api_checker: PublicAPIChecker, tmp_path: pathlib.Path
     ):
         file_string = """
 def example_module_level_function():
@@ -450,13 +471,12 @@ class ExampleClass:
         pass
 
 """
-        ast_definitions = self._class_and_function_definitions(
-            tree=ast.parse(file_string)
-        )
+        test_path = tmp_path / "test_path.py"
+        ast_definitions = self._class_and_function_definitions(tree=ast.parse(file_string))
         definitions = [
             Definition(
                 name="test_name",
-                filepath=pathlib.Path("test_path"),
+                filepath=pathlib.Path(test_path),
                 ast_definition=ast_definition,
             )
             for ast_definition in ast_definitions
@@ -488,6 +508,7 @@ def code_reference_filter_with_non_default_include_exclude(
     docs_example_parser: DocsExampleParser,
     code_parser: CodeParser,
     public_api_checker: PublicAPIChecker,
+    sample_docs_example_python_file_string_filepath: pathlib.Path,
 ) -> CodeReferenceFilter:
     return CodeReferenceFilter(
         repo_root=repo_root,
@@ -496,12 +517,16 @@ def code_reference_filter_with_non_default_include_exclude(
         public_api_checker=public_api_checker,
         includes=[
             IncludeExcludeDefinition(
-                reason="test", name="test_name", filepath=pathlib.Path("test_path")
+                reason="test",
+                name="test_name",
+                filepath=sample_docs_example_python_file_string_filepath,
             )
         ],
         excludes=[
             IncludeExcludeDefinition(
-                reason="test", name="test_name", filepath=pathlib.Path("test_path")
+                reason="test",
+                name="test_name",
+                filepath=sample_docs_example_python_file_string_filepath,
             )
         ],
     )
@@ -530,6 +555,7 @@ def code_reference_filter_with_exclude_by_file(
     docs_example_parser: DocsExampleParser,
     code_parser: CodeParser,
     public_api_checker: PublicAPIChecker,
+    sample_with_definitions_python_file_string_filepath: pathlib.Path,
 ) -> CodeReferenceFilter:
     return CodeReferenceFilter(
         repo_root=repo_root,
@@ -540,20 +566,35 @@ def code_reference_filter_with_exclude_by_file(
         excludes=[
             IncludeExcludeDefinition(
                 reason="test",
-                filepath=pathlib.Path(
-                    "great_expectations/sample_with_definitions_python_file_string.py"
-                ),
+                filepath=sample_with_definitions_python_file_string_filepath,
             )
         ],
     )
 
 
+@pytest.fixture
+def code_reference_filter_with_references_from_docs_content(
+    repo_root: pathlib.Path,
+    empty_docs_example_parser: DocsExampleParser,
+    code_parser: CodeParser,
+    public_api_checker: PublicAPIChecker,
+) -> CodeReferenceFilter:
+    return CodeReferenceFilter(
+        repo_root=repo_root,
+        docs_example_parser=empty_docs_example_parser,
+        code_parser=code_parser,
+        public_api_checker=public_api_checker,
+        references_from_docs_content={"ExampleClass", "ExamplePublicAPIClass"},
+    )
+
+
 @pytest.fixture
 def code_reference_filter_with_exclude_by_file_and_name(
     repo_root: pathlib.Path,
     docs_example_parser: DocsExampleParser,
     code_parser: CodeParser,
     public_api_checker: PublicAPIChecker,
+    sample_with_definitions_python_file_string_filepath: pathlib.Path,
 ) -> CodeReferenceFilter:
     return CodeReferenceFilter(
         repo_root=repo_root,
@@ -565,16 +606,12 @@ def code_reference_filter_with_exclude_by_file_and_name(
             IncludeExcludeDefinition(
                 reason="test",
                 name="example_method",
-                filepath=pathlib.Path(
-                    "great_expectations/sample_with_definitions_python_file_string.py"
-                ),
+                filepath=sample_with_definitions_python_file_string_filepath,
             ),
             IncludeExcludeDefinition(
                 reason="test",
                 name="example_module_level_function",
-                filepath=pathlib.Path(
-                    "great_expectations/sample_with_definitions_python_file_string.py"
-                ),
+                filepath=sample_with_definitions_python_file_string_filepath,
             ),
         ],
     )
@@ -586,6 +623,7 @@ def code_reference_filter_with_include_by_file_and_name_already_included(
     docs_example_parser: DocsExampleParser,
     code_parser: CodeParser,
     public_api_checker: PublicAPIChecker,
+    sample_with_definitions_python_file_string_filepath: pathlib.Path,
 ) -> CodeReferenceFilter:
     return CodeReferenceFilter(
         repo_root=repo_root,
@@ -596,16 +634,12 @@ def code_reference_filter_with_include_by_file_and_name_already_included(
             IncludeExcludeDefinition(
                 reason="test",
                 name="example_method",
-                filepath=pathlib.Path(
-                    "great_expectations/sample_with_definitions_python_file_string.py"
-                ),
+                filepath=sample_with_definitions_python_file_string_filepath,
             ),
             IncludeExcludeDefinition(
                 reason="test",
                 name="example_module_level_function",
-                filepath=pathlib.Path(
-                    "great_expectations/sample_with_definitions_python_file_string.py"
-                ),
+                filepath=sample_with_definitions_python_file_string_filepath,
             ),
         ],
         excludes=[],
@@ -618,6 +652,7 @@ def code_reference_filter_with_include_by_file_and_name_already_excluded(
     docs_example_parser: DocsExampleParser,
     code_parser: CodeParser,
     public_api_checker: PublicAPIChecker,
+    sample_with_definitions_python_file_string_filepath: pathlib.Path,
 ) -> CodeReferenceFilter:
     return CodeReferenceFilter(
         repo_root=repo_root,
@@ -628,24 +663,18 @@ def code_reference_filter_with_include_by_file_and_name_already_excluded(
             IncludeExcludeDefinition(
                 reason="test",
                 name="example_method",
-                filepath=pathlib.Path(
-                    "great_expectations/sample_with_definitions_python_file_string.py"
-                ),
+                filepath=sample_with_definitions_python_file_string_filepath,
             ),
             IncludeExcludeDefinition(
                 reason="test",
                 name="example_module_level_function",
-                filepath=pathlib.Path(
-                    "great_expectations/sample_with_definitions_python_file_string.py"
-                ),
+                filepath=sample_with_definitions_python_file_string_filepath,
             ),
         ],
         excludes=[
             IncludeExcludeDefinition(
                 reason="test",
-                filepath=pathlib.Path(
-                    "great_expectations/sample_with_definitions_python_file_string.py"
-                ),
+                filepath=sample_with_definitions_python_file_string_filepath,
             )
         ],
     )
@@ -657,6 +686,7 @@ def code_reference_filter_with_include_by_file_and_name_not_used_in_docs_example
     docs_example_parser: DocsExampleParser,
     code_parser: CodeParser,
     public_api_checker: PublicAPIChecker,
+    sample_with_definitions_python_file_string_filepath: pathlib.Path,
 ) -> CodeReferenceFilter:
     return CodeReferenceFilter(
         repo_root=repo_root,
@@ -667,42 +697,33 @@ def code_reference_filter_with_include_by_file_and_name_not_used_in_docs_example
             IncludeExcludeDefinition(
                 reason="test",
                 name="example_no_usages_in_sample_docs_example_python_file_string",
-                filepath=pathlib.Path(
-                    "great_expectations/sample_with_definitions_python_file_string.py"
-                ),
+                filepath=sample_with_definitions_python_file_string_filepath,
             ),
         ],
         excludes=[
             IncludeExcludeDefinition(
                 reason="test",
-                filepath=pathlib.Path(
-                    "great_expectations/sample_with_definitions_python_file_string.py"
-                ),
+                filepath=sample_with_definitions_python_file_string_filepath,
             )
         ],
     )
 
 
 class TestCodeReferenceFilter:
-    @pytest.mark.unit
     def test_instantiate(self, code_reference_filter: CodeReferenceFilter):
-        assert isinstance(code_reference_filter, CodeReferenceFilter)
         assert code_reference_filter.excludes
         assert code_reference_filter.includes
 
-    @pytest.mark.integration
     def test_instantiate_with_non_default_include_exclude(
         self,
         code_reference_filter_with_non_default_include_exclude: CodeReferenceFilter,
     ):
         code_reference_filter = code_reference_filter_with_non_default_include_exclude
-        assert isinstance(code_reference_filter, CodeReferenceFilter)
         assert code_reference_filter.excludes
         assert code_reference_filter.includes
         assert len(code_reference_filter.excludes) == 1
         assert len(code_reference_filter.includes) == 1
 
-    @pytest.mark.integration
     def test_filter_definitions_no_include_exclude(
         self, code_reference_filter_with_no_include_exclude: CodeReferenceFilter
     ):
@@ -720,12 +741,20 @@ class TestCodeReferenceFilter:
             "example_staticmethod",
         }
         assert {d.filepath for d in observed} == {
-            pathlib.Path(
-                "great_expectations/sample_with_definitions_python_file_string.py"
-            )
+            pathlib.Path("sample_with_definitions_python_file_string.py")
+        }
+
+    def test_filter_definitions_with_references_from_docs_content(
+        self,
+        code_reference_filter_with_references_from_docs_content: CodeReferenceFilter,
+    ):
+        observed = code_reference_filter_with_references_from_docs_content.filter_definitions()
+        assert len(observed) == 1
+        assert {d.name for d in observed} == {"ExampleClass"}
+        assert {d.filepath for d in observed} == {
+            pathlib.Path("sample_with_definitions_python_file_string.py")
         }
 
-    @pytest.mark.integration
     def test_filter_definitions_exclude_by_file(
         self, code_reference_filter_with_exclude_by_file: CodeReferenceFilter
     ):
@@ -734,13 +763,10 @@ class TestCodeReferenceFilter:
         assert {d.name for d in observed} == set()
         assert {d.filepath for d in observed} == set()
 
-    @pytest.mark.integration
     def test_filter_definitions_exclude_by_file_and_name(
         self, code_reference_filter_with_exclude_by_file_and_name: CodeReferenceFilter
     ):
-        observed = (
-            code_reference_filter_with_exclude_by_file_and_name.filter_definitions()
-        )
+        observed = code_reference_filter_with_exclude_by_file_and_name.filter_definitions()
         assert len(observed) == 4
         assert {d.name for d in observed} == {
             "ExampleClass",
@@ -749,12 +775,9 @@ class TestCodeReferenceFilter:
             "example_staticmethod",
         }
         assert {d.filepath for d in observed} == {
-            pathlib.Path(
-                "great_expectations/sample_with_definitions_python_file_string.py"
-            )
+            pathlib.Path("sample_with_definitions_python_file_string.py")
         }
 
-    @pytest.mark.integration
     def test_filter_definitions_include_by_file_and_name_already_included(
         self,
         code_reference_filter_with_include_by_file_and_name_already_included: CodeReferenceFilter,
@@ -765,9 +788,7 @@ class TestCodeReferenceFilter:
         will not include multiple copies of the same definitions (when not
         accounting for different but equivalent ast definition object instances).
         """
-        observed = (
-            code_reference_filter_with_include_by_file_and_name_already_included.filter_definitions()
-        )
+        observed = code_reference_filter_with_include_by_file_and_name_already_included.filter_definitions()  # noqa: E501 # FIXME CoP
         # There are two extra (8 vs 6) here due to the ast_definition classes
         #  pointing to different but equivalent objects.
         assert len(observed) == 8
@@ -780,12 +801,9 @@ class TestCodeReferenceFilter:
             "example_staticmethod",
         }
         assert {d.filepath for d in observed} == {
-            pathlib.Path(
-                "great_expectations/sample_with_definitions_python_file_string.py"
-            )
+            pathlib.Path("sample_with_definitions_python_file_string.py")
         }
 
-    @pytest.mark.integration
     def test_filter_definitions_include_by_file_and_name_already_excluded(
         self,
         code_reference_filter_with_include_by_file_and_name_already_excluded: CodeReferenceFilter,
@@ -794,9 +812,7 @@ class TestCodeReferenceFilter:
 
         Include overrides exclude.
         """
-        observed = (
-            code_reference_filter_with_include_by_file_and_name_already_excluded.filter_definitions()
-        )
+        observed = code_reference_filter_with_include_by_file_and_name_already_excluded.filter_definitions()  # noqa: E501 # FIXME CoP
         # There are two extra (4 vs 2) here due to the ast_definition classes
         #  pointing to different but equivalent objects.
         assert len(observed) == 4
@@ -805,32 +821,25 @@ class TestCodeReferenceFilter:
             "example_module_level_function",
         }
         assert {d.filepath for d in observed} == {
-            pathlib.Path(
-                "great_expectations/sample_with_definitions_python_file_string.py"
-            )
+            pathlib.Path("sample_with_definitions_python_file_string.py")
         }
 
-    @pytest.mark.integration
     def test_filter_definitions_include_by_file_and_name_already_excluded_not_used_in_docs_example(
         self,
-        code_reference_filter_with_include_by_file_and_name_not_used_in_docs_example_exclude_file: CodeReferenceFilter,
+        code_reference_filter_with_include_by_file_and_name_not_used_in_docs_example_exclude_file: CodeReferenceFilter,  # noqa: E501 # FIXME CoP
     ):
         """What does this test and why?
 
         Include overrides exclude. Method that was not included in docs examples
         is still included if manually added.
         """
-        observed = (
-            code_reference_filter_with_include_by_file_and_name_not_used_in_docs_example_exclude_file.filter_definitions()
-        )
+        observed = code_reference_filter_with_include_by_file_and_name_not_used_in_docs_example_exclude_file.filter_definitions()  # noqa: E501 # FIXME CoP
         assert len(observed) == 1
         assert {d.name for d in observed} == {
             "example_no_usages_in_sample_docs_example_python_file_string",
         }
         assert {d.filepath for d in observed} == {
-            pathlib.Path(
-                "great_expectations/sample_with_definitions_python_file_string.py"
-            )
+            pathlib.Path("sample_with_definitions_python_file_string.py")
         }
 
 
@@ -857,30 +866,19 @@ def public_api_report_filter_out_file(
 
 
 class TestPublicAPIReport:
-    @pytest.mark.unit
-    def test_instantiate(self, public_api_report: PublicAPIReport):
-        assert isinstance(public_api_report, PublicAPIReport)
-
-    @pytest.mark.integration
     def test_generate_printable_definitions(self, public_api_report: PublicAPIReport):
         expected: List[str] = [
-            "File: great_expectations/sample_with_definitions_python_file_string.py Name: "
-            "ExampleClass",
-            "File: great_expectations/sample_with_definitions_python_file_string.py Name: "
-            "example_classmethod",
-            "File: great_expectations/sample_with_definitions_python_file_string.py Name: "
-            "example_method",
-            "File: great_expectations/sample_with_definitions_python_file_string.py Name: "
-            "example_method_with_args",
-            "File: great_expectations/sample_with_definitions_python_file_string.py Name: "
+            "File: sample_with_definitions_python_file_string.py Name: ExampleClass",
+            "File: sample_with_definitions_python_file_string.py Name: example_classmethod",
+            "File: sample_with_definitions_python_file_string.py Name: example_method",
+            "File: sample_with_definitions_python_file_string.py Name: example_method_with_args",
+            "File: sample_with_definitions_python_file_string.py Name: "
             "example_module_level_function",
-            "File: great_expectations/sample_with_definitions_python_file_string.py Name: "
-            "example_staticmethod",
+            "File: sample_with_definitions_python_file_string.py Name: example_staticmethod",
         ]
-        observed = public_api_report.generate_printable_definitions()
+        observed = [str(p) for p in public_api_report.generate_printable_definitions()]
         assert observed == expected
 
-    @pytest.mark.integration
     def test_generate_printable_definitions_exclude_by_file(
         self, public_api_report_filter_out_file: PublicAPIReport
     ):
@@ -890,40 +888,28 @@ class TestPublicAPIReport:
 
 
 class TestIncludeExcludeDefinition:
-    @pytest.mark.unit
-    def test_instantiate_name_and_filepath(self):
-        definition = IncludeExcludeDefinition(
-            reason="reason", name="name", filepath=pathlib.Path("filepath")
+    def test_instantiate_name_and_filepath(self, tmp_path: pathlib.Path):
+        path = tmp_path / "test_path.py"
+        path.touch()
+        IncludeExcludeDefinition(
+            reason="reason",
+            name="name",
+            filepath=path,
         )
-        assert isinstance(definition, IncludeExcludeDefinition)
 
-    @pytest.mark.unit
-    def test_instantiate_filepath_only(self):
-        definition = IncludeExcludeDefinition(
-            reason="reason", filepath=pathlib.Path("filepath")
-        )
-        assert isinstance(definition, IncludeExcludeDefinition)
+    def test_instantiate_filepath_only(self, tmp_path: pathlib.Path):
+        path = tmp_path / "test_path.py"
+        path.touch()
+        IncludeExcludeDefinition(reason="reason", filepath=path)
 
-    @pytest.mark.unit
-    def test_instantiate_name_and_filepath_no_reason(self):
-        with pytest.raises(TypeError):
-            IncludeExcludeDefinition(name="name", filepath=pathlib.Path("filepath"))
-
-    @pytest.mark.unit
     def test_instantiate_name_only(self):
         with pytest.raises(ValueError) as exc:
             IncludeExcludeDefinition(reason="reason", name="name")
 
-        assert (
-            "You must provide a filepath if also providing a name" in exc.value.args[0]
-        )
+        assert "You must provide a filepath if also providing a name" in exc.value.args[0]
 
-    @pytest.mark.unit
     def test_instantiate_reason_only(self):
         with pytest.raises(ValueError) as exc:
             IncludeExcludeDefinition(reason="reason")
 
-        assert (
-            "You must provide at least a filepath or filepath and name"
-            in exc.value.args[0]
-        )
+        assert "You must provide at least a filepath or filepath and name" in exc.value.args[0]
