@@ -1,5 +1,6 @@
 import pytest
 
+from great_expectations.data_context.types.base import ProgressBarsConfig
 from great_expectations.data_context.util import instantiate_class_from_config
 
 
@@ -18,7 +19,6 @@ def test_instantiate_class_from_config():
 
 @pytest.mark.unit
 def test_instantiate_class_from_config_with_overriden_defaults():
-
     # This config structure feels very tidy to me, even with nesting.
     fake_configurable_wrapper_object = instantiate_class_from_config(
         config={
@@ -32,10 +32,7 @@ def test_instantiate_class_from_config_with_overriden_defaults():
         },
         runtime_environment={"x": 1},
     )
-    assert (
-        fake_configurable_wrapper_object.fake_configurable_object.a
-        == "default_value_for_a"
-    )
+    assert fake_configurable_wrapper_object.fake_configurable_object.a == "default_value_for_a"
 
     fake_configurable_wrapper_object = instantiate_class_from_config(
         config={
@@ -50,10 +47,7 @@ def test_instantiate_class_from_config_with_overriden_defaults():
         },
         runtime_environment={"x": 1},
     )
-    assert (
-        fake_configurable_wrapper_object.fake_configurable_object.a
-        == "not_the_default_value"
-    )
+    assert fake_configurable_wrapper_object.fake_configurable_object.a == "not_the_default_value"
 
 
 @pytest.mark.unit
@@ -180,3 +174,42 @@ def test_instantiate_class_from_config_with_config_defaults():
             "a": "value_from_the_config",
         },
     )
+
+
+@pytest.mark.unit
+@pytest.mark.parametrize(
+    "progress_bars_config,expect_global,expect_metric_calculations",
+    [
+        (ProgressBarsConfig(), True, True),
+        (ProgressBarsConfig(metric_calculations=False), True, False),
+        (
+            ProgressBarsConfig(metric_calculations=False),
+            True,
+            False,
+        ),
+        (
+            ProgressBarsConfig(globally=True, metric_calculations=False),
+            True,
+            False,
+        ),
+        (
+            ProgressBarsConfig(globally=False, metric_calculations=True),
+            False,
+            True,
+        ),
+        (ProgressBarsConfig(globally=False), False, False),
+    ],
+)
+def test_config_pbar_option(
+    progress_bars_config: ProgressBarsConfig,
+    expect_global: bool,
+    expect_metric_calculations: bool,
+):
+    enabled_pbars = [
+        progress_bars_config.globally,
+        progress_bars_config.metric_calculations,
+    ]
+    assert enabled_pbars == [
+        expect_global,
+        expect_metric_calculations,
+    ]
