@@ -1,12 +1,17 @@
 import glob
 import re
-from typing import List, Pattern, Tuple, cast
+from typing import List, Pattern, Tuple
 
 import pytest
 from packaging import version
 
 from great_expectations.data_context.util import file_relative_path
 
+UNNEEDED_DEPRECATION_WARNINGS_THRESHOLD = 13
+
+# module level markers
+pytestmark = pytest.mark.unit
+
 
 @pytest.fixture
 def regex_for_deprecation_comments() -> Pattern:
@@ -16,10 +21,22 @@ def regex_for_deprecation_comments() -> Pattern:
 
 @pytest.fixture
 def files_with_deprecation_warnings() -> List[str]:
-    files: List[str] = glob.glob("great_expectations/**/*.py", recursive=True)
+    files: List[str] = glob.glob(  # noqa: PTH207 # FIXME CoP
+        "great_expectations/**/*.py", recursive=True
+    )
+    files_to_exclude = [
+        "great_expectations/compatibility/docstring_parser.py",
+        "great_expectations/compatibility/pyspark.py",
+        "great_expectations/compatibility/sqlalchemy_and_pandas.py",
+        "great_expectations/compatibility/sqlalchemy_compatibility_wrappers.py",
+    ]
+    for file_to_exclude in files_to_exclude:
+        if file_to_exclude in files:
+            files.remove(file_to_exclude)
     return files
 
 
+@pytest.mark.unit
 def test_deprecation_warnings_are_accompanied_by_appropriate_comment(
     regex_for_deprecation_comments: Pattern,
     files_with_deprecation_warnings: List[str],
@@ -27,7 +44,7 @@ def test_deprecation_warnings_are_accompanied_by_appropriate_comment(
     """
     What does this test do and why?
 
-    For every invokation of 'DeprecationWarning', there must be a corresponding
+    For every invocation of 'DeprecationWarning', there must be a corresponding
     comment with the following format: 'deprecated-v<MAJOR>.<MINOR>.<PATCH>'.
 
     This test is meant to capture instances where one or the other is missing.
@@ -38,11 +55,13 @@ def test_deprecation_warnings_are_accompanied_by_appropriate_comment(
 
         matches: List[str] = regex_for_deprecation_comments.findall(contents)
         warning_count: int = contents.count("DeprecationWarning")
-        assert (
-            len(matches) == warning_count
-        ), f"Either a 'deprecated-v...' comment or 'DeprecationWarning' call is missing from {file}"
+        assert len(matches) == warning_count, (
+            "Either a 'deprecated-v...' comment or "
+            f"'DeprecationWarning' call is missing from {file}"
+        )
 
 
+@pytest.mark.unit
 def test_deprecation_warnings_have_been_removed_after_two_minor_versions(
     regex_for_deprecation_comments: Pattern,
     files_with_deprecation_warnings: List[str],
@@ -60,9 +79,8 @@ def test_deprecation_warnings_have_been_removed_after_two_minor_versions(
     with open(deployment_version_path) as f:
         current_version = f.read().strip()
 
-    current_parsed_version: version.Version = cast(
-        version.Version, version.parse(current_version)
-    )
+    current_parsed_version: version.Version = version.parse(current_version)
+    current_major_version: int = current_parsed_version.major
     current_minor_version: int = current_parsed_version.minor
 
     unneeded_deprecation_warnings: List[Tuple[str, str]] = []
@@ -72,21 +90,22 @@ def test_deprecation_warnings_have_been_removed_after_two_minor_versions(
 
         matches: List[str] = regex_for_deprecation_comments.findall(contents)
         for match in matches:
-            parsed_version: version.Version = cast(
-                version.Version, version.parse(match)
-            )
+            parsed_version: version.Version = version.parse(match)
+            major_version: int = parsed_version.major
             minor_version: int = parsed_version.minor
-            if current_minor_version - minor_version > 2:
+            if (current_major_version - major_version > 0) and (
+                current_minor_version - minor_version > 2
+            ):
                 unneeded_deprecation_warning: Tuple[str, str] = (file, match)
                 unneeded_deprecation_warnings.append(unneeded_deprecation_warning)
 
     if unneeded_deprecation_warnings:
-        print(
-            "\nThe following deprecation warnings must be cleared per the code style guide:"
-        )
+        print("\nThe following deprecation warnings must be cleared per the code style guide:")
         for file, version_ in unneeded_deprecation_warnings:
             print(f"{file} - v{version_}")
 
-    # Chetan - 20220316 - Note that this will break as soon as v0.16.0 lands;
-    # this should be cleaned up and made 0 at that point.
-    assert len(unneeded_deprecation_warnings) <= 35
+    # Chetan - 20220316 - Once v0.16.0 lands, this should be cleaned up and made 0.
+    if len(unneeded_deprecation_warnings) > UNNEEDED_DEPRECATION_WARNINGS_THRESHOLD:
+        raise ValueError(
+            f"Found {len(unneeded_deprecation_warnings)} warnings but threshold is {UNNEEDED_DEPRECATION_WARNINGS_THRESHOLD}; please adjust accordingly"  # noqa: E501 # FIXME CoP
+        )
