@@ -1,54 +1,31 @@
 import copy
 import datetime
-import json
-import logging
 import os
-from typing import Any
+from typing import TYPE_CHECKING, Any
 
-import numpy as np
 import pytest
 
 import great_expectations as gx
 from great_expectations.core.util import nested_update
 from great_expectations.util import (
-    convert_json_string_to_be_python_compliant,
     convert_ndarray_datetime_to_float_dtype_utc_timezone,
     convert_ndarray_float_to_datetime_tuple,
     convert_ndarray_to_datetime_dtype_best_effort,
     deep_filter_properties_iterable,
     filter_properties_dict,
-    get_currently_executing_function_call_arguments,
     hyphen,
     is_ndarray_datetime_dtype,
-    lint_code,
 )
 
-
-@pytest.fixture
-def empty_expectation_suite():
-    expectation_suite = {
-        "expectation_suite_name": "default",
-        "meta": {},
-        "expectations": [],
-    }
-    return expectation_suite
-
-
-@pytest.fixture
-def file_data_asset(tmp_path):
-    tmp_path = str(tmp_path)
-    path = os.path.join(tmp_path, "file_data_asset.txt")
-    with open(path, "w+") as file:
-        file.write(json.dumps([0, 1, 2, 3, 4]))
-
-    return gx.data_asset.FileDataAsset(file_path=path)
+if TYPE_CHECKING:
+    import numpy as np
 
 
 @pytest.fixture
 def datetime_array():
     week_idx: int
     return [
-        datetime.datetime(2021, 1, 1, 0, 0, 0) + datetime.timedelta(days=(week_idx * 7))
+        datetime.datetime(2021, 1, 1, 0, 0, 0) + datetime.timedelta(days=(week_idx * 7))  # noqa: DTZ001 # FIXME CoP
         for week_idx in range(4)
     ]
 
@@ -58,8 +35,7 @@ def datetime_string_array():
     week_idx: int
     return [
         (
-            datetime.datetime(2021, 1, 1, 0, 0, 0)
-            + datetime.timedelta(days=(week_idx * 7))
+            datetime.datetime(2021, 1, 1, 0, 0, 0) + datetime.timedelta(days=(week_idx * 7))  # noqa: DTZ001 # FIXME CoP
         ).isoformat()
         for week_idx in range(4)
     ]
@@ -71,176 +47,21 @@ def numeric_array():
     return [idx for idx in range(4)]
 
 
-@pytest.mark.unit
-def test_validate_non_dataset(file_data_asset, empty_expectation_suite):
-    with pytest.raises(
-        ValueError, match=r"The validate util method only supports dataset validations"
-    ):
-        with pytest.warns(
-            Warning,
-            match="No great_expectations version found in configuration object.",
-        ):
-            gx.validate(
-                file_data_asset,
-                empty_expectation_suite,
-                data_asset_class=gx.data_asset.FileDataAsset,
-            )
-
-
-@pytest.mark.unit
-def test_validate_dataset(dataset, basic_expectation_suite):
-    res = gx.validate(dataset, basic_expectation_suite)
-    # assert res.success is True  # will not be true for mysql, where "infinities" column is missing
-    assert res["statistics"]["evaluated_expectations"] == 4
-    if isinstance(dataset, gx.dataset.PandasDataset):
-        res = gx.validate(
-            dataset,
-            expectation_suite=basic_expectation_suite,
-            data_asset_class=gx.dataset.PandasDataset,
-        )
-        assert res.success is True
-        assert res["statistics"]["evaluated_expectations"] == 4
-        with pytest.raises(
-            ValueError,
-            match=r"The validate util method only supports validation for subtypes of the provided data_asset_type",
-        ):
-            gx.validate(
-                dataset,
-                basic_expectation_suite,
-                data_asset_class=gx.dataset.SqlAlchemyDataset,
-            )
-
-    elif (
-        isinstance(dataset, gx.dataset.SqlAlchemyDataset)
-        and dataset.sql_engine_dialect.name.lower() != "mysql"
-    ):
-        res = gx.validate(
-            dataset,
-            expectation_suite=basic_expectation_suite,
-            data_asset_class=gx.dataset.SqlAlchemyDataset,
-        )
-        assert res.success is True
-        assert res["statistics"]["evaluated_expectations"] == 4
-        with pytest.raises(
-            ValueError,
-            match=r"The validate util method only supports validation for subtypes of the provided data_asset_type",
-        ):
-            gx.validate(
-                dataset,
-                expectation_suite=basic_expectation_suite,
-                data_asset_class=gx.dataset.PandasDataset,
-            )
-
-    elif (
-        isinstance(dataset, gx.dataset.SqlAlchemyDataset)
-        and dataset.sql_engine_dialect.name.lower() == "mysql"
-    ):
-        # mysql cannot use the infinities column
-        res = gx.validate(
-            dataset,
-            expectation_suite=basic_expectation_suite,
-            data_asset_class=gx.dataset.SqlAlchemyDataset,
-        )
-        assert res.success is False
-        assert res["statistics"]["evaluated_expectations"] == 4
-        with pytest.raises(
-            ValueError,
-            match=r"The validate util method only supports validation for subtypes of the provided data_asset_type",
-        ):
-            gx.validate(
-                dataset,
-                expectation_suite=basic_expectation_suite,
-                data_asset_class=gx.dataset.PandasDataset,
-            )
-
-    elif isinstance(dataset, gx.dataset.SparkDFDataset):
-        res = gx.validate(
-            dataset, basic_expectation_suite, data_asset_class=gx.dataset.SparkDFDataset
-        )
-        assert res.success is True
-        assert res["statistics"]["evaluated_expectations"] == 4
-        with pytest.raises(
-            ValueError,
-            match=r"The validate util method only supports validation for subtypes of the provided data_asset_type",
-        ):
-            gx.validate(
-                dataset,
-                expectation_suite=basic_expectation_suite,
-                data_asset_class=gx.dataset.PandasDataset,
-            )
-
-
-@pytest.mark.unit
-def test_validate_using_data_context(
-    dataset, data_context_parameterized_expectation_suite
-):
-    # Before running, the data context should not have compiled parameters
-    assert (
-        data_context_parameterized_expectation_suite._evaluation_parameter_dependencies_compiled
-        is False
-    )
-
-    res = gx.validate(
-        dataset,
-        expectation_suite_name="my_dag_node.default",
-        data_context=data_context_parameterized_expectation_suite,
-    )
-
-    # Since the handling of evaluation parameters is no longer happening without an action,
-    # the context should still be not compiles after validation.
-    assert (
-        data_context_parameterized_expectation_suite._evaluation_parameter_dependencies_compiled
-        is False
-    )
-
-    # And, we should have validated the right number of expectations from the context-provided config
-    assert res.success is False
-    assert res.statistics["evaluated_expectations"] == 2
-
-
-@pytest.mark.unit
-def test_validate_using_data_context_path(
-    dataset, data_context_parameterized_expectation_suite
-):
-    data_context_path = data_context_parameterized_expectation_suite.root_directory
-    res = gx.validate(
-        dataset,
-        expectation_suite_name="my_dag_node.default",
-        data_context=data_context_path,
-    )
-
-    # We should have now found the right suite with expectations to evaluate
-    assert res.success is False
-    assert res["statistics"]["evaluated_expectations"] == 2
-
-
-@pytest.mark.integration
-@pytest.mark.slow  # 1.61s
-def test_validate_invalid_parameters(
-    dataset, basic_expectation_suite, data_context_parameterized_expectation_suite
-):
-    with pytest.raises(
-        ValueError,
-        match="Either an expectation suite or a DataContext is required for validation.",
-    ):
-        gx.validate(dataset)
-
-
 @pytest.mark.unit
 def test_gen_directory_tree_str(tmpdir):
     project_dir = str(tmpdir.mkdir("project_dir"))
-    os.mkdir(os.path.join(project_dir, "BBB"))
-    with open(os.path.join(project_dir, "BBB", "bbb.txt"), "w") as f:
+    os.mkdir(os.path.join(project_dir, "BBB"))  # noqa: PTH102, PTH118 # FIXME CoP
+    with open(os.path.join(project_dir, "BBB", "bbb.txt"), "w") as f:  # noqa: PTH118 # FIXME CoP
         f.write("hello")
-    with open(os.path.join(project_dir, "BBB", "aaa.txt"), "w") as f:
+    with open(os.path.join(project_dir, "BBB", "aaa.txt"), "w") as f:  # noqa: PTH118 # FIXME CoP
         f.write("hello")
 
-    os.mkdir(os.path.join(project_dir, "AAA"))
+    os.mkdir(os.path.join(project_dir, "AAA"))  # noqa: PTH102, PTH118 # FIXME CoP
 
     res = gx.util.gen_directory_tree_str(project_dir)
     print(res)
 
-    # Note: files and directories are sorteds alphabetically, so that this method can be used for testing.
+    # Note: files and directories are sorteds alphabetically, so that this method can be used for testing.  # noqa: E501 # FIXME CoP
     assert (
         res
         == """\
@@ -255,7 +76,7 @@ project_dir/
 
 @pytest.mark.unit
 def test_nested_update():
-    # nested_update is useful for update nested dictionaries (such as batch_kwargs with reader_options as a dictionary)
+    # nested_update is useful for update nested dictionaries (such as batch_kwargs with reader_options as a dictionary)  # noqa: E501 # FIXME CoP
     batch_kwargs = {
         "path": "/a/path",
         "reader_method": "read_csv",
@@ -273,7 +94,7 @@ def test_nested_update():
 
 @pytest.mark.unit
 def test_nested_update_lists():
-    # nested_update is useful for update nested dictionaries (such as batch_kwargs with reader_options as a dictionary)
+    # nested_update is useful for update nested dictionaries (such as batch_kwargs with reader_options as a dictionary)  # noqa: E501 # FIXME CoP
     dependencies = {
         "suite.warning": {"metric.name": ["column=foo"]},
         "suite.failure": {"metric.blarg": [""]},
@@ -297,120 +118,6 @@ def test_nested_update_lists():
     }
 
 
-@pytest.mark.unit
-def test_linter_raises_error_on_non_string_input():
-    with pytest.raises(TypeError):
-        lint_code(99)
-
-
-@pytest.mark.unit
-def test_linter_changes_dirty_code():
-    code = "foo = [1,2,3]"
-    assert lint_code(code) == "foo = [1, 2, 3]\n"
-
-
-@pytest.mark.unit
-def test_linter_leaves_clean_code():
-    code = "foo = [1, 2, 3]\n"
-    assert lint_code(code) == "foo = [1, 2, 3]\n"
-
-
-@pytest.mark.unit
-def test_convert_json_string_to_be_python_compliant_null_replacement(caplog):
-    text = """
-    "ge_cloud_id": null,
-    "expectation_context": {"description": null},
-    """
-    expected = """
-    "ge_cloud_id": None,
-    "expectation_context": {"description": None},
-    """
-
-    with caplog.at_level(logging.INFO):
-        res = convert_json_string_to_be_python_compliant(text)
-
-    assert res == expected
-    assert (
-        "Replaced 'ge_cloud_id: null' with 'ge_cloud_id: None' before writing to file"
-        in caplog.text
-    )
-    assert (
-        "Replaced 'description: null' with 'description: None' before writing to file"
-        in caplog.text
-    )
-
-
-@pytest.mark.unit
-def test_convert_json_string_to_be_python_compliant_bool_replacement(caplog):
-    text = """
-    "meta": {},
-    "kwargs": {
-        "column": "input_date",
-        "max_value": "2027-09-03 00:00:00",
-        "min_value": "2015-01-01 00:00:00",
-        "parse_strings_as_datetimes": true,
-        "catch_exceptions": false
-    },
-    """
-    expected = """
-    "meta": {},
-    "kwargs": {
-        "column": "input_date",
-        "max_value": "2027-09-03 00:00:00",
-        "min_value": "2015-01-01 00:00:00",
-        "parse_strings_as_datetimes": True,
-        "catch_exceptions": False
-    },
-    """
-
-    with caplog.at_level(logging.INFO):
-        res = convert_json_string_to_be_python_compliant(text)
-
-    assert res == expected
-    assert (
-        "Replaced '\"parse_strings_as_datetimes\": true' with '\"parse_strings_as_datetimes\": True' before writing to file"
-        in caplog.text
-    )
-    assert (
-        "Replaced '\"catch_exceptions\": false' with '\"catch_exceptions\": False' before writing to file"
-        in caplog.text
-    )
-
-
-@pytest.mark.unit
-def test_convert_json_string_to_be_python_compliant_no_replacement():
-    text = """
-    "kwargs": {"max_value": 10000, "min_value": 10000},
-    "expectation_type": "expect_table_row_count_to_be_between",
-    "meta": {},
-    """
-    res = convert_json_string_to_be_python_compliant(text)
-    assert res == text
-
-
-@pytest.mark.unit
-def test_get_currently_executing_function_call_arguments(a=None, *args, **kwargs):
-    if a is None:
-        test_get_currently_executing_function_call_arguments(0, 1, 2, 3, b=5)
-    else:
-        assert a == 0
-        assert args == (1, 2, 3)
-        assert kwargs == {"b": 5}
-        params = get_currently_executing_function_call_arguments(
-            **{
-                "additional_param_0": "xyz_0",
-                "additional_param_1": "xyz_1",
-                "additional_param_2": "xyz_2",
-            }
-        )
-        assert params["a"] == 0
-        assert params["args"] == (1, 2, 3)
-        assert params["b"] == 5
-        assert params["additional_param_0"] == "xyz_0"
-        assert params["additional_param_1"] == "xyz_1"
-        assert params["additional_param_2"] == "xyz_2"
-
-
 @pytest.mark.unit
 def test_filter_properties_dict():
     source_dict: dict = {
@@ -708,8 +415,7 @@ def test_convert_ndarray_to_datetime_dtype_best_effort(
         parse_strings_as_datetimes=False,
     )
     ndarray_is_datetime_type = (
-        original_ndarray_is_datetime_type
-        or conversion_ndarray_to_datetime_type_performed
+        original_ndarray_is_datetime_type or conversion_ndarray_to_datetime_type_performed
     )
 
     assert ndarray_is_datetime_type
@@ -724,8 +430,7 @@ def test_convert_ndarray_to_datetime_dtype_best_effort(
         parse_strings_as_datetimes=True,
     )
     ndarray_is_datetime_type = (
-        original_ndarray_is_datetime_type
-        or conversion_ndarray_to_datetime_type_performed
+        original_ndarray_is_datetime_type or conversion_ndarray_to_datetime_type_performed
     )
 
     assert ndarray_is_datetime_type
@@ -740,8 +445,7 @@ def test_convert_ndarray_to_datetime_dtype_best_effort(
         parse_strings_as_datetimes=False,
     )
     ndarray_is_datetime_type = (
-        original_ndarray_is_datetime_type
-        or conversion_ndarray_to_datetime_type_performed
+        original_ndarray_is_datetime_type or conversion_ndarray_to_datetime_type_performed
     )
 
     assert not ndarray_is_datetime_type
@@ -756,8 +460,7 @@ def test_convert_ndarray_to_datetime_dtype_best_effort(
         parse_strings_as_datetimes=True,
     )
     ndarray_is_datetime_type = (
-        original_ndarray_is_datetime_type
-        or conversion_ndarray_to_datetime_type_performed
+        original_ndarray_is_datetime_type or conversion_ndarray_to_datetime_type_performed
     )
 
     assert ndarray_is_datetime_type
@@ -773,8 +476,7 @@ def test_convert_ndarray_to_datetime_dtype_best_effort(
         parse_strings_as_datetimes=True,
     )
     ndarray_is_datetime_type = (
-        original_ndarray_is_datetime_type
-        or conversion_ndarray_to_datetime_type_performed
+        original_ndarray_is_datetime_type or conversion_ndarray_to_datetime_type_performed
     )
 
     assert not ndarray_is_datetime_type
@@ -789,8 +491,7 @@ def test_convert_ndarray_to_datetime_dtype_best_effort(
         parse_strings_as_datetimes=False,
     )
     ndarray_is_datetime_type = (
-        original_ndarray_is_datetime_type
-        or conversion_ndarray_to_datetime_type_performed
+        original_ndarray_is_datetime_type or conversion_ndarray_to_datetime_type_performed
     )
 
     assert not ndarray_is_datetime_type
@@ -805,8 +506,7 @@ def test_convert_ndarray_to_datetime_dtype_best_effort(
         parse_strings_as_datetimes=True,
     )
     ndarray_is_datetime_type = (
-        original_ndarray_is_datetime_type
-        or conversion_ndarray_to_datetime_type_performed
+        original_ndarray_is_datetime_type or conversion_ndarray_to_datetime_type_performed
     )
 
     assert not ndarray_is_datetime_type
@@ -820,11 +520,8 @@ def test_convert_ndarray_datetime_to_float_dtype_utc_timezone(
     numeric_array,
 ):
     element: Any
-    assert convert_ndarray_datetime_to_float_dtype_utc_timezone(
-        data=datetime_array
-    ).tolist() == [
-        element.replace(tzinfo=datetime.timezone.utc).timestamp()
-        for element in datetime_array
+    assert convert_ndarray_datetime_to_float_dtype_utc_timezone(data=datetime_array).tolist() == [
+        element.replace(tzinfo=datetime.timezone.utc).timestamp() for element in datetime_array
     ]
 
     with pytest.raises(AttributeError) as e:
@@ -833,9 +530,7 @@ def test_convert_ndarray_datetime_to_float_dtype_utc_timezone(
     assert "'int' object has no attribute 'replace'" in str(e.value)
 
     with pytest.raises(TypeError) as e:
-        _ = convert_ndarray_datetime_to_float_dtype_utc_timezone(
-            data=datetime_string_array
-        )
+        _ = convert_ndarray_datetime_to_float_dtype_utc_timezone(data=datetime_string_array)
 
     assert "replace() takes no keyword arguments" in str(e.value)
 
@@ -847,15 +542,14 @@ def test_convert_ndarray_float_to_datetime_tuple(
     element: Any
     assert convert_ndarray_float_to_datetime_tuple(
         data=[
-            element.replace(tzinfo=datetime.timezone.utc).timestamp()
-            for element in datetime_array
+            element.replace(tzinfo=datetime.timezone.utc).timestamp() for element in datetime_array
         ]
     ) == tuple([element for element in datetime_array])
 
     with pytest.raises(TypeError) as e:
         _ = convert_ndarray_float_to_datetime_tuple(data=datetime_array)
 
-    # Error message varies based on version but mainly looking to validate type error by not using integer
+    # Error message varies based on version but mainly looking to validate type error by not using integer  # noqa: E501 # FIXME CoP
     assert all(string in str(e.value) for string in ("datetime.datetime", "integer"))
 
 
