@@ -4,97 +4,47 @@ import uuid
 import warnings
 from contextlib import contextmanager
 from dataclasses import dataclass
-from pathlib import Path
-from typing import Any, Generator, List, Optional, Set, Tuple, Union, cast
+from typing import Dict, List, Optional, Tuple, Union, cast
 
-import numpy as np
 import pandas as pd
-import pytest
+from sqlalchemy.exc import ProgrammingError
 
 import great_expectations.exceptions as gx_exceptions
 from great_expectations.alias_types import PathStr
+from great_expectations.compatibility import sqlalchemy
+from great_expectations.compatibility.sqlalchemy import Engine, inspect
+from great_expectations.compatibility.sqlalchemy import (
+    sqlalchemy as sa,
+)
+from great_expectations.compatibility.sqlalchemy_compatibility_wrappers import (
+    add_dataframe_to_db,
+)
 from great_expectations.core.yaml_handler import YAMLHandler
+from great_expectations.data_context.data_context.abstract_data_context import AbstractDataContext
 from great_expectations.data_context.store import (
     CheckpointStore,
     ConfigurationStore,
-    ProfilerStore,
     Store,
     StoreBackend,
 )
-from great_expectations.data_context.types.base import BaseYamlConfig, CheckpointConfig
+from great_expectations.data_context.types.base import BaseYamlConfig
 from great_expectations.data_context.types.resource_identifiers import (
     ConfigurationIdentifier,
 )
-from great_expectations.data_context.util import instantiate_class_from_config
+from great_expectations.datasource.fluent.sql_datasource import SQLDatasource
 from great_expectations.execution_engine import SqlAlchemyExecutionEngine
-
-logger = logging.getLogger(__name__)
-
-
-try:
-    import sqlalchemy as sa
-    from sqlalchemy.exc import SQLAlchemyError
-
-except ImportError:
-    logger.debug(
-        "Unable to load SqlAlchemy context; install optional sqlalchemy dependency for support"
-    )
-    sa = None
-    reflection = None
-    Table = None
-    Select = None
-    SQLAlchemyError = None
-
+from great_expectations.execution_engine.sqlalchemy_dialect import GXSqlDialect
 
 logger = logging.getLogger(__name__)
 yaml_handler = YAMLHandler()
 
-
-# Taken from the following stackoverflow:
-# https://stackoverflow.com/questions/23549419/assert-that-two-dictionaries-are-almost-equal
-# noinspection PyPep8Naming
-def assertDeepAlmostEqual(expected, actual, *args, **kwargs):
-    """
-    Assert that two complex structures have almost equal contents.
-
-    Compares lists, dicts and tuples recursively. Checks numeric values
-    using pyteset.approx and checks all other values with an assertion equality statement
-    Accepts additional positional and keyword arguments and pass those
-    intact to pytest.approx() (that's how you specify comparison
-    precision).
-
-    """
-    is_root = "__trace" not in kwargs
-    trace = kwargs.pop("__trace", "ROOT")
-    try:
-        # if isinstance(expected, (int, float, long, complex)):
-        if isinstance(expected, (int, float, complex)):
-            assert expected == pytest.approx(actual, *args, **kwargs)
-        elif isinstance(expected, (list, tuple, np.ndarray)):
-            assert len(expected) == len(actual)
-            for index in range(len(expected)):
-                v1, v2 = expected[index], actual[index]
-                assertDeepAlmostEqual(v1, v2, __trace=repr(index), *args, **kwargs)
-        elif isinstance(expected, dict):
-            assert set(expected) == set(actual)
-            for key in expected:
-                assertDeepAlmostEqual(
-                    expected[key], actual[key], __trace=repr(key), *args, **kwargs
-                )
-        else:
-            assert expected == actual
-    except AssertionError as exc:
-        exc.__dict__.setdefault("traces", []).append(trace)
-        if is_root:
-            trace = " -> ".join(reversed(exc.traces))
-            exc = AssertionError(f"{str(exc)}\nTRACE: {trace}")
-        raise exc
+SQLAlchemyError = sqlalchemy.SQLAlchemyError
 
 
 def safe_remove(path):
     if path is not None:
         try:
-            os.remove(path)
+            os.remove(path)  # noqa: PTH107 # FIXME CoP
         except OSError as e:
             print(e)
 
@@ -106,14 +56,17 @@ def create_files_in_directory(
     for file_name in file_name_list:
         splits = file_name.split("/")
         for i in range(1, len(splits)):
-            subdirectories.append(os.path.join(*splits[:i]))
+            subdirectories.append(os.path.join(*splits[:i]))  # noqa: PTH118 # FIXME CoP
     subdirectories = set(subdirectories)
 
     for subdirectory in subdirectories:
-        os.makedirs(os.path.join(directory, subdirectory), exist_ok=True)
+        os.makedirs(  # noqa: PTH103 # FIXME CoP
+            os.path.join(directory, subdirectory),  # noqa: PTH118 # FIXME CoP
+            exist_ok=True,
+        )
 
     for file_name in file_name_list:
-        file_path = os.path.join(directory, file_name)
+        file_path = os.path.join(directory, file_name)  # noqa: PTH118 # FIXME CoP
         with open(file_path, "w") as f_:
             f_.write(file_content_fn())
 
@@ -148,29 +101,26 @@ def validate_uuid4(uuid_string: str) -> bool:
     return val.hex == uuid_string.replace("-", "")
 
 
-def get_sqlite_temp_table_names(engine):
-    result = engine.execute(
-        """
-SELECT
-    name
-FROM
-    sqlite_temp_master
-"""
-    )
-    rows = result.fetchall()
+def get_sqlite_temp_table_names(execution_engine: SqlAlchemyExecutionEngine):
+    statement = sa.text("SELECT name FROM sqlite_temp_master")
+
+    rows = execution_engine.execute_query(statement).fetchall()
     return {row[0] for row in rows}
 
 
-def get_sqlite_table_names(engine):
-    result = engine.execute(
-        """
-SELECT
-    name
-FROM
-    sqlite_master
-"""
-    )
-    rows = result.fetchall()
+def get_sqlite_table_names(execution_engine: SqlAlchemyExecutionEngine):
+    statement = sa.text("SELECT name FROM sqlite_master")
+
+    rows = execution_engine.execute_query(statement).fetchall()
+
+    return {row[0] for row in rows}
+
+
+def get_sqlite_temp_table_names_from_engine(engine: Engine):
+    statement = sa.text("SELECT name FROM sqlite_temp_master")
+
+    with engine.connect() as connection:
+        rows = connection.execute(statement).fetchall()
     return {row[0] for row in rows}
 
 
@@ -183,7 +133,7 @@ def build_tuple_filesystem_store_backend(
 ) -> StoreBackend:
     logger.debug(
         f"""Starting data_context/store/util.py#build_tuple_filesystem_store_backend using base_directory:
-"{base_directory}"""
+"{base_directory}"""  # noqa: E501 # FIXME CoP
     )
     store_backend_config: dict = {
         "module_name": module_name,
@@ -192,62 +142,12 @@ def build_tuple_filesystem_store_backend(
     }
     store_backend_config.update(**kwargs)
     return Store.build_store_from_config(
-        store_config=store_backend_config,
+        config=store_backend_config,
         module_name=module_name,
         runtime_environment=None,
     )
 
 
-def build_checkpoint_store_using_filesystem(
-    store_name: str,
-    base_directory: str,
-    overwrite_existing: bool = False,
-) -> CheckpointStore:
-    store_config: dict = {"base_directory": base_directory}
-    store_backend_obj: StoreBackend = build_tuple_filesystem_store_backend(
-        **store_config
-    )
-    return build_checkpoint_store_using_store_backend(
-        store_name=store_name,
-        store_backend=store_backend_obj,
-        overwrite_existing=overwrite_existing,
-    )
-
-
-def build_profiler_store_using_store_backend(
-    store_name: str,
-    store_backend: Union[StoreBackend, dict],
-    overwrite_existing: bool = False,
-) -> ProfilerStore:
-    return cast(
-        ProfilerStore,
-        build_configuration_store(
-            class_name="ProfilerStore",
-            module_name="great_expectations.data_context.store",
-            store_name=store_name,
-            store_backend=store_backend,
-            overwrite_existing=overwrite_existing,
-        ),
-    )
-
-
-def build_profiler_store_using_filesystem(
-    store_name: str,
-    base_directory: str,
-    overwrite_existing: bool = False,
-) -> ProfilerStore:
-    store_config: dict = {"base_directory": base_directory}
-    store_backend_obj: StoreBackend = build_tuple_filesystem_store_backend(
-        **store_config
-    )
-    store = build_profiler_store_using_store_backend(
-        store_name=store_name,
-        store_backend=store_backend_obj,
-        overwrite_existing=overwrite_existing,
-    )
-    return store
-
-
 def save_config_to_filesystem(
     configuration_store_class_name: str,
     configuration_store_module_name: str,
@@ -257,9 +157,7 @@ def save_config_to_filesystem(
     configuration: BaseYamlConfig,
 ):
     store_config: dict = {"base_directory": base_directory}
-    store_backend_obj: StoreBackend = build_tuple_filesystem_store_backend(
-        **store_config
-    )
+    store_backend_obj: StoreBackend = build_tuple_filesystem_store_backend(**store_config)
     save_config_to_store_backend(
         class_name=configuration_store_class_name,
         module_name=configuration_store_module_name,
@@ -278,9 +176,7 @@ def load_config_from_filesystem(
     configuration_key: str,
 ) -> BaseYamlConfig:
     store_config: dict = {"base_directory": base_directory}
-    store_backend_obj: StoreBackend = build_tuple_filesystem_store_backend(
-        **store_config
-    )
+    store_backend_obj: StoreBackend = build_tuple_filesystem_store_backend(**store_config)
     return load_config_from_store_backend(
         class_name=configuration_store_class_name,
         module_name=configuration_store_module_name,
@@ -307,7 +203,7 @@ def build_configuration_store(
         store_backend = store_backend.config
     elif not isinstance(store_backend, dict):
         raise gx_exceptions.DataContextError(
-            "Invalid configuration: A store_backend needs to be a dictionary or inherit from the StoreBackend class."
+            "Invalid configuration: A store_backend needs to be a dictionary or inherit from the StoreBackend class."  # noqa: E501 # FIXME CoP
         )
 
     store_backend.update(**kwargs)
@@ -319,8 +215,8 @@ def build_configuration_store(
         "overwrite_existing": overwrite_existing,
         "store_backend": store_backend,
     }
-    configuration_store: ConfigurationStore = Store.build_store_from_config(  # type: ignore[assignment]
-        store_config=store_config,
+    configuration_store: ConfigurationStore = Store.build_store_from_config(  # type: ignore[assignment] # FIXME CoP
+        config=store_config,
         module_name=module_name,
         runtime_environment=None,
     )
@@ -347,27 +243,6 @@ def delete_config_from_store_backend(
     config_store.remove_key(key=key)
 
 
-def load_checkpoint_config_from_store_backend(
-    store_name: str,
-    store_backend: Union[StoreBackend, dict],
-    checkpoint_name: str,
-) -> CheckpointConfig:
-    config_store: CheckpointStore = build_checkpoint_store_using_store_backend(
-        store_name=store_name,
-        store_backend=store_backend,
-    )
-    key = ConfigurationIdentifier(
-        configuration_key=checkpoint_name,
-    )
-    try:
-        return config_store.get(key=key)  # type: ignore[return-value]
-    except gx_exceptions.InvalidBaseYamlConfigError as exc:
-        logger.error(exc.messages)
-        raise gx_exceptions.InvalidCheckpointConfigError(
-            "Error while processing DataContextConfig.", exc
-        )
-
-
 def delete_checkpoint_config_from_store_backend(
     store_name: str,
     store_backend: Union[StoreBackend, dict],
@@ -389,7 +264,7 @@ def build_checkpoint_store_using_store_backend(
     overwrite_existing: bool = False,
 ) -> CheckpointStore:
     return cast(
-        CheckpointStore,
+        "CheckpointStore",
         build_configuration_store(
             class_name="CheckpointStore",
             module_name="great_expectations.data_context.store",
@@ -438,7 +313,7 @@ def load_config_from_store_backend(
     key = ConfigurationIdentifier(
         configuration_key=configuration_key,
     )
-    return config_store.get(key=key)  # type: ignore[return-value]
+    return config_store.get(key=key)  # type: ignore[return-value] # FIXME CoP
 
 
 def delete_config_from_filesystem(
@@ -449,9 +324,7 @@ def delete_config_from_filesystem(
     configuration_key: str,
 ):
     store_config: dict = {"base_directory": base_directory}
-    store_backend_obj: StoreBackend = build_tuple_filesystem_store_backend(
-        **store_config
-    )
+    store_backend_obj: StoreBackend = build_tuple_filesystem_store_backend(**store_config)
     delete_config_from_store_backend(
         class_name=configuration_store_class_name,
         module_name=configuration_store_module_name,
@@ -503,7 +376,7 @@ def get_bigquery_table_prefix() -> str:
 
     Returns:
         String of table prefix, which is the gcp_project and dataset concatenated by a "."
-    """
+    """  # noqa: E501 # FIXME CoP
     gcp_project = os.environ.get("GE_TEST_GCP_PROJECT")
     if not gcp_project:
         raise ValueError(
@@ -555,7 +428,7 @@ def load_and_concatenate_csvs(
 
     Returns:
         A pandas dataframe concatenating data loaded from all csvs.
-    """
+    """  # noqa: E501 # FIXME CoP
 
     if convert_column_names_to_datetime is None:
         convert_column_names_to_datetime = []
@@ -569,7 +442,7 @@ def load_and_concatenate_csvs(
             df=df, column_names_to_convert=convert_column_names_to_datetime
         )
         if not load_full_dataset:
-            # Improving test performance by only loading the first 10 rows of our test data into the db
+            # Improving test performance by only loading the first 10 rows of our test data into the db  # noqa: E501 # FIXME CoP
             df = df.head(10)
 
         dfs.append(df)
@@ -585,7 +458,7 @@ def convert_string_columns_to_datetime(
     """
     Converts specified columns (e.g., "pickup_datetime" and "dropoff_datetime") to datetime column type.
     Side-effect: Passed DataFrame is modified (in-place).
-    """
+    """  # noqa: E501 # FIXME CoP
     if column_names_to_convert is None:
         column_names_to_convert = []
 
@@ -594,7 +467,7 @@ def convert_string_columns_to_datetime(
         df[column_name_to_convert] = pd.to_datetime(df[column_name_to_convert])
 
 
-def load_data_into_test_database(
+def load_data_into_test_database(  # noqa: C901, PLR0912, PLR0915 # FIXME CoP
     table_name: str,
     connection_string: str,
     schema_name: Optional[str] = None,
@@ -624,7 +497,7 @@ def load_data_into_test_database(
         drop_existing_table: boolean value. If set to false, will append to existing table
     Returns:
         LoadedTable which for convenience, contains the pandas dataframe that was used to load the data.
-    """
+    """  # noqa: E501 # FIXME CoP
     if csv_path and csv_paths:
         csv_paths.append(csv_path)
     elif csv_path and not csv_paths:
@@ -645,10 +518,18 @@ def load_data_into_test_database(
         engine = sa.create_engine(connection_string)
     else:
         logger.debug(
-            "Attempting to load data in to tests SqlAlchemy database, but unable to load SqlAlchemy context; "
+            "Attempting to load data in to tests SqlAlchemy database, but unable to load SqlAlchemy context; "  # noqa: E501 # FIXME CoP
             "install optional sqlalchemy dependency for support."
         )
         return return_value
+
+    if engine.dialect.name.lower().startswith("mysql"):
+        # Don't attempt to DROP TABLE IF EXISTS on a table that doesn't exist in mysql because it will error  # noqa: E501 # FIXME CoP
+        inspector = inspect(engine)
+        db_name = connection_string.split("/")[-1]
+        table_names = [name for name in inspector.get_table_names(schema=db_name)]
+        drop_existing_table = table_name in table_names
+
     if engine.dialect.name.lower() == "bigquery":
         # bigquery is handled in a special way
         load_data_into_test_bigquery_database_with_bigquery_client(
@@ -665,44 +546,46 @@ def load_data_into_test_database(
             )
             return return_value
         except SQLAlchemyError:
-            error_message: str = """Docs integration tests encountered an error while loading test-data into test-database."""
-            logger.error(error_message)
+            error_message: str = """Docs integration tests encountered an error while loading test-data into test-database."""  # noqa: E501 # FIXME CoP
+            logger.error(error_message)  # noqa: TRY400 # FIXME CoP
             raise gx_exceptions.DatabaseConnectionError(error_message)
-            # Normally we would call `raise` to re-raise the SqlAlchemyError but we don't to make sure that
+            # Normally we would call `raise` to re-raise the SqlAlchemyError but we don't to make sure that  # noqa: E501 # FIXME CoP
             # sensitive information does not make it into our CI logs.
         finally:
             connection.close()
             engine.dispose()
     else:
         try:
-            connection = engine.connect()
             if drop_existing_table:
                 print(f"Dropping table {table_name}")
-                connection.execute(f"DROP TABLE IF EXISTS {table_name}")
+                with engine.begin() as connection:
+                    connection.execute(sa.text(f"DROP TABLE IF EXISTS {table_name}"))
                 print(f"Creating table {table_name} and adding data from {csv_paths}")
             else:
-                print(
-                    f"Adding to existing table {table_name} and adding data from {csv_paths}"
-                )
+                print(f"Adding to existing table {table_name} and adding data from {csv_paths}")
 
-            all_dfs_concatenated.to_sql(
-                name=table_name,
-                con=engine,
-                schema=schema_name,
-                index=False,
-                if_exists="append",
-                method=to_sql_method,
-            )
+            with engine.connect() as connection:
+                add_dataframe_to_db(
+                    df=all_dfs_concatenated,
+                    name=table_name,
+                    con=connection,
+                    schema=schema_name,
+                    index=False,
+                    if_exists="append",
+                    method=to_sql_method,
+                )
             return return_value
         except SQLAlchemyError:
-            error_message: str = """Docs integration tests encountered an error while loading test-data into test-database."""
-            logger.error(error_message)
+            error_message: str = """Docs integration tests encountered an error while loading test-data into test-database."""  # noqa: E501 # FIXME CoP
+            logger.error(error_message)  # noqa: TRY400 # FIXME CoP
             raise gx_exceptions.DatabaseConnectionError(error_message)
-            # Normally we would call `raise` to re-raise the SqlAlchemyError but we don't to make sure that
+            # Normally we would call `raise` to re-raise the SqlAlchemyError but we don't to make sure that  # noqa: E501 # FIXME CoP
             # sensitive information does not make it into our CI logs.
         finally:
-            connection.close()
-            engine.dispose()
+            if connection:
+                connection.close()
+            if engine:
+                engine.dispose()
 
 
 def load_data_into_test_bigquery_database_with_bigquery_client(
@@ -715,7 +598,7 @@ def load_data_into_test_bigquery_database_with_bigquery_client(
         dataframe (pd.DataFrame): DataFrame to load
         table_name (str): table to load DataFrame to. Prefix containing project and dataset are loaded
                         by helper function.
-    """
+    """  # noqa: E501 # FIXME CoP
     prefix: str = get_bigquery_table_prefix()
     table_id: str = f"""{prefix}.{table_name}"""
     from google.cloud import bigquery
@@ -729,7 +612,14 @@ def load_data_into_test_bigquery_database_with_bigquery_client(
     job: bigquery.LoadJob = client.load_table_from_dataframe(
         dataframe, table_id
     )  # Make an API request.
-    job.result()  # Wait for the job to complete
+    load_job = job.result()  # Wait for the job to complete
+    if load_job.errors or load_job.error_result:
+        raise gx_exceptions.DatabaseConnectionError(
+            "Unable to load data into BigQuery. Load job errors: "
+            + str(load_job.errors)
+            + " Load job error result: "
+            + str(load_job.error_result)
+        )
 
 
 def load_dataframe_into_test_athena_database_as_table(
@@ -785,18 +675,7 @@ def clean_up_tables_with_prefix(connection_string: str, table_prefix: str) -> Li
     execution_engine: SqlAlchemyExecutionEngine = SqlAlchemyExecutionEngine(
         connection_string=connection_string
     )
-    data_connector = instantiate_class_from_config(
-        config={
-            "class_name": "InferredAssetSqlDataConnector",
-            "name": "temp_data_connector",
-        },
-        runtime_environment={
-            "execution_engine": execution_engine,
-            "datasource_name": "temp_datasource",
-        },
-        config_defaults={"module_name": "great_expectations.datasource.data_connector"},
-    )
-    introspection_output = data_connector._introspect_db()
+    introspection_output = introspect_db(execution_engine=execution_engine)
 
     tables_to_drop: List[str] = []
     tables_dropped: List[str] = []
@@ -805,10 +684,9 @@ def clean_up_tables_with_prefix(connection_string: str, table_prefix: str) -> Li
         if table["table_name"].startswith(table_prefix):
             tables_to_drop.append(table["table_name"])
 
-    connection = execution_engine.engine.connect()
     for table_name in tables_to_drop:
         print(f"Dropping table {table_name}")
-        connection.execute(f"DROP TABLE IF EXISTS {table_name}")
+        execution_engine.execute_query_in_transaction(sa.text(f"DROP TABLE IF EXISTS {table_name}"))
         tables_dropped.append(table_name)
 
     tables_skipped: List[str] = list(set(tables_to_drop) - set(tables_dropped))
@@ -818,22 +696,106 @@ def clean_up_tables_with_prefix(connection_string: str, table_prefix: str) -> Li
     return tables_dropped
 
 
-@contextmanager
-def set_directory(path: str) -> Generator:
-    """Sets the cwd within the context
+def introspect_db(  # noqa: C901, PLR0912 # FIXME CoP
+    execution_engine: SqlAlchemyExecutionEngine,
+    schema_name: Union[str, None] = None,
+    ignore_information_schemas_and_system_tables: bool = True,
+    information_schemas: Optional[List[str]] = None,
+    system_tables: Optional[List[str]] = None,
+    include_views=True,
+) -> List[Dict[str, str]]:
+    # This code was broken out from the InferredAssetSqlDataConnector when it was removed
+    if information_schemas is None:
+        information_schemas = [
+            "INFORMATION_SCHEMA",  # snowflake, mssql, mysql, oracle
+            "information_schema",  # postgres, redshift, mysql
+            "performance_schema",  # mysql
+            "sys",  # mysql
+            "mysql",  # mysql
+        ]
 
-    Args:
-        path: The string representation of the desired path to cd into
+    if system_tables is None:
+        system_tables = ["sqlite_master"]  # sqlite
 
-    Yields:
-        None
-    """
-    origin = Path().absolute()
+    engine: sqlalchemy.Engine = execution_engine.engine
+    inspector: sqlalchemy.Inspector = sa.inspect(engine)
+
+    selected_schema_name = schema_name
+
+    tables: List[Dict[str, str]] = []
+    all_schema_names: List[str] = inspector.get_schema_names()
+    for schema in all_schema_names:
+        if ignore_information_schemas_and_system_tables and schema_name in information_schemas:
+            continue
+
+        if selected_schema_name is not None and schema_name != selected_schema_name:
+            continue
+
+        try:
+            table_names: List[str] = inspector.get_table_names(schema=schema)
+        except ProgrammingError:
+            # Likely another test already cleaned up this schema.
+            # TODO: Make tests only clean up after themselves
+            continue
+        for table_name in table_names:
+            if ignore_information_schemas_and_system_tables and (table_name in system_tables):
+                continue
+
+            tables.append(
+                {
+                    "schema_name": schema,
+                    "table_name": table_name,
+                    "type": "table",
+                }
+            )
+
+        # Note Abe 20201112: This logic is currently untested.
+        if include_views:
+            # Note: this is not implemented for bigquery
+            try:
+                view_names = inspector.get_view_names(schema=schema)
+            except NotImplementedError:
+                # Not implemented by Athena dialect
+                pass
+            else:
+                for view_name in view_names:
+                    if ignore_information_schemas_and_system_tables and (
+                        view_name in system_tables
+                    ):
+                        continue
+
+                    tables.append(
+                        {
+                            "schema_name": schema,
+                            "table_name": view_name,
+                            "type": "view",
+                        }
+                    )
+
+    # SQLAlchemy's introspection does not list "external tables" in Redshift Spectrum (tables whose data is stored on S3).  # noqa: E501 # FIXME CoP
+    # The following code fetches the names of external schemas and tables from a special table
+    # 'svv_external_tables'.
     try:
-        os.chdir(path)
-        yield
-    finally:
-        os.chdir(origin)
+        if engine.dialect.name.lower() == GXSqlDialect.REDSHIFT:
+            # noinspection SqlDialectInspection,SqlNoDataSourceInspection
+            result = execution_engine.execute_query(
+                sa.text("select schemaname, tablename from svv_external_tables")
+            ).fetchall()
+            for row in result:
+                tables.append(
+                    {
+                        "schema_name": row[0],
+                        "table_name": row[1],
+                        "type": "table",
+                    }
+                )
+    except Exception as e:
+        # Our testing shows that 'svv_external_tables' table is present in all Redshift clusters. This means that this  # noqa: E501 # FIXME CoP
+        # exception is highly unlikely to fire.
+        if "UndefinedTable" not in str(e):
+            raise e  # noqa: TRY201 # FIXME CoP
+
+    return tables
 
 
 def check_athena_table_count(
@@ -841,12 +803,12 @@ def check_athena_table_count(
 ) -> bool:
     """
     Helper function used by awsathena integration test. Checks whether expected number of tables exist in database
-    """
+    """  # noqa: E501 # FIXME CoP
     if sa:
         engine = sa.create_engine(connection_string)
     else:
         logger.debug(
-            "Attempting to perform test on AWSAthena database, but unable to load SqlAlchemy context; "
+            "Attempting to perform test on AWSAthena database, but unable to load SqlAlchemy context; "  # noqa: E501 # FIXME CoP
             "install optional sqlalchemy dependency for support."
         )
         return False
@@ -857,10 +819,10 @@ def check_athena_table_count(
         result = connection.execute(sa.text(f"SHOW TABLES in {db_name}")).fetchall()
         return len(result) == expected_table_count
     except SQLAlchemyError:
-        error_message: str = """Docs integration tests encountered an error while loading test-data into test-database."""
-        logger.error(error_message)
+        error_message: str = """Docs integration tests encountered an error while loading test-data into test-database."""  # noqa: E501 # FIXME CoP
+        logger.error(error_message)  # noqa: TRY400 # FIXME CoP
         raise gx_exceptions.DatabaseConnectionError(error_message)
-        # Normally we would call `raise` to re-raise the SqlAlchemyError but we don't to make sure that
+        # Normally we would call `raise` to re-raise the SqlAlchemyError but we don't to make sure that  # noqa: E501 # FIXME CoP
         # sensitive information does not make it into our CI logs.
     finally:
         connection.close()
@@ -875,7 +837,7 @@ def clean_athena_db(connection_string: str, db_name: str, table_to_keep: str) ->
         engine = sa.create_engine(connection_string)
     else:
         logger.debug(
-            "Attempting to perform test on AWSAthena database, but unable to load SqlAlchemy context; "
+            "Attempting to perform test on AWSAthena database, but unable to load SqlAlchemy context; "  # noqa: E501 # FIXME CoP
             "install optional sqlalchemy dependency for support."
         )
         return
@@ -906,7 +868,7 @@ def get_default_mysql_url() -> str:
     Returns:
         String of default connection to Docker container
     """
-    return "mysql+pymysql://root@localhost/test_ci"
+    return "mysql+pymysql://root@127.0.0.1/test_ci"
 
 
 def get_default_trino_url() -> str:
@@ -922,9 +884,11 @@ def get_default_mssql_url() -> str:
     Returns:
         String of default connection to Docker container
     """
-    db_hostname = os.getenv("GE_TEST_LOCAL_DB_HOSTNAME", "localhost")
-    connection_string = f"mssql+pyodbc://sa:ReallyStrongPwd1234%^&*@{db_hostname}:1433/test_ci?driver=ODBC Driver 17 for SQL Server&charset=utf8&autocommit=true"
-    return connection_string
+    return (
+        "mssql+pyodbc://sa:ReallyStrongPwd1234%^&*@127.0.0.1:1433/test_ci"
+        "?driver=ODBC Driver 18 for SQL Server&charset=utf8"
+        "&autocommit=true&TrustServerCertificate=yes"
+    )
 
 
 def get_awsathena_db_name(db_name_env_var: str = "ATHENA_DB_NAME") -> str:
@@ -936,7 +900,7 @@ def get_awsathena_db_name(db_name_env_var: str = "ATHENA_DB_NAME") -> str:
     athena_db_name: str = os.getenv(db_name_env_var)
     if not athena_db_name:
         raise ValueError(
-            f"Environment Variable {db_name_env_var} is required to run integration tests against AWS Athena"
+            f"Environment Variable {db_name_env_var} is required to run integration tests against AWS Athena"  # noqa: E501 # FIXME CoP
         )
     return athena_db_name
 
@@ -951,7 +915,7 @@ def get_awsathena_connection_url(db_name_env_var: str = "ATHENA_DB_NAME") -> str
     ATHENA_STAGING_S3: Optional[str] = os.getenv("ATHENA_STAGING_S3")
     if not ATHENA_STAGING_S3:
         raise ValueError(
-            "Environment Variable ATHENA_STAGING_S3 is required to run integration tests against AWS Athena"
+            "Environment Variable ATHENA_STAGING_S3 is required to run integration tests against AWS Athena"  # noqa: E501 # FIXME CoP
         )
 
     return f"awsathena+rest://@athena.us-east-1.amazonaws.com/{ATHENA_DB_NAME}?s3_staging_dir={ATHENA_STAGING_S3}"
@@ -960,7 +924,6 @@ def get_awsathena_connection_url(db_name_env_var: str = "ATHENA_DB_NAME") -> str
 def get_connection_string_and_dialect(
     athena_db_name_env_var: str = "ATHENA_DB_NAME",
 ) -> Tuple[str, str]:
-
     with open("./connection_string.yml") as f:
         db_config: dict = yaml_handler.load(f)
 
@@ -979,46 +942,28 @@ def get_connection_string_and_dialect(
     return dialect, connection_string
 
 
-def find_strings_in_nested_obj(obj: Any, target_strings: List[str]) -> bool:
-    """Recursively traverse a nested structure to find all strings in an input string.
+def add_datasource(
+    context: AbstractDataContext, *, name: str, connection_string: str
+) -> SQLDatasource:
+    """Add a datasource to the context based on the dialect from config file.
 
-    Args:
-        obj (Any): The object to traverse (generally a dict to start with)
-        target_strings (List[str]): The collection of strings to find.
-
-    Returns:
-        True if ALL target strings are found. Otherwise, will return False.
+    Needed because context.data_sources.add_sql is prohibitted when
+    more specific methods are available.
     """
+    with open("./connection_string.yml") as f:
+        db_config: dict = yaml_handler.load(f)
 
-    strings: Set[str] = set(target_strings)
-
-    def _find_string(data: Any) -> bool:
-        if isinstance(data, list):
-            for val in data:
-                if _find_string(val):
-                    return True
-        elif isinstance(data, dict):
-            for key, val in data.items():
-                if _find_string(key) or _find_string(val):
-                    return True
-        elif isinstance(data, str):
-            string_to_remove: Optional[str] = None
-            for string in strings:
-                if string in data:
-                    string_to_remove = string
-                    break
-            if string_to_remove:
-                strings.remove(string_to_remove)
-                if not strings:
-                    return True
-
-        return False
-
-    success: bool = _find_string(obj)
-    if not success:
-        logger.info(f"Could not find the following target strings: {strings}")
-
-    return success
+    dialect: str = db_config["dialect"]
+    if dialect == "snowflake":
+        return context.data_sources.add_snowflake(name=name, connection_string=connection_string)
+    elif dialect == "postgres":
+        return context.data_sources.add_postgres(name=name, connection_string=connection_string)
+    elif dialect == "redshift":
+        return context.data_sources.add_redshift(name=name, connection_string=connection_string)
+    elif dialect == "bigquery":
+        return context.data_sources.add_bigquery(name=name, connection_string=connection_string)
+    else:
+        return context.data_sources.add_sql(name=name, connection_string=connection_string)
 
 
 @contextmanager
@@ -1028,7 +973,7 @@ def working_directory(directory: PathStr):
     Reference:
     https://stackoverflow.com/questions/431684/equivalent-of-shell-cd-command-to-change-the-working-directory/431747#431747
     """
-    owd = os.getcwd()
+    owd = os.getcwd()  # noqa: PTH109 # FIXME CoP
     try:
         os.chdir(directory)
         yield directory
