@@ -24,7 +24,7 @@ def test_exception_info__eq__and__ne__(exception_info: ExceptionInfo) -> None:
 def test_exception_info__repr__(exception_info: ExceptionInfo) -> None:
     assert (
         exception_info.__repr__()
-        == "{'exception_traceback': 'my exception traceback', 'exception_message': 'my exception message', 'raised_exception': True}"
+        == "{'exception_traceback': 'my exception traceback', 'exception_message': 'my exception message', 'raised_exception': True}"  # noqa: E501 # FIXME CoP
     )
 
 
@@ -32,5 +32,5 @@ def test_exception_info__repr__(exception_info: ExceptionInfo) -> None:
 def test_exception_info__str__(exception_info: ExceptionInfo) -> None:
     assert (
         exception_info.__str__()
-        == '{\n  "exception_traceback": "my exception traceback",\n  "exception_message": "my exception message",\n  "raised_exception": true\n}'
+        == '{\n  "exception_traceback": "my exception traceback",\n  "exception_message": "my exception message",\n  "raised_exception": true\n}'  # noqa: E501 # FIXME CoP
     )
